@@ -38,20 +38,22 @@ void AboutDlgUnmap(about_dlg_struct *d);
 void AboutDlgDelete(about_dlg_struct *d);
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ABOUT_DLG_DEF_TITLE		"Untitled Program"
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define ABOUT_DLG_WIDTH			500
+#define ABOUT_DLG_HEIGHT		420
 
 
-#define ABOUT_DLG_WIDTH		500
-#define ABOUT_DLG_HEIGHT	420
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -115,31 +117,38 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	GdkColor color_fg, color_bg;
 	GdkWindow *window;
 	GtkStyle *style;
-	GtkWidget *w, *parent, *parent2, *parent3, *parent4, *main_vbox;
 	GtkAccelGroup *accelgrp;
+	GtkWidget	*w,
+			*parent, *parent2, *parent3, *parent4,
+			*toplevel, *main_vbox;
 	gpointer w_rtn1, w_rtn2;
 	GtkEntry *entry;
 	GtkRcStyle *rcstyle;
 	GtkCList *clist;
 	const cfg_item_struct *cfg_list;
-	about_dlg_struct *d = ABOUT_DLG(g_malloc0(
-	    sizeof(about_dlg_struct)
-	));
-	if((d == NULL) || (core == NULL))
+	about_dlg_struct *d;
+
+	if(core == NULL)
 	    return(NULL);
 
 	cfg_list = core->cfg_list;
 
+	d = ABOUT_DLG(g_malloc0(sizeof(about_dlg_struct)));
+	if(d == NULL)
+	    return(NULL);
+
+	d->toplevel = toplevel = gtk_window_new(GTK_WINDOW_DIALOG);
 	d->accelgrp = accelgrp = gtk_accel_group_new();
 	d->processing = FALSE;
-	d->busy_count = 0;
 	d->freeze_count = 0;
+	d->busy_count = 0;
 	d->core = core;
 
-	/* Begin creating widgets */
+	d->freeze_count++;
 
-	/* Toplevel */
-	d->toplevel = w = gtk_window_new(GTK_WINDOW_DIALOG);
+	/* Toplevel GtkWindow */
+	w = toplevel;
+	gtk_window_set_policy(GTK_WINDOW(w), TRUE, TRUE, TRUE);
 	gtk_widget_set_usize(w, ABOUT_DLG_WIDTH, ABOUT_DLG_HEIGHT);
 #ifdef PROG_NAME_FULL
 	gtk_window_set_title(
@@ -215,20 +224,20 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	parent = w;
 
 
-	/* Main vbox */
+	/* Main GtkVBox */
 	d->main_vbox = main_vbox = w = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(parent), w);
 	gtk_widget_show(w);
 	parent = w;
 
-	/* Vbox to hold notebook */
+	/* Notebook GtkVBox */
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
 	gtk_container_border_width(GTK_CONTAINER(w), border_major);
 	gtk_widget_show(w);
 	parent = w;
 
-	/* Notebook */
+	/* Main GtkNotebook */
 	d->notebook = w = gtk_notebook_new();
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(w), GTK_POS_TOP);
 	gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
@@ -246,9 +255,7 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	parent2 = w;
 
 
-	/* Credits Page ********************************************* */
-
-	/* Credits page vbox */
+	/* Credits page GtkVBox */
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_notebook_append_page(
 	    GTK_NOTEBOOK(parent2),
@@ -280,13 +287,13 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	parent3 = w;
 
 #if defined(EDV_DEF_ABOUT_IMAGE_FILE)
-	/* Hbox for about image */
+	/* About image GtkHBox */
 	w = gtk_hbox_new(TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
 
-	/* Frame for about image */
+	/* About image GtkFrame */
 	w = gtk_frame_new(NULL);
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	gtk_frame_set_shadow_type(GTK_FRAME(w), GTK_SHADOW_OUT);
@@ -296,14 +303,14 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	/* About image */
 	if(cfg_list != NULL)
 	{
-	    /* Get path to image */
+	    /* Get the path to the image */
 	    const gchar *data_dir = CFGItemListGetValueS(
 		cfg_list, EDV_CFG_PARM_DIR_GLOBAL
 	    );
 	    gchar *path = STRDUP(PrefixPaths(
 		data_dir, EDV_DEF_ABOUT_IMAGE_FILE
 	    ));
-	    if(!STRISEMPTY(path))
+	    if(path != NULL)
 	    {
 		/* Open image */
 		GdkBitmap *mask;
@@ -320,8 +327,8 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 		    gtk_container_add(GTK_CONTAINER(parent4), w);
 		    gtk_widget_show(w);
 
-		    GDK_PIXMAP_UNREF(pixmap)
-		    GDK_BITMAP_UNREF(mask)
+		    GDK_PIXMAP_UNREF(pixmap);
+		    GDK_BITMAP_UNREF(mask);
 		}
 	    }
 	    g_free(path);
@@ -359,7 +366,7 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 
-	/* Scrolled window for clist */
+	/* GtkScrolledWindow for the GtkCList */
 	w = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(
 	    GTK_SCROLLED_WINDOW(w),
@@ -368,9 +375,8 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	gtk_box_pack_start(GTK_BOX(parent3), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Credits clist */
-	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(PROG_GTK_FONT_NAME_TEXT_TERMINAL);
+
+	/* Credits GtkCList */
 	heading[0] = "";
 	d->credits_clist = w = gtk_clist_new_with_titles(1, heading);
 	clist = GTK_CLIST(w);
@@ -405,23 +411,30 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	gtk_clist_column_titles_hide(clist);
 	gtk_clist_set_shadow_type(clist, GTK_SHADOW_IN);
 /*	gtk_clist_set_selection_mode(clist, GTK_SELECTION_BROWSE); */
-	gtk_clist_set_column_width(clist, 0, 10);
+        gtk_clist_set_column_auto_resize(clist, 0, TRUE);
+        gtk_clist_set_column_resizeable(clist, 0, FALSE);
+        gtk_clist_set_column_justification(
+            clist, 0, GTK_JUSTIFY_LEFT
+        );
 	gtk_container_add(GTK_CONTAINER(parent4), w);
+
+	rcstyle = gtk_rc_style_new();
+	rcstyle->font_name = STRDUP(PROG_GTK_FONT_NAME_TEXT_TERMINAL);
 	gtk_widget_modify_style(w, rcstyle);
+	GTK_RC_STYLE_UNREF(rcstyle);
+
 	gtk_widget_show(w);
-	GTK_RC_STYLE_UNREF(rcstyle)
 
 #if defined(PROG_CREDITS_LINES)
 	/* Add credits to credits clist */
 	if(clist->columns > 0)
 	{
-	    gint i, row;
-	    gchar **strv = (gchar **)g_malloc(
-		clist->columns * sizeof(gchar *)
-	    );
+	    const gint ncolumns = MAX(clist->columns, 1);
+	    gchar **strv = (gchar **)g_malloc(ncolumns * sizeof(gchar *));
 	    const gchar *credits_lines[] = PROG_CREDITS_LINES;
+	    gint i, row;
 
-	    for(i = 0; i < clist->columns; i++)
+	    for(i = 0; i < ncolumns; i++)
 		strv[i] = "";
 
 	    gtk_clist_freeze(clist);
@@ -429,14 +442,10 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	    {
 		strv[0] = (gchar *)credits_lines[i];
 		row = gtk_clist_append(clist, strv);
-		if(row > -1)
-		{
-		    gtk_clist_set_selectable(clist, row, FALSE);
-		}
-		else
-		{
+		if(row < 0)
 		    break;
-		}
+
+		gtk_clist_set_selectable(clist, row, FALSE);
 	    }
 	    gtk_clist_thaw(clist);
 
@@ -445,9 +454,7 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 #endif
 
 
-	/* Copyright Page ***************************************** */
-
-	/* Copyright page vbox */   
+	/* Copyright page GtkVBox */   
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_notebook_append_page(    
 	    GTK_NOTEBOOK(parent2),
@@ -479,23 +486,26 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	parent3 = w;
 
 #if defined(PROG_COPYRIGHT)
-	/* Hbox for copyright label */
+	/* Copyright GtkHBox */
 	w = gtk_hbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Copyright label */
-	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(PROG_GTK_FONT_NAME_TEXT_HEADING6);
+
+	/* Copyright GtkLabel */
 	w = gtk_label_new(PROG_COPYRIGHT);
 	gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
+
+	rcstyle = gtk_rc_style_new();
+	rcstyle->font_name = STRDUP(PROG_GTK_FONT_NAME_TEXT_HEADING6);
 /*	gtk_widget_modify_style(w, rcstyle); */
+	GTK_RC_STYLE_UNREF(rcstyle);
+
 	gtk_widget_show(w);
-	GTK_RC_STYLE_UNREF(rcstyle)
 #endif
 
-	/* Scrolled window for clist */
+	/* GtkScrolledWindow for the GtkCList */
 	w = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(
 	    GTK_SCROLLED_WINDOW(w),
@@ -504,9 +514,8 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	gtk_box_pack_start(GTK_BOX(parent3), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* License clist */
-	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(PROG_GTK_FONT_NAME_TEXT_LICENSE);
+
+	/* License GtkCList */
 	heading[0] = "";
 	d->license_clist = w = gtk_clist_new_with_titles(1, heading);
 	clist = GTK_CLIST(w);
@@ -541,61 +550,69 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	gtk_clist_column_titles_hide(clist);
 	gtk_clist_set_shadow_type(clist, GTK_SHADOW_IN);
 /*	gtk_clist_set_selection_mode(clist, GTK_SELECTION_BROWSE); */
-	gtk_clist_set_column_width(clist, 0, 10);
+        gtk_clist_set_column_auto_resize(clist, 0, TRUE);
+        gtk_clist_set_column_resizeable(clist, 0, FALSE);
+        gtk_clist_set_column_justification(
+            clist, 0, GTK_JUSTIFY_LEFT
+        );
 	gtk_container_add(GTK_CONTAINER(parent4), w);
+
+	rcstyle = gtk_rc_style_new();
+	rcstyle->font_name = STRDUP(PROG_GTK_FONT_NAME_TEXT_LICENSE);
 	gtk_widget_modify_style(w, rcstyle);
+	GTK_RC_STYLE_UNREF(rcstyle);
+
 	gtk_widget_show(w);
-	GTK_RC_STYLE_UNREF(rcstyle)
 
 #if defined(EDV_DEF_LICENSE_FILE)
-	/* Read license file and load it to the clist */
-	if((clist->columns > 0) && (cfg_list != NULL))
+	/* Read the license file and load it to the GtkCList */
+	if(cfg_list != NULL)
 	{
-	    /* Get path to license file */
+	    /* Get the path to the license file */
 	    const gchar *data_dir = CFGItemListGetValueS(
 		cfg_list, EDV_CFG_PARM_DIR_GLOBAL
 	    );
 	    gchar *path = STRDUP(PrefixPaths(
 		data_dir, EDV_DEF_LICENSE_FILE
 	    ));
+	    const gint ncolumns = MAX(clist->columns, 1);
 
 	    /* Open the license file for reading */
-	    FILE *fp = FOpen(path, "rb");
+	    FILE *fp = (path != NULL) ?
+		fopen((const char *)path, "rb") : NULL;
 	    if(fp != NULL)
 	    {
 		gint i, row;
-		gchar **strv = (gchar **)g_malloc(
-		    clist->columns * sizeof(gchar *)
-		);
-		for(i = 0; i < clist->columns; i++)
+		gchar	*s,
+			**strv = (gchar **)g_malloc(ncolumns * sizeof(gchar *));
+
+		for(i = 0; i < ncolumns; i++)
 		    strv[i] = "";
 
-		/* Add lines from file to clist */
+		/* Add lines from the file to the GtkCList */
 		gtk_clist_freeze(clist);
 		while(TRUE)
 		{
-		    strv[0] = FGetStringLiteral(fp);
-		    if(strv[0] == NULL)
+		    s = FGetStringLiteral(fp);
+		    if(s == NULL)
 			break;
 
+		    strv[0] = s;
 		    row = gtk_clist_append(clist, strv);
-		    g_free(strv[0]);
 
-		    if(row > -1)
-		    {
-			gtk_clist_set_selectable(clist, row, FALSE);
-		    }
-		    else
-		    {
+		    g_free(s);
+
+		    if(row < 0)
 			break;
-		    }
+
+		    gtk_clist_set_selectable(clist, row, FALSE);
 		}
 		gtk_clist_thaw(clist);
 
 		g_free(strv);
 
 		/* Close the license file */
-		FClose(fp);
+		fclose(fp);
 	    }
 
 	    g_free(path);
@@ -603,9 +620,7 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 #endif
 
 
-	/* Version Page ********************************************** */
-
-	/* Version page vbox */
+	/* Version page GtkVBox */
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_notebook_append_page(
 	    GTK_NOTEBOOK(parent2),
@@ -637,24 +652,26 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	parent3 = w;
 
 
-	/* Main Program Information */
-	/* Frame */
+	/* Main Program Information GtkFrame */
 	w = gtk_frame_new(
-#ifdef PROG_NAME_FULL
+#if defined(PROG_NAME_FULL)
 	    PROG_NAME_FULL
+#elif defined(PROG_NAME)
+	    PROG_NAME
 #else
-	    "Untitled Program"
+	    ABOUT_DLG_DEF_TITLE
 #endif
 	);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Vbox in frame */
+
 	w = gtk_vbox_new(FALSE, border_minor);
 	gtk_container_add(GTK_CONTAINER(parent4), w);
 	gtk_container_border_width(GTK_CONTAINER(w), border_major);
 	gtk_widget_show(w);
 	parent4 = w;
+
 	/* Version prompt */
 	w = GUIPromptBar(
 	    NULL,
@@ -679,16 +696,17 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 #endif
 	    ":" , &w_rtn1, &w_rtn2
 	);
-	entry = (GtkEntry *)w_rtn2;
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
-	gtk_entry_set_editable(entry, FALSE);
-	gtk_widget_set_usize(GTK_WIDGET(entry), 200, -1);
 	gtk_widget_show(w);
+
+	w = (GtkWidget *)w_rtn2;
+	entry = GTK_ENTRY(w);
+	gtk_entry_set_editable(entry, FALSE);
 #if defined(PROG_VERSION)
 	gtk_entry_set_text(entry, PROG_VERSION);
 #endif
+
 	/* Language prompt */
-	/* Compiler prompt */
 	w = GUIPromptBar(
 	    NULL,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -712,11 +730,12 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 #endif
 	    ":", &w_rtn1, &w_rtn2
 	);
-	entry = (GtkEntry *)w_rtn2;
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
-	gtk_entry_set_editable(entry, FALSE);
-	gtk_widget_set_usize(GTK_WIDGET(entry), 200, -1);
 	gtk_widget_show(w);
+
+	w = (GtkWidget *)w_rtn2;
+	entry = GTK_ENTRY(w);
+	gtk_entry_set_editable(entry, FALSE);
 	gtk_entry_set_text(
 	    entry,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -764,11 +783,13 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 #endif
 	    ":", &w_rtn1, &w_rtn2
 	);
-	entry = (GtkEntry *)w_rtn2;
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
-	gtk_entry_set_editable(entry, FALSE);
-	gtk_widget_set_usize(GTK_WIDGET(entry), 200, -1);
 	gtk_widget_show(w);
+
+	w = (GtkWidget *)w_rtn2;
+	entry = GTK_ENTRY(w);
+	gtk_entry_set_editable(entry, FALSE);
+
 #if defined(COMPILE_DATE)
 	if(COMPILE_DATE > 0)
 	{
@@ -776,7 +797,7 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	    gchar *s = STRDUP(ctime(&t));
 	    if(s != NULL)
 	    {
-		gchar *s2 = strchr(s, '\n');
+		gchar *s2 = (gchar *)strchr((char *)s, '\n');
 		if(s2 != NULL)
 		    *s2 = '\0';
 		gtk_entry_set_text(entry, s);
@@ -784,6 +805,7 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	    }
 	}
 #endif
+
 	/* Compiler prompt */
 	w = GUIPromptBar(
 	    NULL,
@@ -808,14 +830,16 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 #endif
 	    ":", &w_rtn1, &w_rtn2
 	);
-	entry = (GtkEntry *)w_rtn2;
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
-	gtk_entry_set_editable(entry, FALSE);
-	gtk_widget_set_usize(GTK_WIDGET(entry), 200, -1);
 	gtk_widget_show(w);
+
+	w = (GtkWidget *)w_rtn2;
+	entry = GTK_ENTRY(w);
+	gtk_entry_set_editable(entry, FALSE);
 #if defined(COMPILE_COMPILER)
 	gtk_entry_set_text(entry, COMPILE_COMPILER);
 #endif
+
 	/* Location prompt */
 	w = GUIPromptBar(
 	    NULL,
@@ -840,28 +864,29 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 #endif
 	    ":" , &w_rtn1, &w_rtn2
 	);
-	entry = (GtkEntry *)w_rtn2;
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
-	gtk_entry_set_editable(entry, FALSE);
-	gtk_widget_set_usize(GTK_WIDGET(entry), 200, -1);
 	gtk_widget_show(w);
+
+	w = (GtkWidget *)w_rtn2;
+	entry = GTK_ENTRY(w);
+	gtk_entry_set_editable(entry, FALSE);
 #if defined(COMPILE_LOCATION)
 	gtk_entry_set_text(entry, COMPILE_LOCATION);
 #endif
 
 #ifdef IMLIB_VERSION
-	/* Imlib Information */
-	/* Frame */
+	/* Imlib Information GtkFrame */
 	w = gtk_frame_new("Imlib");
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Vbox in frame */
+
 	w = gtk_vbox_new(FALSE, border_minor);
 	gtk_container_add(GTK_CONTAINER(parent4), w);
 	gtk_container_border_width(GTK_CONTAINER(w), border_major);
 	gtk_widget_show(w);
 	parent4 = w;
+
 	/* Version prompt */
 	w = GUIPromptBar(
 	    NULL,
@@ -886,27 +911,27 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 #endif
 	    ":" , &w_rtn1, &w_rtn2
 	);
-	entry = (GtkEntry *)w_rtn2;
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
-	gtk_entry_set_editable(entry, FALSE);
-	gtk_widget_set_usize(GTK_WIDGET(entry), 200, -1);
 	gtk_widget_show(w);
 
+	w = (GtkWidget *)w_rtn2;
+	entry = GTK_ENTRY(w);
+	gtk_entry_set_editable(entry, FALSE);
 	gtk_entry_set_text(entry, IMLIB_VERSION);
 #endif
 
-	/* GTK+ Information */
-	/* Frame */
+	/* GTK+ Information GtkFrame */
 	w = gtk_frame_new("GTK+");
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Vbox in frame */
+
 	w = gtk_vbox_new(FALSE, border_minor);
 	gtk_container_add(GTK_CONTAINER(parent4), w);
 	gtk_container_border_width(GTK_CONTAINER(w), border_major);
 	gtk_widget_show(w);
 	parent4 = w;
+
 	/* Version prompt */
 	w = GUIPromptBar(
 	    NULL,
@@ -931,12 +956,13 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 #endif
 	    ":" , &w_rtn1, &w_rtn2
 	);
-	entry = (GtkEntry *)w_rtn2;
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
-	gtk_entry_set_editable(entry, FALSE);
-	gtk_widget_set_usize(GTK_WIDGET(entry), 200, -1);
 	gtk_widget_show(w);
 
+	w = (GtkWidget *)w_rtn2;
+	entry = GTK_ENTRY(w);
+	gtk_entry_set_editable(entry, FALSE);
+
 	if((gtk_major_version != 0) || (gtk_minor_version != 0) ||
 	   (gtk_micro_version != 0)
 	)
@@ -950,27 +976,26 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	}
 
 
-	/* End Of Pages ********************************************* */
+	parent = main_vbox;
 
-
-	/* Hbox to hold buttons homogeniously */
+	/* Buttons GtkHBox */
 	w = gtk_hbox_new(TRUE, 0);   
-	gtk_box_pack_start(
-	    GTK_BOX(main_vbox), w, FALSE, FALSE, border_major
-	);
+	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, border_major);
 	gtk_widget_show(w);
 	parent2 = w;
 
 	/* Ok button */
 	d->ok_btn = w = GUIButtonPixmapLabelH(
-	    (guint8 **)icon_ok_20x20_xpm, "OK", NULL
+	    (guint8 **)icon_ok_20x20_xpm,
+	    "OK",
+	    NULL
 	);
 	GTK_WIDGET_SET_FLAGS(w, GTK_CAN_DEFAULT);
 	gtk_widget_set_usize(
 	    w,
 	    GUI_BUTTON_HLABEL_WIDTH_DEF, GUI_BUTTON_HLABEL_HEIGHT_DEF
 	);
-	gtk_box_pack_start(GTK_BOX(parent2), w, TRUE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "clicked",
 	    GTK_SIGNAL_FUNC(AboutDlgOKCB), d
@@ -986,6 +1011,8 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
 	GUIButtonLabelUnderline(w, GDK_o);
 	gtk_widget_show(w);
 
+	d->freeze_count--;
+
 	return(d);
 }
 
@@ -994,8 +1021,10 @@ about_dlg_struct *AboutDlgNew(edv_core_struct *core)
  */
 gboolean AboutDlgIsMapped(about_dlg_struct *d)
 {
-	GtkWidget *w = (d != NULL) ? d->toplevel : NULL;
-	return((w != NULL) ? GTK_WIDGET_MAPPED(w) : FALSE);
+	if(d == NULL)
+	    return(FALSE);
+
+	return(GTK_WIDGET_MAPPED(d->toplevel));
 }
 
 /*
@@ -1003,19 +1032,17 @@ gboolean AboutDlgIsMapped(about_dlg_struct *d)
  */
 void AboutDlgMap(about_dlg_struct *d)
 {
-	GtkWidget *w = (d != NULL) ? d->toplevel : NULL;
-	if(w == NULL)
+	GtkWidget *w;
+
+	if(d == NULL)
 	    return;
   
-	gtk_widget_show_raise(w);
+	gtk_widget_show_raise(d->toplevel);
 
 	/* Grab focus on the OK button */
 	w = d->ok_btn;
-	if(w != NULL)
-	{
-	    gtk_widget_grab_focus(w);
-	    gtk_widget_grab_default(w);
-	}
+	gtk_widget_grab_focus(w);
+	gtk_widget_grab_default(w);
 }
 
 /*
@@ -1023,11 +1050,10 @@ void AboutDlgMap(about_dlg_struct *d)
  */
 void AboutDlgUnmap(about_dlg_struct *d)
 {
-	GtkWidget *w = (d != NULL) ? d->toplevel : NULL;
-	if(w == NULL)
+	if(d == NULL)
 	    return;
 
-	gtk_widget_hide(w);
+	gtk_widget_hide(d->toplevel);
 }
 
 /*
@@ -1038,13 +1064,14 @@ void AboutDlgDelete(about_dlg_struct *d)
 	if(d == NULL)
 	    return;
 
-	GTK_WIDGET_DESTROY(d->credits_clist)
-	GTK_WIDGET_DESTROY(d->license_clist)
-	GTK_WIDGET_DESTROY(d->notebook)
-	GTK_WIDGET_DESTROY(d->ok_btn)
-	GTK_WIDGET_DESTROY(d->main_vbox)
-	GTK_WIDGET_DESTROY(d->toplevel)
-	GTK_ACCEL_GROUP_UNREF(d->accelgrp)
+	AboutDlgUnmap(d);
+
+	d->freeze_count++;
+
+	gtk_widget_destroy(d->toplevel);
+	gtk_accel_group_unref(d->accelgrp);
+
+	d->freeze_count--;
 
 	g_free(d);
 }
