@@ -21,8 +21,8 @@ struct _about_dlg_struct {
 	GtkWidget	*toplevel;
 	GtkAccelGroup	*accelgrp;
 	gboolean	processing;
-	gint		busy_count,
-			freeze_count;
+	gint		freeze_count,
+			busy_count;
 	edv_core_struct *core;
 
 	GtkWidget	*main_vbox,
