@@ -33,6 +33,7 @@
 #include "images/icon_cancel_20x20.xpm"
 
 
+/* Callbacks */
 static gint EDVArchiveInfoDeleteEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
 );
@@ -48,10 +49,12 @@ static void EDVArchiveInfoSetCommentCB(GtkWidget *widget, gpointer data);
 static void EDVArchiveInfoOKCB(GtkWidget *widget, gpointer data);
 static void EDVArchiveInfoCancelCB(GtkWidget *widget, gpointer data);
 
+/* Insert Comment File */
 static void EDVArchiveInfoInsertCommentFile(
 	edv_archive_info_dlg_struct *d, const gchar *path
 );
 
+/* Archive Info Dialog */
 edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 	edv_core_struct *core,
 	const gchar *arch_path,
@@ -62,7 +65,7 @@ void EDVArchiveInfoSetHasChanges(
 	edv_archive_info_dlg_struct *d, const gboolean has_changes
 );
 void EDVArchiveInfoUpdateMenus(edv_archive_info_dlg_struct *d);
-void EDVArchiveInfoSetBusy(edv_archive_info_dlg_struct *d, const gboolean is_busy);
+void EDVArchiveInfoSetBusy(edv_archive_info_dlg_struct *d, const gboolean busy);
 gboolean EDVArchiveInfoIsMapped(edv_archive_info_dlg_struct *d);
 void EDVArchiveInfoMap(edv_archive_info_dlg_struct *d);
 void EDVArchiveInfoUnmap(edv_archive_info_dlg_struct *d);
@@ -700,21 +703,29 @@ edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 {
 	const gint	border_major = 5,
 			border_minor = 2;
-	gchar *s, *s2, *comment = NULL;
-	gint	total_objects = 0,
-		file_objects = 0,
-		directory_objects = 0,
-		link_objects = 0,
-		other_objects = 0;
-	gulong	files_size = 0l,
-		directories_size = 0l,
-		links_size = 0l,
-		others_size = 0l,
-		uncompressed_size = 0l;
+	gint		font_size,
+			total_objects = 0,
+			file_objects = 0,
+			directory_objects = 0,
+			link_objects = 0,
+			other_objects = 0;
+	gulong		files_size = 0l,
+			directories_size = 0l,
+			links_size = 0l,
+			others_size = 0l,
+			uncompressed_size = 0l;
+	const gchar *font_encoding;
+	gchar		*s, *s2,
+			*font_name_h1_bold,
+			*font_name_h2,
+			*font_name_fixed_width,
+			*comment = NULL;
+	GdkFont *font;
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GdkWindow *window;
 	GtkRcStyle *rcstyle;
+	GtkStyle *style;
 	GtkAccelGroup *accelgrp;
 	GtkWidget	*w,
 			*parent, *parent2, *parent3, *parent4, *parent5,
@@ -879,6 +890,7 @@ edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 	    );
 /*	    GUISetWMIcon(window, (guint8 **)archiver_48x48_xpm); */
 	}
+        style = gtk_widget_get_style(w);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "delete_event",
 	    GTK_SIGNAL_FUNC(EDVArchiveInfoDeleteEventCB), d
@@ -903,6 +915,36 @@ edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 	parent = w;
 
 
+        /* Get the base font size */
+        font = style->font;
+        font_size = GDK_FONT_GET_FONT_NAME_SIZE(font);
+        if(font_size < 3)
+            font_size = 3;
+
+        /* Format the font names */
+#if defined(PROG_LANGUAGE_POLISH)
+        font_encoding = "iso8859-2";
+#else
+        font_encoding = "iso8859-1";
+#endif
+
+        font_name_h1_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+            font_size + 2,
+            font_encoding
+        );
+        font_name_h2 = g_strdup_printf(
+"-adobe-helvetica-medium-r-normal-*-%i-*-*-*-*-*-%s",
+            font_size,
+            font_encoding
+        );
+        font_name_fixed_width = g_strdup_printf(
+"-adobe-courier-medium-r-normal-*-%i-*-*-*-*-*-%s",
+            font_size,
+            font_encoding
+        );
+
+
 	/* Information & Statistics GtkVBox */
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_container_border_width(GTK_CONTAINER(w), border_major);
@@ -946,13 +988,7 @@ edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 	g_free(s);
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = g_strdup(
-#if defined(PROG_LANGUAGE_POLISH)
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-2"
-#else
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
-#endif
-	);
+	rcstyle->font_name = STRDUP(font_name_h1_bold);
 	gtk_widget_modify_style(w, rcstyle);
 	GTK_RC_STYLE_UNREF(rcstyle);
 	gtk_widget_show(w);
@@ -965,13 +1001,7 @@ edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 	parent4 = w;
 	/* Label */
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = g_strdup(
-#if defined(PROG_LANGUAGE_POLISH)
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-2"
-#else
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-#endif
-	);
+	rcstyle->font_name = STRDUP(font_name_h2);
 	w = gtk_label_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Ubicacin"
@@ -1009,13 +1039,7 @@ edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 	g_free(s2);
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = g_strdup(
-#if defined(PROG_LANGUAGE_POLISH)
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-2"
-#else
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-#endif
-	);
+	rcstyle->font_name = STRDUP(font_name_h2);
 	gtk_widget_modify_style(w, rcstyle);
 	GTK_RC_STYLE_UNREF(rcstyle);
 	gtk_widget_show(w);
@@ -1098,13 +1122,7 @@ edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 }
 
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = g_strdup(
-#if defined(PROG_LANGUAGE_POLISH)
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-2"
-#else
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-#endif
-	);
+	rcstyle->font_name = STRDUP(font_name_h2);
 #if defined(PROG_LANGUAGE_SPANISH)
 	CREATE_LABEL(0, "Los Archivos:", file_objects, files_size);
 	CREATE_LABEL(1, "Las Guas:", directory_objects, directories_size);
@@ -1154,13 +1172,7 @@ edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 	GTK_RC_STYLE_UNREF(rcstyle);
 
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = g_strdup(
-#if defined(PROG_LANGUAGE_POLISH)
-"-adobe-helvetica-bold-r-normal-*-12-*-*-*-*-*-iso8859-2"
-#else
-"-adobe-helvetica-bold-r-normal-*-12-*-*-*-*-*-iso8859-1"
-#endif
-	);
+	rcstyle->font_name = STRDUP(font_name_h2);
 #if defined(PROG_LANGUAGE_SPANISH)
 	CREATE_LABEL(4, "El Suma:", total_objects, uncompressed_size);
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1341,13 +1353,7 @@ edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 	parent3 = w;
 	/* Comments GtkText */
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = g_strdup(
-#if defined(PROG_LANGUAGE_POLISH)
-"-adobe-courier-medium-r-normal-*-12-*-*-*-*-*-iso8859-2"
-#else
-"-adobe-courier-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-#endif
-	);
+	rcstyle->font_name = STRDUP(font_name_fixed_width);
 	d->comment_text = w = gtk_text_new(NULL, NULL);
 	editable = GTK_EDITABLE(w);
 	text = GTK_TEXT(w);
@@ -1580,6 +1586,12 @@ edv_archive_info_dlg_struct *EDVArchiveInfoNew(
 
 	EDVArchiveInfoUpdateMenus(d);
 
+
+	g_free(font_name_h1_bold);
+	g_free(font_name_h2);
+	g_free(font_name_fixed_width);
+
+
 	d->freeze_count--;
 
 	return(d);
@@ -1666,7 +1678,7 @@ void EDVArchiveInfoUpdateMenus(edv_archive_info_dlg_struct *d)
 /*
  *	Sets the Archive Info Dialog as busy or ready.
  */
-void EDVArchiveInfoSetBusy(edv_archive_info_dlg_struct *d, const gboolean is_busy)
+void EDVArchiveInfoSetBusy(edv_archive_info_dlg_struct *d, const gboolean busy)
 {
 	GdkCursor *cur;
 	GtkWidget *w;
@@ -1676,7 +1688,7 @@ void EDVArchiveInfoSetBusy(edv_archive_info_dlg_struct *d, const gboolean is_bus
 
 	w = d->toplevel;
 
-	if(is_busy)
+	if(busy)
 	{
 	    d->busy_count++;
 	    if(d->busy_count > 1)
