@@ -554,7 +554,10 @@ gboolean EDVArchAddOptsGetResponse(
 	/* Create the option widgets */
 	if(client_vbox != NULL)
 	{
-	    gint i;
+	    gint i, font_size;
+	    const gchar *font_encoding;
+	    gchar *font_name_h1_bold;
+	    GdkFont *font;
 	    GtkStateType state;
 	    GtkRcStyle *rcstyle;
 	    GtkAdjustment *adj;
@@ -562,12 +565,34 @@ gboolean EDVArchAddOptsGetResponse(
 	    pulist_struct *pulist;
 	    pulistbox_struct *pulistbox;
 
+	    /* Get the base font size */
+	    font = style->font;
+	    font_size = GDK_FONT_GET_FONT_NAME_SIZE(font);
+	    if(font_size < 3)
+	        font_size = 3;
+
+	    /* Format the font names */
+#if defined(PROG_LANGUAGE_POLISH)
+            font_encoding = "iso8859-2";
+#else
+            font_encoding = "iso8859-1";
+#endif
+
+            font_name_h1_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+                font_size + 2,
+                font_encoding
+            );
+
+	    /* OK button accel keys */
 	    w = DLG(d)->ok_btn;
 	    gtk_accel_group_add(
 		accelgrp, GDK_a, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE,
 		GTK_OBJECT(w), "clicked"
 	    );
 	    GUIButtonLabelUnderline(w, GDK_a);
+
+	    /* Cancel button accel keys */
 	    w = DLG(d)->cancel_btn;
 	    gtk_accel_group_add(
 		accelgrp, GDK_Escape, 0, GTK_ACCEL_VISIBLE,
@@ -628,19 +653,13 @@ gboolean EDVArchAddOptsGetResponse(
 		gtk_widget_show(w);
 
 		rcstyle = gtk_rc_style_new();
-		rcstyle->font_name = g_strdup(
-#if defined(PROG_LANGUAGE_POLISH)
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-2"
-#else
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
-#endif
-		);
+		rcstyle->font_name = STRDUP(font_name_h1_bold);
 		w = gtk_label_new(g_basename(arch_path));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_modify_style(w, rcstyle);
+		GTK_RC_STYLE_UNREF(rcstyle);
 		gtk_widget_show(w);
-		GTK_RC_STYLE_UNREF(rcstyle)
 
 		w = gtk_hbox_new(FALSE, border_major);
 		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
@@ -1008,7 +1027,7 @@ archive formats and therefore do not apply."
 	    );
 	    gtk_widget_show(w);
 
-
+	    g_free(font_name_h1_bold);
 	}
 
 	/* Map the dialog */
@@ -1194,16 +1213,42 @@ gboolean EDVArchExtractOptsGetResponse(
 	/* Create options widgets */
 	if(client_vbox != NULL)
 	{
+	    gint font_size;
+	    const gchar *font_encoding;
+	    gchar *font_name_h1_bold;
+	    GdkFont *font;
 	    GtkStateType state;
 	    GtkRcStyle *rcstyle;
 	    GtkWidget *w, *parent = client_vbox, *parent2, *parent3;
 
+	    /* Get the base font size */
+	    font = style->font;
+	    font_size = GDK_FONT_GET_FONT_NAME_SIZE(font);
+	    if(font_size < 3)
+	        font_size = 3;
+
+	    /* Format the font names */
+#if defined(PROG_LANGUAGE_POLISH)
+            font_encoding = "iso8859-2";
+#else
+            font_encoding = "iso8859-1";
+#endif
+
+            font_name_h1_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+                font_size + 2,
+                font_encoding
+            );
+
+	    /* OK button accel keys */
 	    w = DLG(d)->ok_btn;
 	    gtk_accel_group_add(
 		accelgrp, GDK_e, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE,
 		GTK_OBJECT(w), "clicked"
 	    );
 	    GUIButtonLabelUnderline(w, GDK_e);
+
+	    /* Cancel button accel keys */
 	    w = DLG(d)->cancel_btn;
 	    gtk_accel_group_add(
 		accelgrp, GDK_Escape, 0, GTK_ACCEL_VISIBLE,
@@ -1264,19 +1309,13 @@ gboolean EDVArchExtractOptsGetResponse(
 		gtk_widget_show(w);
 
 		rcstyle = gtk_rc_style_new();
-		rcstyle->font_name = g_strdup(
-#if defined(PROG_LANGUAGE_POLISH)
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-2"
-#else
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
-#endif
-		);
+		rcstyle->font_name = STRDUP(font_name_h1_bold);
 		w = gtk_label_new(g_basename(arch_path));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_modify_style(w, rcstyle);
+		GTK_RC_STYLE_UNREF(rcstyle);
 		gtk_widget_show(w);
-		GTK_RC_STYLE_UNREF(rcstyle)
 
 		w = gtk_hbox_new(FALSE, border_major);
 		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
@@ -1491,6 +1530,8 @@ archive formats and therefore do not apply."
 #endif
 	    );
 	    gtk_widget_show(w);
+
+	    g_free(font_name_h1_bold);
 	}
 
 	/* Map the dialog */
