@@ -50,6 +50,7 @@
 #include "images/icon_tool_bar_20x20.xpm"
 #include "images/icon_status_bar_20x20.xpm"
 #include "images/icon_wildcards_20x20.xpm"
+#include "images/icon_resize_column_20x20.xpm"
 #include "images/icon_options2_20x20.xpm"
 #include "images/icon_customize_20x20.xpm"
 #include "images/icon_insecure_20x20.xpm"
@@ -584,6 +585,10 @@ void EDVArchiverAccelkeysRegenerate(edv_archiver_struct *archiver)
 	    archiver->contents_list_filter_mi,
 	    EDV_ARCHIVER_OP_CONTENTS_LIST_FILTER
 	);
+	UPDATE_ACCELKEY(
+	    archiver->contents_list_auto_resize_columns_micheck,
+	    EDV_ARCHIVER_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS
+	);
 	UPDATE_ACCELKEY(
 	    archiver->mime_types_mi,
 	    EDV_ARCHIVER_OP_MIME_TYPES
@@ -664,18 +669,6 @@ void EDVArchiverAccelkeysRegenerate(edv_archiver_struct *archiver)
 	    archiver->contents_clist_delete_mi,
 	    EDV_ARCHIVER_OP_DELETE
 	);
-	UPDATE_ACCELKEY(
-	    archiver->contents_clist_comment_and_statistics_mi,
-	    EDV_ARCHIVER_OP_COMMENT_AND_STATISTICS
-	);
-	UPDATE_ACCELKEY(
-	    archiver->contents_clist_check_mi,
-	    EDV_ARCHIVER_OP_COMMENT_AND_STATISTICS
-	);
-	UPDATE_ACCELKEY(
-	    archiver->contents_clist_fix_mi,
-	    EDV_ARCHIVER_OP_COMMENT_AND_STATISTICS
-	);
 	UPDATE_ACCELKEY(
 	    archiver->contents_clist_properties_mi,
 	    EDV_ARCHIVER_OP_PROPERTIES
@@ -841,22 +834,6 @@ void EDVArchiverContentsMenuRegenerate(edv_archiver_struct *archiver)
 
 	DO_ADD_MENU_SEP
 
-	op = EDV_ARCHIVER_OP_COMMENT_AND_STATISTICS;
-	DO_ADD_MENU_ITEM_LABEL
-	archiver->contents_clist_comment_and_statistics_mi = w;
-
-	DO_ADD_MENU_SEP
-
-	op = EDV_ARCHIVER_OP_CHECK;
-	DO_ADD_MENU_ITEM_LABEL
-	archiver->contents_clist_check_mi = w;
-
-	op = EDV_ARCHIVER_OP_FIX;
-	DO_ADD_MENU_ITEM_LABEL
-	archiver->contents_clist_fix_mi = w;
-
-	DO_ADD_MENU_SEP
-
 	op = EDV_ARCHIVER_OP_PROPERTIES;
 	DO_ADD_MENU_ITEM_LABEL
 	archiver->contents_clist_properties_mi = w;
@@ -1567,7 +1544,7 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 #else
 	button_name = "Properties";
 	menu_name = "Properties...";
-	tooltip = "Modify the archive's properties";
+	tooltip = "View the selected object's properties";
 #endif
 	accel_key = GDK_Return;
 	accel_mods = GDK_CONTROL_MASK;
@@ -1899,6 +1876,18 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	accel_mods = 0;
 	DO_APPEND_OPID
 
+	op = EDV_ARCHIVER_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS;
+	tb_item_type = TOOLBAR_ITEM_TOGGLE_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_resize_column_20x20_xpm;
+	menu_icon_data = NULL;
+	button_name = "ReSzCol";
+	menu_name = "Auto Resize Columns";
+	tooltip = "Automatically resize the columns each time the list is updated";
+	accel_key = 0;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
 
 	op = EDV_ARCHIVER_OP_MIME_TYPES;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
@@ -2585,6 +2574,10 @@ static void EDVArchiverCreateMenuBar(
 
 	    DO_ADD_MENU_SEP
 
+	    op = EDV_ARCHIVER_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS;
+	    DO_ADD_MENU_ITEM_CHECK
+	    archiver->contents_list_auto_resize_columns_micheck = w;
+
 	    op = EDV_ARCHIVER_OP_CONTENTS_LIST_FILTER;
 	    DO_ADD_MENU_ITEM_LABEL
 	    archiver->contents_list_filter_mi = w;
@@ -3227,7 +3220,7 @@ edv_archiver_struct *EDVArchiverNew(edv_core_struct *core)
 	/* Create the Find Bar */
 	archiver->find_bar = EDVFindBarNew(
 	    core, parent2,
-	    EDV_FINDBAR_ROLE_ARCHIVE_OBJECT,
+	    EDV_LOCATION_TYPE_ARCHIVE,
 	    EDVArchiverFindBarLocationCB,
 	    EDVArchiverFindBarStartCB,
 	    EDVArchiverFindBarEndCB,
@@ -3493,8 +3486,8 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 	location = EDVArchiverCurrentLocation(archiver);
 
 
-        /* Update the find bar */
-        EDVFindBarUpdateMenus(archiver->find_bar);
+	/* Update the find bar */
+	EDVFindBarUpdateMenus(archiver->find_bar);
 
 
 
@@ -3524,9 +3517,7 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 	ToolBarItemSetSensitiveID(
 	    tb, EDV_ARCHIVER_OP_DELETE, sensitive
 	);
-
 	/* Properties */
-	sensitive = !STRISEMPTY(location);
 	GTK_WIDGET_SET_SENSITIVE(archiver->properties_mi, sensitive);
 	ToolBarItemSetSensitiveID(
 	    tb, EDV_ARCHIVER_OP_PROPERTIES, sensitive
@@ -3571,6 +3562,14 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 	    tb, EDV_ARCHIVER_OP_SHOW_STATUS_BAR, state
 	);
 
+	/* Auto Resize Columns */
+	w = archiver->contents_list_auto_resize_columns_micheck;
+	state = EDV_GET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS);
+	DO_SET_CHECK_STATE
+	ToolBarItemSetToggleID(
+	    tb, EDV_ARCHIVER_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS, state
+	);
+
 
 	/* Settings */
 	if(write_protect_changed)
@@ -3629,18 +3628,18 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 
 
 	/* Contents List popup menu */
-	sensitive = (selected_obj_row < 0) ?
-	    FALSE : TRUE;
+	sensitive = (selected_obj_row > -1) ? TRUE : FALSE;
+	GTK_WIDGET_SET_SENSITIVE(
+	    archiver->contents_clist_add_mi, TRUE
+	);
 	GTK_WIDGET_SET_SENSITIVE(
 	    archiver->contents_clist_extract_mi, sensitive
 	);
 	GTK_WIDGET_SET_SENSITIVE(
-	    archiver->contents_clist_delete_mi, sensitive
+	    archiver->contents_clist_extract_all_mi, TRUE
 	);
-
-	sensitive = !STRISEMPTY(location);
 	GTK_WIDGET_SET_SENSITIVE(
-	    archiver->contents_clist_comment_and_statistics_mi, sensitive
+	    archiver->contents_clist_delete_mi, sensitive
 	);
 	GTK_WIDGET_SET_SENSITIVE(
 	    archiver->contents_clist_properties_mi, sensitive
@@ -3725,8 +3724,8 @@ void EDVArchiverMap(edv_archiver_struct *archiver)
  */
 void EDVArchiverUnmap(edv_archiver_struct *archiver)
 {
-        if(archiver == NULL)
-            return;
+	if(archiver == NULL)
+	    return;
 
 	gtk_widget_hide(archiver->toplevel);
 }
