@@ -1,18 +1,13 @@
 #include <stdlib.h>
-#include <ctype.h>
 #include <string.h>
+#include <ctype.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "../include/string.h"
-#include "../include/disk.h"
-
 #include "guiutils.h"
-#include "cdialog.h"
 
-#include "edv_types.h"
 #include "cfg.h"
-#include "edv_obj.h"
+#include "edv_types.h"
 #include "edv_archive_obj.h"
 #include "edv_status_bar.h"
 #include "archiver.h"
@@ -21,7 +16,6 @@
 #include "archiver_dnd.h"
 #include "archiver_contents_list.h"
 #include "endeavour2.h"
-#include "edv_op.h"
 #include "edv_cb.h"
 #include "edv_utils.h"
 #include "edv_utils_gtk.h"
@@ -33,6 +27,15 @@
 /* GTK+ Signal Callbacks */
 void EDVArchiverContentsItemDestroyCB(gpointer data);
 
+static gint EDVArchiverCListColumnSortIndexCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
+static gint EDVArchiverCListColumnSortSizeCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
+static gint EDVArchiverCListColumnSortCompressedSizeCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
 static gint EDVArchiverCListColumnSortCompressionCB(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
 );
@@ -95,35 +98,43 @@ gint EDVArchiverMenuItemLeaveCB(
 
 /* Find Bar Callbacks */
 const gchar *EDVArchiverFindBarLocationCB(
-	edv_findbar_struct *fb, gpointer data
+	edv_find_bar_struct *fb,
+	gpointer data
+);
+void EDVArchiverFindBarStartCB(
+	edv_find_bar_struct *fb,
+	gpointer data
 );
-void EDVArchiverFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 void EDVArchiverFindBarEndCB(
-	edv_findbar_struct *fb, gint total_matches, gpointer data
+	edv_find_bar_struct *fb,
+	const gint nmatches,
+	gpointer data
 );
 void EDVArchiverFindBarMatchCB(
-	const gchar *path, const struct stat *lstat_buf,
-	const gchar *excerpt, gint line_index,
+	const gchar *path,
+	struct stat *lstat_buf,
+	const gchar *excerpt,
+	const gint line_index,
 	gpointer data
 );
 
 /* Status Bar Callbacks */
 void EDVArchiverStatusMessageCB(const gchar *message, gpointer data);
-void EDVArchiverStatusProgressCB(gfloat progress, gpointer data);
+void EDVArchiverStatusProgressCB(const gfloat progress, gpointer data);
 
 /* Write Protect Changed Callback */
 void EDVArchiverWriteProtectChangedCB(
-	edv_archiver_struct *archiver, gboolean state
+	edv_archiver_struct *archiver, const gboolean state
 );
 
 /* Object Callbacks */
 void EDVArchiverObjectAddedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVArchiverObjectModifiedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *path,
-	const gchar *new_path, const struct stat *lstat_buf
+	const gchar *new_path, struct stat *lstat_buf
 );
 void EDVArchiverObjectRemovedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *path
@@ -146,10 +157,13 @@ void EDVArchiverArchiveObjectRemovedNotifyCB(
 
 /* Recycled Object Callbacks */
 void EDVArchiverRecycledObjectAddedNotifyCB(
-	edv_archiver_struct *archiver, guint index
+	edv_archiver_struct *archiver, const guint index
+);
+void EDVArchiverRecycledObjectModifiedNotifyCB(
+	edv_archiver_struct *archiver, const guint index
 );
 void EDVArchiverRecycledObjectRemovedNotifyCB(
-	edv_archiver_struct *archiver, guint index
+	edv_archiver_struct *archiver, const guint index
 );
 
 /* Reconfigured Callback */
@@ -158,14 +172,15 @@ void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver);
 /* MIME Type Callbacks */
 void EDVArchiverMimeTypeAddedCB(
 	edv_archiver_struct *archiver,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 );
 void EDVArchiverMimeTypeModifiedCB(
 	edv_archiver_struct *archiver,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 );
 void EDVArchiverMimeTypeRemovedCB(
-	edv_archiver_struct *archiver, gint mt_num
+	edv_archiver_struct *archiver,
+	const gint mt_num
 );
 
 
@@ -182,7 +197,7 @@ void EDVArchiverMimeTypeRemovedCB(
 
 
 /*
- *	Archiver contents GtkCList item "destroy" signal callback.
+ *	Contents GtkCList item "destroy" signal callback.
  */
 void EDVArchiverContentsItemDestroyCB(gpointer data)
 {
@@ -191,75 +206,133 @@ void EDVArchiverContentsItemDestroyCB(gpointer data)
 
 
 /*
- *	Returns the sort code for the rows sorted by compression.
+ *	Contents GtkCList column sort index callback.
+ */
+static gint EDVArchiverCListColumnSortIndexCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+)
+{
+	edv_archive_object_struct	*obj1 = EDV_ARCHIVE_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+					*obj2 = EDV_ARCHIVE_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	if(obj1->index <= obj2->index)
+	    return(obj1->index < obj2->index);
+	else
+	    return(-1);
+}
+
+/*
+ *	Contents GtkCList column sort size callback.
+ */
+static gint EDVArchiverCListColumnSortSizeCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+)
+{
+	edv_archive_object_struct	*obj1 = EDV_ARCHIVE_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+					*obj2 = EDV_ARCHIVE_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	if(obj1->size <= obj2->size)
+	    return(obj1->size < obj2->size);
+	else
+	    return(-1);
+}
+
+/*
+ *	Contents GtkCList column sort compressed size callback.
+ */
+static gint EDVArchiverCListColumnSortCompressedSizeCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+)
+{
+	edv_archive_object_struct	*obj1 = EDV_ARCHIVE_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+					*obj2 = EDV_ARCHIVE_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	if(obj1->compressed_size <= obj2->compressed_size)
+	    return(obj1->compressed_size < obj2->compressed_size);
+	else
+	    return(-1);
+}
+
+/*
+ *	Contents GtkCList column sort compression ratio callback.
  */
 static gint EDVArchiverCListColumnSortCompressionCB(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
 )
 {
-	const GtkCListRow *row1 = (const GtkCListRow *)ptr1;
-	const GtkCListRow *row2 = (const GtkCListRow *)ptr2;
-	const edv_archive_object_struct *obj1, *obj2;
-
-	if((clist == NULL) || (row1 == NULL) || (row2 == NULL))
+	edv_archive_object_struct	*obj1 = EDV_ARCHIVE_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+					*obj2 = EDV_ARCHIVE_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((clist == NULL) || (obj1 == NULL) || (obj2 == NULL))
 	    return(0);
 
-	obj1 = EDV_ARCHIVE_OBJECT(row1->data);
-	obj2 = EDV_ARCHIVE_OBJECT(row2->data);
-	if((obj1 != NULL) && (obj2 != NULL))
-	{
-	    if(obj1->compression_ratio <= obj2->compression_ratio)
-		return((gint)(obj1->compression_ratio < obj2->compression_ratio));
-	    else
-		return(-1);
-	}
+	if(obj1->compression_ratio <= obj2->compression_ratio)
+	    return(obj1->compression_ratio < obj2->compression_ratio);
 	else
-	    return(0);
+	    return(-1);
 }
 
 /*
- *      Returns the sort code for the rows sorted by date.
+ *	Contents GtkCList column sort date nexus.
  *
- *      The recycled object structures are obtained from each row and the
- *      dates are compared.
+ *	The archive object structures are obtained from each row and
+ *	the dates are compared.
  */
 static gint EDVArchiverCListColumnSortDateNexus(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2,
 	gint sort_code
 )
 {
-	const GtkCListRow *row1 = (const GtkCListRow *)ptr1;
-	const GtkCListRow *row2 = (const GtkCListRow *)ptr2;
-	const edv_archive_object_struct *obj1, *obj2;
-
-	if((clist == NULL) || (row1 == NULL) || (row2 == NULL))
+	edv_archive_object_struct	*obj1 = EDV_ARCHIVE_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+					*obj2 = EDV_ARCHIVE_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((clist == NULL) || (obj1 == NULL) || (obj2 == NULL))
 	    return(0);
 
-	obj1 = EDV_ARCHIVE_OBJECT(row1->data);
-	obj2 = EDV_ARCHIVE_OBJECT(row2->data);
-	if((obj1 == NULL) || (obj2 == NULL))
-	    return(0);
-
-	/* Handle by sort code */
+	/* Handle by the sort code */
 	switch(sort_code)
 	{
 	  case 0:	/* Access time */
 	    if(obj1->access_time <= obj2->access_time)
-		return((gint)(obj1->access_time < obj2->access_time));
+		return(obj1->access_time < obj2->access_time);
 	    else
 		return(-1);
 	    break;
 
 	  case 1:	/* Modify time */
 	    if(obj1->modify_time <= obj2->modify_time)
-		return((gint)(obj1->modify_time < obj2->modify_time));
+		return(obj1->modify_time < obj2->modify_time);
 	    else
 		return(-1);
 	    break;
 
 	  case 2:	/* Change time */
 	    if(obj1->change_time <= obj2->change_time)
-		return((gint)(obj1->change_time < obj2->change_time));
+		return(obj1->change_time < obj2->change_time);
 	    else
 		return(-1);
 	    break;
@@ -297,7 +370,7 @@ static gint EDVArchiverCListColumnSortDateChangeCB(
 
 
 /*
- *	Archiver toplevel GtkWidget "delete_event" signal callback.
+ *	Toplevel GtkWidget "delete_event" signal callback.
  */
 gint EDVArchiverDeleteEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
@@ -316,7 +389,8 @@ gint EDVArchiverDeleteEventCB(
 }
 
 /*
- *	Archiver "key_press_event" or "key_release_event" signal callback.
+ *	Any GtkWidget "key_press_event" or "key_release_event" signal
+ *	callback.
  */
 gint EDVArchiverKeyEventCB(
 	 GtkWidget *widget, GdkEventKey *key, gpointer data
@@ -333,15 +407,12 @@ gint EDVArchiverKeyEventCB(
 	if((widget == NULL) || (key == NULL) || (archiver == NULL))
 	    return(status);
 
-	if(archiver->processing)
-	    return(status);
-
-	core = archiver->core;
-	if(core == NULL)
+	if(archiver->processing || (archiver->freeze_count > 0))
 	    return(status);
 
 	w = archiver->toplevel;
 	focus_widget = GTK_WINDOW(w)->focus_widget;
+	core = archiver->core;
 	cfg_list = core->cfg_list;
 
 	etype = key->type;
@@ -349,7 +420,6 @@ gint EDVArchiverKeyEventCB(
 	keyval = key->keyval;
 	state = key->state;
 
-/* Stop emit of signal */
 #define STOP_SIGNAL_EMISSION(_w_)	{	\
  gtk_signal_emit_stop_by_name(			\
   GTK_OBJECT(_w_),				\
@@ -385,9 +455,10 @@ gint EDVArchiverKeyEventCB(
 	    }
 	}
 
-	/* Check which widget this signal is for */
-
-	/* Contents List */
+	/* Check which widget this signal is for
+	 *
+	 * Contents GtkCList
+	 */
 	if(widget == archiver->contents_clist)
 	{
 	    GtkCList *clist = GTK_CLIST(widget);
@@ -470,12 +541,13 @@ gint EDVArchiverKeyEventCB(
 	    }
 	}
 
-	return(status);
 #undef STOP_SIGNAL_EMISSION
+
+	return(status);
 }
 
 /*
- *	Archiver GtkWidget "button_press_event" signal callback.
+ *	Any GtkWidget "button_press_event" signal callback.
  */
 gint EDVArchiverButtonPressEventCB(
 	GtkWidget *widget, GdkEventButton *button, gpointer data
@@ -488,17 +560,16 @@ gint EDVArchiverButtonPressEventCB(
 	if((widget == NULL) || (archiver == NULL))
 	    return(status);
 
-	if(archiver->processing)
+	if(archiver->processing || (archiver->freeze_count > 0))
 	    return(status);
 
 	core = archiver->core;
-	if(core == NULL)
-	    return(status);
-
-	/* Get event type */
 	etype = button->type;
 
-	/* Check which widget this signal is for */
+	/* Check which widget this signal is for
+	 *
+	 * Contents GtkCList
+	 */
 	if(widget == archiver->contents_clist)
 	{
 	    gint row, column;
@@ -506,7 +577,6 @@ gint EDVArchiverButtonPressEventCB(
 	    GList *glist;
 	    GtkCList *clist = GTK_CLIST(widget);
 
-
 	    /* Find row and column based on given coordinates */
 	    if(!gtk_clist_get_selection_info(
 		clist, button->x, button->y, &row, &column
@@ -516,7 +586,7 @@ gint EDVArchiverButtonPressEventCB(
 		column = 0;
 	    }
 
-	    /* Get number of selected rows and highest selected row */
+	    /* Get the number of selected rows and the last selected row */
 	    glist = clist->selection;
 	    while(glist != NULL)
 	    {
@@ -528,7 +598,7 @@ gint EDVArchiverButtonPressEventCB(
 	    /* Handle by button number */
 	    switch(button->button)
 	    {
-	      case 3:
+	      case GDK_BUTTON3:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 		    GtkMenu *menu;
@@ -565,7 +635,7 @@ gint EDVArchiverButtonPressEventCB(
 		status = TRUE;
 		break;
 
-	      case 2:
+	      case GDK_BUTTON2:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 		    if((row >= 0) && (row < clist->rows))
@@ -575,7 +645,7 @@ gint EDVArchiverButtonPressEventCB(
 		}
 		break;
 
-	      case 1:
+	      case GDK_BUTTON1:
 		/* Double click? */
 		if(etype == GDK_2BUTTON_PRESS)
 		{
@@ -588,9 +658,6 @@ gint EDVArchiverButtonPressEventCB(
 		}
 		break;
 	    }
-
-	    if(etype == GDK_BUTTON_PRESS)
-		gtk_widget_grab_focus(widget);
 	}
 
 	return(status);
@@ -598,7 +665,7 @@ gint EDVArchiverButtonPressEventCB(
 
 
 /*
- *      GtkHandleBox "child_attached" signal callback.
+ *	GtkHandleBox "child_attached" signal callback.
  */
 void EDVArchiverHandleChildAttachedCB(
 	GtkHandleBox *handle_box, GtkWidget *child, gpointer data
@@ -614,7 +681,7 @@ void EDVArchiverHandleChildAttachedCB(
 }
 
 /*
- *      GtkHandleBox "child_detached" signal callback.
+ *	GtkHandleBox "child_detached" signal callback.
  */
 void EDVArchiverHandleChildDetachedCB(
 	GtkHandleBox *handle_box, GtkWidget *child, gpointer data
@@ -631,26 +698,29 @@ void EDVArchiverHandleChildDetachedCB(
 
 
 /*
- *      Archiver GtkCList "resize_column" signal callback.
+ *	Contents GtkCList "resize_column" signal callback.
  */
 void EDVArchiverResizeColumnCB(
 	GtkCList *clist, gint column, gint width, gpointer data
 )
 {
+	GtkWidget *widget;
 	edv_core_struct *core;
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
 	if((clist == NULL) || (archiver == NULL))
 	    return;
 
-	if(archiver->processing)
+	if(archiver->processing || (archiver->freeze_count > 0))
 	    return;
 
+	widget = GTK_WIDGET(clist);
 	core = archiver->core;
-	if(core == NULL)
-	    return;
 
-	/* Check which clist this signal is for */
-	if(GTK_WIDGET(clist) == archiver->contents_clist)
+	/* Check which clist this signal is for
+	 *
+	 * Contents GtkCList
+	 */
+	if(widget == archiver->contents_clist)
 	{
 	    const gint m = EDV_ARCHIVER_CONTENTS_CLIST_COLUMNS_MAX;
 	    edv_archiver_column_type column_type = EDV_ARCHIVER_COLUMN_TYPE_NAME;
@@ -719,60 +789,69 @@ void EDVArchiverResizeColumnCB(
 }
 
 /*
- *      Archiver GtkCList "click_column" signal callback.
+ *	Contents GtkCList "click_column" signal callback.
  */
 void EDVArchiverClickColumnCB(
 	GtkCList *clist, gint column, gpointer data
 )
 {
+	GtkWidget *widget, *toplevel;
+	const cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
 	if((clist == NULL) || (archiver == NULL))
 	    return;
 
-	if(archiver->processing)
+	if(archiver->processing || (archiver->freeze_count > 0))
 	    return;
 
+	widget = GTK_WIDGET(clist);
+	toplevel = archiver->toplevel;
 	core = archiver->core;
-	if(core == NULL)
-	    return;
+	cfg_list = core->cfg_list;
 
-	/* Check which clist this signal is for */
-	if(GTK_WIDGET(clist) == archiver->contents_clist)
+	/* Check which clist this signal is for
+	 *
+	 * Contents GtkCList
+	 */
+	if(widget == archiver->contents_clist)
 	{
 	    cfg_intlist_struct *column_types_intlist;
 	    GtkCListCompareFunc cmp_func = NULL;
 	    GtkCListCompareFunc cmp_func_str =
 		 (GtkCListCompareFunc)EDVCListColumnSortStringCB;
+#if 0
 	    GtkCListCompareFunc cmp_func_num =
 		(GtkCListCompareFunc)EDVCListColumnSortNumberCB;
-
+#endif
 
 	    EDVArchiverSetBusy(archiver, TRUE);
-	    GUIBlockInput(archiver->toplevel, TRUE);
+	    GUIBlockInput(toplevel, TRUE);
 	    archiver->processing = TRUE;
 
-
-	    /* Get column types mapping */
-	    column_types_intlist = CFGItemListGetValueIntList(
-		core->cfg_list, EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN
+	    /* Get the column types mapping list */
+	    column_types_intlist = EDV_GET_INTLIST(
+		EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN
 	    );
 	    if(column_types_intlist != NULL)
 	    {
-		edv_archiver_column_type column_type = (edv_archiver_column_type)g_list_nth_data(
+		const edv_archiver_column_type column_type = (edv_archiver_column_type)g_list_nth_data(
 		    column_types_intlist->list,
 		    column
 		);
 		switch(column_type)
 		{
+		  case EDV_ARCHIVER_COLUMN_TYPE_INDEX:
+		    cmp_func = EDVArchiverCListColumnSortIndexCB;
+		    break;
 		  case EDV_ARCHIVER_COLUMN_TYPE_NAME:
 		    cmp_func = cmp_func_str;
 		    break;
 		  case EDV_ARCHIVER_COLUMN_TYPE_SIZE:
-		    cmp_func = cmp_func_num;
+		    cmp_func = EDVArchiverCListColumnSortSizeCB;
 		    break;
 		  case EDV_ARCHIVER_COLUMN_TYPE_COMPRESSED_SIZE:
-		    cmp_func = cmp_func_num;
+		    cmp_func = EDVArchiverCListColumnSortCompressedSizeCB;
 		    break;
 		  case EDV_ARCHIVER_COLUMN_TYPE_TYPE:
 		    cmp_func = cmp_func_str;
@@ -819,7 +898,10 @@ void EDVArchiverClickColumnCB(
 
 	    gtk_clist_freeze(clist);
 
-	    /* Set sort column settings on the clist */
+	    /* Set or invert the sort column on the GtkCList based
+	     * on if the clicked on column is already the current
+	     * sort column
+	     */
 	    if(column != clist->sort_column)
 		gtk_clist_set_sort_column(clist, column);
 	    else
@@ -831,13 +913,15 @@ void EDVArchiverClickColumnCB(
 	    if(cmp_func != NULL)
 		gtk_clist_set_compare_func(clist, cmp_func);
 
-	    /* Sort rows */
+	    /* Sort the rows, this will call the GtkCList column
+	     * sort callbacks
+	     */
 	    gtk_clist_sort(clist);
 
 	    gtk_clist_thaw(clist);
 
 	    archiver->processing = FALSE;
-	    GUIBlockInput(archiver->toplevel, FALSE);
+	    GUIBlockInput(toplevel, FALSE);
 	    EDVArchiverSetBusy(archiver, FALSE);
 
 	    EDVArchiverUpdateMenus(archiver);
@@ -845,22 +929,28 @@ void EDVArchiverClickColumnCB(
 }
 
 /*
- *      Archiver GtkCList "select_row" signal callback.
+ *	Archiver GtkCList "select_row" signal callback.
  */
 void EDVArchiverSelectRowCB(
 	GtkCList *clist, gint row, gint column, GdkEvent *event,
 	gpointer data
 )
 {
+	GtkWidget *widget;
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
 	if((clist == NULL) || (archiver == NULL))
 	    return;
 
-	if(archiver->processing)
+	if(archiver->processing || (archiver->freeze_count > 0))
 	    return;
 
-	/* Check which clist this signal is for */
-	if(GTK_WIDGET(clist) == archiver->contents_clist)
+	widget = GTK_WIDGET(clist);
+
+	/* Check which clist this signal is for
+	 *
+	 * Contents GtkCList
+	 */
+	if(widget == archiver->contents_clist)
 	{
 	    /* Get total number of objects selected */
 	    const gint nselected = g_list_length(clist->selection);
@@ -929,13 +1019,34 @@ void EDVArchiverSelectRowCB(
 			break;
 		    }
 
-		    /* Set status bar message */
+		    /* Set the status bar message */
 		    if(nselected > 1)
-			s = g_strdup_printf(
-			    "%s objects selected",
-			    EDVSizeStrDelim(nselected)
+		    {
+			gulong total_size = 0l;
+			edv_archive_object_struct *obj;
+			GList *glist = clist->selection;
+			while(glist != NULL)
+			{
+			    obj = EDV_ARCHIVE_OBJECT(gtk_clist_get_row_data(
+				clist, (gint)glist->data
+			    ));
+			    if(obj != NULL)
+				total_size += obj->size;
+			    glist = g_list_next(glist);
+			}
+			g_free(size_str);
+			size_str = g_strdup_printf(
+			    "%s %s",
+			    EDVSizeStrDelim(total_size),
+			    (total_size == 1l) ? "byte" : "bytes"
 			);
-		    else if(!strcmp(obj->name, ".."))
+			s = g_strdup_printf(
+			    "%s objects selected (totaling %s)",
+			    EDVSizeStrDelim(nselected),
+			    size_str
+			);
+		    }
+		    else if(!strcmp((const char *)obj->name, ".."))
 			s = g_strdup_printf(
 			    "Parent directory selected"
 			);
@@ -978,35 +1089,63 @@ void EDVArchiverSelectRowCB(
 }
 
 /*
- *      Archiver GtkCList "unselect_row" signal callback.
+ *	Archiver GtkCList "unselect_row" signal callback.
  */
 void EDVArchiverUnselectRowCB(
 	GtkCList *clist, gint row, gint column, GdkEvent *event,
 	gpointer data
 )
 {
+	GtkWidget *widget;
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
 	if((clist == NULL) || (archiver == NULL))
 	    return;
 
-	if(archiver->processing)
+	if(archiver->processing || (archiver->freeze_count > 0))
 	    return;
 
-	/* Check which clist this signal is for */
-	if(GTK_WIDGET(clist) == archiver->contents_clist)
+	widget = GTK_WIDGET(clist);
+
+	/* Check which clist this signal is for
+	 *
+	 * Contents GtkCList
+	 */
+	if(widget == archiver->contents_clist)
 	{
 	    gchar *s;
 
 	    /* Get total number of objects selected */
 	    const gint nselected = g_list_length(clist->selection);
 
-	    /* Update status bar message */
+	    /* Update the status bar message */
 	    if(nselected > 0)
-		s = g_strdup_printf(
-		    "%s %s selected",
-		    EDVSizeStrDelim(nselected),
-		    (nselected == 1) ? "object" : "objects"
+	    {
+		gchar *size_str;
+		gulong total_size = 0l;
+		edv_archive_object_struct *obj;
+		GList *glist = clist->selection;
+		while(glist != NULL)
+		{
+		    obj = EDV_ARCHIVE_OBJECT(gtk_clist_get_row_data(
+			clist, (gint)glist->data
+		    ));
+		    if(obj != NULL)
+			total_size += obj->size;
+		    glist = g_list_next(glist);
+		}
+		size_str = g_strdup_printf(
+		    "%s %s",
+		    EDVSizeStrDelim(total_size),
+		    (total_size == 1l) ? "byte" : "bytes"
 		);
+		s = g_strdup_printf(
+		    "%s %s selected (totaling %s)",
+		    EDVSizeStrDelim(nselected),
+		    (nselected == 1) ? "object" : "objects",
+		    size_str
+		);
+		g_free(size_str);
+	    }
 	    else
 		s = STRDUP("No objects selected");
 	    EDVStatusBarMessage(
@@ -1020,7 +1159,7 @@ void EDVArchiverUnselectRowCB(
 
 
 /*
- *      Location combo activate callback.
+ *	Location combo "activate" signal callback.
  */
 void EDVArchiverComboActivateCB(GtkWidget *widget, gpointer data)
 {
@@ -1028,12 +1167,13 @@ void EDVArchiverComboActivateCB(GtkWidget *widget, gpointer data)
 	if((widget == NULL) || (archiver == NULL))
 	    return;
 
-	if(archiver->processing)
+	if(archiver->processing || (archiver->freeze_count > 0))
 	    return;
 
-	/* Check which widget was activated */
-
-	/* Location combo */
+	/* Check which widget was activated
+	 *
+	 * Location GtkCombo
+	 */
 	if(widget == archiver->location_combo)
 	{
 	    GtkCombo *combo = GTK_COMBO(widget);
@@ -1052,7 +1192,7 @@ void EDVArchiverComboActivateCB(GtkWidget *widget, gpointer data)
 		g_free(path);
 	    }
 	}
-	/* Password entry */
+	/* Password GtkEntry */
 	else if(widget == archiver->location_password_entry)
 	{
 	    EDVArchiverOpenArchive(
@@ -1077,7 +1217,7 @@ void EDVArchiverMenuItemCB(GtkWidget *widget, gpointer data)
 /*
  *	Menu item "enter_notify_event" signal callback.
  *
- *      The data must be a edv_archiver_opid_struct *.
+ *	The data must be a edv_archiver_opid_struct *.
  */
 gint EDVArchiverMenuItemEnterCB(
 	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
@@ -1090,7 +1230,7 @@ gint EDVArchiverMenuItemEnterCB(
 /*
  *	Menu item "leave_notify_event" signal callback.
  *
- *      The given client data must be a edv_archiver_opid_struct *.
+ *	The data must be a edv_archiver_opid_struct *.
  */
 gint EDVArchiverMenuItemLeaveCB(
 	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
@@ -1104,26 +1244,28 @@ gint EDVArchiverMenuItemLeaveCB(
 /*
  *	Find Bar get current location callback.
  */
-const gchar *EDVArchiverFindBarLocationCB(edv_findbar_struct *fb, gpointer data)
+const gchar *EDVArchiverFindBarLocationCB(
+	edv_find_bar_struct *fb,
+	gpointer data
+)
 {
-	return(EDVArchiverCurrentLocation(
-	    EDV_ARCHIVER(data)
-	));
+	return(EDVArchiverCurrentLocation(EDV_ARCHIVER(data)));
 }
 
 /*
  *	Find Bar start find callback.
  */
-void EDVArchiverFindBarStartCB(edv_findbar_struct *fb, gpointer data)
+void EDVArchiverFindBarStartCB(
+	edv_find_bar_struct *fb,
+	gpointer data
+)
 {
 	GtkCList *clist;
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
 	if(archiver == NULL)
 	    return;
 
-	clist = (GtkCList *)archiver->contents_clist;
-	if(clist == NULL)
-	    return;
+	clist = GTK_CLIST(archiver->contents_clist);
 
 	EDVArchiverSetBusy(archiver, TRUE);
 
@@ -1138,7 +1280,9 @@ void EDVArchiverFindBarStartCB(edv_findbar_struct *fb, gpointer data)
  *	Find Bar end find callback.
  */
 void EDVArchiverFindBarEndCB(
-	edv_findbar_struct *fb, gint total_matches, gpointer data
+	edv_find_bar_struct *fb,
+	const gint nmatches,
+	gpointer data
 )
 {
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
@@ -1153,8 +1297,10 @@ void EDVArchiverFindBarEndCB(
  *	Find Bar match callback.
  */
 void EDVArchiverFindBarMatchCB(
-	const gchar *path, const struct stat *lstat_buf,
-	const gchar *excerpt, gint line_index,
+	const gchar *path,
+	struct stat *lstat_buf,
+	const gchar *excerpt,
+	const gint line_index,
 	gpointer data
 )
 {
@@ -1164,9 +1310,7 @@ void EDVArchiverFindBarMatchCB(
 	if((path == NULL) || (archiver == NULL))
 	    return;
 
-	clist = (GtkCList *)archiver->contents_clist;
-	if(clist == NULL)
-	    return;
+	clist = GTK_CLIST(archiver->contents_clist);
 
 	row = EDVArchiverContentsFindRowByPath(archiver, path);
 	if((row >= 0) && (row < clist->rows))
@@ -1189,7 +1333,7 @@ void EDVArchiverStatusMessageCB(const gchar *message, gpointer data)
 /*
  *	Status progress callback.
  */
-void EDVArchiverStatusProgressCB(gfloat progress, gpointer data)
+void EDVArchiverStatusProgressCB(const gfloat progress, gpointer data)
 {
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
 	if(archiver == NULL)
@@ -1199,12 +1343,10 @@ void EDVArchiverStatusProgressCB(gfloat progress, gpointer data)
 }
 
 /*
- *      Called whenever the global write protect has changed.
- *
- *      The new state is given as state.
+ *	Write protect changed callback.
  */
 void EDVArchiverWriteProtectChangedCB(
-	edv_archiver_struct *archiver, gboolean state
+	edv_archiver_struct *archiver, const gboolean state
 )
 {
 	if(archiver == NULL)
@@ -1218,11 +1360,11 @@ void EDVArchiverWriteProtectChangedCB(
 
 
 /*
- *	Object added notify callback.
+ *	Object added callback.
  */
 void EDVArchiverObjectAddedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	if((archiver == NULL) || STRISEMPTY(path))
@@ -1239,11 +1381,11 @@ void EDVArchiverObjectAddedNotifyCB(
 }
 
 /*
- *	Object modified notify callback.
+ *	Object modified callback.
  */
 void EDVArchiverObjectModifiedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *path,
-	const gchar *new_path, const struct stat *lstat_buf
+	const gchar *new_path, struct stat *lstat_buf
 )
 {
 	gchar *cur_arch_path;
@@ -1287,7 +1429,7 @@ void EDVArchiverObjectModifiedNotifyCB(
 }
 
 /*
- *      Called whenever a disk object has been removed.
+ *	Object removed callback.
  */
 void EDVArchiverObjectRemovedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *path
@@ -1320,7 +1462,7 @@ void EDVArchiverObjectRemovedNotifyCB(
 
 
 /*
- *	Object added to archive callback.
+ *	Archive object added callback.
  */
 void EDVArchiverArchiveObjectAddedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *arch_path,
@@ -1356,7 +1498,7 @@ void EDVArchiverArchiveObjectAddedNotifyCB(
 }
 
 /*
- *	Object modified in archive callback.
+ *	Archive object modified callback.
  */
 void EDVArchiverArchiveObjectModifiedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *arch_path,
@@ -1396,7 +1538,7 @@ void EDVArchiverArchiveObjectModifiedNotifyCB(
 }
 
 /*
- *	Object removed from archive callback.
+ *	Archive object removed callback.
  */
 void EDVArchiverArchiveObjectRemovedNotifyCB(
 	edv_archiver_struct *archiver, const gchar *arch_path,
@@ -1435,7 +1577,7 @@ void EDVArchiverArchiveObjectRemovedNotifyCB(
  *	Recycled object added callback.
  */
 void EDVArchiverRecycledObjectAddedNotifyCB(
-	edv_archiver_struct *archiver, guint index
+	edv_archiver_struct *archiver, const guint index
 )
 {
 	edv_core_struct *core;
@@ -1443,10 +1585,36 @@ void EDVArchiverRecycledObjectAddedNotifyCB(
 	if(archiver == NULL)
 	    return;
 
-	core = archiver->core;
-	if(core == NULL)
+	if(archiver->processing)
 	    return;
 
+	core = archiver->core;
+
+	/* There is not much interest when a recycled object has been
+	 * added or removed. Only the menus need to be updated if there
+	 * is a change in the number of recycled objects
+	 */
+	if(core->last_recbin_items != archiver->last_recbin_items)
+	    EDVArchiverUpdateMenus(archiver);
+}
+
+/*
+ *	Recycled object modified callback.
+ */
+void EDVArchiverRecycledObjectModifiedNotifyCB(
+	edv_archiver_struct *archiver, const guint index
+)
+{
+	edv_core_struct *core;
+
+	if(archiver == NULL)
+	    return;
+
+	if(archiver->processing)
+	    return;
+
+	core = archiver->core;
+
 	/* There is not much interest when a recycled object has been
 	 * added or removed. Only the menus need to be updated if there
 	 * is a change in the number of recycled objects
@@ -1459,7 +1627,7 @@ void EDVArchiverRecycledObjectAddedNotifyCB(
  *	Recycled object removed callback.
  */
 void EDVArchiverRecycledObjectRemovedNotifyCB(
-	edv_archiver_struct *archiver, guint index
+	edv_archiver_struct *archiver, const guint index
 )
 {
 	edv_core_struct *core;
@@ -1467,10 +1635,11 @@ void EDVArchiverRecycledObjectRemovedNotifyCB(
 	if(archiver == NULL)
 	    return;
 
-	core = archiver->core;
-	if(core == NULL)
+	if(archiver->processing)
 	    return;
 
+	core = archiver->core;
+
 	/* There is not much interest when a recycled object has been
 	 * added or removed. Only the menus need to be updated if there
 	 * is a change in the number of recycled objects
@@ -1499,9 +1668,6 @@ void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver)
 	    return;
 
 	core = archiver->core;
-	if(core == NULL)
-	    return;
-
 	cfg_list = core->cfg_list;
 	standard_rcstyle = core->standard_rcstyle;
 	lists_rcstyle = core->lists_rcstyle;
@@ -1597,10 +1763,10 @@ void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver)
 
 	EDVArchiverUpdateMenus(archiver);
 
-	/* Notify archiver's toplevel widget to resize */
-	w = archiver->toplevel;
-	if(w != NULL)
-	    gtk_widget_queue_resize(w);
+        /* Notify GTK about possible size changes (such as the tool
+         * bar resizing)
+         */
+        gtk_widget_queue_resize(archiver->toplevel);
 
 	g_free(cur_loc);
 }
@@ -1611,7 +1777,7 @@ void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver)
  */
 void EDVArchiverMimeTypeAddedCB(
 	edv_archiver_struct *archiver,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 )
 {
 	/* Treat a MIME Type added the same as it would be for a MIME
@@ -1626,7 +1792,7 @@ void EDVArchiverMimeTypeAddedCB(
  */
 void EDVArchiverMimeTypeModifiedCB(
 	edv_archiver_struct *archiver,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 )
 {
 	gchar *cur_loc;
@@ -1639,8 +1805,6 @@ void EDVArchiverMimeTypeModifiedCB(
 	    return;
 
 	core = archiver->core;
-	if(core == NULL)
-	    return;
 
 	/* Get the current location */
 	cur_loc = STRDUP(EDVArchiverCurrentLocation(archiver));
@@ -1657,7 +1821,8 @@ void EDVArchiverMimeTypeModifiedCB(
  *	MIME Type removed callback.
  */
 void EDVArchiverMimeTypeRemovedCB(
-	edv_archiver_struct *archiver, gint mt_num
+	edv_archiver_struct *archiver,
+	const gint mt_num
 )
 {
 	gchar *cur_loc;
@@ -1670,13 +1835,11 @@ void EDVArchiverMimeTypeRemovedCB(
 	    return;
 
 	core = archiver->core;
-	if(core == NULL)
-	    return;
 
 	/* Get the current location */
 	cur_loc = STRDUP(EDVArchiverCurrentLocation(archiver));
 
-	/* Realize listings */
+	/* Realize the listings */
 	EDVArchiverContentsRealizeListing(archiver);
 
 /*	EDVArchiverUpdateMenus(archiver); */
