@@ -48,11 +48,23 @@ static gint EDVArchiverContentsStatNextObjectReturnCB(
 	gpointer data
 );
 
+/* Columns */
 static void EDVArchiverContentsResetColumns(
 	edv_core_struct *core, edv_archiver_struct *archiver,
 	GtkCList *clist
 );
+void EDVArchiverContentsResizeColumnOptimul(
+	edv_archiver_struct *archiver,
+	const gint column_num
+);
+void EDVArchiverContentsResizeColumnsOptimul(edv_archiver_struct *archiver);
 
+/* Set Cells */
+static void EDVArchiverContentsSetCellIndex(
+	edv_core_struct *core, edv_archiver_struct *archiver,
+	GtkCList *clist, edv_archive_object_struct *obj,
+	const gint row, const gint column
+);
 static void EDVArchiverContentsSetCellName(
 	edv_core_struct *core, edv_archiver_struct *archiver,
 	GtkCList *clist, edv_archive_object_struct *obj,
@@ -63,16 +75,16 @@ static void EDVArchiverContentsSetCellSize(
 	GtkCList *clist, edv_archive_object_struct *obj,
 	const gint row, const gint column,
 	const gboolean hide_dir_size, const gboolean hide_link_size,
-        const edv_size_format size_format,
-        const gulong block_size
+	const edv_size_format size_format,
+	const gulong block_size
 );
 static void EDVArchiverContentsSetCellCompressedSize(
 	edv_core_struct *core, edv_archiver_struct *archiver,
 	GtkCList *clist, edv_archive_object_struct *obj,
 	const gint row, const gint column,
 	const gboolean hide_dir_size, const gboolean hide_link_size,
-        const edv_size_format size_format,
-        const gulong block_size
+	const edv_size_format size_format,
+	const gulong block_size
 );
 static void EDVArchiverContentsSetCellType(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -187,11 +199,11 @@ void EDVArchiverContentsClear(edv_archiver_struct *archiver);
 /* Object Callbacks */
 void EDVArchiverContentsObjectAddedNotify(
 	edv_archiver_struct *archiver, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVArchiverContentsObjectModifiedNotify(
 	edv_archiver_struct *archiver, const gchar *path,
-	const gchar *new_path, const struct stat *lstat_buf
+	const gchar *new_path, struct stat *lstat_buf
 );
 void EDVArchiverContentsObjectRemovedNotify(
 	edv_archiver_struct *archiver, const gchar *path
@@ -383,6 +395,10 @@ static void EDVArchiverContentsResetColumns(
 	     */
 	    switch(column_type)
 	    {
+	      case EDV_ARCHIVER_COLUMN_TYPE_INDEX:
+		title = "Index";
+		justify = GTK_JUSTIFY_RIGHT;
+		break;
 	      case EDV_ARCHIVER_COLUMN_TYPE_NAME:
 		title = "Name";
 		justify = GTK_JUSTIFY_LEFT;
@@ -472,8 +488,92 @@ static void EDVArchiverContentsResetColumns(
 
 
 /*
- *	Sets the archive object name for the specified cell on the given
- *	clist.
+ *      Resizes the column to optimul size.
+ */
+void EDVArchiverContentsResizeColumnOptimul(
+	edv_archiver_struct *archiver,
+	const gint column_num
+)
+{
+	gint ncolumns, width;
+	GtkCList *clist;
+
+	if(archiver == NULL)
+	    return;
+
+	clist = GTK_CLIST(archiver->contents_clist);
+	ncolumns = clist->columns;
+	if((column_num < 0) || (column_num >= ncolumns))
+	    return;
+
+	gtk_clist_freeze(clist);
+
+	width = gtk_clist_optimal_column_width(clist, column_num);
+	gtk_clist_set_column_width(clist, column_num, width);
+
+	gtk_clist_thaw(clist);
+}
+
+/*
+ *      Resizes all the columns to optimul sizes.
+ */
+void EDVArchiverContentsResizeColumnsOptimul(edv_archiver_struct *archiver)
+{
+	gint i, ncolumns;
+	GtkCList *clist;
+
+	if(archiver == NULL)
+	    return;
+
+	clist = GTK_CLIST(archiver->contents_clist);
+	ncolumns = clist->columns;
+
+	gtk_clist_freeze(clist);
+
+	for(i = 0; i < ncolumns; i++)
+	    EDVArchiverContentsResizeColumnOptimul(archiver, i);
+
+	gtk_clist_thaw(clist);
+}
+
+
+/*
+ *	Sets the cell's index value and attributes.
+ */
+static void EDVArchiverContentsSetCellIndex(
+	edv_core_struct *core, edv_archiver_struct *archiver,
+	GtkCList *clist, edv_archive_object_struct *obj,
+	const gint row, const gint column
+)
+{
+	const gint border_minor = 2;
+	const guint index = obj->index;
+	gchar num_str[40];
+
+	/* Format the index string */
+	if(index != 0)
+	    g_snprintf(
+		num_str, sizeof(num_str),
+		"#%u",
+		obj->index
+	    );
+	else
+	    *num_str = '\0';
+
+	/* Set the cell */
+	gtk_clist_freeze(clist);
+	gtk_clist_set_text(
+	    clist, row, column,
+	    num_str
+	);
+	gtk_clist_set_shift(
+	    clist, row, column, 0, -border_minor
+	);
+	gtk_clist_thaw(clist);
+}
+
+/*
+ *	Sets the cell's name value and attributes.
  */
 static void EDVArchiverContentsSetCellName(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -486,7 +586,7 @@ static void EDVArchiverContentsSetCellName(
 	GdkBitmap *mask, *mask_hid;
 
 	if(STRISEMPTY(name))
-	    name = obj->full_path;
+	    name = (obj->full_path != NULL) ? obj->full_path : "(null)";
 
 	/* Get pixmap and mask for the given object */
 	EDVMatchObjectIcon(
@@ -504,30 +604,28 @@ static void EDVArchiverContentsSetCellName(
 	);
 
 	/* Hidden? */
-	if((name != NULL) ?
-	    ((*name == '.') && (pixmap_hid != NULL)) : FALSE
-	)
+	if(EDVIsObjectNameHidden(name))
 	{
-	    if(g_strcasecmp(name, "..") && g_strcasecmp(name, "."))
+	    if(pixmap_hid != NULL)
 	    {
 		pixmap = pixmap_hid;
 		mask = mask_hid;
 	    }
 	}
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	if(pixmap != NULL)
 	    gtk_clist_set_pixtext(
 		clist, row, column,
-		(name != NULL) ? name : "(null)",
+		name,
 		EDV_LIST_PIXMAP_TEXT_SPACING,
 		pixmap, mask
 	    );
 	else
 	    gtk_clist_set_text(
 		clist, row, column,
-		(name != NULL) ? name : "(null)"
+		name
 	    );
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -537,16 +635,15 @@ static void EDVArchiverContentsSetCellName(
 }
 
 /*
- *	Sets the archive object size for the specified cell on the given
- *	clist.
+ *	Sets the cell's size value and attrbiutes.
  */
 static void EDVArchiverContentsSetCellSize(
 	edv_core_struct *core, edv_archiver_struct *archiver,
 	GtkCList *clist, edv_archive_object_struct *obj,
 	const gint row, const gint column,
 	const gboolean hide_dir_size, const gboolean hide_link_size,
-        const edv_size_format size_format,
-        const gulong block_size
+	const edv_size_format size_format,
+	const gulong block_size
 )
 {
 	const gint border_minor = 2;
@@ -567,10 +664,11 @@ static void EDVArchiverContentsSetCellSize(
 		obj->size, size_format, block_size, ',', TRUE
 	    );
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, (s != NULL) ? s : ""
+	    clist, row, column,
+	    (s != NULL) ? s : ""
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -580,16 +678,15 @@ static void EDVArchiverContentsSetCellSize(
 }
 
 /*
- *	Sets the archive object compressed size for the specified cell
- *	on the given clist.
+ *	Sets the cell's compressed size value and attributes.
  */
 static void EDVArchiverContentsSetCellCompressedSize(
 	edv_core_struct *core, edv_archiver_struct *archiver,
 	GtkCList *clist, edv_archive_object_struct *obj,
 	const gint row, const gint column,
 	const gboolean hide_dir_size, const gboolean hide_link_size,
-        const edv_size_format size_format,
-        const gulong block_size
+	const edv_size_format size_format,
+	const gulong block_size
 )
 {
 	const gint border_minor = 2;
@@ -610,10 +707,11 @@ static void EDVArchiverContentsSetCellCompressedSize(
 		obj->compressed_size, size_format, block_size, ',', TRUE
 	    );
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, (s != NULL) ? s : ""
+	    clist, row, column,
+	    (s != NULL) ? s : ""
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -623,8 +721,7 @@ static void EDVArchiverContentsSetCellCompressedSize(
 }
 
 /*
- *	Sets the archive object type for the specified cell on the given
- *	clist.
+ *	Sets the cell's MIME Type value and attributes.
  */
 static void EDVArchiverContentsSetCellType(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -643,10 +740,11 @@ static void EDVArchiverContentsSetCellType(
 	    &type_str
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, (type_str != NULL) ? type_str : ""
+	    clist, row, column,
+	    (type_str != NULL) ? type_str : ""
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -656,8 +754,7 @@ static void EDVArchiverContentsSetCellType(
 }
 
 /*
- *	Sets the archive object permissions for the specified cell on the given
- *	clist.
+ *	Sets the cell's permissions value and attributes.
  */
 static void EDVArchiverContentsSetCellPermissions(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -667,47 +764,31 @@ static void EDVArchiverContentsSetCellPermissions(
 )
 {
 	const edv_permission_flags permissions = obj->permissions;
-	gchar s[80];
+	gchar *s;
 
-	/* Format permissions string */
+	/* Format the permissions string */
 	if(hide_link_permissions && (obj->type == EDV_OBJECT_TYPE_LINK))
-	    *s = '\0';
+	    s = NULL;
 	else
-	    g_snprintf(
-		s, sizeof(s),
-		"%c%c%c%c%c%c%c%c%c",
-	    (permissions & EDV_PERMISSION_UREAD) ? 'r' : '-',
-	    (permissions & EDV_PERMISSION_UWRITE) ? 'w' : '-',
-	    (permissions & EDV_PERMISSION_SETUID) ?
-		'S' :
-		((permissions & EDV_PERMISSION_UEXECUTE) ? 'x' : '-'),
-	    (permissions & EDV_PERMISSION_GREAD) ? 'r' : '-',
-	    (permissions & EDV_PERMISSION_GWRITE) ? 'w' : '-',
-	    (permissions & EDV_PERMISSION_SETGID) ?
-		'G' :
-		((permissions & EDV_PERMISSION_GEXECUTE) ? 'x' : '-'),
-	    (permissions & EDV_PERMISSION_AREAD) ? 'r' : '-',
-	    (permissions & EDV_PERMISSION_AWRITE) ? 'w' : '-',
-	    (permissions & EDV_PERMISSION_STICKY) ?
-		'T' :
-		((permissions & EDV_PERMISSION_AEXECUTE) ? 'x' : '-')
-	    );
+	    s = EDVGetPermissionsString(permissions);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, s
+	    clist, row, column,
+	    (s != NULL) ? s : ""
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
 	gtk_clist_thaw(clist);
+
+	g_free(s);
 }
 
 /*
- *	Sets the archive object owner for the specified cell on the given
- *	clist.
+ *	Sets the cell's owner value and attrbiutes.
  */
 static void EDVArchiverContentsSetCellOwner(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -715,12 +796,12 @@ static void EDVArchiverContentsSetCellOwner(
 	const gint row, const gint column
 )
 {
-	/* Get owner name */
+	/* Get the owner name */
 	const gchar *owner_name = obj->owner_name;
 	if(owner_name == NULL)
 	    owner_name = "";
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, owner_name
@@ -732,8 +813,7 @@ static void EDVArchiverContentsSetCellOwner(
 }
 
 /*
- *	Sets the archive object owner for the specified cell on the given
- *	clist.
+ *	Sets the cell's group value and attrbiutes.
  */
 static void EDVArchiverContentsSetCellGroup(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -741,12 +821,12 @@ static void EDVArchiverContentsSetCellGroup(
 	const gint row, const gint column
 )
 {
-	/* Get group name */
+	/* Get the group name */
 	const gchar *group_name = obj->group_name;
 	if(group_name == NULL)
 	    group_name = "";
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, group_name
@@ -759,8 +839,7 @@ static void EDVArchiverContentsSetCellGroup(
 }
 
 /*
- *	Sets the archive object last access date for the specified cell
- *	on the given clist.
+ *	Sets the cell's access date value and attrbiutes.
  */
 static void EDVArchiverContentsSetCellDateAccess(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -770,21 +849,16 @@ static void EDVArchiverContentsSetCellDateAccess(
 	const gchar *date_format
 )
 {
-	const gchar *date_str;
+	/* Get/format the date string */
+	const gulong t = obj->access_time;
+	const gchar *date_str = (t > 0l) ?
+	    EDVDateFormatString(t, date_format, date_relativity) : "";
 
-	/* Get string for date accessed */
-	gulong t = obj->access_time;
-	if(t > 0)
-	    date_str = EDVDateFormatString(
-		t, date_format, date_relativity
-	    );
-	else
-	    date_str = "";
-
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, date_str
+	    clist, row, column,
+	    date_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -794,8 +868,7 @@ static void EDVArchiverContentsSetCellDateAccess(
 }
 
 /*
- *	Sets the archive object last modified date for the specified cell
- *	on the given clist.
+ *	Sets the cell's modified date value and attributes.
  */
 static void EDVArchiverContentsSetCellDateModified(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -805,21 +878,16 @@ static void EDVArchiverContentsSetCellDateModified(
 	const gchar *date_format
 )
 {
-	const gchar *date_str;
+	/* Get/format the date string */
+	const gulong t = obj->modify_time;
+	const gchar *date_str = (t > 0l) ?
+	    EDVDateFormatString(t, date_format, date_relativity) : "";
 
-	/* Get string for date modified */
-	gulong t = obj->modify_time;
-	if(t > 0)
-	    date_str = EDVDateFormatString(
-		t, date_format, date_relativity
-	    );
-	else
-	    date_str = "";
-
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, date_str
+	    clist, row, column,
+	    date_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -829,8 +897,7 @@ static void EDVArchiverContentsSetCellDateModified(
 }
 
 /*
- *	Sets the archive object last changed date for the specified cell
- *	on the given clist.
+ *	Sets the cell's changed date value and attributes.
  */
 static void EDVArchiverContentsSetCellDateChanged(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -840,21 +907,16 @@ static void EDVArchiverContentsSetCellDateChanged(
 	const gchar *date_format
 )
 {
-	const gchar *date_str;
+	/* Get/format the date string */
+	const gulong t = obj->change_time;
+	const gchar *date_str = (t > 0l) ?
+	    EDVDateFormatString(t, date_format, date_relativity) : "";
 
-	/* Get string for date changed */
-	gulong t = obj->change_time;
-	if(t > 0)
-	    date_str = EDVDateFormatString(
-		t, date_format, date_relativity
-	    );
-	else
-	    date_str = "";
-
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, date_str
+	    clist, row, column,
+	    date_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -864,8 +926,7 @@ static void EDVArchiverContentsSetCellDateChanged(
 }
 
 /*
- *	Sets the archive object location relative to the archive for the
- *	specified cell on the given clist.
+ *	Sets the cell's location in the archive value and attrbiutes.
  */
 static void EDVArchiverContentsSetCellLocation(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -874,29 +935,32 @@ static void EDVArchiverContentsSetCellLocation(
 )
 {
 	gchar *path, *location;
-	const gchar *full_path = obj->full_path;
+	const gchar *path_in_arch = obj->full_path;
 	GdkBitmap *mask = NULL;
 	GdkPixmap *pixmap = NULL;
 
-
-	/* Get copy of path that we want displayed */
-	if(STRISEMPTY(full_path))
+	/* Get the path in the archive with the appropriate prefix */
+	if(STRISEMPTY(path_in_arch))
 	    path = STRDUP("");
-	else if(g_path_is_absolute(full_path))
-	    path = STRDUP(full_path);
+	else if(g_path_is_absolute(path_in_arch))
+	    path = STRDUP(path_in_arch);
 	else
-	    path = g_strdup_printf(
-		".%c%s",
-		G_DIR_SEPARATOR, full_path
+	    path = g_strconcat(
+		".",
+		G_DIR_SEPARATOR_S,
+		path_in_arch,
+		NULL
 	    );
 
-	/* Get location */
+	/* Get the location */
 	location = g_dirname(path);
 	if(location == NULL)
 	    location = STRDUP("");
 
+	/* Get the icon */
 	if(!STRISEMPTY(location))
 	{
+	    /* Get the directory icon */
 	    edv_mime_type_struct *m = EDVMimeTypesListMatchType(
 		core->mimetype, core->total_mimetypes,
 		NULL,
@@ -910,7 +974,7 @@ static void EDVArchiverContentsSetCellLocation(
 	    }
 	}
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	if(pixmap != NULL)
 	    gtk_clist_set_pixtext(
@@ -921,7 +985,8 @@ static void EDVArchiverContentsSetCellLocation(
 	    );
 	else
 	    gtk_clist_set_text(
-		clist, row, column, location
+		clist, row, column,
+		location
 	    );
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -934,8 +999,7 @@ static void EDVArchiverContentsSetCellLocation(
 }
 
 /*
- *	Sets the archive object linked to path for the specified cell
- *	on the given clist.
+ *	Sets the cell's link target value and attrbiutes.
  */
 static void EDVArchiverContentsSetCellLinkedTo(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -947,10 +1011,11 @@ static void EDVArchiverContentsSetCellLinkedTo(
 	const gchar *target = (obj->link_target != NULL) ?
 	    obj->link_target : "";
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, target
+	    clist, row, column,
+	    target
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -960,8 +1025,7 @@ static void EDVArchiverContentsSetCellLinkedTo(
 }
 
 /*
- *	Sets the object device type for the specified cell on the given
- *	clist.
+ *	Sets the cell's device type value and attributes.
  */
 static void EDVArchiverContentsSetCellDeviceType(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -972,10 +1036,9 @@ static void EDVArchiverContentsSetCellDeviceType(
 	const gint border_minor = 2;
 	const edv_object_type type = obj->type;
 	gint major, minor;
-	gchar num_str[2 * 80];
+	gchar num_str[2 * 40];
 
-
-	/* Is object a block or character device? */
+	/* Is the object a block or character device? */
 	if((type == EDV_OBJECT_TYPE_DEVICE_BLOCK) ||
 	   (type == EDV_OBJECT_TYPE_DEVICE_CHARACTER)
 	)
@@ -994,10 +1057,11 @@ static void EDVArchiverContentsSetCellDeviceType(
 	    *num_str = '\0';
 	}
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, num_str
+	    clist, row, column,
+	    num_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -1007,8 +1071,7 @@ static void EDVArchiverContentsSetCellDeviceType(
 }
 
 /*
- *	Sets the object compression for the specified cell on the given
- *	clist.
+ *	Sets the cell's compression value and attributes.
  */
 static void EDVArchiverContentsSetCellCompression(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -1017,7 +1080,6 @@ static void EDVArchiverContentsSetCellCompression(
 	const gboolean hide_dir_size, const gboolean hide_link_size
 )
 {
-#if 1
 	GdkBitmap *mask = NULL;
 	GdkPixmap *pixmap;
 
@@ -1056,57 +1118,27 @@ static void EDVArchiverContentsSetCellCompression(
 		pixmap = NULL;
 	}
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	if(pixmap != NULL)
-	    gtk_clist_set_pixmap(clist, row, column, pixmap, mask);
+	    gtk_clist_set_pixmap(
+		clist, row, column,
+		pixmap, mask
+	    );
 	else
-	    gtk_clist_set_text(clist, row, column, "");
+	    gtk_clist_set_text(
+		clist, row, column,
+		""
+	    );
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_thaw(clist);
 
 	GDK_PIXMAP_UNREF(pixmap);
 	GDK_BITMAP_UNREF(mask);
-#else
-	const gint border_minor = 2;
-	gchar s[40];
-
-	/* Get compression ratio and compression type string */
-	if(hide_dir_size && (obj->type == EDV_OBJECT_TYPE_DIRECTORY))
-	{
-	    *s = '\0';
-	}
-	else if(hide_link_size && (obj->type == EDV_OBJECT_TYPE_LINK))
-	{
-	    *s = '\0';
-	}
-	else
-	{
-	    const gfloat ratio = obj->compression_ratio;
-	    if(ratio >= 0.0f)
-		g_snprintf(
-		    s, sizeof(s),
-		    "%.1f%%",
-		    ratio * 100.0f
-		);
-	    else
-		*s = '\0';
-	}
-
-	/* Set cell */
-	gtk_clist_freeze(clist);
-	gtk_clist_set_text(clist, row, column, s);
-	gtk_clist_set_cell_style(clist, row, column, NULL);
-	gtk_clist_set_shift(
-	    clist, row, column, 0, -border_minor
-	);
-	gtk_clist_thaw(clist);
-#endif
 }
 
 /*
- *	Sets the object method of storage for the specified cell on the
- *	given clist.
+ *	Sets the cell's compression method value and attributes.
  */
 static void EDVArchiverContentsSetCellMethod(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -1128,9 +1160,12 @@ static void EDVArchiverContentsSetCellMethod(
 	else
 	    method = STRDUP("");
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
-	gtk_clist_set_text(clist, row, column, method);
+	gtk_clist_set_text(
+	    clist, row, column,
+	    method
+	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
@@ -1141,8 +1176,7 @@ static void EDVArchiverContentsSetCellMethod(
 }
 
 /*
- *	Sets the object CRC checksum for the specified cell on the
- *	given clist.
+ *	Sets the cell's CRC checksum value and attributes.
  */
 static void EDVArchiverContentsSetCellCRC(
 	edv_core_struct *core, edv_archiver_struct *archiver,
@@ -1154,9 +1188,12 @@ static void EDVArchiverContentsSetCellCRC(
 	if(crc == NULL)
 	    crc = "";
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
-	gtk_clist_set_text(clist, row, column, crc);
+	gtk_clist_set_text(
+	    clist, row, column,
+	    crc
+	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
@@ -1224,6 +1261,12 @@ static void EDVArchiverContentsSetRow(
 	    column_type = (edv_archiver_column_type)glist->data;
 	    switch(column_type)
 	    {
+	      case EDV_ARCHIVER_COLUMN_TYPE_INDEX:
+		EDVArchiverContentsSetCellIndex(
+		    core, archiver, clist, obj,
+		    row, i
+		);
+		break;
 	      case EDV_ARCHIVER_COLUMN_TYPE_NAME:
 		EDVArchiverContentsSetCellName(
 		    core, archiver, clist, obj,
@@ -1497,6 +1540,7 @@ void EDVArchiverContentsRealizeListing(edv_archiver_struct *archiver)
 {
 	gint i, n;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 	edv_archive_object_struct *obj;
 
@@ -1505,6 +1549,7 @@ void EDVArchiverContentsRealizeListing(edv_archiver_struct *archiver)
 
 	clist = GTK_CLIST(archiver->contents_clist);
 	core = archiver->core;
+	cfg_list = core->cfg_list;
 
 	gtk_clist_freeze(clist);
 
@@ -1527,6 +1572,10 @@ void EDVArchiverContentsRealizeListing(edv_archiver_struct *archiver)
 	    );
 	}
 
+	/* Resize the columns */
+	if(EDV_GET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+	    EDVArchiverContentsResizeColumnsOptimul(archiver);
+
 	gtk_clist_thaw(clist);
 }
 
@@ -1562,6 +1611,7 @@ void EDVArchiverContentsGetListing(
 {
 	gchar *cur_path, *filter, *password;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 
 	if(archiver == NULL)
@@ -1569,6 +1619,7 @@ void EDVArchiverContentsGetListing(
 
 	clist = GTK_CLIST(archiver->contents_clist);
 	core = archiver->core;
+	cfg_list = core->cfg_list;
 
 	/* Clear all the error messages on the core */
 	EDVClearErrorMessages(core);
@@ -1615,6 +1666,10 @@ void EDVArchiverContentsGetListing(
 	    update_status_bar
 	);
 
+	/* Resize the columns */
+	if(EDV_GET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+	    EDVArchiverContentsResizeColumnsOptimul(archiver);
+
 	gtk_clist_thaw(clist);
 
 	/* Report the final progress? */
@@ -1657,7 +1712,7 @@ void EDVArchiverContentsClear(edv_archiver_struct *archiver)
  */
 void EDVArchiverContentsObjectAddedNotify(
 	edv_archiver_struct *archiver, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	gchar *cur_arch_path;
@@ -1692,12 +1747,11 @@ void EDVArchiverContentsObjectAddedNotify(
  */
 void EDVArchiverContentsObjectModifiedNotify(
 	edv_archiver_struct *archiver, const gchar *path,
-	const gchar *new_path, const struct stat *lstat_buf
+	const gchar *new_path, struct stat *lstat_buf
 )
 {
 	gchar *cur_arch_path;
-	GtkCList *clist;
-	const cfg_item_struct *cfg_list;
+	cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 
 	if((archiver == NULL) || STRISEMPTY(path) || (lstat_buf == NULL))
@@ -1710,7 +1764,6 @@ void EDVArchiverContentsObjectModifiedNotify(
 	if(cur_arch_path == NULL)
 	    return;
 
-	clist = GTK_CLIST(archiver->contents_clist);
 	core = archiver->core;
 	cfg_list = core->cfg_list;
 
@@ -1775,6 +1828,7 @@ void EDVArchiverContentsArchiveObjectAddedNotify(
 	gint row;
 	gchar *cur_arch_path;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 
 	if((archiver == NULL) || STRISEMPTY(arch_path) ||
@@ -1788,6 +1842,7 @@ void EDVArchiverContentsArchiveObjectAddedNotify(
 
 	clist = GTK_CLIST(archiver->contents_clist);
 	core = archiver->core;
+	cfg_list = core->cfg_list;
 
 	/* Not our archive? */
 	if(strcmp((const char *)arch_path, (const char *)cur_arch_path))
@@ -1815,6 +1870,11 @@ void EDVArchiverContentsArchiveObjectAddedNotify(
 		obj,
 		row
 	    );
+
+	    /* Resize the columns */
+	    if(EDV_GET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		EDVArchiverContentsResizeColumnsOptimul(archiver);
+
 	    gtk_clist_thaw(clist);
 	}
 	else
@@ -1822,10 +1882,16 @@ void EDVArchiverContentsArchiveObjectAddedNotify(
 	    /* Append this object to the list */
 	    edv_archive_object_struct *new_obj = EDVArchObjectCopy(obj);
 	    if(new_obj != NULL)
+	    {
 		EDVArchiverContentsAppendObject(
 		    core, archiver, clist,
 		    new_obj
 		);
+
+		/* Resize the columns */
+		if(EDV_GET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		    EDVArchiverContentsResizeColumnsOptimul(archiver);
+	    }
 	}
 
 	g_free(cur_arch_path);
@@ -1854,6 +1920,7 @@ void EDVArchiverContentsArchiveObjectModifiedNotify(
 	gint row;
 	gchar *cur_arch_path;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 
 	if((archiver == NULL) || STRISEMPTY(arch_path) ||
@@ -1870,6 +1937,7 @@ void EDVArchiverContentsArchiveObjectModifiedNotify(
 
 	clist = GTK_CLIST(archiver->contents_clist);
 	core = archiver->core;
+	cfg_list = core->cfg_list;
 
 	/* Not our archive? */
 	if(strcmp((const char *)arch_path, (const char *)cur_arch_path))
@@ -1897,6 +1965,11 @@ void EDVArchiverContentsArchiveObjectModifiedNotify(
 		obj,
 		row
 	    );
+
+	    /* Resize the columns */
+	    if(EDV_GET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		EDVArchiverContentsResizeColumnsOptimul(archiver);
+
 	    gtk_clist_thaw(clist);
 	}
 
@@ -1919,6 +1992,7 @@ void EDVArchiverContentsArchiveObjectRemovedNotify(
 	gint row;
 	gchar *cur_arch_path;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 
 	if((archiver == NULL) || STRISEMPTY(arch_path) ||
@@ -1932,6 +2006,7 @@ void EDVArchiverContentsArchiveObjectRemovedNotify(
 
 	clist = GTK_CLIST(archiver->contents_clist);
 	core = archiver->core;
+	cfg_list = core->cfg_list;
 
 	/* Not our archive? */
 	if(strcmp((const char *)arch_path, (const char *)cur_arch_path))
@@ -1952,6 +2027,10 @@ void EDVArchiverContentsArchiveObjectRemovedNotify(
 		row = EDVArchiverContentsFindRowByPath(archiver, path);
 	    } while(row > -1);
 	    gtk_clist_thaw(clist);
+
+	    /* Resize the columns */
+	    if(EDV_GET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		EDVArchiverContentsResizeColumnsOptimul(archiver);
 	}
 
 	g_free(cur_arch_path);
