@@ -244,10 +244,13 @@ static void EDVArchiverDragDataReceivedNexus(
 	);
 	const gint nurls = g_list_length(url_list);
 
-#define DO_FREE_LOCALS  {				\
- g_list_foreach(url_list, (GFunc)URLDelete, NULL);	\
- g_list_free(url_list);					\
- url_list = NULL;					\
+#define CLEANUP_RETURN		{			\
+ if(url_list != NULL) {					\
+  g_list_foreach(url_list, (GFunc)URLDelete, NULL);	\
+  g_list_free(url_list);				\
+ }							\
+							\
+ return;						\
 }
 
 	/* Check if there is exactly one URL and if it is an archive,
@@ -267,7 +270,7 @@ static void EDVArchiverDragDataReceivedNexus(
 		     * it instead of adding it to the current archive
 		     */
 		    gint status;
-		    gchar *buf = g_strdup_printf(
+		    gchar *msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El archivo abierto \"%s\" en vez de agregarlo al\n\
 archivo actual?\n"
@@ -320,14 +323,14 @@ current archive?\n"
 #else
 "Open Archive?"
 #endif
-			, buf, NULL,
+			, msg, NULL,
 			CDIALOG_ICON_QUESTION,
 			CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO,
 			CDIALOG_BTNFLAG_YES
 		    );
 		    CDialogSetTransientFor(NULL);
 
-		    g_free(buf);
+		    g_free(msg);
 
 		    if(status == CDIALOG_RESPONSE_YES)
 		    {
@@ -336,8 +339,7 @@ current archive?\n"
 			    archiver, url->path,
 			    EDVArchiverCurrentPassword(archiver)
 			);
-			DO_FREE_LOCALS
-			return;
+			CLEANUP_RETURN;
 		    }
 		}
 	    }
@@ -350,8 +352,7 @@ current archive?\n"
 	 */
 	if(EDVCheckWriteProtect(core, TRUE, toplevel))
 	{
-	    DO_FREE_LOCALS
-	    return;
+	    CLEANUP_RETURN;
 	}
 
 	/* Make initial user confirmation querying to proceed with this
@@ -370,17 +371,18 @@ current archive?\n"
 	   )
 	)
 	{
-	    gint status = -1;
 	    gboolean	yes_to_all = FALSE,
 			recurse = TRUE,
 			dereference_links = FALSE,
 			archive_existed = FALSE;
-	    gint	compression = 50;	/* 0 to 100 */
-	    gint	objects_added = 0;
-	    const gchar	*arch_obj, *error_msg;
+	    gint	status = -1,
+			compression = 50,	/* 0 to 100 */
+			objects_added = 0;
+	    gchar	*password = NULL;
+	    const gchar	*arch_path, *error_msg;
 
-	    /* Get current archive path */
-	    arch_obj = EDVArchiverCurrentLocation(archiver);
+	    /* Get the current archive path */
+	    arch_path = EDVArchiverCurrentLocation(archiver);
 
 	    if(archiver != NULL)
 	    {
@@ -389,8 +391,11 @@ current archive?\n"
 	    }
 
 	    /* Get add to archive options */
+	    password = STRDUP(EDVArchiverCurrentPassword(archiver));
 	    if(!EDVArchAddOptsGetResponse(
-		core, toplevel, arch_obj,
+		core, toplevel,
+		arch_path,
+		&password,
 		&recurse, &compression, &dereference_links
 	    ))
 	    {
@@ -400,27 +405,28 @@ current archive?\n"
 		    archiver->processing = FALSE;
 		    EDVArchiverSetBusy(archiver, FALSE);
 		}
-		DO_FREE_LOCALS
-		return;
+		g_free(password);
+		CLEANUP_RETURN;
 	    }
 
-	    /* Record if the archive exists */
-	    if(!STRISEMPTY(arch_obj))
+	    /* Record the archive's original statistics and if it exists */
+	    if(arch_path != NULL)
 	    {
 		struct stat stat_buf;
-		if(!stat(arch_obj, &stat_buf))
+		if(!stat((const char *)arch_path, &stat_buf))
 		    archive_existed = TRUE;
 	    }
 
 	    if(nurls > 0)
 	    {
-		/* Create list of object paths to be added to the
+		GList	*glist,
+			*tar_paths_list,
+			*new_paths_list;
+
+		/* Create a list of object paths to be added to the
 		 * archive from the URL list
 		 */
-		GList	*glist,
-			*tar_paths_list = NULL,
-			*new_paths_list = NULL;
-
+		tar_paths_list = NULL;
 		for(glist = url_list;
 		    glist != NULL;
 		    glist = g_list_next(glist)
@@ -436,19 +442,21 @@ current archive?\n"
 		    );
 		}
 
-		error_msg = NULL;
+		/* Add the objects to the archive */
 		status = -1;
+		error_msg = NULL;
+		new_paths_list = NULL;
 		switch((gint)dc->action)
 		{
 		  case GDK_ACTION_COPY:
 		    /* Add object(s) to the archive */
 		    status = EDVArchAdd(
-			core, arch_obj,
+			core, arch_path,
 			tar_paths_list,		/* List of objects to add to
 						 * the archive */
 			&new_paths_list,	/* Return list of objects
 						 * added to the archive */
-			EDVArchiverCurrentPassword(archiver),
+			password,
 			toplevel, TRUE, TRUE, &yes_to_all,
 			recurse, compression, dereference_links
 		    );
@@ -465,54 +473,54 @@ current archive?\n"
 		}
 
 		/* Delete the list of objects to be added to the archive */
-		g_list_foreach(tar_paths_list, (GFunc)g_free, NULL);
-		g_list_free(tar_paths_list);
-		tar_paths_list = NULL;
+		if(tar_paths_list != NULL)
+		{
+		    g_list_foreach(tar_paths_list, (GFunc)g_free, NULL);
+		    g_list_free(tar_paths_list);
+		}
 
-		/* Get error message (if any) that might have occured
-		 * in the above operation
-		 */
+		/* Check for errors */
 		if(error_msg == NULL)
-		    error_msg = EDVArchAddGetError();
+		    error_msg = EDVArchAddGetError(core);
 		if(!STRISEMPTY(error_msg))
 		{
+		    /* Report the error */
 		    EDVPlaySoundError(core);
-		    EDVMessageObjectOPError(
+		    EDVMessageError(
 			"Add Object Error",
 			error_msg,
-			arch_obj,
+			NULL,
 			toplevel
 		    );
 		}
 
-		/* Count objects added to the archive */
 		if(new_paths_list != NULL)
+		{
+		    /* Count objects added to the archive */
 		    objects_added += g_list_length(new_paths_list);
 
-		/* Delete the list of objects added to the archive */
-		g_list_foreach(new_paths_list, (GFunc)g_free, NULL);
-		g_list_free(new_paths_list);
-		new_paths_list = NULL;
+		    /* Delete the list of objects added to the archive */
+		    g_list_foreach(new_paths_list, (GFunc)g_free, NULL);
+		    g_list_free(new_paths_list);
+		}
 	    }
 
-	    /* Emit object modified signal to signal that objects
-	     * have been added to the archive
-	     */
-	    if(!STRISEMPTY(arch_obj))
+	    /* Notify about objects being added to this archive */
+	    if(arch_path != NULL)
 	    {
 		struct stat lstat_buf;
-		if(!lstat(arch_obj, &lstat_buf))
+		if(!lstat((const char *)arch_path, &lstat_buf))
 		{
 		    if(archiver != NULL)
 			archiver->processing = FALSE;
 
 		    if(archive_existed)
 			EDVObjectModifiedEmit(
-			    core, arch_obj, arch_obj, &lstat_buf
+			    core, arch_path, arch_path, &lstat_buf
 			);
 		    else
 			EDVObjectAddedEmit(
-			    core, arch_obj, &lstat_buf
+			    core, arch_path, &lstat_buf
 			);
 
 		    if(archiver != NULL)
@@ -527,13 +535,13 @@ current archive?\n"
 		    nurls, objects_added, status
 		);
 
-	    /* Unmap progress dialog, it may have been mapped if any
-	     * operations occured in the above loop
-	     */
+	    /* Unmap the progress dialog */
 	    ProgressDialogBreakQuery(TRUE);
 	    ProgressDialogSetTransientFor(NULL);
 
-	    /* Play completed sound on success */
+	    g_free(password);
+
+	    /* Play the "completed" sound on success */
 	    if(status == 0)
 		EDVPlaySoundCompleted(core);
 
@@ -559,8 +567,8 @@ current archive?\n"
 	}
 
 
-	DO_FREE_LOCALS
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN;
+#undef CLEANUP_RETURN
 }
 
 
@@ -705,7 +713,7 @@ void EDVArchiverContentsDNDSetIcon(
  *	Archiver Contents List "drag_motion" signal callback.
  *
  *	This is used to constrain all drags (regardless of its type
- *	or source data type) to be a drag action of move.
+ *	or source data type) to be a drag action of copy.
  */
 gboolean EDVArchiverContentsDragMotionCB(
 	GtkWidget *widget, GdkDragContext *dc,
@@ -759,7 +767,7 @@ void EDVArchiverContentsDragDataGetCB(
 
 	EDVArchiverSyncData(archiver);
 
-	/* Add first URL as the archive itself */
+	/* Add the first URL as the archive itself */
 	url = URLNew();
 	url->path = STRDUP(EDVArchiverCurrentLocation(archiver));
 	url_list = g_list_append(url_list, url);
