@@ -20,6 +20,7 @@
 
 #include "cfg.h"
 #include "edv_types.h"
+#include "edv_id.h"
 #include "edv_confirm.h"
 #include "edv_obj.h"
 #include "edv_archive_obj.h"
@@ -316,6 +317,21 @@ void EDVArchiverOPCB(
 	    EDVArchiverContentsFilter(archiver);
 	    break;
 
+	  case EDV_ARCHIVER_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS:
+	    if(core != NULL)
+	    {
+		gboolean state = !CFGItemListGetValueI(
+		    core->cfg_list,
+		    EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS
+		);
+		CFGItemListSetValueI(
+		    core->cfg_list,
+		    EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS,
+		    state, FALSE
+		);
+		EDVReconfiguredEmit(core);
+	    }
+	    break;
 
 	  case EDV_ARCHIVER_OP_MIME_TYPES:
 	    EDVArchiverMIMETypes(archiver);
@@ -565,7 +581,7 @@ void EDVArchiverOPNew(edv_archiver_struct *archiver)
 	    "*.*", "All Files"
 	);
 
-	/* Query user for new archive */
+	/* Query the user for the name of the new archive */
 	FileBrowserSetTransientFor(toplevel);
 	response = FileBrowserGetResponse(
 	    "Create Archive",
@@ -2303,14 +2319,12 @@ void EDVArchiverOPInvertSelection(edv_archiver_struct *archiver)
 }
 
 /*
- *	Archive Properties.
+ *	Properties.
  */
 void EDVArchiverOPProperties(edv_archiver_struct *archiver)
 {
-	struct stat lstat_buf;
-	gchar *arch_path;
 	GtkWidget *toplevel;
-	edv_object_struct *obj;
+	edv_archive_object_struct *obj = NULL;
 	edv_core_struct *core;
 
 	if(archiver == NULL)
@@ -2321,44 +2335,35 @@ void EDVArchiverOPProperties(edv_archiver_struct *archiver)
 	toplevel = archiver->toplevel;
 	core = archiver->core;
 
-	/* Get the current archive */
-	arch_path = STRDUP(EDVArchiverCurrentLocation(archiver));
-	if(arch_path == NULL)
+	EDVArchiverSyncData(archiver);
+
+	/* Get the selected object */
+	if(archiver->contents_clist_selected_row > -1)
 	{
-	    EDVArchiverSetBusy(archiver, FALSE);
-	    return;
+	    GtkCList *clist = GTK_CLIST(archiver->contents_clist);
+	    GList *glist = clist->selection_end;
+	    if(glist != NULL)
+		obj = EDV_ARCHIVE_OBJECT(gtk_clist_get_row_data(
+		    clist,
+		    (gint)glist->data
+		));
 	}
 
-	obj = EDVObjectNew();
+	/* No selected object? */
 	if(obj == NULL)
 	{
 	    EDVArchiverSetBusy(archiver, FALSE);
 	    return;
 	}
 
-	EDVObjectSetPath(obj, arch_path);
-	if(lstat((const char *)arch_path, &lstat_buf))
-	{
-	    const gint error_code = (gint)errno;
-	    EDVObjectPropSet(
-		obj,
-		EDV_OBJECT_PROP_NAME_ERROR,
-		g_strerror(error_code),
-		TRUE
-	    );
-	}
-	else
-	{
-	    EDVObjectSetStat(obj, &lstat_buf);
-	}
-	EDVObjectUpdateLinkFlags(obj);
-
-	/* Create a new Properties Dialog */
-	EDVNewPropertiesDialog(core, obj, toplevel);
-
-	EDVObjectDelete(obj);
-
-	g_free(arch_path);
+	/* Create a new properties dialog displaying the object */
+	EDVNewPropertiesDialogArchivePage(
+	    core,
+	    obj,
+	    EDVArchiverCurrentLocation(archiver),
+	    NULL,				/* Default page */
+	    toplevel
+	);
 
 	EDVArchiverSetBusy(archiver, FALSE);
 }
