@@ -30,23 +30,26 @@ void BlitImageScaleRGBA(
 );
 
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)	(((x) < 0) ? ((x) * -1) : (x))
 
 
 /*
- *	Returns x as the rounded off value to the nearest integer value.
+ *	Returns x as the rounded off value to the nearest integer
+ *	value.
  */
 static gint BlitRoundIntegerF(const gfloat x)
 {
-	return((gint)(x + 0.5));
+	return((gint)(x + 0.5f));
 }
 
 /*
  *	Returns an opaque pointer to the BlitPixel*RGBA() function based
- *	on pixel_op.
+ *	on the pixel operation.
+ *
+ *	The pixel_op specifies the pixel operation.
  *
  *	This function always returns a valid function pointer.
  */
