@@ -17,11 +17,13 @@
 
 typedef struct _edv_browser_struct	edv_browser_struct;
 #define EDV_BROWSER(p)			((edv_browser_struct *)(p))
+
+typedef struct _edv_browser_opid_struct	edv_browser_opid_struct;
+#define EDV_BROWSER_OPID(p)		((edv_browser_opid_struct *)(p))
+
 typedef struct _edv_browser_cmd_struct	edv_browser_cmd_struct;
 #define EDV_BROWSER_CMD(p)		((edv_browser_cmd_struct *)(p))
 #define EDV_BROWSER_CMD_DATA_KEY	"EDV/BROWSER/CMD"
-typedef struct _edv_browser_opid_struct	edv_browser_opid_struct;
-#define EDV_BROWSER_OPID(p)		((edv_browser_opid_struct *)(p))
 
 
 /*
@@ -147,6 +149,7 @@ typedef enum {
 	EDV_BROWSER_OP_SHOW_STATUS_BAR		= 1304,
 
 	EDV_BROWSER_OP_CONTENTS_LIST_FILTER	= 1400,
+	EDV_BROWSER_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS = 1410,
 	EDV_BROWSER_OP_SHOW_HIDDEN_OBJECTS	= 1420,
 	EDV_BROWSER_OP_SHOW_NOACCESS_OBJECTS	= 1421,
 
@@ -272,7 +275,7 @@ struct _edv_browser_struct {
 	edv_mount_bar_struct	*mount_bar;
 
 	/* Find Bar */
-	edv_findbar_struct	*find_bar;
+	edv_find_bar_struct	*find_bar;
 
 	/* Menus and Menu Items */
 	GtkWidget	*file_menu,
@@ -320,10 +323,11 @@ struct _edv_browser_struct {
 			*show_mount_bar_micheck,
 			*show_find_bar_micheck,
 			*show_status_bar_micheck,
-			*contents_list_filter_mi,
+			*directory_tree_origin_mi,
 			*show_hidden_objects_micheck,
 			*show_noaccess_objects_micheck,
-			*directory_tree_origin_mi,
+			*contents_list_filter_mi,
+			*contents_list_auto_resize_columns_micheck,
 			*mime_types_mi,
 
 			*device_menu,
@@ -454,10 +458,12 @@ struct _edv_browser_struct {
 
 /* Utilities */
 extern edv_browser_opid_struct *EDVBrowserMatchOPID(
-	edv_browser_struct *browser, edv_browser_op op
+	edv_browser_struct *browser,
+	const edv_browser_op op
 );
 extern gboolean EDVBrowserIsPathFromDirTreeOrigin(
-	edv_browser_struct *browser, const gchar *path
+	edv_browser_struct *browser,
+	const gchar *path
 );
 
 /* Title */
@@ -467,18 +473,21 @@ extern void EDVBrowserSetTitle(
 );
 
 /* Location */
-extern gchar *EDVBrowserCurrentLocation(edv_browser_struct *browser);
+extern const gchar *EDVBrowserCurrentLocation(edv_browser_struct *browser);
 extern void EDVBrowserSetLocation(
 	edv_browser_struct *browser,
-	const gchar *path, const gboolean record_history
+	const gchar *path,
+	const gboolean record_history
 );
 extern void EDVBrowserUpdateLocationIcon(
-	edv_browser_struct *browser, const gchar *path
+	edv_browser_struct *browser,
+	const gchar *path
 );
 
 /* Selected Objects & Paths */
 extern GList *EDVBrowserGetSelectedObjectsList(
-	edv_browser_struct *browser, const gboolean copy
+	edv_browser_struct *browser,
+	const gboolean copy
 );
 extern GList *EDVBrowserGetSelectedPathsList(edv_browser_struct *browser);
 
@@ -489,7 +498,8 @@ extern void EDVBrowserToolBarRegenerate(edv_browser_struct *browser);
 extern void EDVBrowserFileMenuItemsRegenerate(edv_browser_struct *browser);
 extern void EDVBrowserNewObjectMenuItemsRegenerate(edv_browser_struct *browser);
 extern void EDVBrowserOpenToMenuRegenerate(
-	edv_browser_struct *browser, edv_mime_type_struct *m
+	edv_browser_struct *browser,
+	edv_mime_type_struct *m
 );
 extern void EDVBrowserDirectoryMenuRegenerate(edv_browser_struct *browser);
 extern void EDVBrowserContentsMenuRegenerate(edv_browser_struct *browser);
@@ -498,9 +508,7 @@ extern void EDVBrowserContentsMenuRegenerate(edv_browser_struct *browser);
 extern void EDVBrowserSyncConfiguration(edv_browser_struct *browser);
 
 /* Operation IDs */
-extern GList *EDVBrowserOPIDListNew(
-	edv_browser_struct *browser		/* Can be NULL */
-);
+extern GList *EDVBrowserOPIDListNew(edv_browser_struct *browser);
 extern void EDVBrowserOPIDListDelete(GList *glist);
 
 /* Accelkeys */
@@ -510,7 +518,7 @@ extern cfg_accelkey_list_struct *EDVBrowserAccelkeysListNewDefault(void);
 extern edv_browser_struct *EDVBrowserNew(edv_core_struct *core);
 extern void EDVBrowserSyncData(edv_browser_struct *browser);
 extern void EDVBrowserUpdateMenus(edv_browser_struct *browser);
-extern void EDVBrowserSetBusy(edv_browser_struct *browser, gboolean busy);
+extern void EDVBrowserSetBusy(edv_browser_struct *browser, const gboolean busy);
 extern gboolean EDVBrowserIsMapped(edv_browser_struct *browser);
 extern void EDVBrowserMap(edv_browser_struct *browser);
 extern void EDVBrowserUnmap(edv_browser_struct *browser);
