@@ -47,6 +47,9 @@ void EDVBrowserCmdDestroyCB(gpointer data);
 void EDVBrowserContentsItemDestroyCB(gpointer data);
 void EDVBrowserDirTreeItemDestroyCB(gpointer data);
 
+static gint EDVBrowserCListColumnSortSizeCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
 static gint EDVBrowserCListColumnSortDateNexus(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2,
 	gint sort_code
@@ -60,6 +63,21 @@ static gint EDVBrowserCListColumnSortDateModifyCB(
 static gint EDVBrowserCListColumnSortDateChangeCB(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
 );
+static gint EDVBrowserCListColumnSortHardLinksCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
+static gint EDVBrowserCListColumnSortIndexCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
+static gint EDVBrowserCListColumnSortDeviceIndexCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
+static gint EDVBrowserCListColumnSortBlockSizeCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
+static gint EDVBrowserCListColumnSortBlocksCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
 
 gint EDVBrowserDeleteEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
@@ -154,36 +172,44 @@ void EDVBrowserMountBarGoToCB(
 
 /* Find Bar Callbacks */
 const gchar *EDVBrowserFindBarLocationCB(
-	edv_findbar_struct *fb, gpointer data
+	edv_find_bar_struct *fb,
+	gpointer data
+);
+void EDVBrowserFindBarStartCB(
+	edv_find_bar_struct *fb,
+	gpointer data
 );
-void EDVBrowserFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 void EDVBrowserFindBarEndCB(
-	edv_findbar_struct *fb, gint total_matches, gpointer data
+	edv_find_bar_struct *fb,
+	const gint nmatches,
+	gpointer data
 );
 void EDVBrowserFindBarMatchCB(
-	const gchar *path, const struct stat *lstat_buf,
-	const gchar *excerpt, gint line_index,
+	const gchar *path,
+	struct stat *lstat_buf,
+	const gchar *excerpt,
+	const gint line_index,
 	gpointer data
 );
 
 /* Status Bar Callbacks */
 void EDVBrowserStatusMessageCB(const gchar *message, gpointer data);
-void EDVBrowserStatusProgressCB(gfloat progress, gpointer data);
+void EDVBrowserStatusProgressCB(const gfloat progress, gpointer data);
 
 /* Write Protect Changed Callback */
 void EDVBrowserWriteProtectChangedCB(
-	edv_browser_struct *browser, gboolean state
+	edv_browser_struct *browser, const gboolean state
 );
 
 /* Object Callbacks */
 void EDVBrowserObjectAddedNotifyCB(
 	edv_browser_struct *browser, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVBrowserObjectModifiedNotifyCB(
 	edv_browser_struct *browser, const gchar *path,
 	const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVBrowserObjectRemovedNotifyCB(
 	edv_browser_struct *browser, const gchar *path
@@ -192,16 +218,19 @@ void EDVBrowserObjectRemovedNotifyCB(
 /* Mount/Unmount Callback */
 void EDVBrowserMountNotifyCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev,
-	gboolean is_mounted
+	const gint dev_num, edv_device_struct *dev,
+	const gboolean is_mounted
 );
 
 /* Recycled Object Callbacks */
 void EDVBrowserRecycledObjectAddedNotifyCB(
-	edv_browser_struct *browser, guint index
+	edv_browser_struct *browser, const guint index
+);
+void EDVBrowserRecycledObjectModifiedNotifyCB(
+	edv_browser_struct *browser, const guint index
 );
 void EDVBrowserRecycledObjectRemovedNotifyCB(
-	edv_browser_struct *browser, guint index
+	edv_browser_struct *browser, const guint index
 );
 
 /* Reconfigured Callback */
@@ -210,27 +239,29 @@ void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser);
 /* MIME Type Callbacks */
 void EDVBrowserMimeTypeAddedCB(
 	edv_browser_struct *browser,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 );
 void EDVBrowserMimeTypeModifiedCB(
 	edv_browser_struct *browser,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 );
 void EDVBrowserMimeTypeRemovedCB(
-	edv_browser_struct *browser, gint mt_num
+	edv_browser_struct *browser,
+	const gint mt_num
 );
 
 /* Device Callbacks */
 void EDVBrowserDeviceAddedCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 );
 void EDVBrowserDeviceModifiedCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 );
 void EDVBrowserDeviceRemovedCB(
-	edv_browser_struct *browser, gint dev_num
+	edv_browser_struct *browser,
+	const gint dev_num
 );
 
 
@@ -253,7 +284,7 @@ struct _browser_dir_tree_cb_data_struct {
 
 
 /*
- *	Browser command "destroy" signal callback.
+ *	Command "destroy" signal callback.
  */
 void EDVBrowserCmdDestroyCB(gpointer data)
 {
@@ -269,7 +300,7 @@ void EDVBrowserCmdDestroyCB(gpointer data)
 }
 
 /*
- *	Browser contents GtkCList item "destroy" signal callback.
+ *	Contents GtkCList item "destroy" signal callback.
  */
 void EDVBrowserContentsItemDestroyCB(gpointer data)
 {
@@ -277,7 +308,7 @@ void EDVBrowserContentsItemDestroyCB(gpointer data)
 }
 
 /*
- *	Browser directory GtkCTree item "destroy" signal callback.
+ *	Directory GtkCTree item "destroy" signal callback.
  */
 void EDVBrowserDirTreeItemDestroyCB(gpointer data)
 {
@@ -286,54 +317,71 @@ void EDVBrowserDirTreeItemDestroyCB(gpointer data)
 
 
 /*
- *	Returns the sort code for the rows sorted by date.
+ *	Contents GtkCList column sort size callback.
+ */
+static gint EDVBrowserCListColumnSortSizeCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+)
+{
+	edv_object_struct	*obj1 = EDV_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+				*obj2 = EDV_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	if(obj1->size <= obj2->size)
+	    return(obj1->size < obj2->size);
+	else
+	    return(-1);
+}
+
+/*
+ *	Contents GtkCList column sort date nexus.
  *
- *	The disk object structures are obtained from each row and the
- *	dates are compared.
+ *	The ptr1 and ptr2 specifies the two GtkCListRow * rows
+ *	that contain the object date data to compare.
+ *
+ *	The sort_code specifies which date value to compare.
  */
 static gint EDVBrowserCListColumnSortDateNexus(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2,
 	gint sort_code
 )
 {
-	gint sort_column;
-	const GtkCListRow *row1 = (const GtkCListRow *)ptr1;
-	const GtkCListRow *row2 = (const GtkCListRow *)ptr2;
-	edv_object_struct *obj1, *obj2;
-
-	if((clist == NULL) || (row1 == NULL) || (row2 == NULL))
-	    return(0);
-
-	sort_column = clist->sort_column;
-	if((sort_column < 0) || (sort_column >= clist->columns))
-	    return(0);
-
-	obj1 = EDV_OBJECT(row1->data);
-	obj2 = EDV_OBJECT(row2->data);
-	if((obj1 == NULL) || (obj2 == NULL))
+	edv_object_struct	*obj1 = EDV_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+				*obj2 = EDV_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((clist == NULL) || (obj1 == NULL) || (obj2 == NULL))
 	    return(0);
 
+	/* Handle by the sort code */
 	switch(sort_code)
 	{
 	  case 0:	/* Access time */
 	    if(obj1->access_time <= obj2->access_time)
-		    return((gint)(obj1->access_time < obj2->access_time));
-		else
-		    return(-1);
+		return(obj1->access_time < obj2->access_time);
+	    else
+		return(-1);
 	    break;
 
-	  case 1:       /* Modify time */
+	  case 1:	/* Modify time */
 	    if(obj1->modify_time <= obj2->modify_time)
-		    return((gint)(obj1->modify_time < obj2->modify_time));
-		else
-		    return(-1);
+		return(obj1->modify_time < obj2->modify_time);
+	    else
+		return(-1);
 	    break;
 
-	  case 2:       /* Change time */
+	  case 2:	/* Change time */
 	    if(obj1->change_time <= obj2->change_time)
-		    return((gint)(obj1->change_time < obj2->change_time));
-		else
-		    return(-1);
+		return(obj1->change_time < obj2->change_time);
+	    else
+		return(-1);
 	    break;
 	}
 
@@ -367,9 +415,119 @@ static gint EDVBrowserCListColumnSortDateChangeCB(
 	));
 }
 
+/*
+ *	Contents GtkCList column sort hard links callback.
+ */
+static gint EDVBrowserCListColumnSortHardLinksCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+)
+{
+	edv_object_struct	*obj1 = EDV_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+				*obj2 = EDV_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	if(obj1->hard_links <= obj2->hard_links)
+	    return(obj1->hard_links < obj2->hard_links);
+	else
+	    return(-1);
+}
 
 /*
- *	Browser toplevel GtkWidget "delete_event" signal callback.
+ *	Contents GtkCList column sort indices callback.
+ */
+static gint EDVBrowserCListColumnSortIndexCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+)
+{
+	edv_object_struct	*obj1 = EDV_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+				*obj2 = EDV_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	if(obj1->index <= obj2->index)
+	    return(obj1->index < obj2->index);
+	else
+	    return(-1);
+}
+
+/*
+ *	Contents GtkCList column sort device indices callback.
+ */
+static gint EDVBrowserCListColumnSortDeviceIndexCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+)
+{
+	edv_object_struct	*obj1 = EDV_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+				*obj2 = EDV_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	if(obj1->device_index <= obj2->device_index)
+	    return(obj1->device_index < obj2->device_index);
+	else
+	    return(-1);
+}
+
+/*
+ *	Contents GtkCList column sort block size callback.
+ */
+static gint EDVBrowserCListColumnSortBlockSizeCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+)
+{
+	edv_object_struct	*obj1 = EDV_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+				*obj2 = EDV_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	if(obj1->block_size <= obj2->block_size)
+	    return(obj1->block_size < obj2->block_size);
+	else
+	    return(-1);
+}
+
+/*
+ *	Contents GtkCList column sort blocks callback.
+ */
+static gint EDVBrowserCListColumnSortBlocksCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+)
+{
+	edv_object_struct	*obj1 = EDV_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+				*obj2 = EDV_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	if(obj1->blocks <= obj2->blocks)
+	    return(obj1->blocks < obj2->blocks);
+	else
+	    return(-1);
+}
+
+
+/*
+ *	Toplevel GtkWidget "delete_event" signal callback.
  */
 gint EDVBrowserDeleteEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
@@ -388,7 +546,7 @@ gint EDVBrowserDeleteEventCB(
 }
 
 /*
- *	File Browser "key_press_event" or "key_release_event" signal
+ *	Any GtkWidget "key_press_event" or "key_release_event" signal
  *	callback.
  */
 gint EDVBrowserKeyEventCB(
@@ -406,7 +564,7 @@ gint EDVBrowserKeyEventCB(
 	if((widget == NULL) || (key == NULL) || (browser == NULL))
 	    return(status);
 
-	if(browser->processing)
+	if(browser->processing || (browser->freeze_count > 0))
 	    return(status);
 
 	w = browser->toplevel;
@@ -419,7 +577,6 @@ gint EDVBrowserKeyEventCB(
 	keyval = key->keyval;
 	state = key->state;
 
-/* Stop emit of signal */
 #define STOP_SIGNAL_EMISSION(_w_) {		\
  gtk_signal_emit_stop_by_name(			\
   GTK_OBJECT(_w_),				\
@@ -455,8 +612,10 @@ gint EDVBrowserKeyEventCB(
 	    }
 	}
 
-	/* Check which widget this signal is for */
-	/* Directory Tree */
+	/* Check which widget this signal is for
+	 *
+	 * Directory GtkCTree
+	 */
 	if(widget == browser->directory_ctree)
 	{
 	    GtkCList *clist = GTK_CLIST(widget);
@@ -499,7 +658,7 @@ gint EDVBrowserKeyEventCB(
 		break;
 	    }
 	}
-	/* Contents List */
+	/* Contents GtkCList */
 	else if(widget == browser->contents_clist)
 	{
 	    GtkCList *clist = GTK_CLIST(widget);
@@ -548,9 +707,9 @@ gint EDVBrowserKeyEventCB(
 		 */
 		if(isalnum((int)keyval) && is_press)
 		{
-                    const gboolean backwards = (state & GDK_MOD1_MASK) ? TRUE : FALSE;
-                    const gint start_row = (backwards) ?
-                        (clist->rows - 1) : 0;
+		    const gboolean backwards = (state & GDK_MOD1_MASK) ? TRUE : FALSE;
+		    const gint start_row = (backwards) ?
+			(clist->rows - 1) : 0;
 
 		    /* Find the column that is set to display the name */
 		    cfg_intlist_struct *intlist = EDV_GET_INTLIST(
@@ -583,12 +742,13 @@ gint EDVBrowserKeyEventCB(
 	    }
 	}
 
-	return(status);
 #undef STOP_SIGNAL_EMISSION
+
+	return(status);
 }
 
 /*
- *	File Browser GtkWidget "button_press_event" signal callback.
+ *	Any GtkWidget "button_press_event" signal callback.
  */
 gint EDVBrowserButtonPressEventCB(
 	GtkWidget *widget, GdkEventButton *button, gpointer data
@@ -603,7 +763,7 @@ gint EDVBrowserButtonPressEventCB(
 	if((widget == NULL) || (button == NULL) || (browser == NULL))
 	    return(status);
 
-	if(browser->processing)
+	if(browser->processing || (browser->freeze_count > 0))
 	    return(status);
 
 	core = browser->core;
@@ -611,11 +771,14 @@ gint EDVBrowserButtonPressEventCB(
 	etype = button->type;
 	state = button->state;
 
-	/* Check which widget this signal is for */
-	/* Directory Tree */
+	/* Check which widget this signal is for
+	 *
+	 * Directory GtkCTree
+	 */
 	if(widget == browser->directory_ctree)
 	{
-	    gint row, column, nodes_selected = 0;
+	    gint	row, column,
+			nodes_selected = 0;
 	    GList *glist;
 	    GtkCTreeNode *selected_node = NULL;
 	    GtkCList *clist = GTK_CLIST(widget);
@@ -628,7 +791,6 @@ gint EDVBrowserButtonPressEventCB(
 		clist->column_title_area.y : 0)
 	    );
 
-
 	    /* Find row and column based on given coordinates */
 	    if(!gtk_clist_get_selection_info(
 		clist, button->x, button->y, &row, &column
@@ -638,7 +800,7 @@ gint EDVBrowserButtonPressEventCB(
 		column = 0;
 	    }
 
-	    /* Get number of selected rows and highest selected row */
+	    /* Get number of selected rows and the last selected row */
 	    glist = clist->selection;
 	    while(glist != NULL)
 	    {
@@ -648,10 +810,10 @@ gint EDVBrowserButtonPressEventCB(
 		glist = g_list_next(glist);
 	    }
 
-	    /* Handle by button number */
+	    /* Handle by the button number */
 	    switch(button->button)
 	    {
-	      case 3:
+	      case GDK_BUTTON3:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 		    GtkMenu *menu;
@@ -682,7 +844,7 @@ gint EDVBrowserButtonPressEventCB(
 		status = TRUE;
 		break;
 
-	      case 2:
+	      case GDK_BUTTON2:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 		    if(node != NULL)
@@ -691,20 +853,17 @@ gint EDVBrowserButtonPressEventCB(
 		status = TRUE;
 		break;
 	    }
-
-	    if(etype == GDK_BUTTON_PRESS)
-		gtk_widget_grab_focus(widget);
 	}
-	/* Contents List */
+	/* Contents GtkCList */
 	else if(widget == browser->contents_clist)
 	{
-	    gint row, column;
-	    gint rows_selected = 0, selected_row = -1;
+	    gint	row, column,
+			rows_selected = 0,
+			selected_row = -1;
 	    GList *glist;
 	    GtkCList *clist = GTK_CLIST(widget);
 
-
-	    /* Find row and column based on given coordinates */
+	    /* Find the row and column */
 	    if(!gtk_clist_get_selection_info(
 		clist, button->x, button->y, &row, &column
 	    ))
@@ -713,7 +872,7 @@ gint EDVBrowserButtonPressEventCB(
 		column = 0;
 	    }
 
-	    /* Get number of selected rows and highest selected row */
+	    /* Get the number of selected rows and the last selected row */
 	    glist = clist->selection;
 	    while(glist != NULL)
 	    {
@@ -725,7 +884,7 @@ gint EDVBrowserButtonPressEventCB(
 	    /* Handle by button number */
 	    switch(button->button)
 	    {
-	      case 3:
+	      case GDK_BUTTON3:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 		    GtkMenu *menu;
@@ -762,7 +921,7 @@ gint EDVBrowserButtonPressEventCB(
 		status = TRUE;
 		break;
 
-	      case 2:
+	      case GDK_BUTTON2:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 		    if((row >= 0) && (row < clist->rows))
@@ -773,7 +932,7 @@ gint EDVBrowserButtonPressEventCB(
 		status = TRUE;
 		break;
 
-	      case 1:
+	      case GDK_BUTTON1:
 		/* Double click? */
 		if(etype == GDK_2BUTTON_PRESS)
 		{
@@ -789,9 +948,6 @@ gint EDVBrowserButtonPressEventCB(
 		}
 		break;
 	    }
-
-	    if(etype == GDK_BUTTON_PRESS)
-		gtk_widget_grab_focus(widget);
 	}
 
 	return(status);
@@ -814,7 +970,7 @@ void EDVBrowserHandleChildAttachedCB(
 }
 
 /*
- *      GtkHandleBox "child_detached" signal callback.
+ *	GtkHandleBox "child_detached" signal callback.
  */
 void EDVBrowserHandleChildDetachedCB(
 	GtkHandleBox *handle_box, GtkWidget *child, gpointer data
@@ -831,7 +987,7 @@ void EDVBrowserHandleChildDetachedCB(
 
 
 /*
- *	Browser GtkCTree selct row idle callback.
+ *	Directory GtkCTree selct row idle callback.
  */
 static gint EDVBrowserTreeSelectRowIdleCB(gpointer data)
 {
@@ -973,7 +1129,7 @@ static gint EDVBrowserTreeSelectRowIdleCB(gpointer data)
 }
 
 /*
- *	Browser GtkCTree expand optimize idle callback.
+ *	Directory GtkCTree expand optimize idle callback.
  */
 static gint EDVBrowserTreeExpandScrollOptimizeIdleCB(gpointer data)
 {
@@ -1001,7 +1157,7 @@ static gint EDVBrowserTreeExpandScrollOptimizeIdleCB(gpointer data)
 }
 
 /*
- *	Browser GtkCTree "tree_select_row" signal callback.
+ *	Directory GtkCTree "tree_select_row" signal callback.
  */
 void EDVBrowserTreeSelectRowCB(
 	GtkCTree *ctree, GtkCTreeNode *node, gint column,
@@ -1047,7 +1203,7 @@ void EDVBrowserTreeSelectRowCB(
 }
 
 /*
- *      File Browser GtkCTree "tree_unselect_row" signal callback.
+ *	Directory GtkCTree "tree_unselect_row" signal callback.
  */
 void EDVBrowserTreeUnselectRowCB(
 	GtkCTree *ctree, GtkCTreeNode *node, gint column,
@@ -1104,7 +1260,7 @@ void EDVBrowserTreeUnselectRowCB(
 }
 
 /*
- *	Browser GtkCTree "tree_expand" signal callback.
+ *	Directory GtkCTree "tree_expand" signal callback.
  */
 void EDVBrowserTreeExpandCB(
 	GtkCTree *ctree, GtkCTreeNode *node, gpointer data
@@ -1168,7 +1324,7 @@ void EDVBrowserTreeExpandCB(
 }
 
 /*
- *      File Browser GtkCTree "tree_collapse" signal callback.
+ *	Directory GtkCTree "tree_collapse" signal callback.
  */
 void EDVBrowserTreeCollapseCB(
 	GtkCTree *ctree, GtkCTreeNode *node, gpointer data
@@ -1238,7 +1394,7 @@ void EDVBrowserTreeCollapseCB(
 
 
 /*
- *	Browser GtkCList "resize_column" signal callback.
+ *	Contents GtkCList "resize_column" signal callback.
  */
 void EDVBrowserResizeColumnCB(
 	GtkCList *clist, gint column, gint width, gpointer data
@@ -1327,48 +1483,53 @@ void EDVBrowserResizeColumnCB(
 }
 
 /*
- *	Browser GtkCList "click_column" signal callback.
+ *	Contents GtkCList "click_column" signal callback.
  */
 void EDVBrowserClickColumnCB(
 	GtkCList *clist, gint column, gpointer data
 )
 {
+	GtkWidget *widget, *toplevel;
 	const cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 	edv_browser_struct *browser = EDV_BROWSER(data);
 	if((clist == NULL) || (browser == NULL))
 	    return;
 
-	if(browser->processing)
+	if((browser->processing) || (browser->freeze_count > 0))
 	    return;
 
+	widget = GTK_WIDGET(clist);
+	toplevel = browser->toplevel;
 	core = browser->core;
 	cfg_list = core->cfg_list;
 
-	/* Check which widget this signal is for */
-	/* Contents List */
-	if(GTK_WIDGET(clist) == browser->contents_clist)
+	/* Check which widget this signal is for
+	 *
+	 * Contents GtkCList
+	 */
+	if(widget == browser->contents_clist)
 	{
-	    cfg_intlist_struct *column_types_intlist;
 	    GtkCListCompareFunc cmp_func = NULL;
 	    GtkCListCompareFunc cmp_func_str =
 		 (GtkCListCompareFunc)EDVCListColumnSortStringCB;
+#if 0
 	    GtkCListCompareFunc cmp_func_num =
 		(GtkCListCompareFunc)EDVCListColumnSortNumberCB;
-
+#endif
+	    cfg_intlist_struct *column_types_intlist;
 
 	    EDVBrowserSetBusy(browser, TRUE);
-	    GUIBlockInput(browser->toplevel, TRUE);
+	    GUIBlockInput(toplevel, TRUE);
 	    browser->processing = TRUE;	    
 
-
-	    /* Get column types mapping */
+	    /* Get the column types mapping list */
 	    column_types_intlist = EDV_GET_INTLIST(
 		EDV_CFG_PARM_BROWSER_CONTENTS_COLUMN
 	    );
 	    if(column_types_intlist != NULL)
 	    {
-		edv_browser_column_type column_type = (edv_browser_column_type)g_list_nth_data(
+		const edv_browser_column_type column_type = (edv_browser_column_type)g_list_nth_data(
 		    column_types_intlist->list,
 		    column
 		);
@@ -1378,7 +1539,7 @@ void EDVBrowserClickColumnCB(
 		    cmp_func = cmp_func_str;
 		    break;
 		  case EDV_BROWSER_COLUMN_TYPE_SIZE:
-		    cmp_func = cmp_func_num;
+		    cmp_func = EDVBrowserCListColumnSortSizeCB;
 		    break;
 		  case EDV_BROWSER_COLUMN_TYPE_TYPE:
 		    cmp_func = cmp_func_str;
@@ -1402,25 +1563,25 @@ void EDVBrowserClickColumnCB(
 		    cmp_func = EDVBrowserCListColumnSortDateChangeCB;
 		    break;
 		  case EDV_BROWSER_COLUMN_TYPE_HARD_LINKS:
-		    cmp_func = cmp_func_num;
+		    cmp_func = EDVBrowserCListColumnSortHardLinksCB;
 		    break;
 		  case EDV_BROWSER_COLUMN_TYPE_LINKED_TO:
 		    cmp_func = cmp_func_str;
 		    break;
 		  case EDV_BROWSER_COLUMN_TYPE_DEVICE_INDEX:
-		    cmp_func = cmp_func_num;
+		    cmp_func = EDVBrowserCListColumnSortDeviceIndexCB;
 		    break;
 		  case EDV_BROWSER_COLUMN_TYPE_INDEX:
-		    cmp_func = cmp_func_num;
+		    cmp_func = EDVBrowserCListColumnSortIndexCB;
 		    break;
 		  case EDV_BROWSER_COLUMN_TYPE_DEVICE_TYPE:
 		    cmp_func = cmp_func_str;
 		    break;
 		  case EDV_BROWSER_COLUMN_TYPE_BLOCK_SIZE:
-		    cmp_func = cmp_func_num;
+		    cmp_func = EDVBrowserCListColumnSortBlockSizeCB;
 		    break;
 		  case EDV_BROWSER_COLUMN_TYPE_BLOCKS:
-		    cmp_func = cmp_func_num;
+		    cmp_func = EDVBrowserCListColumnSortBlocksCB;
 		    break;
 		}
 	    }
@@ -1428,7 +1589,10 @@ void EDVBrowserClickColumnCB(
 
 	    gtk_clist_freeze(clist);
 
-	    /* Set sort column settings on the clist */
+	    /* Set or invert the sort column on the GtkCList based
+	     * on if the clicked on column is already the current
+	     * sort column
+	     */
 	    if(column != clist->sort_column)
 		gtk_clist_set_sort_column(clist, column);
 	    else
@@ -1440,15 +1604,15 @@ void EDVBrowserClickColumnCB(
 	    if(cmp_func != NULL)
 		gtk_clist_set_compare_func(clist, cmp_func);
 
-	    /* Sort rows, this will call the GtkCList column sort
-	     * callbacks.
+	    /* Sort the rows, this will call the GtkCList column
+	     * sort callbacks
 	     */
 	    gtk_clist_sort(clist);
 
 	    gtk_clist_thaw(clist);
 
 	    browser->processing = FALSE;
-	    GUIBlockInput(browser->toplevel, FALSE);
+	    GUIBlockInput(toplevel, FALSE);
 	    EDVBrowserSetBusy(browser, FALSE);
 
 	    EDVBrowserUpdateMenus(browser);
@@ -1558,13 +1722,34 @@ void EDVBrowserSelectRowCB(
 			break;
 		    }
 
-		    /* Set status bar message */
+		    /* Set the status bar message */
 		    if(nselected > 1)
-			s = g_strdup_printf(
-			    "%s objects selected",
-			    EDVSizeStrDelim(nselected)
+		    {
+			gulong total_size = 0l;
+			edv_object_struct *obj;
+			GList *glist = clist->selection;
+			while(glist != NULL)
+			{
+			    obj = EDV_OBJECT(gtk_clist_get_row_data(
+				clist, (gint)glist->data
+			    ));
+			    if(obj != NULL)
+				total_size += obj->size;
+			    glist = g_list_next(glist);
+			}
+			g_free(size_str);
+			size_str = g_strdup_printf(
+			    "%s %s",
+			    EDVSizeStrDelim(total_size),
+			    (total_size == 1l) ? "byte" : "bytes"
 			);
-		    else if(!strcmp(obj->name, ".."))
+			s = g_strdup_printf(
+			    "%s objects selected (totaling %s)",
+			    EDVSizeStrDelim(nselected),
+			    size_str
+			);
+		    }
+		    else if(!strcmp((const char *)obj->name, ".."))
 			s = g_strdup_printf(
 			    "Parent directory selected"
 			);
@@ -1590,16 +1775,16 @@ void EDVBrowserSelectRowCB(
 		}
 	    }
 
-	    /* If selected row is not fully visible then scroll to
-	     * position the selected row in the center of the list
+	    /* If the selected row is not fully visible then scroll
+	     * to position the selected row in the center of the list
 	     */
 	    if(gtk_clist_row_is_visible(clist, row) !=
 		GTK_VISIBILITY_FULL
 	    )
 		gtk_clist_moveto(
 		    clist,
-		    row, -1,	/* Row, column */
-		    0.5f, 0.0f	/* Row, column */
+		    row, -1,			/* Row, column */
+		    0.5f, 0.0f			/* Row, column */
 		);
 
 	    EDVBrowserUpdateMenus(browser);
@@ -1655,11 +1840,33 @@ void EDVBrowserUnselectRowCB(
 
 	    /* Update the status bar message */
 	    if(nselected > 0)
-		s = g_strdup_printf(
-		    "%s %s selected",
-		    EDVSizeStrDelim(nselected),
-		    (nselected == 1) ? "object" : "objects"
+	    {
+		gchar *size_str;
+		gulong total_size = 0l;
+		edv_object_struct *obj;
+		GList *glist = clist->selection;
+		while(glist != NULL)
+		{
+		    obj = EDV_OBJECT(gtk_clist_get_row_data(
+			clist, (gint)glist->data
+		    ));
+		    if(obj != NULL)
+			total_size += obj->size;
+		    glist = g_list_next(glist);
+		}
+		size_str = g_strdup_printf(
+		    "%s %s",
+		    EDVSizeStrDelim(total_size),
+		    (total_size == 1l) ? "byte" : "bytes"
 		);
+		s = g_strdup_printf(
+		    "%s %s selected (totaling %s)",
+		    EDVSizeStrDelim(nselected),
+		    (nselected == 1) ? "object" : "objects",
+		    size_str
+		);
+		g_free(size_str);
+	    }
 	    else
 		s = STRDUP("No objects selected");
 	    EDVStatusBarMessage(
@@ -1706,9 +1913,11 @@ void EDVBrowserComboActivateCB(GtkWidget *widget, gpointer data)
 		 * detect the processing and not expand the node
 		 */
 
-		/* If the specified path's prefix is not the same as
-		 * the current Directory Tree Origin then the Directory
-		 * Tree Origin needs to be updated first
+		/* If the specified path's prefix is the same as the
+		 * current Directory Tree Origin then do not change
+		 * the Directory Tree Origin, otherwise the
+		 * Directory Tree Origin needs to be changed to
+		 * the specified path
 		 */
 		if(EDVBrowserIsPathFromDirTreeOrigin(browser, path))
 		{
@@ -2314,17 +2523,21 @@ extern void EDVBrowserMountBarGoToCB(
 /*
  *	Find Bar get current location callback.
  */
-const gchar *EDVBrowserFindBarLocationCB(edv_findbar_struct *fb, gpointer data)
+const gchar *EDVBrowserFindBarLocationCB(
+	edv_find_bar_struct *fb,
+	gpointer data
+)
 {
-	return(EDVBrowserCurrentLocation(
-	    EDV_BROWSER(data)
-	));
+	return(EDVBrowserCurrentLocation(EDV_BROWSER(data)));
 }
 
 /*
  *	Find Bar start find callback.
  */
-void EDVBrowserFindBarStartCB(edv_findbar_struct *fb, gpointer data)
+void EDVBrowserFindBarStartCB(
+	edv_find_bar_struct *fb,
+	gpointer data
+)
 {
 	GtkCList *clist;
 	edv_browser_struct *browser = EDV_BROWSER(data);
@@ -2346,7 +2559,9 @@ void EDVBrowserFindBarStartCB(edv_findbar_struct *fb, gpointer data)
  *	Find Bar end find callback.
  */
 void EDVBrowserFindBarEndCB(
-	edv_findbar_struct *fb, gint total_matches, gpointer data
+	edv_find_bar_struct *fb,
+	const gint nmatches,
+	gpointer data
 )
 {
 	edv_browser_struct *browser = EDV_BROWSER(data);
@@ -2360,8 +2575,10 @@ void EDVBrowserFindBarEndCB(
  *	Find Bar match callback.
  */
 void EDVBrowserFindBarMatchCB(
-	const gchar *path, const struct stat *lstat_buf,
-	const gchar *excerpt, gint line_index,
+	const gchar *path,
+	struct stat *lstat_buf,
+	const gchar *excerpt,
+	const gint line_index,
 	gpointer data
 )
 {
@@ -2398,7 +2615,7 @@ void EDVBrowserStatusMessageCB(const gchar *message, gpointer data)
 /*
  *	Status Progress callback.
  */
-void EDVBrowserStatusProgressCB(gfloat progress, gpointer data)
+void EDVBrowserStatusProgressCB(const gfloat progress, gpointer data)
 {
 	edv_browser_struct *browser = EDV_BROWSER(data);
 	if(browser == NULL)
@@ -2412,7 +2629,7 @@ void EDVBrowserStatusProgressCB(gfloat progress, gpointer data)
  *	Write protect changed callback.
  */
 void EDVBrowserWriteProtectChangedCB(
-	edv_browser_struct *browser, gboolean state
+	edv_browser_struct *browser, const gboolean state
 )
 {
 	if(browser == NULL)
@@ -2429,7 +2646,7 @@ void EDVBrowserWriteProtectChangedCB(
  */
 void EDVBrowserObjectAddedNotifyCB(
 	edv_browser_struct *browser, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	if((browser == NULL) || STRISEMPTY(path))
@@ -2460,7 +2677,7 @@ void EDVBrowserObjectAddedNotifyCB(
 void EDVBrowserObjectModifiedNotifyCB(
 	edv_browser_struct *browser, const gchar *path,
 	const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	gchar *cur_path;
@@ -2569,8 +2786,8 @@ void EDVBrowserObjectRemovedNotifyCB(
  */
 void EDVBrowserMountNotifyCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev,
-	gboolean is_mounted
+	const gint dev_num, edv_device_struct *dev,
+	const gboolean is_mounted
 )
 {
 	if(browser == NULL)
@@ -2593,7 +2810,7 @@ void EDVBrowserMountNotifyCB(
  *	Recycled object added callback.
  */
 void EDVBrowserRecycledObjectAddedNotifyCB(
-	edv_browser_struct *browser, guint index
+	edv_browser_struct *browser, const guint index
 )
 {
 	edv_core_struct *core;
@@ -2601,6 +2818,34 @@ void EDVBrowserRecycledObjectAddedNotifyCB(
 	if(browser == NULL)
 	    return;
 
+	if(browser->processing)
+	    return;
+
+	core = browser->core;
+
+	/* There is not much interest when a recycled object has been
+	 * added or removed. Only the menus need to be updated if there
+	 * is a change in the number of recycled objects
+	 */
+	if(core->last_recbin_items != browser->last_recbin_items)
+	    EDVBrowserUpdateMenus(browser);
+}
+
+/*
+ *	Recycled object modified callback.
+ */
+void EDVBrowserRecycledObjectModifiedNotifyCB(
+	edv_browser_struct *browser, const guint index
+)
+{
+	edv_core_struct *core;
+
+	if(browser == NULL)
+	    return;
+
+	if(browser->processing)
+	    return;
+
 	core = browser->core;
 
 	/* There is not much interest when a recycled object has been
@@ -2615,7 +2860,7 @@ void EDVBrowserRecycledObjectAddedNotifyCB(
  *	Recycled object removed callback.
  */
 void EDVBrowserRecycledObjectRemovedNotifyCB(
-	edv_browser_struct *browser, guint index
+	edv_browser_struct *browser, const guint index
 )
 {
 	edv_core_struct *core;
@@ -2623,6 +2868,9 @@ void EDVBrowserRecycledObjectRemovedNotifyCB(
 	if(browser == NULL)
 	    return;
 
+	if(browser->processing)
+	    return;
+
 	core = browser->core;
 
 	/* There is not much interest when a recycled object has been
@@ -2803,10 +3051,10 @@ void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser)
 
 	EDVBrowserUpdateMenus(browser);
 
-	/* Notify browser's toplevel widget to resize */
-	w = browser->toplevel;
-	if(w != NULL)
-	    gtk_widget_queue_resize(w);
+        /* Notify GTK about possible size changes (such as the tool
+         * bar resizing)
+         */
+        gtk_widget_queue_resize(browser->toplevel);
 
 	g_free(cur_loc);
 }
@@ -2817,7 +3065,7 @@ void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser)
  */
 void EDVBrowserMimeTypeAddedCB(
 	edv_browser_struct *browser,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 )
 {
 	/* Treat a MIME Type added the same as it would be for a
@@ -2832,7 +3080,7 @@ void EDVBrowserMimeTypeAddedCB(
  */
 void EDVBrowserMimeTypeModifiedCB(
 	edv_browser_struct *browser,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 )
 {
 	gchar *cur_loc;
@@ -2862,7 +3110,8 @@ void EDVBrowserMimeTypeModifiedCB(
  *	MIME Type removed callback.
  */
 void EDVBrowserMimeTypeRemovedCB(
-	edv_browser_struct *browser, gint mt_num
+	edv_browser_struct *browser,
+	const gint mt_num
 )
 {
 	gchar *cur_loc;
@@ -2890,12 +3139,11 @@ void EDVBrowserMimeTypeRemovedCB(
 
 
 /*
- *      Called whenever a device has been added to the core
- *      structure's list of devices.
+ *	Device added callback.
  */
 void EDVBrowserDeviceAddedCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 )
 {
 	/* Treat a device added the same as it would be for a device
@@ -2905,12 +3153,11 @@ void EDVBrowserDeviceAddedCB(
 }
 
 /*
- *	Called whenever a device has been modified on the core
- *	structure's list of devices.
+ *	Device modified callback.
  */
 void EDVBrowserDeviceModifiedCB(
 	edv_browser_struct *browser,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 )
 {
 	gchar *cur_loc;
@@ -2937,11 +3184,11 @@ void EDVBrowserDeviceModifiedCB(
 }
 
 /*
- *      Called whenever a device has been removed from the core
- *      structure's list of devices.
+ *      Device removed callback.
  */
 void EDVBrowserDeviceRemovedCB(
-	edv_browser_struct *browser, gint dev_num
+	edv_browser_struct *browser,
+	const  gint dev_num
 )
 {
 	gchar *cur_loc;
