@@ -45,11 +45,16 @@ static edv_object_struct *EDVBrowserNewErrorObject(
 	const gchar *path, const gchar *error_msg
 );
 
-/* Column Setting */
+/* Columns */
 static void EDVBrowserContentsResetColumns(
 	edv_core_struct *core, edv_browser_struct *browser,
 	GtkCList *clist
 );
+void EDVBrowserContentsResizeColumnOptimul(
+	edv_browser_struct *browser,
+	const gint column_num
+);
+void EDVBrowserContentsResizeColumnsOptimul(edv_browser_struct *browser);
 
 /* Cell Setting */
 static void EDVBrowserContentsSetCellName(
@@ -62,8 +67,8 @@ static void EDVBrowserContentsSetCellSize(
 	GtkCList *clist, edv_object_struct *obj,
 	const gint row, const gint column,
 	const gboolean hide_dir_size, const gboolean hide_link_size,
-        const edv_size_format size_format,
-        const gulong block_size
+	const edv_size_format size_format,
+	const gulong block_size
 );
 static void EDVBrowserContentsSetCellType(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -145,13 +150,11 @@ static void EDVBrowserContentsSetRow(
 );
 
 static gint EDVBrowserContentsAppendObject(
-	edv_core_struct *core, edv_browser_struct *browser,
-	GtkCList *clist,
+	edv_browser_struct *browser,
 	edv_object_struct *obj
 );
 static void EDVBrowserContentsAppendListing(
-	edv_core_struct *core, edv_browser_struct *browser,
-	GtkCList *clist,
+	edv_browser_struct *browser,
 	const gchar *path,
 	const gboolean update_status_bar
 );
@@ -173,7 +176,8 @@ void EDVBrowserContentsRealizeListing(edv_browser_struct *browser);
 
 /* Get Listing */
 void EDVBrowserContentsGetListing(
-	edv_browser_struct *browser, const gchar *path,
+	edv_browser_struct *browser,
+	const gchar *path,
 	const gboolean update_status_bar
 );
 void EDVBrowserContentsClear(edv_browser_struct *browser);
@@ -185,7 +189,8 @@ void EDVBrowserContentsOpen(
 	const guint state		/* Modifier keys */
 );
 void EDVBrowserContentsOpenWith(
-	edv_browser_struct *browser, const gint row, const gint column
+	edv_browser_struct *browser,
+	const gint row, const gint column
 );
 
 /* Renaming */
@@ -194,18 +199,19 @@ static void EDVBrowserContentsFPromptRenameApplyCB(
 );
 static void EDVBrowserContentsFPromptRenameCancelCB(gpointer data);
 void EDVBrowserContentsPromptRename(
-	edv_browser_struct *browser, const gint row, const gint column
+	edv_browser_struct *browser,
+	const gint row, const gint column
 );
 
 /* Object Callbacks */
 void EDVBrowserContentsObjectAddedNotify(
 	edv_browser_struct *browser, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVBrowserContentsObjectModifiedNotify(
 	edv_browser_struct *browser, const gchar *path,
 	const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVBrowserContentsObjectRemovedNotify(
 	edv_browser_struct *browser, const gchar *path
@@ -214,13 +220,12 @@ void EDVBrowserContentsObjectRemovedNotify(
 /* Mount Callbacks */
 void EDVBrowserContentsMountNotify(
 	edv_browser_struct *browser, edv_device_struct *dev,
-	gboolean is_mounted
+	const gboolean is_mounted
 );
 
 
 struct _EDVBrowserContentsListFPromptData {
 	edv_browser_struct	*browser;
-	GtkWidget	*clist;
 	gint		row,
 			column;
 };
@@ -426,7 +431,57 @@ static void EDVBrowserContentsResetColumns(
 }
 
 /*
- *	Sets the object name for the specified cell on the given clist.
+ *	Resizes the column to optimul size.
+ */
+void EDVBrowserContentsResizeColumnOptimul(
+	edv_browser_struct *browser,
+	const gint column_num
+)
+{
+	gint ncolumns, width;
+	GtkCList *clist;
+
+	if(browser == NULL)
+	    return;
+
+	clist = GTK_CLIST(browser->contents_clist);
+	ncolumns = clist->columns;
+	if((column_num < 0) || (column_num >= ncolumns))
+	    return;
+
+	gtk_clist_freeze(clist);
+
+	width = gtk_clist_optimal_column_width(clist, column_num);
+	gtk_clist_set_column_width(clist, column_num, width);
+
+	gtk_clist_thaw(clist);
+}
+
+/*
+ *	Resizes all the columns to optimul sizes.
+ */
+void EDVBrowserContentsResizeColumnsOptimul(edv_browser_struct *browser)
+{
+	gint i, ncolumns;
+	GtkCList *clist;
+
+	if(browser == NULL)
+	    return;
+
+	clist = GTK_CLIST(browser->contents_clist);
+	ncolumns = clist->columns;
+
+	gtk_clist_freeze(clist);
+
+	for(i = 0; i < ncolumns; i++)
+	    EDVBrowserContentsResizeColumnOptimul(browser, i);
+
+	gtk_clist_thaw(clist);
+}
+
+
+/*
+ *	Sets the cell's name value and attributes.
  */
 static void EDVBrowserContentsSetCellName(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -434,13 +489,13 @@ static void EDVBrowserContentsSetCellName(
 	const gint row, const gint column
 )
 {
-	const gchar *name = obj->name;
+	const gchar *name = (obj->name != NULL) ? obj->name : "(null)";
 	GdkPixmap *pixmap, *pixmap_exp, *pixmap_ext, *pixmap_hid;
 	GdkBitmap *mask, *mask_exp, *mask_ext, *mask_hid;
 	GtkStyle	**cell_styles = browser->cell_style,
 			*style = NULL;
 
-	/* Get icon */
+	/* Get the icon */
 	EDVMatchObjectIcon(
 	    core->device, core->total_devices,
 	    core->mimetype, core->total_mimetypes,
@@ -454,8 +509,8 @@ static void EDVBrowserContentsSetCellName(
 	    &pixmap_ext, &mask_ext,
 	    &pixmap_hid, &mask_hid
 	);
-	/* Get style and alternate icon based on any type-specific
-	 * conditions
+	/* Get the style and alternate icon based on any
+	 * type-specific conditions
 	 */
 	switch(obj->type)
 	{
@@ -483,7 +538,7 @@ static void EDVBrowserContentsSetCellName(
 		}
 	    }
 	    /* Special directory notations? */
-	    if(!strcmp(name, ".."))
+	    if(!strcmp((const char *)name, ".."))
 	    {
 		if(browser->folder_parent_pixmap != NULL)
 		{
@@ -493,12 +548,13 @@ static void EDVBrowserContentsSetCellName(
 	    }
 #if 0
 	    /* Home directory? */
-	    if((!STRISEMPTY(obj->full_path) &&
-		!STRISEMPTY(core->home_dir)) ?
-		!strcmp(obj->full_path, core->home_dir) : FALSE
+	    if(!STRISEMPTY(obj->full_path) &&
+	       !STRISEMPTY(core->home_dir)
 	    )
 	    {
-		if(browser->folder_home_pixmap != NULL)
+		if(!strcmp((const char *)obj->full_path, (const char *)core->home_dir) &&
+		   (browser->folder_home_pixmap != NULL)
+		)
 		{
 		    pixmap = browser->folder_home_pixmap;
 		    mask = browser->folder_home_mask;
@@ -590,19 +646,19 @@ static void EDVBrowserContentsSetCellName(
 	    break;
 	}
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	if(pixmap != NULL)
 	     gtk_clist_set_pixtext(
 		clist, row, column,
-		(name != NULL) ? name : "(null)",
+		name,
 		EDV_LIST_PIXMAP_TEXT_SPACING,
 		pixmap, mask
 	    );
 	else
 	    gtk_clist_set_text(
 		clist, row, column,
-		(name != NULL) ? name : "(null)"
+		name
 	    );
 	gtk_clist_set_cell_style(clist, row, column, style);
 	gtk_clist_set_shift(
@@ -612,15 +668,15 @@ static void EDVBrowserContentsSetCellName(
 }
 
 /*
- *      Sets the object size for the specified cell on the given clist.
+ *	Sets the cell's size value and attributes.
  */
 static void EDVBrowserContentsSetCellSize(
 	edv_core_struct *core, edv_browser_struct *browser,
 	GtkCList *clist, edv_object_struct *obj,
 	const gint row, const gint column,
 	const gboolean hide_dir_size, const gboolean hide_link_size,
-        const edv_size_format size_format,
-        const gulong block_size
+	const edv_size_format size_format,
+	const gulong block_size
 )
 {
 	const gint border_minor = 2;
@@ -640,7 +696,7 @@ static void EDVBrowserContentsSetCellSize(
 		obj->size, size_format, block_size, ',', TRUE
 	    );
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, (s != NULL) ? s : ""
@@ -653,7 +709,7 @@ static void EDVBrowserContentsSetCellSize(
 }
 
 /*
- *	Sets the object type for the specified cell on the given clist.
+ *	Sets the cell's MIME Type value and attributes.
  */
 static void EDVBrowserContentsSetCellType(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -671,7 +727,7 @@ static void EDVBrowserContentsSetCellType(
 	    &type_str
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, (type_str != NULL) ? type_str : ""
@@ -684,8 +740,7 @@ static void EDVBrowserContentsSetCellType(
 }
 
 /*
- *      Sets the object permissions for the specified cell on the given
- *	clist.
+ *	Sets the cell's permissions value and attributes.
  */
 static void EDVBrowserContentsSetCellPermissions(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -694,45 +749,30 @@ static void EDVBrowserContentsSetCellPermissions(
 )
 {
 	edv_permission_flags permissions = obj->permissions;
-	gchar s[80];
+	gchar *s;
 
 	if(hide_link_permissions && (obj->type == EDV_OBJECT_TYPE_LINK))
-	    *s = '\0';
+	    s = NULL;
 	else
-	    g_snprintf(
-		s, sizeof(s),
-		"%c%c%c%c%c%c%c%c%c",
-	    (permissions & EDV_PERMISSION_UREAD) ? 'r' : '-',
-	    (permissions & EDV_PERMISSION_UWRITE) ? 'w' : '-',
-	    (permissions & EDV_PERMISSION_SETUID) ?
-		'S' :
-		((permissions & EDV_PERMISSION_UEXECUTE) ? 'x' : '-'),
-	    (permissions & EDV_PERMISSION_GREAD) ? 'r' : '-',
-	    (permissions & EDV_PERMISSION_GWRITE) ? 'w' : '-',
-	    (permissions & EDV_PERMISSION_SETGID) ?
-		'G' :
-		((permissions & EDV_PERMISSION_GEXECUTE) ? 'x' : '-'),
-	    (permissions & EDV_PERMISSION_AREAD) ? 'r' : '-',
-	    (permissions & EDV_PERMISSION_AWRITE) ? 'w' : '-',
-	    (permissions & EDV_PERMISSION_STICKY) ?
-		'T' :
-		((permissions & EDV_PERMISSION_AEXECUTE) ? 'x' : '-')
-	    );
+	    s = EDVGetPermissionsString(permissions);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, s
+	    clist, row, column,
+	    (s != NULL) ? s : ""
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
 	gtk_clist_thaw(clist);
+
+	g_free(s);
 }
 
 /*
- *      Sets the object owner for the specified cell on the given clist.
+ *	Sets the cell's owner value and attributes.
  */
 static void EDVBrowserContentsSetCellOwner(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -746,7 +786,7 @@ static void EDVBrowserContentsSetCellOwner(
 	    obj->owner_id, NULL
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column,
@@ -762,7 +802,7 @@ static void EDVBrowserContentsSetCellOwner(
 }
 
 /*
- *      Sets the object group for the specified cell on the given clist.
+ *	Sets the cell's group value and attributes.
  */
 static void EDVBrowserContentsSetCellGroup(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -776,7 +816,7 @@ static void EDVBrowserContentsSetCellGroup(
 	    obj->group_id, NULL
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column,
@@ -792,8 +832,7 @@ static void EDVBrowserContentsSetCellGroup(
 }
 
 /*
- *	Sets the object access date for the specified cell on the given
- *	clist.
+ *	Sets the cell's access date value and attributes.
  */
 static void EDVBrowserContentsSetCellDateAccess(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -802,21 +841,16 @@ static void EDVBrowserContentsSetCellDateAccess(
 	edv_date_relativity date_relativity, const gchar *date_format
 )
 {
-	const gchar *s;
-
-	/* Get date string for last access date */
+	/* Get/format the date string */
 	const gulong t = obj->access_time;
-	if(t > 0)
-	    s = EDVDateFormatString(
-		t, date_format, date_relativity
-	    );
-	else
-	    s = "";
+	const gchar *date_str = (t > 0l) ?
+	    EDVDateFormatString(t, date_format, date_relativity) : "";
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, s
+	    clist, row, column,
+	    date_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -826,8 +860,7 @@ static void EDVBrowserContentsSetCellDateAccess(
 }
 
 /*
- *      Sets the object modified date for the specified cell on the given
- *      clist.
+ *	Sets the cell's modified date value and attributes.
  */
 static void EDVBrowserContentsSetCellDateModified(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -836,21 +869,16 @@ static void EDVBrowserContentsSetCellDateModified(
 	edv_date_relativity date_relativity, const gchar *date_format
 )
 {
-	const gchar *s;
-
-	/* Get date string for last modify date */
+	/* Get/format the date string */
 	const gulong t = obj->modify_time;
-	if(t > 0)
-	    s = EDVDateFormatString(
-		t, date_format, date_relativity
-	    );
-	else
-	    s = "";
+	const gchar *date_str = (t > 0l) ?
+	    EDVDateFormatString(t, date_format, date_relativity) : "";
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, s
+	    clist, row, column,
+	    date_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -860,8 +888,7 @@ static void EDVBrowserContentsSetCellDateModified(
 }
 
 /*
- *      Sets the object change date for the specified cell on the given
- *      clist.
+ *	Sets the cell's changed date value and attributes.
  */
 static void EDVBrowserContentsSetCellDateChanged(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -870,21 +897,16 @@ static void EDVBrowserContentsSetCellDateChanged(
 	edv_date_relativity date_relativity, const gchar *date_format
 )
 {
-	const gchar *s;
-
-	/* Get date string for last change date */
+	/* Get/format the date string */
 	const gulong t = obj->change_time;
-	if(t > 0)
-	    s = EDVDateFormatString(
-		t, date_format, date_relativity
-	    );
-	else
-	    s = "";
+	const gchar *date_str = (t > 0l) ?
+	    EDVDateFormatString(t, date_format, date_relativity) : "";
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, s
+	    clist, row, column,
+	    date_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -894,8 +916,7 @@ static void EDVBrowserContentsSetCellDateChanged(
 }
 
 /*
- *      Sets the object hard links for the specified cell on the given
- *      clist.
+ *	Sets the cell's hard links value and attributes.
  */
 static void EDVBrowserContentsSetCellHardLinks(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -913,7 +934,7 @@ static void EDVBrowserContentsSetCellHardLinks(
 	    obj->hard_links
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, num_str
@@ -926,8 +947,7 @@ static void EDVBrowserContentsSetCellHardLinks(
 }
 
 /*
- *	Sets the object link destination for the specified cell on the
- *	given clist.
+ *	Sets the cell's linked to value and attributes.
  */
 static void EDVBrowserContentsSetCellLinkedTo(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -980,155 +1000,160 @@ static void EDVBrowserContentsSetCellLinkedTo(
 	    )
 	    {
 		edv_object_struct *dest_obj = EDVObjectNew();
-		EDVObjectSetPath(dest_obj, dest_path);
-		EDVObjectSetStat(dest_obj, &lstat_buf);
-		EDVObjectUpdateLinkFlags(dest_obj);
-
-		/* Get icon for the link destination */
-		EDVMatchObjectIcon(
-		    core->device, core->total_devices,
-		    core->mimetype, core->total_mimetypes,
-		    dest_obj->type,
-		    dest_obj->full_path,
-		    EDV_OBJECT_IS_LINK_VALID(dest_obj),
-		    dest_obj->permissions,
-		    0,				/* Small icons */
-		    &pixmap, &mask,
-		    NULL, NULL,
-		    &pixmap_ext, &mask_ext,
-		    &pixmap_hid, &mask_hid
-		);
-		/* Checking if an alternate GtkStyle and icon should
-		 * be used based on certain object types
-		 */
-		switch(dest_obj->type)
+		if(dest_obj != NULL)
 		{
-		  case EDV_OBJECT_TYPE_UNKNOWN:
-		    break;
-		  case EDV_OBJECT_TYPE_FILE:
-		    /* Hidden */
-		    if(EDVIsObjectHidden(obj))
-		    {
-			if(pixmap_hid != NULL)
-			{
-			    pixmap = pixmap_hid;
-			    mask = mask_hid;
-			}
-		    }
-		    break;
-		  case EDV_OBJECT_TYPE_DIRECTORY:
-		    /* Hidden */
-		    if(EDVIsObjectHidden(obj))
-		    {
-			if(pixmap_hid != NULL)
-			{
-			    pixmap = pixmap_hid;
-			    mask = mask_hid;
-			}
-		    }
-		    /* Special directory notations? */
-		    if(!STRISEMPTY(dest_obj->name) ?
-			!strcmp(dest_obj->name, "..") : FALSE
-		    )
-		    {
-			if(browser->folder_parent_pixmap != NULL)
-			{
-			    pixmap = browser->folder_parent_pixmap;
-			    mask = browser->folder_parent_mask;
-			}
-		    }
-#if 0
-		    /* Home directory? */
-		    if((!STRISEMPTY(dest_obj->full_path) &&
-			!STRISEMPTY(core->home_dir)) ?
-			!strcmp(dest_obj->full_path, core->home_dir) : FALSE
-		       )
-		    {
-			if(browser->folder_home_pixmap != NULL)
-			{
-			    pixmap = browser->folder_home_pixmap;
-			    mask = browser->folder_home_mask;
-			}
-		    }
-#endif
-		    /* Directory not accessable? */
-		    if(!EDVIsObjectAccessable(core, dest_obj))
-		    {
-			if(pixmap_ext != NULL)
-			{
-			    pixmap = pixmap_ext;
-			    mask = mask_ext;
-			}
-			if(style == NULL)
-			    style = cell_styles[
-				EDV_BROWSER_CELL_STYLE_NO_ACCESS
-			    ];
-		    }
-		    break;
-		  case EDV_OBJECT_TYPE_LINK:
-		    if(EDV_OBJECT_IS_LINK_TAR_GRAND_PARENT(dest_obj))
-		    {
-			if(style == NULL)
-			    style = cell_styles[
-				EDV_BROWSER_CELL_STYLE_RECURSIVE_LINK
-			    ];
-		    }
-		    break;
-		  case EDV_OBJECT_TYPE_DEVICE_BLOCK:
-		    /* Hidden */
-		    if(EDVIsObjectHidden(obj))
-		    {
-			if(pixmap_hid != NULL)
-			{
-			    pixmap = pixmap_hid;
-			    mask = mask_hid;
-			}
-		    }
-		    break;
-		  case EDV_OBJECT_TYPE_DEVICE_CHARACTER:
-		    /* Hidden */
-		    if(EDVIsObjectHidden(obj))
-		    {
-			if(pixmap_hid != NULL)
-			{
-			    pixmap = pixmap_hid;
-			    mask = mask_hid;
-			}
-		    }
-		    break;
-		  case EDV_OBJECT_TYPE_FIFO:
-		    /* Hidden */
-		    if(EDVIsObjectHidden(obj))
-		    {
-			if(pixmap_hid != NULL)
-			{
-			    pixmap = pixmap_hid;
-			    mask = mask_hid;
-			}
-		    }
-		    break;
-		  case EDV_OBJECT_TYPE_SOCKET:
-		    /* Hidden */
-		    if(EDVIsObjectHidden(obj))
-		    {
-			if(pixmap_hid != NULL)
-			{
-			    pixmap = pixmap_hid;
-			    mask = mask_hid;
-			}
-		    }
-		    break;
-		  case EDV_OBJECT_TYPE_ERROR:
-		    break;
-		}
+		    EDVObjectSetPath(dest_obj, dest_path);
+		    EDVObjectSetStat(dest_obj, &lstat_buf);
+		    EDVObjectUpdateLinkFlags(dest_obj);
 
-		EDVObjectDelete(dest_obj);
+		    /* Get the icon for the link destination */
+		    EDVMatchObjectIcon(
+			core->device, core->total_devices,
+			core->mimetype, core->total_mimetypes,
+			dest_obj->type,
+			dest_obj->full_path,
+			EDV_OBJECT_IS_LINK_VALID(dest_obj),
+			dest_obj->permissions,
+			0,			/* Small icons */
+			&pixmap, &mask,
+			NULL, NULL,
+			&pixmap_ext, &mask_ext,
+			&pixmap_hid, &mask_hid
+		    );
+
+		    /* Checking if an alternate GtkStyle and icon
+		     * should be used based on certain object types
+		     */
+		    switch(dest_obj->type)
+		    {
+		      case EDV_OBJECT_TYPE_UNKNOWN:
+			break;
+		      case EDV_OBJECT_TYPE_FILE:
+			/* Hidden */
+			if(EDVIsObjectHidden(dest_obj))
+			{
+			    if(pixmap_hid != NULL)
+			    {
+				pixmap = pixmap_hid;
+				mask = mask_hid;
+			    }
+			}
+			break;
+		      case EDV_OBJECT_TYPE_DIRECTORY:
+			/* Hidden */
+			if(EDVIsObjectHidden(dest_obj))
+			{
+			    if(pixmap_hid != NULL)
+			    {
+				pixmap = pixmap_hid;
+				mask = mask_hid;
+			    }
+			}
+			/* Special directory notations? */
+			if(!STRISEMPTY(dest_obj->name))
+			{
+			    if(!strcmp((const char *)dest_obj->name, "..") &&
+			       (browser->folder_parent_pixmap != NULL)
+			    )
+			    {
+				pixmap = browser->folder_parent_pixmap;
+				mask = browser->folder_parent_mask;
+			    }
+			}
+#if 0
+			/* Home directory? */
+			if(!STRISEMPTY(dest_obj->full_path &&
+			   !STRISEMPTY(core->home_dir)
+			)
+			{
+			    if(!strcmp((const char *)dest_obj->full_path, core->home_dir) &&
+			       (browser->folder_home_pixmap != NULL)
+			    )
+			    {
+				pixmap = browser->folder_home_pixmap;
+				mask = browser->folder_home_mask;
+			    }
+			}
+#endif
+			/* Directory not accessable? */
+			if(!EDVIsObjectAccessable(core, dest_obj))
+			{
+			    if(pixmap_ext != NULL)
+			    {
+				pixmap = pixmap_ext;
+				mask = mask_ext;
+			    }
+			    if(style == NULL)
+				style = cell_styles[
+				    EDV_BROWSER_CELL_STYLE_NO_ACCESS
+				];
+			}
+			break;
+		      case EDV_OBJECT_TYPE_LINK:
+			if(EDV_OBJECT_IS_LINK_TAR_GRAND_PARENT(dest_obj))
+			{
+			    if(style == NULL)
+				style = cell_styles[
+				    EDV_BROWSER_CELL_STYLE_RECURSIVE_LINK
+				];
+			}
+			break;
+		      case EDV_OBJECT_TYPE_DEVICE_BLOCK:
+			/* Hidden */
+			if(EDVIsObjectHidden(dest_obj))
+			{
+			    if(pixmap_hid != NULL)
+			    {
+				pixmap = pixmap_hid;
+				mask = mask_hid;
+			    }
+			}
+			break;
+		      case EDV_OBJECT_TYPE_DEVICE_CHARACTER:
+			/* Hidden */
+			if(EDVIsObjectHidden(dest_obj))
+			{
+			    if(pixmap_hid != NULL)
+			    {
+				pixmap = pixmap_hid;
+				mask = mask_hid;
+			    }
+			}
+			break;
+		      case EDV_OBJECT_TYPE_FIFO:
+			/* Hidden */
+			if(EDVIsObjectHidden(dest_obj))
+			{
+			    if(pixmap_hid != NULL)
+			    {
+				pixmap = pixmap_hid;
+				mask = mask_hid;
+			    }
+			}
+			break;
+		      case EDV_OBJECT_TYPE_SOCKET:
+			/* Hidden */
+			if(EDVIsObjectHidden(dest_obj))
+			{
+			    if(pixmap_hid != NULL)
+			    {
+				pixmap = pixmap_hid;
+				mask = mask_hid;
+			    }
+			}
+			break;
+		      case EDV_OBJECT_TYPE_ERROR:
+			break;
+		    }
+
+		    EDVObjectDelete(dest_obj);
+		}
 	    }
 	    g_free(dest_path);
 	    g_free(parent);
 	}
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	if(pixmap != NULL)
 	    gtk_clist_set_pixtext(
@@ -1149,8 +1174,7 @@ static void EDVBrowserContentsSetCellLinkedTo(
 }
 
 /*
- *	Sets the object's device index or the specified cell on
- *	the given clist.
+ *	Sets the cell's device index value and attributes.
  */
 static void EDVBrowserContentsSetCellDevice(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -1168,7 +1192,7 @@ static void EDVBrowserContentsSetCellDevice(
 	    obj->device_index
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, num_str
@@ -1181,7 +1205,7 @@ static void EDVBrowserContentsSetCellDevice(
 }
 
 /*
- *	Sets the object's index for the specified cell on the given clist.
+ *	Sets the cell's index value and attributes.
  */
 static void EDVBrowserContentsSetCellIndex(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -1198,7 +1222,7 @@ static void EDVBrowserContentsSetCellIndex(
 	    obj->index
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, num_str
@@ -1211,8 +1235,7 @@ static void EDVBrowserContentsSetCellIndex(
 }
 
 /*
- *      Sets the object device type for the specified cell on the given
- *	clist.
+ *	Sets the cell's device type value and attributes.
  */
 static void EDVBrowserContentsSetCellDeviceType(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -1244,7 +1267,7 @@ static void EDVBrowserContentsSetCellDeviceType(
 	    *num_str = '\0';
 	}
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, num_str
@@ -1257,8 +1280,7 @@ static void EDVBrowserContentsSetCellDeviceType(
 }
 
 /*
- *      Sets the object block size for the specified cell on the given
- *	clist.
+ *	Sets the cell's block size value and attributes.
  */
 static void EDVBrowserContentsSetCellBlockSize(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -1267,19 +1289,13 @@ static void EDVBrowserContentsSetCellBlockSize(
 )
 {
 	const gint border_minor = 2;
-	gchar num_str[80];
+	const gchar *s = EDVSizeStrDelim(obj->block_size);
 
-	/* Get string for block size */
-	g_snprintf(
-	    num_str, sizeof(num_str),
-	    "%ld",
-	    obj->block_size
-	);
-
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, num_str
+	    clist, row, column,
+	    (s != NULL) ? s : ""
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -1289,7 +1305,7 @@ static void EDVBrowserContentsSetCellBlockSize(
 }
 
 /*
- *      Sets the object blocks for the specified cell on the given clist.
+ *	Sets the cell's blocks value and attributes.
  */
 static void EDVBrowserContentsSetCellBlocks(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -1307,7 +1323,7 @@ static void EDVBrowserContentsSetCellBlocks(
 	    obj->blocks
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, num_str
@@ -1484,8 +1500,6 @@ static void EDVBrowserContentsSetRow(
 /*
  *	Appends the object to the Contents List.
  *
- *	The clist specifies the Contents List.
- *
  *	The obj specifies the object who's values will be used to
  *	append a new row on the Contents List and will be transfered
  *	to the Content List's row data. The obj should not be
@@ -1496,14 +1510,15 @@ static void EDVBrowserContentsSetRow(
  *	All inputs assumed valid.
  */
 static gint EDVBrowserContentsAppendObject(
-	edv_core_struct *core, edv_browser_struct *browser,
-	GtkCList *clist,
+	edv_browser_struct *browser,
 	edv_object_struct *obj
 )
 {
+	GtkCList *clist = GTK_CLIST(browser->contents_clist);
 	const gint ncolumns = MAX(clist->columns, 1);
 	gint i, new_row;
 	gchar **strv;
+	edv_core_struct *core = browser->core;
 
 	gtk_clist_freeze(clist);
 
@@ -1548,8 +1563,6 @@ static gint EDVBrowserContentsAppendObject(
  *	Appends the objects from a specified location to the Contents
  *	List.
  *
- *	The clist specifies the Contents List.
- *
  *	The path specifies the full path to the location.
  *
  *	If update_status_bar is TRUE then the status bar will be
@@ -1558,8 +1571,7 @@ static gint EDVBrowserContentsAppendObject(
  *	All inputs assumed valid.
  */
 static void EDVBrowserContentsAppendListing(
-	edv_core_struct *core, edv_browser_struct *browser,
-	GtkCList *clist,
+	edv_browser_struct *browser,
 	const gchar *path,
 	const gboolean update_status_bar
 )
@@ -1571,8 +1583,9 @@ static void EDVBrowserContentsAppendListing(
 	const gchar *filter = browser->contents_list_filter;
 	gint nobjs;
 	gchar **names_list;
-	const cfg_item_struct *cfg_list = core->cfg_list;
 	edv_status_bar_struct *sb = browser->status_bar;
+	edv_core_struct *core = browser->core;
+	const cfg_item_struct *cfg_list = core->cfg_list;
 
 	hide_object_hidden = !EDV_GET_B(
 	    EDV_CFG_PARM_BROWSER_SHOW_OBJECT_HIDDEN
@@ -1584,7 +1597,7 @@ static void EDVBrowserContentsAppendListing(
 #if defined(HAVE_REGEX)
 	/* Compile the regex search criteria */
 	if(STRISEMPTY(filter) ?
-	    FALSE : strcmp(filter, "*")
+	    FALSE : strcmp((const char *)filter, "*")
 	)
 	{
 	    regex_filter = (regex_t *)g_malloc(sizeof(regex_t));
@@ -1622,13 +1635,15 @@ static void EDVBrowserContentsAppendListing(
 	    {
 		struct stat stat_buf;
 		gint	i,
-			nobjs_loaded = 0, last_progress_percent = -1;
+			nobjs_loaded = 0,
+			last_progress_percent = -1;
 		const gchar *name;
 		gchar *full_path = NULL;
 		edv_object_struct *obj;
 #define UPDATE_PROGRESS	{				\
  if(update_status_bar && (nobjs > 0)) {			\
-  const gint progress_percent = nobjs_loaded * 100 / nobjs; \
+  const gint progress_percent = nobjs_loaded *		\
+   100 / nobjs;						\
   if(progress_percent > last_progress_percent) {	\
    EDVStatusBarProgress(				\
     sb,							\
@@ -1639,6 +1654,33 @@ static void EDVBrowserContentsAppendListing(
   }							\
  }							\
 }
+
+		/* Add the parent directory */
+		if(TRUE)
+		{
+		    obj = EDVObjectNew();
+		    if(obj != NULL)
+		    {
+			full_path = STRDUP(PrefixPaths(path, ".."));
+			if(full_path != NULL)
+			{
+			    EDVObjectSetPath(obj, full_path);
+			    if(!lstat((const char *)full_path, &stat_buf))
+				EDVObjectSetStat(obj, &stat_buf);
+			    EDVObjectUpdateLinkFlags(obj);
+
+			    g_free(full_path);
+			    full_path = NULL;
+			}
+
+			/* Append/transfer this object to the listing */
+			EDVBrowserContentsAppendObject(browser, obj);
+
+			/* Do not count this object */
+/*			nobjs_loaded++; */
+		    }
+		}
+
 		/* Iterate through the directory contents and pick
 		 * out just the directories for this first iteration
 		 */
@@ -1659,15 +1701,17 @@ static void EDVBrowserContentsAppendListing(
 		    if(name == NULL)
 			FREE_AND_CONTINUE
 
-		    /* Skip special dir notations */
-		    if(!strcmp(name, "."))
+		    /* Skip special directory notations */
+		    if(!strcmp((const char *)name, ".") ||
+		       !strcmp((const char *)name, "..")
+		    )
 		    {
 			nobjs_loaded++;
 			UPDATE_PROGRESS
 			FREE_AND_CONTINUE
 		    }
 
-		    /* Complete a full path to this object */
+		    /* Get the full path to this object */
 		    full_path = STRDUP(PrefixPaths(path, name));
 		    if(full_path == NULL)
 		    {
@@ -1703,10 +1747,7 @@ static void EDVBrowserContentsAppendListing(
 			const gint error_code = (gint)errno;
 			obj = EDVBrowserNewErrorObject(full_path, g_strerror(error_code));
 			if(obj != NULL)
-			    EDVBrowserContentsAppendObject(
-				core, browser, clist,
-				obj
-			    );
+			    EDVBrowserContentsAppendObject(browser, obj);
 			nobjs_loaded++;
 			UPDATE_PROGRESS
 			g_free(names_list[i]);
@@ -1737,10 +1778,7 @@ static void EDVBrowserContentsAppendListing(
 			else
 			{
 			    /* Append/transfer this object to the listing */
-			    EDVBrowserContentsAppendObject(
-				core, browser, clist,
-				obj
-			    );
+			    EDVBrowserContentsAppendObject(browser, obj);
 			}
 		    }
 
@@ -1776,8 +1814,10 @@ static void EDVBrowserContentsAppendListing(
 		    if(name == NULL)
 			FREE_AND_CONTINUE
 
-		    /* Skip special dir notations */
-		    if(!strcmp(name, "."))
+		    /* Skip special directory notations */
+		    if(!strcmp((const char *)name, ".") ||
+		       !strcmp((const char *)name, "..")
+		    )
 			FREE_AND_CONTINUE
 
 		    /* Filter check */
@@ -1822,10 +1862,7 @@ static void EDVBrowserContentsAppendListing(
 			const gint error_code = (gint)errno;
 			obj = EDVBrowserNewErrorObject(full_path, g_strerror(error_code));
 			if(obj != NULL)
-			    EDVBrowserContentsAppendObject(
-				core, browser, clist,
-				obj                  
-			    );
+			    EDVBrowserContentsAppendObject(browser, obj);
 			nobjs_loaded++;
 			UPDATE_PROGRESS
 			FREE_AND_CONTINUE
@@ -1856,10 +1893,7 @@ static void EDVBrowserContentsAppendListing(
 			else
 			{
 			    /* Append/transfer this object to the listing */
-			    EDVBrowserContentsAppendObject(
-				core, browser, clist,
-				obj
-			    );
+			    EDVBrowserContentsAppendObject(browser, obj);
 			}
 		    }
 
@@ -2025,6 +2059,7 @@ void EDVBrowserContentsRealizeListing(edv_browser_struct *browser)
 {
 	gint i, n;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_object_struct *obj;
 	edv_core_struct *core;
 
@@ -2033,6 +2068,7 @@ void EDVBrowserContentsRealizeListing(edv_browser_struct *browser)
 
 	clist = GTK_CLIST(browser->contents_clist);
 	core = browser->core;
+	cfg_list = core->cfg_list;
 
 	gtk_clist_freeze(clist);
 
@@ -2054,6 +2090,10 @@ void EDVBrowserContentsRealizeListing(edv_browser_struct *browser)
 	    );
 	}
 
+	/* Resize the columns */
+	if(EDV_GET_B(EDV_CFG_PARM_BROWSER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+	    EDVBrowserContentsResizeColumnsOptimul(browser);
+
 	gtk_clist_thaw(clist);
 }
 
@@ -2068,12 +2108,14 @@ void EDVBrowserContentsRealizeListing(edv_browser_struct *browser)
  *	during this operation.
  */
 void EDVBrowserContentsGetListing(
-	edv_browser_struct *browser, const gchar *path,
+	edv_browser_struct *browser,
+	const gchar *path,
 	const gboolean update_status_bar
 )
 {
 	GtkWidget *w;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_status_bar_struct *sb;
 	edv_core_struct *core;
 
@@ -2084,6 +2126,7 @@ void EDVBrowserContentsGetListing(
 	clist = GTK_CLIST(w);
 	sb = browser->status_bar;
 	core = browser->core;
+	cfg_list = core->cfg_list;
 
 	/* Report the initial progress? */
 	if(update_status_bar)
@@ -2107,11 +2150,15 @@ void EDVBrowserContentsGetListing(
 	/* Append the list of objects to the listing */
 	if(!STRISEMPTY(path))
 	    EDVBrowserContentsAppendListing(
-		core, browser, clist,
+		browser,
 		path,				/* Location */
 		update_status_bar
 	    );
 
+	/* Resize the columns */
+	if(EDV_GET_B(EDV_CFG_PARM_BROWSER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+	    EDVBrowserContentsResizeColumnsOptimul(browser);
+
 	gtk_clist_thaw(clist);
 
 	/* Report the final progress? */
@@ -2331,25 +2378,23 @@ static void EDVBrowserContentsFPromptRenameApplyCB(
 )
 {
 	gint row;
-	GtkCList *clist;
-	edv_status_bar_struct *sb;
 	edv_browser_struct *browser;
 	EDVBrowserContentsListFPromptData *d = EDV_BROWSER_CONTENTS_LIST_FPROMPT_DATA(data);
 	if(d == NULL)
 	    return;
 
 	browser = d->browser;
-	clist = GTK_CLIST(d->clist);
 	row = d->row;
-	sb = browser->status_bar;
 
 	/* Inputs valid? */
-	if((browser != NULL) && (clist != NULL) && (row >= 0) &&
-	   (value != NULL)
-	)
+	if((browser != NULL) && (row > -1) && (value != NULL))
 	{
 	    GtkWidget *toplevel = browser->toplevel;
+	    GtkCList *clist = GTK_CLIST(browser->contents_clist);
+	    edv_status_bar_struct *sb = browser->status_bar;
 	    edv_core_struct *core = browser->core;
+
+	    /* Get the object from the selected row */
 	    edv_object_struct *obj = EDV_OBJECT(
 		gtk_clist_get_row_data(clist, row)
 	    );
@@ -2365,7 +2410,7 @@ static void EDVBrowserContentsFPromptRenameApplyCB(
 		GList *modified_paths_list;
 
 		/* Rename */
-		EDVObjectOPRename(
+		(void)EDVObjectOPRename(
 		    core,
 		    old_full_path, value,
 		    &modified_paths_list,
@@ -2428,13 +2473,11 @@ static void EDVBrowserContentsFPromptRenameApplyCB(
 			}
 		    }
 
-		    if(modified_paths_list != NULL)
-		    {
-			g_list_foreach(
-			    modified_paths_list, (GFunc)g_free, NULL
-			);
-			g_list_free(modified_paths_list);
-		    }
+		    /* Delete the modified paths list */
+		    g_list_foreach(
+			modified_paths_list, (GFunc)g_free, NULL
+		    );
+		    g_list_free(modified_paths_list);
 		}
 		else
 		{   
@@ -2470,13 +2513,13 @@ static void EDVBrowserContentsFPromptRenameCancelCB(gpointer data)
 /*
  *	Prompts to rename the object.
  *
- *	The row specifies the row index.
- *
- *	The column specifies which column to rename. If column is
- *	-1 then it implies any column is valid.
+ *	The row and column specifies the object on the list to map
+ *	the rename prompt at. If column is -1 then the column that
+ *	is set to EDV_BROWSER_COLUMN_TYPE_NAME will be used.
  */
 void EDVBrowserContentsPromptRename(
-	edv_browser_struct *browser, const gint row, const gint column
+	edv_browser_struct *browser,
+	const gint row, const gint column
 )
 {
 	gint cx, cy, px, py, pwidth, pheight, name_column;
@@ -2572,18 +2615,17 @@ void EDVBrowserContentsPromptRename(
 	{
 	    gchar *value = STRDUP(obj->name);
 	    EDVBrowserContentsListFPromptData *d = EDV_BROWSER_CONTENTS_LIST_FPROMPT_DATA(
-		g_malloc0(sizeof(EDVBrowserContentsListFPromptData))
+		g_malloc(sizeof(EDVBrowserContentsListFPromptData))
 	    );
 	    if(d != NULL)
 	    {
 		d->browser = browser;
-		d->clist = GTK_WIDGET(clist);
 		d->row = row;
 		d->column = column;
 	    }
 
 	    /* Map floating prompt to change values */
-	    FPromptSetTransientFor(browser->toplevel);
+	    FPromptSetTransientFor(toplevel);
 	    FPromptSetPosition(px, py);
 	    FPromptMapQuery(
 		NULL,			/* No label */
@@ -2611,12 +2653,13 @@ void EDVBrowserContentsPromptRename(
  */
 void EDVBrowserContentsObjectAddedNotify(
 	edv_browser_struct *browser, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	gint row;
 	gchar *cur_path, *parent_path;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 
 	if((browser == NULL) || STRISEMPTY(path) || (lstat_buf == NULL))
@@ -2628,6 +2671,7 @@ void EDVBrowserContentsObjectAddedNotify(
 
 	clist = GTK_CLIST(browser->contents_clist);
 	core = browser->core;
+	cfg_list = core->cfg_list;
 
 	/* Is the current location the same as the added object? */
 	if(!strcmp((const char *)cur_path, (const char *)path))
@@ -2660,6 +2704,10 @@ void EDVBrowserContentsObjectAddedNotify(
 		    obj,
 		    row
 		);
+
+		/* Resize the columns */
+		if(EDV_GET_B(EDV_CFG_PARM_BROWSER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		    EDVBrowserContentsResizeColumnsOptimul(browser);
 	    }
 	    g_free(cur_path);
 	    return;
@@ -2685,9 +2733,11 @@ void EDVBrowserContentsObjectAddedNotify(
 		    EDVObjectUpdateLinkFlags(obj);
 
 		    /* Append/transfer this object to the listing */
-		    new_row = EDVBrowserContentsAppendObject(
-			core, browser, clist, obj
-		    );
+		    new_row = EDVBrowserContentsAppendObject(browser, obj);
+
+		    /* Resize the columns */
+		    if(EDV_GET_B(EDV_CFG_PARM_BROWSER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+			EDVBrowserContentsResizeColumnsOptimul(browser);
 		}
 	    }
 	    g_free(parent_path);
@@ -2702,12 +2752,13 @@ void EDVBrowserContentsObjectAddedNotify(
 void EDVBrowserContentsObjectModifiedNotify(
 	edv_browser_struct *browser, const gchar *path,
 	const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	gint row;
 	gchar *cur_path;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 
 	if((browser == NULL) || STRISEMPTY(path) || (lstat_buf == NULL))
@@ -2722,6 +2773,7 @@ void EDVBrowserContentsObjectModifiedNotify(
 
 	clist = GTK_CLIST(browser->contents_clist);
 	core = browser->core;
+	cfg_list = core->cfg_list;
 
 	/* Is the new modified path the same as the current location? */
 	if(!strcmp((const char *)new_path, (const char *)cur_path))
@@ -2754,6 +2806,10 @@ void EDVBrowserContentsObjectModifiedNotify(
 		    obj,
 		    row
 		);
+
+		/* Resize the columns */
+		if(EDV_GET_B(EDV_CFG_PARM_BROWSER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		    EDVBrowserContentsResizeColumnsOptimul(browser);
 	    }
 	}
 
@@ -2769,6 +2825,8 @@ void EDVBrowserContentsObjectRemovedNotify(
 {
 	gchar *cur_path;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
+	edv_core_struct *core;
 
 	if((browser == NULL) || STRISEMPTY(path))
 	    return;
@@ -2778,6 +2836,8 @@ void EDVBrowserContentsObjectRemovedNotify(
 	    return;
 
 	clist = GTK_CLIST(browser->contents_clist);
+	core = browser->core;
+	cfg_list = core->cfg_list;
 
 	/* Is the removed path the same as the current location? */
 	if(!strcmp((const char *)path, (const char *)cur_path))
@@ -2799,6 +2859,10 @@ void EDVBrowserContentsObjectRemovedNotify(
 		    row = EDVBrowserContentsFindRowByPath(browser, path);
 		} while(row > -1);
 		gtk_clist_thaw(clist);
+
+		/* Resize the columns */
+		if(EDV_GET_B(EDV_CFG_PARM_BROWSER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		    EDVBrowserContentsResizeColumnsOptimul(browser);
 	    }
 	}
 
@@ -2812,7 +2876,7 @@ void EDVBrowserContentsObjectRemovedNotify(
  */
 void EDVBrowserContentsMountNotify(
 	edv_browser_struct *browser, edv_device_struct *dev,
-	gboolean is_mounted
+	const gboolean is_mounted
 )
 {
 	gchar *cur_path = NULL, *mount_path = NULL;
