@@ -69,7 +69,8 @@ static GtkCTreeNode *EDVBrowserDirTreeInsertNode(
 
 /* Origin Path */
 void EDVBrowserDirTreeSetOriginPath(
-	edv_browser_struct *browser, const gchar *path
+	edv_browser_struct *browser,
+	const gchar *path
 );
 
 /* Get Listing */
@@ -88,7 +89,8 @@ static void EDVBrowserDirTreeGetChildrenList(
 );
 void EDVBrowserDirTreeCreateToplevels(edv_browser_struct *browser);
 void EDVBrowserDirTreeGetListing(
-	edv_browser_struct *browser, GtkCTreeNode *node,
+	edv_browser_struct *browser,
+	GtkCTreeNode *node,
 	const gboolean update_progress
 );
 void EDVBrowserDirTreeClear(edv_browser_struct *browser);
@@ -106,7 +108,8 @@ static void EDVBrowserDirTreeRealizeListingIterate(
 	const gboolean parent_is_expanded
 );
 void EDVBrowserDirTreeRealizeListing(
-	edv_browser_struct *browser, GtkCTreeNode *node
+	edv_browser_struct *browser,
+	GtkCTreeNode *node
 );
 
 /* Selecting */
@@ -118,7 +121,8 @@ static void EDVBrowserDirTreeSelectPathIterate(
 	GtkCTreeNode **partial_matched_node_rtn
 );
 void EDVBrowserDirTreeSelectPath(
-	edv_browser_struct *browser, const gchar *path
+	edv_browser_struct *browser,
+	const gchar *path
 );
 
 /* Finding */
@@ -139,7 +143,8 @@ static void EDVBrowserDirTreeFindNodeByPathIterate(
 	GtkCTreeNode **matched_node
 );
 GtkCTreeNode *EDVBrowserDirTreeFindNodeByPath(
-	edv_browser_struct *browser, const gchar *path
+	edv_browser_struct *browser,
+	const gchar *path
 );
 
 /* Removing */
@@ -158,18 +163,19 @@ static void EDVBrowserDirTreeFPromptRenameApplyCB(
 );
 static void EDVBrowserDirTreeFPromptRenameCancelCB(gpointer data);
 void EDVBrowserDirTreePromptRename(
-	edv_browser_struct *browser, GtkCTreeNode *node
+	edv_browser_struct *browser,
+	GtkCTreeNode *node
 );
 
 /* Object Callbacks */
 void EDVBrowserDirTreeObjectAddedNotify(
 	edv_browser_struct *browser, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVBrowserDirTreeObjectModifiedNotify(
 	edv_browser_struct *browser,
 	const gchar *path, const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVBrowserDirTreeObjectRemovedNotify(
 	edv_browser_struct *browser, const gchar *path
@@ -178,13 +184,12 @@ void EDVBrowserDirTreeObjectRemovedNotify(
 /* Mount Callbacks */
 void EDVBrowserDirTreeMountNotify(
 	edv_browser_struct *browser, edv_device_struct *dev,
-	gboolean is_mounted
+	const gboolean is_mounted
 );
 
 
 struct _EDVBrowserDirTreeFPromptData {
 	edv_browser_struct	*browser;
-	GtkWidget	*ctree;
 	GtkCTreeNode	*node;
 };
 
@@ -626,7 +631,8 @@ static GtkCTreeNode *EDVBrowserDirTreeInsertNode(
  *	Sets the origin path and recreates the toplevel nodes.
  */
 void EDVBrowserDirTreeSetOriginPath(
-	edv_browser_struct *browser, const gchar *path
+	edv_browser_struct *browser,
+	const gchar *path
 )
 {
 	const gchar *origin_path;
@@ -1085,7 +1091,8 @@ void EDVBrowserDirTreeCreateToplevels(edv_browser_struct *browser)
  *	first before getting the new list of child nodes.
  */
 void EDVBrowserDirTreeGetListing(
-	edv_browser_struct *browser, GtkCTreeNode *node,
+	edv_browser_struct *browser,
+	GtkCTreeNode *node,
 	const gboolean update_progress
 )
 {
@@ -1357,7 +1364,8 @@ static void EDVBrowserDirTreeRealizeListingIterate(
  *	will be used.
  */
 void EDVBrowserDirTreeRealizeListing(
-	edv_browser_struct *browser, GtkCTreeNode *node
+	edv_browser_struct *browser,
+	GtkCTreeNode *node
 )
 {
 	GtkCList *clist;
@@ -1504,7 +1512,8 @@ static void EDVBrowserDirTreeSelectPathIterate(
  *	The path specifies the full path.
  */
 void EDVBrowserDirTreeSelectPath(
-	edv_browser_struct *browser, const gchar *path
+	edv_browser_struct *browser,
+	const gchar *path
 )
 {
 	gchar *dpath;
@@ -1739,7 +1748,8 @@ static void EDVBrowserDirTreeFindNodeByPathIterate(
  *	Returns the matched node or NULL on error.
  */
 GtkCTreeNode *EDVBrowserDirTreeFindNodeByPath(
-	edv_browser_struct *browser, const gchar *path
+	edv_browser_struct *browser,
+	const gchar *path
 )
 {
 	gchar *full_path;
@@ -1938,26 +1948,24 @@ static void EDVBrowserDirTreeFPromptRenameApplyCB(
 	gpointer data, const gchar *value
 )
 {
-	GtkCTree *ctree;
 	GtkCTreeNode *node;
 	edv_browser_struct *browser;
-	edv_status_bar_struct *sb;
 	EDVBrowserDirTreeFPromptData *d = EDV_BROWSER_DIR_TREE_FPROMPT_DATA(data);
 	if(d == NULL)
 	    return;
 
 	browser = d->browser;
-	ctree = GTK_CTREE(d->ctree);
 	node = d->node;
-	sb = browser->status_bar;
 
 	/* Inputs valid? */
-	if((browser != NULL) && (ctree != NULL) && (node != NULL) &&
-	   (value != NULL)
-	)
+	if((browser != NULL) && (node != NULL) && (value != NULL))
 	{
 	    GtkWidget *toplevel = browser->toplevel;
+	    GtkCTree *ctree = GTK_CTREE(browser->directory_ctree);
+	    edv_status_bar_struct *sb = browser->status_bar;
 	    edv_core_struct *core = browser->core;
+
+	    /* Get the object from the selected node */
 	    edv_object_struct *obj = EDV_OBJECT(
 		gtk_ctree_node_get_row_data(ctree, node)
 	    );
@@ -2076,7 +2084,8 @@ static void EDVBrowserDirTreeFPromptRenameCancelCB(gpointer data)
  *	to rename.
  */
 void EDVBrowserDirTreePromptRename(
-	edv_browser_struct *browser, GtkCTreeNode *node
+	edv_browser_struct *browser,
+	GtkCTreeNode *node
 )
 {
 	gint row, column;
@@ -2145,12 +2154,11 @@ void EDVBrowserDirTreePromptRename(
 	{
 	    gchar *value = STRDUP(obj->name);
 	    EDVBrowserDirTreeFPromptData *d = EDV_BROWSER_DIR_TREE_FPROMPT_DATA(
-		g_malloc0(sizeof(EDVBrowserDirTreeFPromptData))
+		g_malloc(sizeof(EDVBrowserDirTreeFPromptData))
 	    );
 	    if(d != NULL)
 	    {
 		d->browser = browser;
-		d->ctree = GTK_WIDGET(ctree);
 		d->node = node;
 	    }
 
@@ -2180,7 +2188,7 @@ void EDVBrowserDirTreePromptRename(
  */
 void EDVBrowserDirTreeObjectAddedNotify(
 	edv_browser_struct *browser, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	struct stat stat_buf;
@@ -2312,7 +2320,7 @@ void EDVBrowserDirTreeObjectAddedNotify(
 void EDVBrowserDirTreeObjectModifiedNotify(
 	edv_browser_struct *browser,
 	const gchar *path, const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	struct stat stat_buf;
@@ -2495,7 +2503,7 @@ void EDVBrowserDirTreeObjectRemovedNotify(
  */
 void EDVBrowserDirTreeMountNotify(
 	edv_browser_struct *browser, edv_device_struct *dev,
-	gboolean is_mounted
+	const gboolean is_mounted
 )
 {
 	gchar *mount_path;
