@@ -903,7 +903,7 @@ void EDVBrowserDirTreeDragDataGetCB(
 )
 {
 	gboolean data_sent = FALSE;
-	GList *glist, *url_list = NULL;
+	GList *glist, *url_list;
 	GtkWidget *w;
 	GtkCList *clist;
 	GtkCTree *ctree;
@@ -923,6 +923,7 @@ void EDVBrowserDirTreeDragDataGetCB(
 	EDVBrowserSyncData(browser);
 
 	/* Generate a list of URLs from the selected nodes */
+	url_list = NULL;
 	for(glist = clist->selection;
 	    glist != NULL;
 	    glist = g_list_next(glist)
@@ -940,14 +941,14 @@ void EDVBrowserDirTreeDragDataGetCB(
 	    url_list = g_list_append(url_list, url);
 	}
 
-	/* Encode DDE buffer from the URL list */
+	/* Encode the DDE buffer from the URL list */
 	if(url_list != NULL)
 	{
 	    gint buf_len;
 	    guint8 *buf = URLEncode(url_list, &buf_len);
 	    if(buf != NULL)
 	    {
-		/* Send out buffer */
+		/* Send out the buffer */
 		gtk_selection_data_set(
 		    selection_data,
 		    GDK_SELECTION_TYPE_STRING,
@@ -1042,7 +1043,7 @@ void EDVBrowserDirTreeDragDataReceivedCB(
 	if((obj != NULL) ? STRISEMPTY(obj->full_path) : TRUE)
 	    return;
 
-	/* Handle received drag data */
+	/* Handle the received drag data */
 	EDVBrowserDragDataReceivedNexus(
 	    browser, core,
 	    dc, info,
