@@ -384,6 +384,20 @@ void EDVBrowserOPCB(
 	    EDVBrowserContentsFilter(browser);
 	    break;
 
+	  case EDV_BROWSER_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS:
+	    if(core != NULL)
+	    {
+		const gboolean state = !EDV_GET_B(
+		    EDV_CFG_PARM_BROWSER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS
+		);
+		EDV_SET_B(
+		    EDV_CFG_PARM_BROWSER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS,
+		    state
+		);
+		EDVReconfiguredEmit(core);
+	    }
+	    break;
+
 	  case EDV_BROWSER_OP_SHOW_HIDDEN_OBJECTS:
 	    if(core != NULL)
 	    {
@@ -1400,6 +1414,7 @@ void EDVBrowserOPMove(edv_browser_struct *browser)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_MOVE,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVBrowserCurrentLocation(browser),
 	    toplevel
@@ -1459,6 +1474,7 @@ void EDVBrowserOPCopy(edv_browser_struct *browser)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_COPY,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVBrowserCurrentLocation(browser),
 	    toplevel
@@ -1526,6 +1542,7 @@ void EDVBrowserOPLink(edv_browser_struct *browser)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_LINK,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVBrowserCurrentLocation(browser),
 	    toplevel
@@ -1542,18 +1559,20 @@ void EDVBrowserOPLink(edv_browser_struct *browser)
  */
 void EDVBrowserOPRename(edv_browser_struct *browser)
 {
+	GtkWidget *toplevel;
 	edv_core_struct *core;
 
 	if(browser == NULL)
 	    return;
 
+	toplevel = browser->toplevel;
 	core = browser->core;
 
 /* This will actually be checked again when the rename fprompt map call
  * but we check it first initially anyways
  */
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core, TRUE, browser->toplevel))
+	if(EDVCheckWriteProtect(core, TRUE, toplevel))
 	    return;
 
 	/* Check which list contains the last selected object, that will
@@ -1630,6 +1649,7 @@ void EDVBrowserOPChMod(edv_browser_struct *browser)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_CHMOD,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVBrowserCurrentLocation(browser),
 	    toplevel
@@ -1689,6 +1709,7 @@ void EDVBrowserOPChOwn(edv_browser_struct *browser)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_CHOWN,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVBrowserCurrentLocation(browser),
 	    toplevel
@@ -1748,6 +1769,7 @@ void EDVBrowserOPChTime(edv_browser_struct *browser)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_CHTIME,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVBrowserCurrentLocation(browser),
 	    toplevel
@@ -1960,10 +1982,7 @@ void EDVBrowserOPProperties(edv_browser_struct *browser)
 
 	EDVBrowserSyncData(browser);
 
-	/* Get the object from last selected directory tree item or
-	 * the contents list item
-	 */
-	/* Contents clist was last selected? */
+	/* Get the selected object */
 	if(browser->contents_clist_selected_row > -1)
 	{
 	    GtkCList *clist = GTK_CLIST(browser->contents_clist);
@@ -1974,7 +1993,6 @@ void EDVBrowserOPProperties(edv_browser_struct *browser)
 		    (gint)glist->data
 		));
 	}
-	/* Directory ctree was last selected? */
 	else if(browser->directory_ctree_selected_node != NULL)
 	{
 	    GtkCTree *ctree = GTK_CTREE(browser->directory_ctree);
@@ -1987,9 +2005,19 @@ void EDVBrowserOPProperties(edv_browser_struct *browser)
 		));
 	}
 
-	/* Create a new Properties Dialog displaying this object */
-	if(obj != NULL)
-	    EDVNewPropertiesDialog(core, obj, toplevel);
+	/* No selected object */
+	if(obj == NULL)
+	{
+	    EDVBrowserSetBusy(browser, FALSE);
+	    return;
+	}
+
+	/* Create a new properties dialog displaying the object */
+	EDVNewPropertiesDialogVFS(
+	    core,
+	    obj,
+	    toplevel
+	);
 
 	EDVBrowserSetBusy(browser, FALSE);
 }
