@@ -1,11 +1,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
+#include <ctype.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "../include/fio.h"
-
 #include "guiutils.h"
 #include "cdialog.h"
 #include "config.h"
@@ -20,7 +20,7 @@
 #include "images/icon_wand_32x32.xpm"
 #include "images/icon_search_32x32.xpm"
 #include "images/icon_security_32x32.xpm"
-#include "images/icon_print_32x32.xpm"
+#include "images/icon_print2_32x32.xpm"
 #include "images/icon_sound_32x32.xpm"
 #include "images/icon_bulb_32x32.xpm"
 #include "images/icon_power_32x32.xpm"
@@ -29,10 +29,10 @@
 #else
 # include "images/icon_linux_32x32.xpm"
 #endif
-#include "images/icon_terminal_32x32.xpm"
+#include "images/icon_terminal2_32x32.xpm"
 #include "images/icon_tuning_32x32.xpm"
 #include "images/icon_tools_32x32.xpm"
-#include "images/icon_monitor_32x32.xpm"
+#include "images/icon_monitor2_32x32.xpm"
 #include "images/icon_clipboard_32x32.xpm"
 #include "images/icon_clipboard_empty_32x32.xpm"
 #include "images/icon_install_32x32.xpm"
@@ -67,41 +67,7 @@
 #include "images/icon_help_20x20.xpm"
 
 
-/*
- *	Confirmation Dialog:
- */
 typedef struct _CDlg			CDlg;
-struct _CDlg {
-
-	GtkWidget	*toplevel;
-	GtkAccelGroup	*accelgrp;
-
-	GtkWidget	*main_vbox,
-			*label_hbox,
-			*icon_pm,
-			*label,
-			*help_vbox,
-			*help_icon_pm,
-			*help_label,
-			*button_hbox;
-
-	GtkWidget	*ok_btn,
-			*yes_btn,
-			*yes_to_all_btn,
-			*no_btn,
-			*cancel_btn,
-			*ignore_btn,
-			*retry_btn,
-			*abort_btn,
-			*help_btn;
-
-	GtkWidget	*last_transient_for;	/* Do not reference */
-	cdialog_icon	last_icon_code;
-
-	gint		response_code;
-	gint		block_loop_level;
-
-};
 #define CDLG(p)		((CDlg *)(p))
 
 
@@ -111,6 +77,7 @@ static gint CDialogCloseCB(
 );
 static void CDialogButtonCB(GtkWidget *widget, gpointer data);
 
+/* Utilities */
 static guint8 **CDialogGetMessageIconDataFromCode(cdialog_icon icon_code);
 static void CDialogLoadIcon(CDlg *d, guint8 **icon_data);
 
@@ -156,16 +123,43 @@ void CDialogUnmap(void);
 void CDialogShutdown(void);
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+/*
+ *	Confirmation Dialog:
+ */
+struct _CDlg {
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+	GtkWidget	*toplevel;
+	GtkAccelGroup	*accelgrp;
+	gint		freeze_count,
+			main_level,
+			response_code;
+
+	GtkWidget	*main_vbox,
+			*label_hbox,
+			*icon_pm,
+			*label,
+			*help_vbox,
+			*help_icon_pm,
+			*help_label,
+			*button_hbox;
+
+	GtkWidget	*ok_btn,
+			*yes_btn,
+			*yes_to_all_btn,
+			*no_btn,
+			*cancel_btn,
+			*ignore_btn,
+			*retry_btn,
+			*abort_btn,
+			*help_btn;
+
+	GtkWidget	*last_transient_for;	/* Do not reference */
+	cdialog_icon	last_icon_code;
+
+};
+
+
+static CDlg *cdlg;
 
 
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -205,7 +199,16 @@ void CDialogShutdown(void);
 #endif
 
 
-static CDlg		*cdlg;
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -217,11 +220,18 @@ static gint CDialogCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 	if((widget == NULL) || (d == NULL))
 	    return(FALSE);
 
+	if(d->freeze_count > 0)
+	    return(FALSE);
+
+	/* Set the response code to "cancel" */
 	d->response_code = CDIALOG_RESPONSE_CANCEL;
 
-	/* Break out of one main loop level */
-	gtk_main_quit();
-	d->block_loop_level--;
+	/* Break out of this dialog's GTK main loop */
+	if(d->main_level > 0)
+	{
+	    gtk_main_quit();
+	    d->main_level--;
+	}
 
 	return(TRUE);
 }
@@ -236,9 +246,12 @@ static void CDialogButtonCB(GtkWidget *widget, gpointer data)
 	if((widget == NULL) || (d == NULL))
 	    return;
 
-	/* Check if button is not shown, which implies this signal
-	 * was received synthetically or from an keyboard accelerator.
-	 * in which case we should ignore it
+	if(d->freeze_count > 0)
+	    return;
+
+	/* If this button is not mapped (which implies this signal
+	 * was received synthetically or from an keyboard accelerator)
+	 * then it should be ignored
 	 */
 	if(!GTK_WIDGET_MAPPED(widget))
 	    return;
@@ -264,12 +277,15 @@ static void CDialogButtonCB(GtkWidget *widget, gpointer data)
 	    if(w != NULL)
 		gtk_widget_hide(w);
 
-	    return;	/* Return, do not break out of block loop */
+	    return;	/* Return, do not pop a main loop */
 	}
 
-	/* Break out of one main loop level */
-	gtk_main_quit();
-	d->block_loop_level--;
+	/* Break out of this dialog's GTK main loop */
+	if(d->main_level > 0)
+	{
+	    gtk_main_quit();
+	    d->main_level--;
+	}
 }
 
 
@@ -310,7 +326,7 @@ static guint8 **CDialogGetMessageIconDataFromCode(cdialog_icon icon_code)
 	    d = (guint8 **)icon_security_32x32_xpm;
 	    break;
 	  case CDIALOG_ICON_PRINTER:
-	    d = (guint8 **)icon_print_32x32_xpm;
+	    d = (guint8 **)icon_print2_32x32_xpm;
 	    break;
 	  case CDIALOG_ICON_SPEAKER:
 	    d = (guint8 **)icon_sound_32x32_xpm;
@@ -329,7 +345,7 @@ static guint8 **CDialogGetMessageIconDataFromCode(cdialog_icon icon_code)
 #endif
 	    break;
 	  case CDIALOG_ICON_TERMINAL:
-	    d = (guint8 **)icon_terminal_32x32_xpm;
+	    d = (guint8 **)icon_terminal2_32x32_xpm;
 	    break;
 	  case CDIALOG_ICON_SETTINGS:
 	    d = (guint8 **)icon_tuning_32x32_xpm;
@@ -338,7 +354,7 @@ static guint8 **CDialogGetMessageIconDataFromCode(cdialog_icon icon_code)
 	    d = (guint8 **)icon_tools_32x32_xpm;
 	    break;
 	  case CDIALOG_ICON_MONITOR:
-	    d = (guint8 **)icon_monitor_32x32_xpm;
+	    d = (guint8 **)icon_monitor2_32x32_xpm;
 	    break;
 	  case CDIALOG_ICON_CLIPBOARD_EMPTY:
 	    d = (guint8 **)icon_clipboard_empty_32x32_xpm;
@@ -460,30 +476,34 @@ gint CDialogInit(void)
 	GtkAccelGroup *accelgrp;
 	GtkRcStyle *rcstyle;
 	GtkStyle *style;
-	GtkWidget *w, *parent, *parent2, *parent3, *parent4, *parent5;
+	GtkWidget	*w,
+			*parent, *parent2, *parent3, *parent4,
+			*parent5,
+			*toplevel;
 	CDlg *d;
 
 	/* Already initialized? */
 	if(cdlg != NULL)
 	    return(0);
 
-	/* Create new Dialog */
+	/* Create the new Dialog */
 	cdlg = d = CDLG(g_malloc0(sizeof(CDlg)));
 	if(d == NULL)
 	    return(-3);
 
-	/* Reset globals */
+	d->toplevel = toplevel = gtk_window_new(GTK_WINDOW_DIALOG);
+	d->accelgrp = accelgrp = gtk_accel_group_new();
+	d->freeze_count = 0;
+	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
+	d->main_level = 0;
 	d->last_transient_for = NULL;
 	d->last_icon_code = CDIALOG_ICON_INFO;
-	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
-	d->block_loop_level = 0;
 
-	/* Keyboard accelerator group */
-	d->accelgrp = accelgrp = gtk_accel_group_new();
+	d->freeze_count++;
 
-
-	/* Toplevel */
-	d->toplevel = w = gtk_window_new(GTK_WINDOW_DIALOG);
+	/* Toplevel GtkWindow */
+	w = toplevel;
+        gtk_window_set_policy(GTK_WINDOW(w), TRUE, TRUE, TRUE);
 	gtk_window_set_title(GTK_WINDOW(w), CDIALOG_DEF_TITLE);
 #ifdef PROG_NAME
 	gtk_window_set_wmclass(
@@ -500,12 +520,11 @@ gint CDialogInit(void)
 
 	    gdk_window_set_decorations(
 		window,
-		GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
-		GDK_DECOR_MINIMIZE
+		GDK_DECOR_BORDER | GDK_DECOR_TITLE
 	    );
 	    gdk_window_set_functions(
 		window,
-		GDK_FUNC_MOVE | GDK_FUNC_MINIMIZE | GDK_FUNC_CLOSE
+		GDK_FUNC_MOVE | GDK_FUNC_CLOSE
 	    );
 
 	    geo.min_width = 100;
@@ -1046,6 +1065,8 @@ gint CDialogInit(void)
 	);
 	GUIButtonLabelUnderline(w, GDK_h);
 
+	d->freeze_count--;
+
 	return(0);
 }
 
@@ -1126,7 +1147,7 @@ gboolean CDialogIsQuery(void)
 	if(d == NULL)
 	    return(FALSE);
 
-	return((d->block_loop_level > 0) ? TRUE : FALSE);
+	return((d->main_level > 0) ? TRUE : FALSE);
 }
 
 /*
@@ -1141,13 +1162,13 @@ void CDialogBreakQuery(void)
 
 	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
 
-	/* Break out of all main loops */
-	while(d->block_loop_level > 0)
+	/* Break out of all of this dialog's main loops */
+	while(d->main_level > 0)
 	{
 	    gtk_main_quit();
-	    d->block_loop_level--;
+	    d->main_level--;
 	}
-	d->block_loop_level = 0;
+	d->main_level = 0;
 }
 
 /*
@@ -1177,17 +1198,17 @@ static void CDialogRemapButtons(
 	if(d == NULL)
 	    return;
 
-#define DO_MAP_BUTTON(w)	\
+#define DO_MAP_BUTTON(w)		\
 { if((w) != NULL) { gtk_widget_show(w); } }
-#define DO_UNMAP_BUTTON(w)	\
+#define DO_UNMAP_BUTTON(w)		\
 { if((w) != NULL) { gtk_widget_hide(w); } }
-#define DO_DEFAULT_BUTTON(w)	\
-{ if((w) != NULL) {		\
-  gtk_widget_grab_focus(w);	\
-  gtk_widget_grab_default(w);	\
+#define DO_DEFAULT_BUTTON(w)		\
+{ if((w) != NULL) {			\
+  gtk_widget_grab_focus(w);		\
+  gtk_widget_grab_default(w);		\
 } }
-#define DO_UNDEFAULT_BUTTON(w)	\
-{ if((w) != NULL) {		\
+#define DO_UNDEFAULT_BUTTON(w)		\
+{ if((w) != NULL) {			\
 /*  GTK_WIDGET_UNSET_FLAGS(w, GTK_HAS_DEFAULT); \
   GTK_WIDGET_UNSET_FLAGS(w, GTK_RECEIVES_DEFAULT);  */ \
 } }
@@ -1320,12 +1341,12 @@ gint CDialogGetResponse(
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
 	/* Already waiting for user response? */
-	if(d->block_loop_level > 0)
+	if(d->main_level > 0)
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
 	/* Reset values */
 	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
-	d->block_loop_level = 0;
+	d->main_level = 0;
 
 	toplevel = d->toplevel;
 
@@ -1392,19 +1413,19 @@ gint CDialogGetResponse(
 	CDialogMap();
 
 	/* Block until user response */
-	d->block_loop_level++;
+	d->main_level++;
 	gtk_main();
 
 	/* Unmap the CDialog */
 	CDialogUnmap();
 
-	/* Break out of all main loops */
-	while(d->block_loop_level > 0)
+	/* Break out of all of this dialog's main loops */
+	while(d->main_level > 0)
 	{
 	    gtk_main_quit();
-	    d->block_loop_level--;
+	    d->main_level--;
 	}
-	d->block_loop_level = 0;
+	d->main_level = 0;
 
 	return(d->response_code);
 }
@@ -1428,12 +1449,12 @@ gint CDialogGetResponseIconData(
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
 	/* Already waiting for user response? */
-	if(d->block_loop_level > 0)
+	if(d->main_level > 0)
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
-	/* Reset values */
+	/* Reset the values */
 	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
-	d->block_loop_level = 0;
+	d->main_level = 0;
 
 	toplevel = d->toplevel;
 
@@ -1498,19 +1519,19 @@ gint CDialogGetResponseIconData(
 	CDialogMap();
 
 	/* Block until user response */
-	d->block_loop_level++;
+	d->main_level++;
 	gtk_main();
 
 	/* Unmap the CDialog */
 	CDialogUnmap();
 
-	/* Break out of all main loops */
-	while(d->block_loop_level > 0)
+	/* Break out of all of this dialog's main loops */
+	while(d->main_level > 0)
 	{
 	    gtk_main_quit();
-	    d->block_loop_level--;
+	    d->main_level--;
 	}
-	d->block_loop_level = 0;
+	d->main_level = 0;
 
 	return(d->response_code);
 }
@@ -1530,22 +1551,9 @@ gint CDialogGetResponseFile(
 {
 	gint response;
 	gchar *buf;
-	FILE *fp = !STRISEMPTY(filename) ?
-	    FOpen((const char *)filename, "rb") : NULL;
-	if(fp == NULL)
-	{
-	    /* Failed to open file */
-	    if(!STRISEMPTY(filename))
-		buf = g_strdup_printf(
-"Unable to open file:\n\
-\n\
-    %s\n",
-		    filename
-		);
-	    else
-		buf = STRDUP("No file specified");
-	}
-	else
+	FILE *fp = (filename != NULL) ?
+	    fopen((const char *)filename, "rb") : NULL;
+	if(fp != NULL)
 	{
 	    gint	buf_len = 2048,
 			bytes_read;
@@ -1561,7 +1569,35 @@ gint CDialogGetResponseFile(
 		bytes_read = buf_len - 1;
 	    buf[bytes_read] = '\0';
 
-	    FClose(fp);
+	    fclose(fp);
+	}
+	else
+	{
+	    const gint error_code = errno;
+	    if(filename != NULL)
+	    {
+		gchar *error_msg = STRDUP(g_strerror(error_code));
+		if(error_msg != NULL)
+		{
+		    *error_msg = (gchar)toupper((int)(*error_msg));
+		    buf = g_strdup_printf(
+"%s:\n\
+\n\
+    %s",
+			error_msg,
+			filename
+		    );
+		    g_free(error_msg);
+		}
+		else
+		{
+		    buf = STRDUP("Unable to open the file for reading");
+		}
+	    }
+	    else
+	    {
+		buf = STRDUP("No file specified");
+	    }
 	}
 
 	/* Map the CDialog using the message loaded from the file
@@ -1618,41 +1654,27 @@ void CDialogShutdown(void)
 
 	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
 
-	/* Break out of all main loops */
-	while(d->block_loop_level > 0)
+	/* Break out of all of this dialog's main loops */
+	while(d->main_level > 0)
 	{
 	    gtk_main_quit();
-	    d->block_loop_level--;
+	    d->main_level--;
 	}
-	d->block_loop_level = 0;
+	d->main_level = 0;
 
-	/* Unmap Dialog */
+	/* Unmap the dialog */
 	CDialogUnmap();
 
-	/* Begin destroying widgets */
-	GTK_WIDGET_DESTROY(d->icon_pm)
-	GTK_WIDGET_DESTROY(d->label)
-	GTK_WIDGET_DESTROY(d->label_hbox)
-	GTK_WIDGET_DESTROY(d->help_icon_pm)
-	GTK_WIDGET_DESTROY(d->help_label)
-	GTK_WIDGET_DESTROY(d->help_vbox)
-
-	GTK_WIDGET_DESTROY(d->ok_btn)
-	GTK_WIDGET_DESTROY(d->yes_btn)
-	GTK_WIDGET_DESTROY(d->yes_to_all_btn)
-	GTK_WIDGET_DESTROY(d->no_btn)
-	GTK_WIDGET_DESTROY(d->cancel_btn)
-	GTK_WIDGET_DESTROY(d->ignore_btn)
-	GTK_WIDGET_DESTROY(d->retry_btn)
-	GTK_WIDGET_DESTROY(d->abort_btn)
-	GTK_WIDGET_DESTROY(d->help_btn)
-
-	GTK_WIDGET_DESTROY(d->button_hbox)
-	GTK_WIDGET_DESTROY(d->main_vbox)
-	GTK_WIDGET_DESTROY(d->toplevel)
-
-	GTK_ACCEL_GROUP_UNREF(d->accelgrp)
-
+	/* Clear the dialog pointer before deleting the dialog */
 	cdlg = NULL;
+
+	/* Delete this dialog */
+	d->freeze_count++;
+
+	gtk_widget_destroy(d->toplevel);
+	gtk_accel_group_unref(d->accelgrp);
+
+	d->freeze_count--;
+
 	g_free(d);
 }
