@@ -1,7 +1,7 @@
 /*
                    Endeavour Compile Time Configuration
 
-	See edv_cfg_list.h for confirmation list.
+	For the configuration list declaration, see edv_cfg_list.h
  */
 
 #ifndef CONFIG_H
@@ -27,11 +27,11 @@
  */
 #define PROG_NAME			"Endeavour"
 #define PROG_NAME_FULL			"Endeavour Mark II"
-#define PROG_VERSION			"2.8.2"
+#define PROG_VERSION			"2.8.4"
 
 #define PROG_VERSION_MAJOR		2
 #define PROG_VERSION_MINOR		8
-#define PROG_VERSION_RELEASE		2
+#define PROG_VERSION_RELEASE		4
 
 /*
  *      Copyright message:
@@ -108,7 +108,7 @@ to the fullest extent of the law.\n"
  *      Credits Lines:
  */
 #define PROG_CREDITS_LINES	{				\
- "                  http://wolfpack.twu.net/Endeavour2/",	\
+ "                  http://www.battlefieldlinux.com/wolfpack/Endeavour2/",	\
  " ",								\
  " Project Captain: Tara Milana",				\
  " ",								\
@@ -330,6 +330,11 @@ to the fullest extent of the law.\n"
 #define EDV_DEF_ABOUT_IMAGE_FILE	EDV_DEF_IMAGES_SUBDIR \
  "/endeavour_about.xpm"
 
+/*
+ *	Default splash image file:
+ */
+#define EDV_DEF_SPLASH_IMAGE_FILE	EDV_DEF_IMAGES_SUBDIR \
+ "/endeavour_splash.xpm"
 
 /*
  *	Default device icon files:
