@@ -17,25 +17,31 @@
 #include "config.h"
 
 
-/* Archiver */
+/* Callbacks */
 static void EDVCustomizeArchiverKeymapsDefaultsCB(
 	keymap_list_struct *kmlist, keymap_key_struct *km,
 	gpointer data
 );
+
+/* Create Pages */
 void EDVCustomizeArchiverCreateKeymapsPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 void EDVCustomizeArchiverCreateContentsListPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 void EDVCustomizeArchiverCreateToolBarPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 void EDVCustomizeArchiverCreateAppearancePage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 
@@ -73,7 +79,10 @@ static void EDVCustomizeArchiverKeymapsDefaultsCB(
 	if(ak_list == NULL)
 	    return;
 
-	for(glist = ak_list->list; glist != NULL; glist = g_list_next(glist))
+	for(glist = ak_list->list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
 	    ak = CFG_ACCELKEY(glist->data);
 	    if(ak == NULL)
@@ -94,7 +103,8 @@ static void EDVCustomizeArchiverKeymapsDefaultsCB(
  *	Creates the Archiver Keymaps page.
  */
 void EDVCustomizeArchiverCreateKeymapsPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
@@ -109,7 +119,7 @@ void EDVCustomizeArchiverCreateKeymapsPage(
 	edv_archiver_opid_struct *opid;
 
 
-	/* Accelerator Keys frame */
+	/* Accelerator Keys GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Acelerador Adapta"
@@ -172,7 +182,7 @@ void EDVCustomizeArchiverCreateKeymapsPage(
 	    GList *glist, *glist2, *ak_glist = ak_list->list;
 	    cfg_accelkey_struct *ak;
 
-	    /* Iterate through Operation IDs */
+	    /* Iterate through the Operation IDs */
 	    for(glist = opid_list;
 		glist != NULL;
 		glist = g_list_next(glist)
@@ -231,18 +241,19 @@ void EDVCustomizeArchiverCreateKeymapsPage(
  *	Create Archiver Contents List page.
  */
 void EDVCustomizeArchiverCreateContentsListPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
 	const gint	border_major = 5,
 			border_minor = 2;
-	GtkWidget *w, *parent2;
+	GtkWidget *w, *parent2, *parent3;
 	edv_gen_opt_wref_struct *wref;
 	stack_list_struct *slist;
 
 
-	/* Display options frame */
+	/* Cell Display Options GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Las Opciones Del Despliegue De La Clula"
@@ -273,7 +284,7 @@ void EDVCustomizeArchiverCreateContentsListPage(
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Hide dir size check */
+	/* Hide Directory Size GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Esconda Tamao Gua"
@@ -302,7 +313,7 @@ void EDVCustomizeArchiverCreateContentsListPage(
 	    EDV_CFG_PARM_ARCHIVER_CONTENTS_HIDE_DIR_SIZE
 	);
 
-	/* Hide link size check */
+	/* Hide Link Size GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Esconda tamao del enlace"
@@ -331,7 +342,7 @@ void EDVCustomizeArchiverCreateContentsListPage(
 	    EDV_CFG_PARM_ARCHIVER_CONTENTS_HIDE_LINK_SIZE
 	);
 
-	/* Hide link permission check */
+	/* Hide Link Permission GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Esconda permisos del enlace"
@@ -361,7 +372,7 @@ void EDVCustomizeArchiverCreateContentsListPage(
 	);
 
 
-	/* Arrangement frame */
+	/* Arrangement GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Arreglo"
@@ -392,7 +403,30 @@ void EDVCustomizeArchiverCreateContentsListPage(
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Create contents list stack list */
+	w = gtk_hbox_new(FALSE, border_minor);
+	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
+	gtk_widget_show(w);
+	parent3 = w;
+
+	/* Automatically Resize Columns GtkCheckButton */
+	w = gtk_check_button_new_with_label(
+"Automatically Resize Columns"
+	);
+	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
+	GUISetWidgetTip(
+	    w,
+"Check this to automatically resize the columns each time the list\
+ is updated"
+	);
+	gtk_widget_show(w);
+	wref = EDVGenOptWinWRefAppend(
+	    optwin,
+	    EDV_GEN_OPT_WIDGET_TOGGLE_BUTTON, w,
+	    NULL,
+	    EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS
+	);
+
+	/* Contents List Stack List */
 	slist = StackListNew(
 	    parent2,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -423,7 +457,16 @@ void EDVCustomizeArchiverCreateContentsListPage(
 	    EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN
 	);
 
-	/* Create Contents List Headings Stack List */
+	/* Add the headings list */
+	StackListAppend(
+	    slist,
+"Index",
+"Archive object index number",
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
+	    EDV_ARCHIVER_COLUMN_TYPE_INDEX,
+	    FALSE, FALSE		/* No multiple, no stay on target */
+	);
 	StackListAppend(
 	    slist,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -451,10 +494,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Name",
 "Name of the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_NAME,
-	    FALSE, TRUE         /* No multiple, stay on target */
+	    FALSE, TRUE			/* No multiple, stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -483,10 +526,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Size",
 "Size of the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_SIZE,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -515,10 +558,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Compressed Size",
 "Compressed size of the object",
 #endif
-	    NULL,		/* No icon data */
-	    NULL,		/* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_COMPRESSED_SIZE,
-	    FALSE, FALSE	/* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -547,10 +590,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Type",
 "MIME Type associated with the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_TYPE,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -579,10 +622,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Permissions",
 "Access rights to the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_PERMISSIONS,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -611,10 +654,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Owner",
 "User that the object belongs to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_OWNER,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -643,10 +686,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Group",
 "Group that the object belongs to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_GROUP,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -675,10 +718,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Date Access",
 "Date and time that the object was last read from or written to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_DATE_ACCESS,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -707,10 +750,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Date Modified",
 "Date and time that the object was last written to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_DATE_MODIFIED,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -739,10 +782,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Date Changed",
 "Date and time that the object was last written to or its properties were modified",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_DATE_CHANGED,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -771,10 +814,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Location",
 "Location for the object when extracted",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_LOCATION,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -803,10 +846,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Linked To",
 "Link target value",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_LINKED_TO,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -835,10 +878,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Device Type",
 "Device major and minor number pair",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_DEVICE_TYPE,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -867,10 +910,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Compression",
 "Compression ratio of the object's data",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_COMPRESSION,
-	    FALSE, FALSE	/* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -897,12 +940,12 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "Metode av  lagre objektet",
 #else
 "Method",
-"Method of storing the object",
+"Storage method and encryption",
 #endif
-	    NULL,		/* No icon data */
-	    NULL,		/* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_METHOD,
-	    FALSE, FALSE	/* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -931,10 +974,10 @@ void EDVCustomizeArchiverCreateContentsListPage(
 "CRC",
 "CRC checksum of the object's data",
 #endif
-	    NULL,		/* No icon data */
-	    NULL,		/* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_ARCHIVER_COLUMN_TYPE_CRC,
-	    FALSE, FALSE	/* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 
 	StackListUpdateMenus(slist);
@@ -945,7 +988,8 @@ void EDVCustomizeArchiverCreateContentsListPage(
  *      Creates the Archiver Tool Bar page.
  */
 void EDVCustomizeArchiverCreateToolBarPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
@@ -960,14 +1004,13 @@ void EDVCustomizeArchiverCreateToolBarPage(
 	edv_archiver_opid_struct *opid;
 
 
-	/* GtkHBox for Tool Bar Display and Relief frames */
+	/* Display Buttons As and Buttons Relief GtkHBox */
 	w = gtk_hbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
 
-
-	/* Tool Bar Display GtkFrame */
+	/* Display Buttons As GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Despliegue Abrocha Como"
@@ -998,9 +1041,10 @@ void EDVCustomizeArchiverCreateToolBarPage(
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Text */
+	/* Text GtkRadioButton */
 	gslist = NULL;
-	w = gtk_radio_button_new_with_label(gslist,
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Texto"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1019,6 +1063,7 @@ void EDVCustomizeArchiverCreateToolBarPage(
 "Text"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1028,10 +1073,10 @@ void EDVCustomizeArchiverCreateToolBarPage(
 	    EDV_CFG_PARM_ARCHIVER_TOOL_BAR_DISPLAY
 	);
 	wref->radio_value = TOOLBAR_DISPLAY_TEXT;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Pictures */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Pictures GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Los Retratos"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1050,6 +1095,7 @@ void EDVCustomizeArchiverCreateToolBarPage(
 "Pictures"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1059,10 +1105,10 @@ void EDVCustomizeArchiverCreateToolBarPage(
 	    EDV_CFG_PARM_ARCHIVER_TOOL_BAR_DISPLAY
 	);
 	wref->radio_value = TOOLBAR_DISPLAY_PICTURES;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Pictures & Text */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Pictures & Text GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Los Retratos & Texto"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1081,6 +1127,7 @@ void EDVCustomizeArchiverCreateToolBarPage(
 "Pictures & Text"
 #endif
 	);
+/*	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w)); */
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1123,9 +1170,10 @@ void EDVCustomizeArchiverCreateToolBarPage(
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Flush */
+	/* Flush GtkRadioButton */
 	gslist = NULL;
-	w = gtk_radio_button_new_with_label(gslist,
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Rubor"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1144,6 +1192,7 @@ void EDVCustomizeArchiverCreateToolBarPage(
 "Flush"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1153,10 +1202,10 @@ void EDVCustomizeArchiverCreateToolBarPage(
 	    EDV_CFG_PARM_ARCHIVER_TOOL_BAR_RELIEF
 	);
 	wref->radio_value = TOOLBAR_RELIEF_NONE;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Half */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Half GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Mitad"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1175,6 +1224,7 @@ void EDVCustomizeArchiverCreateToolBarPage(
 "Half"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1184,10 +1234,10 @@ void EDVCustomizeArchiverCreateToolBarPage(
 	    EDV_CFG_PARM_ARCHIVER_TOOL_BAR_RELIEF
 	);
 	wref->radio_value = TOOLBAR_RELIEF_HALF;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Raised */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Raised GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Levantado"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1206,6 +1256,7 @@ void EDVCustomizeArchiverCreateToolBarPage(
 "Raised"
 #endif
 	);
+/*	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w)); */
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1248,7 +1299,7 @@ void EDVCustomizeArchiverCreateToolBarPage(
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Create Tool Bar Stack List */
+	/* Tool Bar Stack List */
 	slist = StackListNew(
 	    parent2,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1279,9 +1330,12 @@ void EDVCustomizeArchiverCreateToolBarPage(
 	    EDV_CFG_PARM_ARCHIVER_TOOL_BAR
 	);
 
-	/* Create tool bar items from archiver operation ids */
+	/* Add the tool bar items from the Archiver operation ids */
 	opid_list = EDVArchiverOPIDListNew(NULL);
-	for(glist = opid_list; glist != NULL; glist = g_list_next(glist))
+	for(glist = opid_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
 	    opid = EDV_ARCHIVER_OPID(glist->data);
 	    if(opid == NULL)
@@ -1291,10 +1345,10 @@ void EDVCustomizeArchiverCreateToolBarPage(
 	    StackListAppend(
 		slist, name, opid->tooltip,
 		opid->button_icon_data,
-		NULL,				/* Client Data */
+		NULL,				/* No user data */
 		(gint)opid->op,			/* ID */
-		opid->flags & EDV_OPID_ALLOW_MULTIPLE,	/* Allow Multiple */
-		FALSE				/* Fixed On Target? */
+		opid->flags & EDV_OPID_ALLOW_MULTIPLE,	/* Allow multiple? */
+		FALSE				/* Not stay on target */
 	    );
 	    g_free(name);
 	}
@@ -1307,7 +1361,8 @@ void EDVCustomizeArchiverCreateToolBarPage(
  *	Creates the Archiver Appearance page.
  */
 void EDVCustomizeArchiverCreateAppearancePage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
@@ -1366,7 +1421,7 @@ void EDVCustomizeArchiverCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Nombre Del Usuario"
@@ -1400,7 +1455,7 @@ void EDVCustomizeArchiverCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Ubicacin"
@@ -1466,7 +1521,7 @@ void EDVCustomizeArchiverCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra De Instrumento"
@@ -1500,7 +1555,7 @@ void EDVCustomizeArchiverCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra De Ubicacin"
@@ -1534,7 +1589,7 @@ void EDVCustomizeArchiverCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra La Encuentre"
@@ -1568,7 +1623,7 @@ void EDVCustomizeArchiverCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra La Posicin"
@@ -1640,7 +1695,7 @@ void EDVCustomizeArchiverCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Muestre Archivo Informacin En Abierto"
