@@ -18,39 +18,45 @@
 #include "config.h"
 
 
-/* File Browser */
+/* Callbacks */
 static void EDVCustomizeBrowserKeymapsDefaultsCB(
 	keymap_list_struct *kmlist, keymap_key_struct *km,
 	gpointer data
 );
+
+/* Create Pages */
 void EDVCustomizeBrowserCreateKeymapsPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 void EDVCustomizeBrowserCreateContentsListPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 void EDVCustomizeBrowserCreateToolBarPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 void EDVCustomizeBrowserCreateAppearancePage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -74,7 +80,10 @@ static void EDVCustomizeBrowserKeymapsDefaultsCB(
 	if(ak_list == NULL)
 	    return;
 
-	for(glist = ak_list->list; glist != NULL; glist = g_list_next(glist))
+	for(glist = ak_list->list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
 	    ak = CFG_ACCELKEY(glist->data);
 	    if(ak == NULL)
@@ -95,7 +104,8 @@ static void EDVCustomizeBrowserKeymapsDefaultsCB(
  *	Creates the File Browser Keymaps page.
  */
 void EDVCustomizeBrowserCreateKeymapsPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
@@ -110,7 +120,7 @@ void EDVCustomizeBrowserCreateKeymapsPage(
 	edv_browser_opid_struct *opid;
 
 
-	/* Accelerator Keys frame */
+	/* Accelerator Keys GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Acelerador Adapta"
@@ -173,7 +183,7 @@ void EDVCustomizeBrowserCreateKeymapsPage(
 	    GList *glist, *glist2, *ak_glist = ak_list->list;
 	    cfg_accelkey_struct *ak;
 
-	    /* Iterate through Operation IDs */
+	    /* Iterate through the Operation IDs */
 	    for(glist = opid_list;
 		glist != NULL;
 		glist = g_list_next(glist)
@@ -232,18 +242,19 @@ void EDVCustomizeBrowserCreateKeymapsPage(
  *      Creates the File Browser Contents List page.
  */
 void EDVCustomizeBrowserCreateContentsListPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
 	const gint	border_major = 5,
 			border_minor = 2;
-	GtkWidget *w, *parent2;
+	GtkWidget *w, *parent2, *parent3;
 	edv_gen_opt_wref_struct *wref;
 	stack_list_struct *slist;
 
 
-	/* Display options frame */
+	/* Cell Display Options GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Las Opciones Del Despliegue De La Clula"
@@ -274,7 +285,7 @@ void EDVCustomizeBrowserCreateContentsListPage(
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Hide dir size check */
+	/* Hide Directory Size GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Esconda Tamao Gua"
@@ -303,7 +314,7 @@ void EDVCustomizeBrowserCreateContentsListPage(
 	    EDV_CFG_PARM_BROWSER_CONTENTS_HIDE_DIR_SIZE
 	);
 
-	/* Hide link size check */
+	/* Hide Link Size GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Esconda tamao del enlace"
@@ -332,7 +343,7 @@ void EDVCustomizeBrowserCreateContentsListPage(
 	    EDV_CFG_PARM_BROWSER_CONTENTS_HIDE_LINK_SIZE
 	);
 
-	/* Hide link permission check */
+	/* Hide Link Permission GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Esconda permisos del enlace"
@@ -362,7 +373,7 @@ void EDVCustomizeBrowserCreateContentsListPage(
 	);
 
 
-	/* Arrangement frame */
+	/* Arrangement GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Arreglo"
@@ -393,7 +404,30 @@ void EDVCustomizeBrowserCreateContentsListPage(
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Create contents list stack list */
+	w = gtk_hbox_new(FALSE, border_minor);
+	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
+	gtk_widget_show(w);
+	parent3 = w;
+
+	/* Auto Resize Columns GtkCheckButton */
+	w = gtk_check_button_new_with_label(
+"Automatically Resize Columns"
+	);
+	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
+	GUISetWidgetTip(
+	    w,
+"Check this to automatically resize the columns each time the list\
+ is updated"
+	);
+	gtk_widget_show(w);
+	wref = EDVGenOptWinWRefAppend(
+	    optwin,
+	    EDV_GEN_OPT_WIDGET_TOGGLE_BUTTON, w,
+	    NULL,
+	    EDV_CFG_PARM_BROWSER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS
+	);
+
+	/* Contents List Stack List */
 	slist = StackListNew(
 	    parent2,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -424,7 +458,7 @@ void EDVCustomizeBrowserCreateContentsListPage(
 	    EDV_CFG_PARM_BROWSER_CONTENTS_COLUMN
 	);
 
-	/* Create Contents List Headings Stack List */
+	/* Add the headings list */
 	StackListAppend(
 	    slist,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -452,10 +486,10 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Name",
 "Name of the object",
 #endif
-	    NULL,		/* No icon data */
-	    NULL,		/* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_NAME,
-	    FALSE, TRUE		/* No multiple, stay on target */
+	    FALSE, TRUE			/* No multiple, stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -484,10 +518,10 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Size",
 "Size of the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,		/* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_SIZE,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -516,10 +550,10 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Type",
 "MIME Type associated with the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_TYPE,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -548,10 +582,10 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Permissions",
 "Access rights to the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_PERMISSIONS,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -580,10 +614,10 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Owner",
 "User that the object belongs to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_OWNER,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -612,10 +646,10 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Group",
 "Group that the object belongs to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_GROUP,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -644,10 +678,10 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Date Access",
 "Date and time that the object was last read from or written to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_DATE_ACCESS,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -676,10 +710,10 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Date Modified",
 "Date and time that the object was last written to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_DATE_MODIFIED,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -708,19 +742,19 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Date Changed",
 "Date and time that the object was last written to or its properties were modified",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_DATE_CHANGED,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
 "Hard Links",
 "Number of hard links to the object",
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_HARD_LINKS,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -749,28 +783,28 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Linked To",
 "Link target value",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_LINKED_TO,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
 "Device Index",
 "Index of the device that the object resides on",
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_DEVICE_INDEX,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
 "Index",
 "Index on the device that the object resides at",
- 	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+ 	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_INDEX,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -799,28 +833,28 @@ void EDVCustomizeBrowserCreateContentsListPage(
 "Device Type",
 "Device major and minor number pair",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_DEVICE_TYPE,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
 "Block Size",
 "Optimul size for reading or writing a block of the object's data",
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_BLOCK_SIZE,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
 "Blocks",
 "Number of blocks allocated to the object",
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_BROWSER_COLUMN_TYPE_BLOCKS,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 
 	StackListUpdateMenus(slist);
@@ -831,7 +865,8 @@ void EDVCustomizeBrowserCreateContentsListPage(
  *	Creates the File Browser Tool Bar page.
  */
 void EDVCustomizeBrowserCreateToolBarPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
@@ -846,14 +881,14 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	edv_browser_opid_struct *opid;
 
 
-	/*GtkHBox for Tool Bar Display and Relief frames */
+	/* Display Buttons As and Buttons Relief GtkHBox */
 	w = gtk_hbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
 
 
-	/* Display Buttons AsGtkFrame */
+	/* Display Buttons As GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Despliegue Abrocha Como"
@@ -884,9 +919,10 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Text */
+	/* Text GtkRadioButton */
 	gslist = NULL;
-	w = gtk_radio_button_new_with_label(gslist,
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Texto"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -905,6 +941,7 @@ void EDVCustomizeBrowserCreateToolBarPage(
 "Text"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -914,10 +951,10 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	    EDV_CFG_PARM_BROWSER_TOOL_BAR_DISPLAY
 	);
 	wref->radio_value = TOOLBAR_DISPLAY_TEXT;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Pictures */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Pictures GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Los Retratos"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -936,6 +973,7 @@ void EDVCustomizeBrowserCreateToolBarPage(
 "Pictures"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -945,10 +983,10 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	    EDV_CFG_PARM_BROWSER_TOOL_BAR_DISPLAY
 	);
 	wref->radio_value = TOOLBAR_DISPLAY_PICTURES;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Pictures & Text */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Pictures & Text GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Los Retratos & Texto"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -967,6 +1005,7 @@ void EDVCustomizeBrowserCreateToolBarPage(
 "Pictures & Text"
 #endif
 	);
+/*	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w)); */
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -978,7 +1017,7 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	wref->radio_value = TOOLBAR_DISPLAY_PICTURES_AND_TEXT;
 
 
-	/* Buttons ReliefGtkFrame */
+	/* Buttons Relief GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Alivio De Botones"
@@ -1009,9 +1048,10 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Flush */
+	/* Flush GtkRadioButton */
 	gslist = NULL;
-	w = gtk_radio_button_new_with_label(gslist,
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Rubor"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1030,6 +1070,7 @@ void EDVCustomizeBrowserCreateToolBarPage(
 "Flush"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1039,10 +1080,10 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	    EDV_CFG_PARM_BROWSER_TOOL_BAR_RELIEF
 	);
 	wref->radio_value = TOOLBAR_RELIEF_NONE;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Half */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Half GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Mitad"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1061,6 +1102,7 @@ void EDVCustomizeBrowserCreateToolBarPage(
 "Half"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1070,10 +1112,10 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	    EDV_CFG_PARM_BROWSER_TOOL_BAR_RELIEF
 	);
 	wref->radio_value = TOOLBAR_RELIEF_HALF;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Raised */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Raised GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Levantado"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1092,6 +1134,7 @@ void EDVCustomizeBrowserCreateToolBarPage(
 "Raised"
 #endif
 	);
+/*	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w)); */
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1104,7 +1147,7 @@ void EDVCustomizeBrowserCreateToolBarPage(
 
 
 
-	/* ArrangementGtkFrame */
+	/* Arrangement GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Arreglo"
@@ -1135,7 +1178,7 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Create Tool Bar Stack List */
+	/* Tool Bar Stack List */
 	slist = StackListNew(
 	    parent2,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1166,7 +1209,7 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	    EDV_CFG_PARM_BROWSER_TOOL_BAR
 	);
 
-	/* Create tool bar items from browser operation ids */
+	/* Add the tool bar items from the browser operation ids */
 	opid_list = EDVBrowserOPIDListNew(NULL);
 	for(glist = opid_list;
 	    glist != NULL;
@@ -1181,10 +1224,10 @@ void EDVCustomizeBrowserCreateToolBarPage(
 	    StackListAppend(
 		slist, name, opid->tooltip,
 		opid->button_icon_data,
-		NULL,				/* Client Data */
+		NULL,				/* No user data */
 		(gint)opid->op,			/* ID */
-		opid->flags & EDV_OPID_ALLOW_MULTIPLE,	/* Allow Multiples? */
-		FALSE				/* Fixed On Target? */
+		opid->flags & EDV_OPID_ALLOW_MULTIPLE,	/* Allow multiples? */
+		FALSE				/* Not stay on target */
 	    );
 	    g_free(name);
 	}
@@ -1198,7 +1241,8 @@ void EDVCustomizeBrowserCreateToolBarPage(
  *	Creates the File Browser Appearance page.
  */
 void EDVCustomizeBrowserCreateAppearancePage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
@@ -1208,20 +1252,20 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	edv_gen_opt_wref_struct *wref;
 
 
-	/*GtkHBox to separate two columns */
+	/* GtkHBox to separate two columns */
 	w = gtk_hbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent = w;
 
 
-	/* First columnGtkVBox */
+	/* First column GtkVBox */
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Show In Title BarGtkFrame */
+	/* Show In Title Bar GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Muestre En La Barra Del Ttulo"
@@ -1257,7 +1301,7 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Nombre Del Usuario"
@@ -1291,7 +1335,7 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Ubicacin"
@@ -1321,7 +1365,7 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	);
 
 
-	/* DisplayGtkFrame */
+	/* Display GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Despliegue"
@@ -1357,7 +1401,7 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra De Instrumento"
@@ -1391,7 +1435,7 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra De Ubicacin"
@@ -1425,7 +1469,7 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra El Monte"
@@ -1459,7 +1503,7 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra La Encuentre"
@@ -1493,7 +1537,7 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra La Posicin"
@@ -1523,14 +1567,14 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	);
 
 
-	/* Second columnGtkVBox */
+	/* Second column GtkVBox */
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
 
 
-	/* FilterGtkFrame */
+	/* Show GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Filtro"
@@ -1566,7 +1610,7 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Los Objetos Escondidos"
@@ -1600,7 +1644,7 @@ void EDVCustomizeBrowserCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Ningn Acceso Se Opone"
