@@ -18,25 +18,31 @@
 #include "config.h"
 
 
-/* Recycle Bin */
+/* Callbacks */
 static void EDVCustomizeRecBinKeymapsDefaultsCB(
 	keymap_list_struct *kmlist, keymap_key_struct *km,
 	gpointer data
 );
+
+/* Create Pages */
 void EDVCustomizeRecBinCreateKeymapsPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 void EDVCustomizeRecBinCreateContentsListPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 void EDVCustomizeRecBinCreateToolBarPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 void EDVCustomizeRecBinCreateAppearancePage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 );
 
@@ -74,7 +80,10 @@ static void EDVCustomizeRecBinKeymapsDefaultsCB(
 	if(ak_list == NULL)                           
 	    return;
 		   
-	for(glist = ak_list->list; glist != NULL; glist = g_list_next(glist))
+	for(glist = ak_list->list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
 	    ak = CFG_ACCELKEY(glist->data);
 	    if(ak == NULL)
@@ -95,7 +104,8 @@ static void EDVCustomizeRecBinKeymapsDefaultsCB(
  *	Creates the Recycle Bin Keymaps page.
  */
 void EDVCustomizeRecBinCreateKeymapsPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
@@ -109,7 +119,7 @@ void EDVCustomizeRecBinCreateKeymapsPage(
 	keymap_list_struct *kmlist;
 	edv_recbin_opid_struct *opid;
 
-	/* Accelerator Keys frame */
+	/* Accelerator Keys GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Acelerador Adapta"
@@ -229,18 +239,19 @@ void EDVCustomizeRecBinCreateKeymapsPage(
  *	Creates the Recycle Bin Contents List page.
  */
 void EDVCustomizeRecBinCreateContentsListPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
 	const gint	border_major = 5,
 			border_minor = 2;
-	GtkWidget *w, *parent2;
+	GtkWidget *w, *parent2, *parent3;
 	edv_gen_opt_wref_struct *wref;
 	stack_list_struct *slist;
 
 
-	/* Display options frame */
+	/* Cell Display Options GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Las Opciones Del Despliegue De La Clula"
@@ -271,7 +282,7 @@ void EDVCustomizeRecBinCreateContentsListPage(
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Hide dir size check */
+	/* Hide Directory Size GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Esconda Tamao Gua"
@@ -300,7 +311,7 @@ void EDVCustomizeRecBinCreateContentsListPage(
 	    EDV_CFG_PARM_RECBIN_CONTENTS_HIDE_DIR_SIZE
 	);
 
-	/* Hide link size check */
+	/* Hide Link Size GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Esconda tamao del enlace"
@@ -329,7 +340,7 @@ void EDVCustomizeRecBinCreateContentsListPage(
 	    EDV_CFG_PARM_RECBIN_CONTENTS_HIDE_LINK_SIZE
 	);
 
-	/* Hide link permission check */
+	/* Hide Link Permissions GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Esconda permisos del enlace"
@@ -359,7 +370,7 @@ void EDVCustomizeRecBinCreateContentsListPage(
 	);
 
 
-	/* Arrangement frame */
+	/* Arrangement GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Arreglo"
@@ -390,7 +401,30 @@ void EDVCustomizeRecBinCreateContentsListPage(
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Create contents list stack list */
+	w = gtk_hbox_new(FALSE, border_minor);
+	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
+	gtk_widget_show(w);
+	parent3 = w;
+
+	/* Automatically Resize Columns GtkCheckButton */
+	w = gtk_check_button_new_with_label(
+"Automatically Resize Columns"
+	);
+	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
+	GUISetWidgetTip(
+	    w,
+"Check this to automatically resize the columns each time the list\
+ is updated"
+	);
+	gtk_widget_show(w);
+	wref = EDVGenOptWinWRefAppend(
+	    optwin,
+	    EDV_GEN_OPT_WIDGET_TOGGLE_BUTTON, w,
+	    NULL,
+	    EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS
+	);
+
+	/* Contents List Stack List */
 	slist = StackListNew(
 	    parent2,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -421,7 +455,16 @@ void EDVCustomizeRecBinCreateContentsListPage(
 	    EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN
 	);
 
-	/* Create Contents List Headings Stack List */
+	/* Add the headings list */
+	StackListAppend(
+	    slist,
+"Index",
+"Recycled object index number",
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
+	    EDV_RECBIN_COLUMN_TYPE_INDEX,
+	    FALSE, FALSE		/* No multiple, no stay on target */
+	);
 	StackListAppend(
 	    slist,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -449,10 +492,10 @@ void EDVCustomizeRecBinCreateContentsListPage(
 "Name",
 "Name of the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_NAME,
-	    FALSE, TRUE         /* No multiple, stay on target */
+	    FALSE, TRUE			/* No multiple, stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -481,10 +524,10 @@ void EDVCustomizeRecBinCreateContentsListPage(
 "Size",
 "Size of the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_SIZE,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -513,10 +556,10 @@ void EDVCustomizeRecBinCreateContentsListPage(
 "Type",
 "MIME Type associated with the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_TYPE,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -545,10 +588,10 @@ void EDVCustomizeRecBinCreateContentsListPage(
 "Permissions",
 "Access rights to the object",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_PERMISSIONS,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -577,10 +620,10 @@ void EDVCustomizeRecBinCreateContentsListPage(
 "Owner",
 "User that the object belongs to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_OWNER,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -609,10 +652,10 @@ void EDVCustomizeRecBinCreateContentsListPage(
 "Group",
 "Group that the object belongs to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_GROUP,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -641,10 +684,10 @@ void EDVCustomizeRecBinCreateContentsListPage(
 "Date Access",
 "Date and time that the object was last read from or written to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_DATE_ACCESS,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -673,10 +716,10 @@ void EDVCustomizeRecBinCreateContentsListPage(
 "Date Modified",
 "Date and time that the object was last written to",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_DATE_MODIFIED,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -705,19 +748,19 @@ void EDVCustomizeRecBinCreateContentsListPage(
 "Date Changed",
 "Date and time that the object was last written to or its properties were modified",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_DATE_CHANGED,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
 "Date Deleted",
-"Date that the object was deleted on",
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+"Date and time that the object was deleted on",
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_DATE_DELETED,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
@@ -746,37 +789,28 @@ void EDVCustomizeRecBinCreateContentsListPage(
 "Linked To",
 "Link target value",
 #endif
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_LINKED_TO,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
 "Original Location",
 "Location of the object before it was deleted",
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION,
-	    FALSE, FALSE        /* No multiple, no stay on target */
-	);
-	StackListAppend(
-	    slist,
-"Index",
-"Recycled object index number",
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
-	    EDV_RECBIN_COLUMN_TYPE_INDEX,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
 "Capacity Used",
 "Percentage of the recycle bin capacity that this object takes up",
-	    NULL,               /* No icon data */
-	    NULL,               /* No client data */
+	    NULL,			/* No icon data */
+	    NULL,			/* No user data */
 	    EDV_RECBIN_COLUMN_TYPE_CAPACITY_USED,
-	    FALSE, FALSE        /* No multiple, no stay on target */
+	    FALSE, FALSE		/* No multiple, no stay on target */
 	);
 
 	StackListUpdateMenus(slist);
@@ -787,7 +821,8 @@ void EDVCustomizeRecBinCreateContentsListPage(
  *	Creates the Recycle Bin Tool Bar page.
  */
 void EDVCustomizeRecBinCreateToolBarPage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
@@ -802,13 +837,12 @@ void EDVCustomizeRecBinCreateToolBarPage(
 	edv_recbin_opid_struct *opid;
 
 
-	/* Hbox for toolbar display and relief frames */
+	/* Display Buttons As and Buttons Relief GtkHBox */
 	w = gtk_hbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
 
-
 	/* Display Buttons As GtkFrame */
 	w = gtk_frame_new(
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -840,9 +874,10 @@ void EDVCustomizeRecBinCreateToolBarPage(
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Text */
+	/* Text GtkRadioButton */
 	gslist = NULL;
-	w = gtk_radio_button_new_with_label(gslist,
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Texto"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -861,6 +896,7 @@ void EDVCustomizeRecBinCreateToolBarPage(
 "Text"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -870,10 +906,10 @@ void EDVCustomizeRecBinCreateToolBarPage(
 	    EDV_CFG_PARM_RECBIN_TOOL_BAR_DISPLAY
 	);
 	wref->radio_value = TOOLBAR_DISPLAY_TEXT;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Pictures */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Pictures GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Los Retratos"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -892,6 +928,7 @@ void EDVCustomizeRecBinCreateToolBarPage(
 "Pictures"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -901,10 +938,10 @@ void EDVCustomizeRecBinCreateToolBarPage(
 	    EDV_CFG_PARM_RECBIN_TOOL_BAR_DISPLAY
 	);
 	wref->radio_value = TOOLBAR_DISPLAY_PICTURES;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Pictures & Text */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Pictures & Text GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Los Retratos & Texto"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -923,6 +960,7 @@ void EDVCustomizeRecBinCreateToolBarPage(
 "Pictures & Text"
 #endif
 	);
+/*	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w)); */
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -965,9 +1003,10 @@ void EDVCustomizeRecBinCreateToolBarPage(
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Flush */
+	/* Flush GtkRadioButton */
 	gslist = NULL;
-	w = gtk_radio_button_new_with_label(gslist,
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Rubor"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -986,6 +1025,7 @@ void EDVCustomizeRecBinCreateToolBarPage(
 "Flush"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -995,10 +1035,10 @@ void EDVCustomizeRecBinCreateToolBarPage(
 	    EDV_CFG_PARM_RECBIN_TOOL_BAR_RELIEF
 	);
 	wref->radio_value = TOOLBAR_RELIEF_NONE;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Half */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Half GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Mitad"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1017,6 +1057,7 @@ void EDVCustomizeRecBinCreateToolBarPage(
 "Half"
 #endif
 	);
+	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1026,10 +1067,10 @@ void EDVCustomizeRecBinCreateToolBarPage(
 	    EDV_CFG_PARM_RECBIN_TOOL_BAR_RELIEF
 	);
 	wref->radio_value = TOOLBAR_RELIEF_HALF;
-	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w));
 
-	/* Raised */
-	w = gtk_radio_button_new_with_label(gslist,
+	/* Raised GtkRadioButton */
+	w = gtk_radio_button_new_with_label(
+	    gslist,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Levantado"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1048,6 +1089,7 @@ void EDVCustomizeRecBinCreateToolBarPage(
 "Raised"
 #endif
 	);
+/*	gslist = gtk_radio_button_group(GTK_RADIO_BUTTON(w)); */
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	wref = EDVGenOptWinWRefAppend(
@@ -1090,7 +1132,7 @@ void EDVCustomizeRecBinCreateToolBarPage(
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Create Tool Bar Stack List */
+	/* Tool Bar Stack List */
 	slist = StackListNew(
 	    parent2,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1121,9 +1163,12 @@ void EDVCustomizeRecBinCreateToolBarPage(
 	    EDV_CFG_PARM_RECBIN_TOOL_BAR
 	);
 
-	/* Create tool bar items from recycle bin operation ids */
+	/* Add the tool bar items from the Recycle Bin operation ids */
 	opid_list = EDVRecBinOPIDListNew(NULL);
-	for(glist = opid_list; glist != NULL; glist = g_list_next(glist))
+	for(glist = opid_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
 	    opid = EDV_RECBIN_OPID(glist->data);
 	    if(opid == NULL)
@@ -1133,10 +1178,10 @@ void EDVCustomizeRecBinCreateToolBarPage(
 	    StackListAppend(
 		slist, name, opid->tooltip,
 		opid->button_icon_data,
-		NULL,				/* Client Data */
+		NULL,				/* No user data */
 		(gint)opid->op,			/* ID */
-		opid->flags & EDV_OPID_ALLOW_MULTIPLE,	/* Allow Multiple? */
-		FALSE				/* Fixed On Target? */
+		opid->flags & EDV_OPID_ALLOW_MULTIPLE,	/* Allow multiples? */
+		FALSE				/* Not fixed on target */
 	    );
 	    g_free(name);
 	}
@@ -1150,7 +1195,8 @@ void EDVCustomizeRecBinCreateToolBarPage(
  *	Creates the Recycle Bin Appearance page.
  */
 void EDVCustomizeRecBinCreateAppearancePage(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	GtkWidget *parent
 )
 {
@@ -1160,14 +1206,14 @@ void EDVCustomizeRecBinCreateAppearancePage(
 	edv_gen_opt_wref_struct *wref;
 
 
-	/* Hbox to separate two columns */
+	/* GtkHBox to separate two columns */
 	w = gtk_hbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent = w;
 
 
-	/* First column vbox */
+	/* First column GtkVBox */
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
@@ -1210,7 +1256,7 @@ void EDVCustomizeRecBinCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Nombre Del Usuario"
@@ -1276,7 +1322,7 @@ void EDVCustomizeRecBinCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra De Instrumento"
@@ -1310,7 +1356,7 @@ void EDVCustomizeRecBinCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra La Encuentre"
@@ -1344,7 +1390,7 @@ void EDVCustomizeRecBinCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Barra La Posicin"
@@ -1378,7 +1424,7 @@ void EDVCustomizeRecBinCreateAppearancePage(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Check Button */
+	/* GtkCheckButton */
 	w = gtk_check_button_new_with_label(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Icono De Sobremesa"
