@@ -74,7 +74,8 @@ void EDVDevicesEditWinFetchValues(
 	edv_device_edit_dlg_struct *d, const gint dev_num
 );
 void EDVDevicesEditWinDeviceRemovedCB(
-	edv_device_edit_dlg_struct *d, gint dev_num
+	edv_device_edit_dlg_struct *d,
+	const gint dev_num
 );
 
 static edv_device_icon_picker_struct *EDVDevicesEditIconNew(
@@ -1146,7 +1147,8 @@ void EDVDevicesEditWinFetchValues(
  *	Device removed signal callback.
  */
 void EDVDevicesEditWinDeviceRemovedCB(
-	edv_device_edit_dlg_struct *d, gint dev_num
+	edv_device_edit_dlg_struct *d,
+	const gint dev_num
 )
 {
 	if(d == NULL)
