@@ -105,19 +105,20 @@ void EDVDevicesListWinReconfiguredNotifyCB(
 );
 void EDVDevicesListWinMountNotifyCB(
 	edv_devices_list_win_struct *lw,
-	gint dev_num, edv_device_struct *dev,
-	gboolean is_mounted
+	const gint dev_num, edv_device_struct *d,
+	const gboolean is_mounted
 );
 void EDVDevicesListWinDeviceAddedCB(
 	edv_devices_list_win_struct *lw,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *d
 );
 void EDVDevicesListWinDeviceModifiedCB(
 	edv_devices_list_win_struct *lw,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *d
 );
 void EDVDevicesListWinDeviceRemovedCB(
-	edv_devices_list_win_struct *lw, gint dev_num
+	edv_devices_list_win_struct *lw,
+	const gint dev_num
 );
 
 edv_devices_list_win_struct *EDVDevicesListWinNew(
@@ -722,7 +723,7 @@ static void EDVDevicesListWinPropertiesCB(GtkWidget *widget, gpointer data)
 		EDVObjectUpdateLinkFlags(obj);
 
 		/* Create a new Properties Dialog */
-		EDVNewPropertiesDialogPage(
+		EDVNewPropertiesDialogVFSPage(
 		    core,
 		    obj,
 		    "Device",			/* Page Name */
@@ -1424,7 +1425,15 @@ static void EDVDevicesListWinUpdateDisplay(
 {
 	const gint	border_major = 5,
 			border_minor = 2;
+	gint font_size;
+	const gchar *font_encoding;
+	gchar	*font_name_h1_bold,
+		*font_name_h1,
+		*font_name_h2_bold,
+		*font_name_h2;
+	GdkFont *font;
 	GtkRcStyle *rcstyle, *standard_rcstyle;
+	GtkStyle *style;
 	GtkWidget *w, *parent, *parent2, *parent3, *parent4;
 	const cfg_item_struct *cfg_list;
 	edv_core_struct *core;
@@ -1433,9 +1442,6 @@ static void EDVDevicesListWinUpdateDisplay(
 	    return;
 
 	core = lw->core;
-	if(core == NULL)
-	    return;
-
 	cfg_list = core->cfg_list;
 	standard_rcstyle = core->standard_rcstyle;
 
@@ -1488,7 +1494,54 @@ static void EDVDevicesListWinUpdateDisplay(
 	if(parent == NULL)
 	    return;
 
-	/* Create new client hbox for multiple columns */
+	style = gtk_widget_get_style(parent);
+	if(style == NULL)
+	    return;
+
+	/* Get the base font size */
+	font = style->font;
+	font_size = GDK_FONT_GET_FONT_NAME_SIZE(font);
+	if(font_size < 3)
+	    font_size = 3;
+
+	/* Format the font names */
+#if defined(PROG_LANGUAGE_POLISH)
+	font_encoding = "iso8859-2";
+#else
+	font_encoding = "iso8859-1";
+#endif
+
+	font_name_h1_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+	    font_size + 2,
+	    font_encoding
+	);
+	font_name_h1 = g_strdup_printf(
+"-adobe-helvetica-medium-r-normal-*-%i-*-*-*-*-*-%s",
+	    font_size + 2,
+	    font_encoding
+	);
+	font_name_h2_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+	    font_size,
+	    font_encoding
+	);
+	font_name_h2 = g_strdup_printf(
+"-adobe-helvetica-medium-r-normal-*-%i-*-*-*-*-*-%s",
+	    font_size,
+	    font_encoding
+	);
+
+#define CLEANUP_RETURN	{		\
+ g_free(font_name_h1_bold);		\
+ g_free(font_name_h1);			\
+ g_free(font_name_h2_bold);		\
+ g_free(font_name_h2);			\
+					\
+ return;				\
+}
+
+	/* Create the new client GtkHBox for multiple columns */
 	lw->display_client = w = gtk_hbox_new(FALSE, border_major);
 	gtk_container_border_width(GTK_CONTAINER(w), border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
@@ -1496,14 +1549,14 @@ static void EDVDevicesListWinUpdateDisplay(
 	parent2 = w;
 
 
-	/* Left column vbox */
+	/* Left column GtkVBox */
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent2), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
 	parent3 = w;
 
 
-	/* HBox for icon and name line */
+	/* GtkHBox for icon and name line */
 	w = gtk_hbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
@@ -1559,9 +1612,7 @@ static void EDVDevicesListWinUpdateDisplay(
 	}
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
-	);
+	rcstyle->font_name = STRDUP(font_name_h1_bold);
 	gtk_widget_modify_style(w, rcstyle);
 	gtk_widget_show(w);
 	GTK_RC_STYLE_UNREF(rcstyle);
@@ -1575,9 +1626,7 @@ static void EDVDevicesListWinUpdateDisplay(
 
 	/* Device path label */
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-	);
+	rcstyle->font_name = STRDUP(font_name_h2);
 	w = gtk_label_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Sendero Del Artefacto: "
@@ -1596,9 +1645,7 @@ static void EDVDevicesListWinUpdateDisplay(
 	if(!STRISEMPTY(dev->device_path))
 	{
 	    rcstyle = gtk_rc_style_new();
-	    rcstyle->font_name = STRDUP(
-"-adobe-courier-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-	    );
+	    rcstyle->font_name = STRDUP(font_name_h2);
 	    lw->dev_device_path_label = w = gtk_label_new(
 		dev->device_path
 	    );
@@ -1617,9 +1664,7 @@ static void EDVDevicesListWinUpdateDisplay(
 
 	/* Mount path label */
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-	);
+	rcstyle->font_name = STRDUP(font_name_h2);
 	w = gtk_label_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Monte Sendero: "
@@ -1638,16 +1683,14 @@ static void EDVDevicesListWinUpdateDisplay(
 	if(!STRISEMPTY(dev->mount_path))
 	{
 	    rcstyle = gtk_rc_style_new();
-	    rcstyle->font_name = STRDUP(
-"-adobe-courier-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-	    );
+	    rcstyle->font_name = STRDUP(font_name_h2);
 	    lw->dev_mount_path_label = w = gtk_label_new(
 		dev->mount_path
 	    );
 	    gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	    gtk_widget_modify_style(w, rcstyle);
-	    gtk_widget_show(w);
 	    GTK_RC_STYLE_UNREF(rcstyle);
+	    gtk_widget_show(w);
 	}
 
 	/* HBox for mount, eject, and properties buttons */
@@ -2067,8 +2110,15 @@ static void EDVDevicesListWinUpdateDisplay(
 	{
 	    w = gtk_label_new("(Device Not Mounted)");
 	    gtk_box_pack_start(GTK_BOX(parent3), w, TRUE, FALSE, 0);
+	    rcstyle = gtk_rc_style_new();
+	    rcstyle->font_name = STRDUP(font_name_h1_bold);
+	    gtk_widget_modify_style(w, rcstyle);
+	    GTK_RC_STYLE_UNREF(rcstyle);
 	    gtk_widget_show(w);
 	}
+
+	CLEANUP_RETURN;
+#undef CLEANUP_RETURN
 }
 
 
@@ -2097,10 +2147,8 @@ void EDVDevicesListWinSetRow(
 	if((lw == NULL) || (dev == NULL))
 	    return;
 
-	clist = (GtkCList *)lw->devices_clist;
+	clist = GTK_CLIST(lw->devices_clist);
 	core = lw->core;
-	if((clist == NULL) || (core == NULL))
-	    return;
 
 	/* Realize the Device so that its icon pixmap & mask will
 	 * be available
@@ -2397,14 +2445,12 @@ void EDVDevicesListWinReconfiguredNotifyCB(
  */
 void EDVDevicesListWinMountNotifyCB(
 	edv_devices_list_win_struct *lw,
-	gint dev_num, edv_device_struct *dev,
-	gboolean is_mounted
+	const gint dev_num, edv_device_struct *d,
+	const gboolean is_mounted
 )
 {
-	/* Just forward this to the device modified callback */
-	EDVDevicesListWinDeviceModifiedCB(
-	    lw, dev_num, dev
-	);
+	/* Forward this to the device modified callback */
+	EDVDevicesListWinDeviceModifiedCB(lw, dev_num, d);
 }
 
 /*
@@ -2412,32 +2458,28 @@ void EDVDevicesListWinMountNotifyCB(
  */
 void EDVDevicesListWinDeviceAddedCB(
 	edv_devices_list_win_struct *lw,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *d
 )
 {
-	gint row, new_row;
+	gint row, new_row, ncolumns;
 	gchar **strv;
 	GtkCList *clist;
 
-	if((lw == NULL) || (dev == NULL))
+	if((lw == NULL) || (d == NULL))
 	    return;
 
-	clist = (GtkCList *)lw->devices_clist;
-	if(clist == NULL)
-	    return;
-
-	if(clist->columns < 1)
-	    return;
+	clist = GTK_CLIST(lw->devices_clist);
+	ncolumns = MAX(clist->columns, 1);
 
 	/* The added device index corresponds to the GtkCList row */
 	row = dev_num;
 
 	/* Add the new device to the GtkCList */
-	strv = (gchar **)g_malloc(clist->columns * sizeof(gchar *));
+	strv = (gchar **)g_malloc(ncolumns * sizeof(gchar *));
 	if(strv != NULL)
 	{
 	    gint i;
-	    for(i = 0; i < clist->columns; i++)
+	    for(i = 0; i < ncolumns; i++)
 		strv[i] = "";
 	}
 	if(row >= clist->rows)
@@ -2450,7 +2492,7 @@ void EDVDevicesListWinDeviceAddedCB(
 	if(new_row < 0)
 	    return;
 
-	EDVDevicesListWinSetRow(lw, new_row, dev);
+	EDVDevicesListWinSetRow(lw, new_row, d);
 
 	EDVDevicesListWinUpdateMenus(lw);
 }
@@ -2460,18 +2502,16 @@ void EDVDevicesListWinDeviceAddedCB(
  */
 void EDVDevicesListWinDeviceModifiedCB(
 	edv_devices_list_win_struct *lw,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *d
 )
 {
 	gint row;
 	GtkCList *clist;
 
-	if((lw == NULL) || (dev == NULL))
+	if((lw == NULL) || (d == NULL))
 	    return;
 
-	clist = (GtkCList *)lw->devices_clist;
-	if(clist == NULL)
-	    return;
+	clist = GTK_CLIST(lw->devices_clist);
 
 	/* The modified device index corresponds to the GtkCList row */
 	row = dev_num;
@@ -2480,13 +2520,13 @@ void EDVDevicesListWinDeviceModifiedCB(
 	    const gint sel_row = EDVCListGetSelectedLast(clist, NULL);
 
 	    /* Update the GtkCList row corresponding to this device */
-	    EDVDevicesListWinSetRow(lw, row, dev);
+	    EDVDevicesListWinSetRow(lw, row, d);
 
 	    /* Is this device currently selected? */
 	    if(row == sel_row)
 	    {
 		/* Update the displayed device info */
-		EDVDevicesListWinUpdateDisplay(lw, dev);
+		EDVDevicesListWinUpdateDisplay(lw, d);
 	    }
 	}
 
@@ -2497,7 +2537,8 @@ void EDVDevicesListWinDeviceModifiedCB(
  *	Device removed notify.
  */
 void EDVDevicesListWinDeviceRemovedCB(
-	edv_devices_list_win_struct *lw, gint dev_num
+	edv_devices_list_win_struct *lw,
+	const gint dev_num
 )
 {
 	gint row;
@@ -2506,9 +2547,7 @@ void EDVDevicesListWinDeviceRemovedCB(
 	if(lw == NULL)
 	    return;
 
-	clist = (GtkCList *)lw->devices_clist;
-	if(clist == NULL)
-	    return;
+	clist = GTK_CLIST(lw->devices_clist);
 
 	/* The removed device index corresponds to the GtkCList row */
 	row = dev_num;
