@@ -40,16 +40,27 @@ Usage: download.front <source_url> <target_path> [options] [GUI_options]\n\
 \n\
     The [options] can be any of the following:\n\
 \n\
-        -b, --beep              Beep when the download has been completed.\n\
         -c, --confirm           Query the user for confirmation before\n\
                                 downloading.\n\
+        -b, --beep              Beep when the download has been\n\
+                                completed.\n\
+        -k, --keep-dialog       Keep the dialog mapped after the\n\
+                                download has completed.\n\
+\n\
+        -m, --original-name     Maintain the original name of the object\n\
+                                even with tokens, control, and wildcard\n\
+                                characters.\n\
+\n\
+        -l, --last              (Re)download the last object.\n\
+\n\
         -o, --open              Open the object afterwards (only if the\n\
                                 download was successful and complete).\n\
-        -l, --last              (Re)download the last object.\n\
+\n\
         -i <ms>                 Check download progress and update\n\
                                 messages interval in milliseconds\n\
                                 (default is 1000).\n\
-        --help                  Prints (this) help screen and exits.\n\
+\n\
+        --help                  Prints this help screen and exits.\n\
         --version               Prints version information and exits.\n\
 \n\
     The [GUI_options] can be any options standard to your GUI,\n\
