@@ -54,6 +54,18 @@ static gchar *DownloadBrowseTargetPathCB(
 	gpointer d, gpointer data, gint prompt_num
 );
 
+static void DownloadFileSelectorCreatedCB(
+        const gchar *path, gpointer data
+);
+static void DownloadFileSelectorModifiedCB(
+        const gchar *old_path,
+        const gchar *new_path,
+        gpointer data
+);
+static void DownloadFileSelectorDeletedCB(
+        const gchar *path, gpointer data
+);
+
 static gulong DownloadTryGetTotalLength(FILE *fp);
 static gint DownloadMonitor(
 	edv_context_struct *ctx,
@@ -226,6 +238,46 @@ static gchar *DownloadBrowseTargetPathCB(
 	return((response && (npaths > 0)) ? paths_list[0] : NULL);
 }
 
+
+/*
+ *      File selector created callback.
+ */
+static void DownloadFileSelectorCreatedCB(
+        const gchar *path, gpointer data
+) 
+{
+	edv_context_struct *ctx = EDV_CONTEXT(data);
+        EDVNotifyQueueObjectAdded(ctx, path);
+        EDVContextFlush(ctx);
+}
+
+/*
+ *      File selector changed callback.
+ */
+static void DownloadFileSelectorModifiedCB(
+        const gchar *old_path,
+        const gchar *new_path,
+        gpointer data
+)
+{
+	edv_context_struct *ctx = EDV_CONTEXT(data);
+        EDVNotifyQueueObjectModified(ctx, old_path, new_path);
+        EDVContextFlush(ctx);
+}
+
+/*
+ *      File selector deleted callback.
+ */
+static void DownloadFileSelectorDeletedCB(
+        const gchar *path, gpointer data
+) 
+{
+	edv_context_struct *ctx = EDV_CONTEXT(data);
+        EDVNotifyQueueObjectRemoved(ctx, path);
+        EDVContextFlush(ctx);
+}
+
+
 /*
  *	Reads the first 1024 bytes (or less) of the file specified by
  *	fp, searching for the total length header (prefixed by the
@@ -1712,6 +1764,16 @@ int main(int argc, char *argv[])
 	ctx = EDVContextNew();
 	EDVContextLoadConfigurationFile(ctx, NULL);
 
+        /* Set the file selector callbacks */
+        FileBrowserSetObjectCreatedCB(
+            DownloadFileSelectorCreatedCB, ctx
+        );
+        FileBrowserSetObjectModifiedCB(
+            DownloadFileSelectorModifiedCB, ctx
+        );
+        FileBrowserSetObjectDeletedCB(
+            DownloadFileSelectorDeletedCB, ctx
+        );
 
 	/* (Re)download the last object? */
 	if(download_last_object)
