@@ -85,10 +85,10 @@ void EditCListRemoveRow(editclist_struct *ec, gint row);
 void EditCListClear(editclist_struct *ec);
 
 void EditCListSetRowData(
-	editclist_struct *ec, gint row,
+	editclist_struct *ec, const gint row,
 	gpointer data, GtkDestroyNotify destroy_func_cb
 );
-gpointer EditCListGetRowData(editclist_struct *ec, gint row);
+gpointer EditCListGetRowData(editclist_struct *ec, const gint row);
 
 /* Front Ends */
 editclist_struct *EditCListNew(
@@ -993,10 +993,20 @@ void EditCListClear(editclist_struct *ec)
 
 
 /*
- *	Sets Edit CList's row data.
+ *	Sets the Edit CList's row data.
+ *
+ *	The ec specifies the Edit CList.
+ *
+ *	The row specifies the row index.
+ *
+ *	The data specifies the row data.
+ *
+ *	The destroy_func_cb specifies the destroy data callback
+ *	function. If destroy_func_cb is NULL then no destroy data
+ *	callback function will be set.
  */
 void EditCListSetRowData(
-	editclist_struct *ec, gint row,
+	editclist_struct *ec, const gint row,
 	gpointer data, GtkDestroyNotify destroy_func_cb
 )
 {
@@ -1020,7 +1030,7 @@ void EditCListSetRowData(
 /*
  *	Gets the Edit CList's row data.
  */
-gpointer EditCListGetRowData(editclist_struct *ec, gint row)
+gpointer EditCListGetRowData(editclist_struct *ec, const gint row)
 {
 	GtkCList *clist = (GtkCList *)EDITCLIST_CLIST(ec);
 	if(clist == NULL)
