@@ -125,10 +125,10 @@ extern void EditCListRemoveRow(editclist_struct *ec, gint row);
 extern void EditCListClear(editclist_struct *ec);
 
 extern void EditCListSetRowData(
-	editclist_struct *ec, gint row,
+	editclist_struct *ec, const gint row,
 	gpointer data, GtkDestroyNotify destroy_func_cb
 );
-extern gpointer EditCListGetRowData(editclist_struct *ec, gint row);
+extern gpointer EditCListGetRowData(editclist_struct *ec, const gint row);
 
 extern editclist_struct *EditCListNew(
 	GtkWidget *parent,		/* GtkBox or GtkContainer */
