@@ -1506,12 +1506,55 @@ To:\n\
 			    REPORT_ERROR_QUERY_CONTINUE_ADDING
 			}
 		    }
-		    /* Destination is some other type of object
-		     * (not a file, directory, or link)
+		    /* Destination is some other type of object that
+		     * is not supported by the PKZip format
 		     */
 		    else
 		    {
-			/* Ignore this object type */
+			if(*status == 0)
+			{
+			    const gchar *error_msg =
+"This type of object is not supported by the PKZip format";
+			    gchar *msg;
+#ifdef S_ISCHR
+			    if(S_ISCHR(m))
+				error_msg = 
+"Character devices are not supported by the PKZip format";
+#endif
+#ifdef S_ISBLK
+			    if(S_ISBLK(m))
+				error_msg = 
+"Block devices are not supported by the PKZip format";
+#endif
+#ifdef S_ISFIFO
+			    if(S_ISFIFO(m))
+				error_msg = 
+"FIFO pipes are not supported by the PKZip format";
+#endif
+#ifdef S_ISSOCK
+			    if(S_ISSOCK(m))
+				error_msg = 
+"Sockets are not supported by the PKZip format";
+#endif
+			    msg = g_strdup_printf(
+"Unable to add:\n\
+\n\
+    %s\n\
+\n\
+To:\n\
+\n\
+    %s\n\
+\n\
+%s.",
+				path,
+				arch_path,
+				error_msg
+			    );
+			    EDVArchAddCopyErrorMessage(core, msg);
+			    g_free(msg);
+			    *status = -2;
+			}
+			return;
 		    }
 		}
 	    }
@@ -1559,10 +1602,55 @@ To:\n\
 		REPORT_ERROR_QUERY_CONTINUE_ADDING
 	    }
 	}
-	/* Destination is some other type of object */
+	/* Destination is some other type of object not supported by
+	 * the PKZIP format
+	 */
 	else
 	{
-	    /* Ignore this object type */
+	    if(*status == 0)
+	    {
+		const gchar *error_msg =
+"This type of object is not supported by the PKZip format";
+		gchar *msg;
+#ifdef S_ISCHR
+		if(S_ISCHR(m))
+		    error_msg = 
+"Character devices are not supported by the PKZip format";
+#endif
+#ifdef S_ISBLK
+		if(S_ISBLK(m))
+		    error_msg = 
+"Block devices are not supported by the PKZip format";
+#endif
+#ifdef S_ISFIFO
+		if(S_ISFIFO(m))
+		    error_msg = 
+"FIFO pipes are not supported by the PKZip format";
+#endif
+#ifdef S_ISSOCK
+		if(S_ISSOCK(m))
+		    error_msg = 
+"Sockets are not supported by the PKZip format";
+#endif
+		msg = g_strdup_printf(
+"Unable to add:\n\
+\n\
+    %s\n\
+\n\
+To:\n\
+\n\
+    %s\n\
+\n\
+%s.",
+		    path,
+		    arch_path,
+		    error_msg
+		);
+		EDVArchAddCopyErrorMessage(core, msg);
+		g_free(msg);
+		*status = -2;
+	    }
+	    return;
 	}
 
 #undef REPORT_ERROR_QUERY_CONTINUE_ADDING
