@@ -5,11 +5,11 @@
 #include "edv_types.h"
 
 
-extern const gchar *EDVArchChkGetError(void);
+extern const gchar *EDVArchChkGetError(edv_core_struct *core);
 
 extern gint EDVArchChk(
         edv_core_struct *core,
-        const gchar *arch_obj,
+        const gchar *arch_path,
         const gchar *password,
         GtkWidget *toplevel,
         const gboolean show_progress, const gboolean interactive,
