@@ -28,14 +28,14 @@
 #include "edv_cfg_list.h"
 #include "config.h"
 
-#include "images/pdi_trash01_20x20.xpm"
-#include "images/pdi_trash02_20x20.xpm"
-#include "images/pdi_trash03_20x20.xpm"
-#include "images/pdi_trash04_20x20.xpm"
-#include "images/pdi_trash05_20x20.xpm"
-#include "images/pdi_trash06_20x20.xpm"
-#include "images/pdi_package_32x32.xpm"
-#include "images/pdi_packagefile_32x32.xpm"
+#include "animations/trash01_20x20.xpm"
+#include "animations/trash02_20x20.xpm"
+#include "animations/trash03_20x20.xpm"
+#include "animations/trash04_20x20.xpm"
+#include "animations/trash05_20x20.xpm"
+#include "animations/trash06_20x20.xpm"
+#include "animations/package_32x32.xpm"
+#include "animations/packagefile_32x32.xpm"
 
 
 /*
@@ -44,16 +44,18 @@
  *	0	Success.
  *	-1	General error.
  *	-2	Invalid value.
- *	-3	Systems error; out of memory or out of disk space.
+ *	-3	Systems error, out of memory, or out of disk space.
  *	-4	User responded with "Cancel".
  *	-5	User responded with "No" or response was not available.
- *	-6	Call would cause reentry.
+ *	-6	An operation is already in progress.
  */
 
 
 /* Error Message */
-const gchar *EDVArchDeleteGetError(void);
-static void EDVArchDeleteCopyErrorMessage(const gchar *msg);
+const gchar *EDVArchDeleteGetError(edv_core_struct *core);
+static void EDVArchDeleteCopyErrorMessage(
+	edv_core_struct *core, const gchar *msg
+);
 
 static void EDVArchDeleteMapProgressDialog(
 	const gchar *label, const gfloat progress,
@@ -66,29 +68,30 @@ static void EDVArchDeleteMapProgressDialogUnknown(
 
 #ifdef HAVE_LIBZIP
 static struct zip *EDVOpenZipWriting(
-	const gchar *arch_obj,
-        gint *zip_error_code, gint *sys_error_code
+	const gchar *arch_path,
+	gint *zip_error_code, gint *sys_error_code
 );
 #endif
 
 /* Delete Object From Archive */
 static gint EDVArchDeleteARJ(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path, GList *obj_list,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all
 );
 static gint EDVArchDeleteRAR(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path, GList *obj_list,
+	const gchar *password,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all
 );
 static gint EDVArchDeleteTar(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path, GList *obj_list,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all,
@@ -98,7 +101,7 @@ static gint EDVArchDeleteTar(
 );
 static gint EDVArchDeleteZip(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path, GList *obj_list,
 	const gchar *password,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
@@ -106,7 +109,7 @@ static gint EDVArchDeleteZip(
 );
 gint EDVArchDelete(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path, GList *obj_list,
 	const gchar *password,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
@@ -114,12 +117,6 @@ gint EDVArchDelete(
 );
 
 
-static const gchar *last_error = NULL;
-static gchar last_error_buf[256];
-
-
-#define ISCR(c)		(((c) == '\n') || ((c) == '\r'))
-
 #define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
 #define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
 #define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
@@ -134,6 +131,8 @@ static gchar last_error_buf[256];
 #define UNLINK(p)	(((p) != NULL) ? (gint)unlink((const char *)(p)) : -1)
 #define INTERRUPT(i)	(((i) > 0) ? (gint)kill((int)(i), SIGINT) : -1)
 
+#define ISCR(c)		(((c) == '\n') || ((c) == '\r'))
+
 
 static gchar *G_STRCAT(gchar *s, const gchar *s2)
 {
@@ -157,23 +156,28 @@ static gchar *G_STRCAT(gchar *s, const gchar *s2)
  *	Returns the last error message as a statically allocated
  *	string or NULL if there was no previous error.
  */
-const gchar *EDVArchDeleteGetError(void)
+const gchar *EDVArchDeleteGetError(edv_core_struct *core)
 {
-	return(last_error);
+	return((core != NULL) ? core->archive_last_error : NULL);
 }
 
 /*
- *	Coppies the error message specified by msg to the last error
- *	message buffer and sets last_error to point to that buffer.
+ *	Coppies the error message to the core's archive_last_error_buf
+ *	and sets the core's archive_last_error to point to it.
  */
-static void EDVArchDeleteCopyErrorMessage(const gchar *msg)
+static void EDVArchDeleteCopyErrorMessage(
+	edv_core_struct *core, const gchar *msg
+)
 {
-        if(msg == NULL)
-            return;
+	if(core == NULL)
+	    return;
 
-        strncpy(last_error_buf, msg, sizeof(last_error_buf));
-        last_error_buf[sizeof(last_error_buf) - 1] = '\0';
-        last_error = last_error_buf;
+	core->archive_last_error = NULL;
+
+	g_free(core->archive_last_error_buf);
+	core->archive_last_error_buf = STRDUP(msg);
+
+	core->archive_last_error = core->archive_last_error_buf;
 }
 
 
@@ -215,15 +219,15 @@ static void EDVArchDeleteMapProgressDialog(
 
 	ProgressDialogSetTransientFor(toplevel);
 
-	start_icon_data[0] = (guint8 **)pdi_packagefile_32x32_xpm;
-	start_icon_data[1] = (guint8 **)pdi_package_32x32_xpm;
-	start_icon_data[2] = (guint8 **)pdi_package_32x32_xpm;
-	icon_data[0] = (guint8 **)pdi_trash01_20x20_xpm;
-	icon_data[1] = (guint8 **)pdi_trash02_20x20_xpm;
-	icon_data[2] = (guint8 **)pdi_trash03_20x20_xpm;
-	icon_data[3] = (guint8 **)pdi_trash04_20x20_xpm;
-	icon_data[4] = (guint8 **)pdi_trash05_20x20_xpm;
-	icon_data[5] = (guint8 **)pdi_trash06_20x20_xpm;
+	start_icon_data[0] = (guint8 **)packagefile_32x32_xpm;
+	start_icon_data[1] = (guint8 **)package_32x32_xpm;
+	start_icon_data[2] = (guint8 **)package_32x32_xpm;
+	icon_data[0] = (guint8 **)trash01_20x20_xpm;
+	icon_data[1] = (guint8 **)trash02_20x20_xpm;
+	icon_data[2] = (guint8 **)trash03_20x20_xpm;
+	icon_data[3] = (guint8 **)trash04_20x20_xpm;
+	icon_data[4] = (guint8 **)trash05_20x20_xpm;
+	icon_data[5] = (guint8 **)trash06_20x20_xpm;
 	end_icon_data[0] = (guint8 **)NULL;
 	end_icon_data[1] = (guint8 **)NULL;
 	end_icon_data[2] = (guint8 **)NULL;
@@ -316,15 +320,15 @@ static void EDVArchDeleteMapProgressDialogUnknown(
 
 	ProgressDialogSetTransientFor(toplevel);
 
-	start_icon_data[0] = (guint8 **)pdi_packagefile_32x32_xpm;
-	start_icon_data[1] = (guint8 **)pdi_package_32x32_xpm;
-	start_icon_data[2] = (guint8 **)pdi_package_32x32_xpm;
-	icon_data[0] = (guint8 **)pdi_trash01_20x20_xpm;
-	icon_data[1] = (guint8 **)pdi_trash02_20x20_xpm;
-	icon_data[2] = (guint8 **)pdi_trash03_20x20_xpm;
-	icon_data[3] = (guint8 **)pdi_trash04_20x20_xpm;
-	icon_data[4] = (guint8 **)pdi_trash05_20x20_xpm;
-	icon_data[5] = (guint8 **)pdi_trash06_20x20_xpm;
+	start_icon_data[0] = (guint8 **)packagefile_32x32_xpm;
+	start_icon_data[1] = (guint8 **)package_32x32_xpm;
+	start_icon_data[2] = (guint8 **)package_32x32_xpm;
+	icon_data[0] = (guint8 **)trash01_20x20_xpm;
+	icon_data[1] = (guint8 **)trash02_20x20_xpm;
+	icon_data[2] = (guint8 **)trash03_20x20_xpm;
+	icon_data[3] = (guint8 **)trash04_20x20_xpm;
+	icon_data[4] = (guint8 **)trash05_20x20_xpm;
+	icon_data[5] = (guint8 **)trash06_20x20_xpm;
 	end_icon_data[0] = (guint8 **)NULL;
 	end_icon_data[1] = (guint8 **)NULL;
 	end_icon_data[2] = (guint8 **)NULL;
@@ -387,26 +391,26 @@ static void EDVArchDeleteMapProgressDialogUnknown(
  *	Returns the handle to the PKZip archive.
  */
 static struct zip *EDVOpenZipWriting(
-	const gchar *arch_obj,
+	const gchar *arch_path,
 	gint *zip_error_code, gint *sys_error_code
 )
 {
-        struct stat stat_buf;
-        struct zip *archive;
+	struct stat stat_buf;
+	struct zip *archive;
 
-        /* If the PKZip archive exists but has a size of 0 bytes then
-         * it must be deleted first or else libzip will return an
-         * error stating that it is not a valid PKZip archive
-         */
-        if(!stat(arch_obj, &stat_buf))
-        {
-            if(stat_buf.st_size == 0l)
-                unlink(arch_obj);
-        }
+	/* If the PKZip archive exists but has a size of 0 bytes then
+	 * it must be deleted first or else libzip will return an
+	 * error stating that it is not a valid PKZip archive
+	 */
+	if(!stat((const char *)arch_path, &stat_buf))
+	{
+	    if(stat_buf.st_size == 0l)
+		unlink(arch_path);
+	}
 
-        archive = zip_open(arch_obj, ZIP_CREATE, zip_error_code);
-        if(sys_error_code != NULL)
-            *sys_error_code = errno;
+	archive = zip_open(arch_path, ZIP_CREATE, zip_error_code);
+	if(sys_error_code != NULL)
+	    *sys_error_code = errno;
 
 	return(archive);
 }
@@ -418,7 +422,7 @@ static struct zip *EDVOpenZipWriting(
  */
 static gint EDVArchDeleteARJ(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path, GList *obj_list,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all
@@ -431,10 +435,10 @@ static gint EDVArchDeleteARJ(
 	gchar *cmd = NULL;
 	GList *glist;
 
-#define DO_FREE_LOCALS	\
-{			\
- g_free(cmd);		\
- cmd = NULL;		\
+#define CLEANUP_RETURN(_v_)	{	\
+ g_free(cmd);				\
+					\
+ return(_v_);				\
 }
 
 	/* Format the delete objects from archive command */
@@ -444,13 +448,12 @@ static gint EDVArchDeleteARJ(
 
 	    cmd = g_strdup_printf(
 		"\"%s\" d -i -y \"%s\"",
-		prog_arj, arch_obj
+		prog_arj, arch_path
 	    );
 	    if(cmd == NULL)
 	    {
-		last_error = "Unable to generate the delete command";
-		DO_FREE_LOCALS
-		return(-2);
+		core->archive_last_error = "Unable to generate the delete command.";
+		CLEANUP_RETURN(-1);
 	    }
 	    for(glist = obj_list; glist != NULL; glist = g_list_next(glist))
 	    {
@@ -467,9 +470,8 @@ static gint EDVArchDeleteARJ(
 	    p = (gint)ExecOE((const char *)cmd, "/dev/null", "/dev/null");
 	    if(p <= 0)
 	    {
-		last_error = "Unable to execute the delete command";
-		DO_FREE_LOCALS
-		return(-1);
+		core->archive_last_error = "Unable to execute the delete command.";
+		CLEANUP_RETURN(-1);
 	    }
 
 	    /* Delete the command */
@@ -499,9 +501,8 @@ static gint EDVArchDeleteARJ(
 	    }
 	}
 
-	DO_FREE_LOCALS
-	return(status);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(status);
+#undef CLEANUP_RETURN
 }
 
 /*
@@ -509,7 +510,7 @@ static gint EDVArchDeleteARJ(
  */
 static gint EDVArchDeleteLHA(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path, GList *obj_list,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all
@@ -522,8 +523,10 @@ static gint EDVArchDeleteLHA(
 	gchar *cmd = NULL;
 	GList *glist;
 
-#define DO_FREE_LOCALS	{	\
- g_free(cmd);			\
+#define CLEANUP_RETURN(_v_)	{	\
+ g_free(cmd);				\
+					\
+ return(_v_);				\
 }
 
 	/* Format the delete objects from archive command */
@@ -533,13 +536,12 @@ static gint EDVArchDeleteLHA(
 
 	    cmd = g_strdup_printf(
 		"\"%s\" -df \"%s\"",
-		prog_lha, arch_obj
+		prog_lha, arch_path
 	    );
 	    if(cmd == NULL)
 	    {
-		last_error = "Unable to generate the delete command";
-		DO_FREE_LOCALS
-		return(-2);
+		core->archive_last_error = "Unable to generate the delete command.";
+		CLEANUP_RETURN(-1);
 	    }
 	    for(glist = obj_list; glist != NULL; glist = g_list_next(glist))
 	    {
@@ -556,9 +558,8 @@ static gint EDVArchDeleteLHA(
 	    p = (gint)ExecOE((const char *)cmd, "/dev/null", "/dev/null");
 	    if(p <= 0)
 	    {
-		last_error = "Unable to execute the delete command";
-		DO_FREE_LOCALS
-		return(-1);
+		core->archive_last_error = "Unable to execute the delete command.";
+		CLEANUP_RETURN(-1);
 	    }
 
 	    /* Delete the command */
@@ -587,9 +588,8 @@ static gint EDVArchDeleteLHA(
 	    }
 	}
 
-	DO_FREE_LOCALS
-	return(status);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(status);
+#undef CLEANUP_RETURN
 }
 
 /*
@@ -597,7 +597,8 @@ static gint EDVArchDeleteLHA(
  */
 static gint EDVArchDeleteRAR(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path, GList *obj_list,
+	const gchar *password,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all
@@ -610,8 +611,10 @@ static gint EDVArchDeleteRAR(
 	gchar *cmd = NULL;
 	GList *glist;
 
-#define DO_FREE_LOCALS	{	\
- g_free(cmd);			\
+#define CLEANUP_RETURN(_v_)	{	\
+ g_free(cmd);				\
+					\
+ return(_v_);				\
 }
 
 	/* Format the delete objects from archive command */
@@ -619,16 +622,20 @@ static gint EDVArchDeleteRAR(
 	{
 	    edv_archive_object_struct *obj;
 
+	    /* Format the base command */
 	    cmd = g_strdup_printf(
-		"\"%s\" d -y -c- \"%s\"",
-		prog_rar, arch_obj
+	        "\"%s\" d \"-p%s\" -y -c- \"%s\"",
+	        prog_rar,
+		(STRISEMPTY(password)) ? "-" : password,
+	        arch_path
 	    );
 	    if(cmd == NULL)
 	    {
-		last_error = "Unable to generate the delete command";
-		DO_FREE_LOCALS
-		return(-2);
+		core->archive_last_error = "Unable to generate the delete command.";
+		CLEANUP_RETURN(-1);
 	    }
+
+	    /* Append each object to delete to the command */
 	    for(glist = obj_list; glist != NULL; glist = g_list_next(glist))
 	    {
 		obj = EDV_ARCHIVE_OBJECT(glist->data);
@@ -644,9 +651,8 @@ static gint EDVArchDeleteRAR(
 	    p = (gint)ExecOE((const char *)cmd, "/dev/null", "/dev/null");
 	    if(p <= 0)
 	    {
-		last_error = "Unable to execute the delete command";
-		DO_FREE_LOCALS
-		return(-1);
+		core->archive_last_error = "Unable to execute the delete command.";
+		CLEANUP_RETURN(-1);
 	    }
 
 	    /* Delete the command */
@@ -675,9 +681,8 @@ static gint EDVArchDeleteRAR(
 	    }
 	}
 
-	DO_FREE_LOCALS
-	return(status);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(status);
+#undef CLEANUP_RETURN
 }
 
 /*
@@ -685,7 +690,7 @@ static gint EDVArchDeleteRAR(
  */
 static gint EDVArchDeleteTar(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path, GList *obj_list,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all,
@@ -715,28 +720,29 @@ static gint EDVArchDeleteTar(
 	const gchar *prog_bunzip2 = CFGItemListGetValueS(
 	    core->cfg_list, EDV_CFG_PARM_PROG_BUNZIP2
 	);
+	FILE *fp;
 	gint status, p, nobjs;
 	gchar *s, *s2;
 	gchar	*cmd = NULL,
 		*arch_uncompressed_path = NULL,
 		*stdout_path = NULL,
 		*stderr_path = NULL;
-	FILE *fp;
 	GList *glist;
 
-#define DO_FREE_LOCALS			\
-{					\
+#define CLEANUP_RETURN(_v_)	{	\
  g_free(cmd);				\
+ g_free(arch_uncompressed_path);	\
  g_free(stdout_path);			\
  g_free(stderr_path);			\
- g_free(arch_uncompressed_path);	\
+					\
+ return(_v_);				\
 }
 
-	/* Generate tar plain path from the given arch_obj which is
+	/* Generate tar plain path from the given arch_path which is
 	 * gauranteed to have a .tar, .tgz, .tar.gz, or .tar.bz2
 	 * postfix
 	 */
-	arch_uncompressed_path = STRDUP(arch_obj);
+	arch_uncompressed_path = STRDUP(arch_path);
 	s = g_basename(arch_uncompressed_path);
 	s2 = strstr(s, ".tgz");
 	if(s2 == NULL)
@@ -755,17 +761,17 @@ static gint EDVArchDeleteTar(
 	if(is_compress_compressed)
 	    cmd = g_strdup_printf(
 		"\"%s\" \"%s\"",
-		prog_uncompress, arch_obj
+		prog_uncompress, arch_path
 	    );
 	else if(is_gzip_compressed)
 	    cmd = g_strdup_printf(
 		"\"%s\" \"%s\"",
-		prog_gunzip, arch_obj
+		prog_gunzip, arch_path
 	    );
 	else if(is_bzip2_compressed)
 	    cmd = g_strdup_printf(
 		"\"%s\" \"%s\"",
-		prog_bunzip2, arch_obj
+		prog_bunzip2, arch_path
 	    );
 	else
 	    cmd = NULL;
@@ -775,13 +781,14 @@ static gint EDVArchDeleteTar(
 	p = 0;
 	if(cmd != NULL)
 	{
+	    gulong last_sec = (gulong)time(NULL);
+
 	    /* Execute the decompress archive command */
 	    p = (gint)ExecOE((const char *)cmd, "/dev/null", "/dev/null");
 	    if(p <= 0)
 	    {
-		last_error = "Unable to execute decompress command";
-		DO_FREE_LOCALS
-		return(-1);
+		core->archive_last_error = "Unable to execute decompress command.";
+		CLEANUP_RETURN(-1);
 	    }
 
 	    /* Delete the command */
@@ -791,10 +798,11 @@ static gint EDVArchDeleteTar(
 	    /* Map the progress dialog */
 	    if(show_progress)
 	    {
-		gchar *p1 = EDVShortenPath(
-		    arch_obj, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
-		), *msg = g_strdup_printf(
-"Decompressing archive:\n\
+		gchar	*p1 = EDVShortenPath(
+		    arch_path,
+		    EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX - 10
+		),	*msg = g_strdup_printf(
+"Decompressing Archive:\n\
 \n\
     %s\n",
 		    p1
@@ -809,9 +817,52 @@ static gint EDVArchDeleteTar(
 	    {
 		if(show_progress && ProgressDialogIsQuery())
 		{
-		    ProgressDialogUpdateUnknown(
-			NULL, NULL, NULL, NULL, TRUE
-		    );
+		    const gulong        cur_sec = (gulong)time(NULL),
+					d_sec = cur_sec - last_sec;  
+
+		    /* Update the label every second */
+		    if(d_sec >= 1l)
+		    {
+			struct stat stat_buf;
+			gchar *p1, *s1, *msg;
+			gulong cur_size;
+
+			p1 = EDVShortenPath(
+			    arch_path,
+			    EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX - 10
+			);
+			if(stat((const char *)arch_uncompressed_path, &stat_buf))
+			    memset(&stat_buf, 0x00, sizeof(struct stat));
+			cur_size = (gulong)stat_buf.st_size;
+			if(cur_size > 0l)
+			{
+			    s1 = STRDUP(EDVSizeStrDelim(cur_size));
+			    msg = g_strdup_printf(
+"Decompressing Archive:\n\
+\n\
+    %s (%s %s)\n",
+				p1, s1, (cur_size == 1l) ? "byte" : "bytes"
+			    );
+			}
+			else
+			{
+			    s1 = NULL;
+			    msg = NULL;
+			}
+			g_free(p1);
+			g_free(s1);
+			ProgressDialogUpdateUnknown(
+			    NULL, msg, NULL, NULL, TRUE
+			);
+			g_free(msg);
+			last_sec = cur_sec;
+		    }
+		    else
+		    {
+			ProgressDialogUpdateUnknown(
+			    NULL, NULL, NULL, NULL, TRUE
+			);
+		    }
 		    if(ProgressDialogStopCount() > 0)
 		    {
 			INTERRUPT(p);
@@ -826,8 +877,7 @@ static gint EDVArchDeleteTar(
 	/* Error or user aborted? */
 	if(status != 0)
 	{
-	    DO_FREE_LOCALS
-	    return(status);
+	    CLEANUP_RETURN(status);
 	}
 
 
@@ -843,11 +893,13 @@ static gint EDVArchDeleteTar(
 	    );
 	    if(cmd == NULL)
 	    {
-		last_error = "Unable to generate the delete command";
-		DO_FREE_LOCALS
-		return(-2);
+		core->archive_last_error = "Unable to generate the delete command.";
+		CLEANUP_RETURN(-1);
 	    }
-	    for(glist = obj_list; glist != NULL; glist = g_list_next(glist))
+	    for(glist = obj_list;
+		glist != NULL;
+		glist = g_list_next(glist)
+	    )
 	    {
 		obj = EDV_ARCHIVE_OBJECT(glist->data);
 		if(obj == NULL)
@@ -872,9 +924,8 @@ static gint EDVArchDeleteTar(
 	    );
 	    if(p <= 0)
 	    {
-		last_error = "Unable to execute the delete command";
-		DO_FREE_LOCALS
-		return(-1);
+		core->archive_last_error = "Unable to execute the delete command.";
+		CLEANUP_RETURN(-1);
 	    }
 
 	    /* Delete the command */
@@ -965,7 +1016,7 @@ static gint EDVArchDeleteTar(
 				s, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 			    ),
 					*p2 = EDVShortenPath(
-				arch_obj, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
+				arch_path, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 			    ),
 					*msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1086,8 +1137,7 @@ From:\n\
 	/* Error or user aborted? */
 	if(status != 0)
 	{
-	    DO_FREE_LOCALS
-	    return(status);
+	    CLEANUP_RETURN(status);
 	}
 
 	/* Format the compress archive command as needed */
@@ -1112,13 +1162,14 @@ From:\n\
 	/* Need to compress the archive? */
 	if(cmd != NULL)
 	{
+	    gulong last_sec = (gulong)time(NULL);
+
 	    /* Execute the compress archive command */
-	    p = (gint)ExecOE((const char *)cmd, (const char *)arch_obj, "/dev/null");
+	    p = (gint)ExecOE((const char *)cmd, (const char *)arch_path, "/dev/null");
 	    if(p <= 0)
 	    {
-		last_error = "Unable to execute the compress command";
-		DO_FREE_LOCALS
-		return(-1);
+		core->archive_last_error = "Unable to execute the compress command.";
+		CLEANUP_RETURN(-1);
 	    }
 
 	    /* Delete the command */
@@ -1128,10 +1179,12 @@ From:\n\
 	    /* Map the progress dialog? */
 	    if(show_progress)
 	    {
-		gchar *p1 = EDVShortenPath(
-		    arch_obj, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
-		), *msg = g_strdup_printf(
-"Compressing archive:\n\
+		gchar	*p1 = EDVShortenPath(
+		    arch_path,
+		    EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX - 10
+		),
+			*msg = g_strdup_printf(
+"Compressing Archive:\n\
 \n\
     %s\n",
 		    p1
@@ -1146,9 +1199,52 @@ From:\n\
 	    {
 		if(show_progress && ProgressDialogIsQuery())
 		{
-		    ProgressDialogUpdateUnknown(
-			NULL, NULL, NULL, NULL, TRUE
-		    );
+		    const gulong        cur_sec = (gulong)time(NULL),
+					d_sec = cur_sec - last_sec;  
+
+		    /* Update the label every second */
+		    if(d_sec >= 1l)
+		    {
+			struct stat stat_buf;
+			gchar *p1, *s1, *msg;
+			gulong cur_size;
+
+			p1 = EDVShortenPath(
+			    arch_path,
+			    EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX - 10
+			);
+			if(stat((const char *)arch_path, &stat_buf))
+			    memset(&stat_buf, 0x00, sizeof(struct stat));
+			cur_size = (gulong)stat_buf.st_size;
+			if(cur_size > 0l)
+			{
+			    s1 = STRDUP(EDVSizeStrDelim(cur_size));
+			    msg = g_strdup_printf(
+"Compressing Archive:\n\
+\n\
+    %s (%s %s)\n",
+				p1, s1, (cur_size == 1l) ? "byte" : "bytes"
+			    );
+			}
+			else
+			{
+			    s1 = NULL;
+			    msg = NULL;
+			}
+			g_free(p1);
+			g_free(s1);
+			ProgressDialogUpdateUnknown(
+			    NULL, msg, NULL, NULL, TRUE
+			);
+			g_free(msg);
+			last_sec = cur_sec;
+		    }
+		    else
+		    {
+			ProgressDialogUpdateUnknown(
+			    NULL, NULL, NULL, NULL, TRUE
+			);
+		    }
 		    if(ProgressDialogStopCount() > 0)
 		    {
 			INTERRUPT(p);
@@ -1164,9 +1260,8 @@ From:\n\
 	    UNLINK(arch_uncompressed_path);
 	}
 
-	DO_FREE_LOCALS
-	return(status);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(status);
+#undef CLEANUP_RETURN
 }
 
 /*
@@ -1174,7 +1269,7 @@ From:\n\
  */
 static gint EDVArchDeleteZip(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path, GList *obj_list,
 	const gchar *password,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
@@ -1213,7 +1308,7 @@ static gint EDVArchDeleteZip(
 		    path, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 		),
 			*p2 = EDVShortenPath(
-		    arch_obj, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
+		    arch_path, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 		),
 			*msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1302,16 +1397,26 @@ From:\n\
 
 	    /* Open the PKZip archive for writing */
 	    archive = EDVOpenZipWriting(
-		arch_obj,
+		arch_path,
 		&zip_error_code, &sys_error_code
 	    );
 	    if(archive == NULL)
 	    {
+		gchar *msg, err_msg[1024];
 		zip_error_to_str(
-		    last_error_buf, sizeof(last_error_buf),
+		    err_msg, sizeof(err_msg),
 		    zip_error_code, sys_error_code
 		);
-		last_error = last_error_buf;
+		msg = g_strdup_printf(
+"Unable to open the PKZip archive for writing:\n\
+\n\
+    %s\n\
+\n\
+%s.",
+		    arch_path, err_msg
+		);
+		EDVArchDeleteCopyErrorMessage(core, msg);
+		g_free(msg);
 		status = -1;
 		break;
 	    }
@@ -1349,7 +1454,7 @@ From:\n\
 	    if(tar_path == NULL)
 	    {
 		zip_close(archive);
-		last_error = "Memory allocation error";
+		core->archive_last_error = "Memory allocation error.";
 		status = -3;
 		break;
 	    }
@@ -1386,15 +1491,20 @@ From:\n\
 	    if(zip_delete(archive, n))
 	    {
 		/* Unable to delete this object */
-                gchar *s = g_strconcat(
-                    "Unable to delete \"",
-                    g_basename(tar_path),
-                    "\" from the archive, ",
-                    (const gchar *)zip_strerror(archive),
-                    NULL
-                );
-                EDVArchDeleteCopyErrorMessage(s);
-                g_free(s);
+		gchar *msg = g_strdup_printf(
+"Unable to delete:\n\
+\n\
+    %s\n\
+\n\
+From the archive:\n\
+\n\
+    %s\n\
+\n\
+%s.",
+		    tar_path, arch_path, zip_strerror(archive)
+		);
+		EDVArchDeleteCopyErrorMessage(core, msg);
+		g_free(msg);
 		zip_close(archive);
 		g_free(tar_path);
 		status = -1;
@@ -1410,7 +1520,16 @@ From:\n\
 		 */
 		if(status != -4)
 		{
-		    EDVArchDeleteCopyErrorMessage(zip_strerror(archive));
+		    gchar *msg = g_strdup_printf(
+"Unable to close the PKZip archive:\n\
+\n\
+    %s\n\
+\n\
+%s.",
+			arch_path, zip_strerror(archive)
+		    );
+		    EDVArchDeleteCopyErrorMessage(core, msg);
+		    g_free(msg);
 		    g_free(tar_path);
 		    status = -1;
 		    break;
@@ -1445,8 +1564,10 @@ From:\n\
 	gint status = 0, p;
 	gchar *cmd = NULL;
 
-#define DO_FREE_LOCALS	{	\
- g_free(cmd);			\
+#define CLEANUP_RETURN(_v_)	{	\
+ g_free(cmd);				\
+					\
+ return(_v_);				\
 }
 
 	/* Format the delete from archive command */
@@ -1457,13 +1578,12 @@ From:\n\
 
 	    cmd = g_strdup_printf(
 		"\"%s\" -d -q \"%s\"",
-		prog_zip, arch_obj
+		prog_zip, arch_path
 	    );
 	    if(cmd == NULL)
 	    {
-		last_error = "Unable to generate the delete command";
-		DO_FREE_LOCALS
-		return(-2);
+		core->archive_last_error = "Unable to generate the delete command.";
+		CLEANUP_RETURN(-1);
 	    }
 	    for(glist = obj_list; glist != NULL; glist = g_list_next(glist))
 	    {
@@ -1480,9 +1600,8 @@ From:\n\
 	    p = (gint)ExecOE((const char *)cmd, "/dev/null", "/dev/null");
 	    if(p <= 0)
 	    {
-		last_error = "Unable to execute the delete command";
-		DO_FREE_LOCALS
-		return(-1);
+		core->archive_last_error = "Unable to execute the delete command.";
+		CLEANUP_RETURN(-1);
 	    }
 
 	    /* Delete the command */
@@ -1512,77 +1631,73 @@ From:\n\
 	    }
 	}
 
-	DO_FREE_LOCALS
-	return(status);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(status);
+#undef CLEANUP_RETURN
 #endif	/* !HAVE_LIBZIP */
 }
 
 /*
  *	Deletes the object(s) from the archive.
  *
- *	The arch_obj specifies the archive.
+ *	The arch_path specifies the archive.
  *
  *	The obj_list specifies the list of objects to delete from the
  *	archive.
  */
 gint EDVArchDelete(
 	edv_core_struct *core,
-	const gchar *arch_obj, GList *obj_list,
+	const gchar *arch_path,
+	GList *obj_list,
 	const gchar *password,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all
 )
 {
-	static gboolean reenterent = FALSE;
 	gint status;
 	gulong time_start = (gulong)time(NULL);
 	const gchar *arch_name;
 
-#define DO_FREE_LOCALS		{	\
+#define CLEANUP_RETURN(_v_)	{	\
+					\
+ return(_v_);				\
 }
 
-	if(reenterent)
+	if(ProgressDialogIsQuery())
 	{
-	    last_error =
-"An operation is already in progress, please try again later";
+	    EDVArchDeleteCopyErrorMessage(
+		core,
+"An operation is already in progress, please try again later."
+	    );
 	    return(-6);
 	}
-	else
-	{
-	    reenterent = TRUE;
-	}
 
-	/* Reset the last error message */
-	last_error = NULL;
+	/* Clear the last error message */
+	EDVArchDeleteCopyErrorMessage(core, NULL);
 
-	if((core == NULL) || STRISEMPTY(arch_obj) ||
+	if((core == NULL) || STRISEMPTY(arch_path) ||
 	   (yes_to_all == NULL)
 	)
 	{
-	    reenterent = FALSE;
+	    EDVArchDeleteCopyErrorMessage(core, "Invalid value.");
 	    return(-2);
 	}
 
-	/* No objects to delete from the archive? */
+	/* No objects to delete? */
 	if(obj_list == NULL)
-	{
-	    reenterent = FALSE;
 	    return(0);
-	}
 
 	/* Begin deleting the source object from the archive object
-	 * arch_obj. The deleting method will be determined by taking
+	 * arch_path. The deleting method will be determined by taking
 	 * the extension of the archive object's name
 	 */
 
 	/* ARJ Archive */
-	arch_name = g_basename(arch_obj);
+	arch_name = g_basename(arch_path);
 	if(EDVIsExtension(arch_name, ".arj"))
 	{
 	    status = EDVArchDeleteARJ(
-		core, arch_obj, obj_list,
+		core, arch_path, obj_list,
 		toplevel, show_progress, interactive, yes_to_all
 	    );
 	}
@@ -1590,7 +1705,7 @@ gint EDVArchDelete(
 	else if(EDVIsExtension(arch_name, ".lha"))
 	{
 	    status = EDVArchDeleteLHA(
-		core, arch_obj, obj_list,
+		core, arch_path, obj_list,
 		toplevel, show_progress, interactive, yes_to_all
 	    );
 	}
@@ -1598,7 +1713,8 @@ gint EDVArchDelete(
 	else if(EDVIsExtension(arch_name, ".rar"))
 	{
 	    status = EDVArchDeleteRAR(
-		core, arch_obj, obj_list,
+		core, arch_path, obj_list,
+		password,
 		toplevel, show_progress, interactive, yes_to_all
 	    );
 	}
@@ -1606,7 +1722,7 @@ gint EDVArchDelete(
 	else if(EDVIsExtension(arch_name, ".tar.Z"))
 	{
 	    status = EDVArchDeleteTar(
-		core, arch_obj, obj_list,
+		core, arch_path, obj_list,
 		toplevel, show_progress, interactive, yes_to_all,
 		TRUE,		/* Is compress compressed */
 		FALSE,		/* Not gzip compressed */
@@ -1617,7 +1733,7 @@ gint EDVArchDelete(
 	else if(EDVIsExtension(arch_name, ".tgz .tar.gz"))
 	{
 	    status = EDVArchDeleteTar(
-		core, arch_obj, obj_list,
+		core, arch_path, obj_list,
 		toplevel, show_progress, interactive, yes_to_all,
 		FALSE,		/* Not compress compressed */
 		TRUE,		/* Is gzip compressed */
@@ -1628,7 +1744,7 @@ gint EDVArchDelete(
 	else if(EDVIsExtension(arch_name, ".tar.bz2"))
 	{
 	    status = EDVArchDeleteTar(
-		core, arch_obj, obj_list,
+		core, arch_path, obj_list,
 		toplevel, show_progress, interactive, yes_to_all,
 		FALSE,		/* Not compress compressed */
 		FALSE,		/* Not gzip compressed */
@@ -1639,7 +1755,7 @@ gint EDVArchDelete(
 	else if(EDVIsExtension(arch_name, ".tar"))
 	{
 	    status = EDVArchDeleteTar(
-		core, arch_obj, obj_list,
+		core, arch_path, obj_list,
 		toplevel, show_progress, interactive, yes_to_all,
 		FALSE,		/* Not compress compressed */
 		FALSE,		/* Not gzip compressed */
@@ -1650,13 +1766,13 @@ gint EDVArchDelete(
 	else if(EDVIsExtension(arch_name, ".xpi .zip"))
 	{
 	    status = EDVArchDeleteZip(
-		core, arch_obj, obj_list, password,
+		core, arch_path, obj_list, password,
 		toplevel, show_progress, interactive, yes_to_all
 	    );
 	}
 	else
 	{
-	    last_error = "Unsupported archive format";
+	    core->archive_last_error = "Unsupported archive format.";
 	    status = -2;
 	}
 
@@ -1672,9 +1788,9 @@ gint EDVArchDelete(
 		EDV_HISTORY_ARCHIVE_OBJECT_DELETE,
 		time_start, time_end,
 		status,
-		arch_obj,		/* Source */
+		arch_path,		/* Source */
 		(obj != NULL) ? obj->full_path : NULL, /* Target */
-		last_error		/* Comment */
+		core->archive_last_error		/* Comment */
 	    );
 	}
 	else
@@ -1683,7 +1799,10 @@ gint EDVArchDelete(
 	    GList *glist;
 	    edv_archive_object_struct *obj;
 
-	    for(glist = obj_list; glist != NULL; glist = g_list_next(glist))
+	    for(glist = obj_list;
+		glist != NULL;
+		glist = g_list_next(glist)
+	    )
 	    {
 		obj = EDV_ARCHIVE_OBJECT(glist->data);
 		if(obj == NULL)
@@ -1694,9 +1813,9 @@ gint EDVArchDelete(
 		    EDV_HISTORY_ARCHIVE_OBJECT_DELETE,
 		    time_start, time_end,
 		    status,
-		    arch_obj,		/* Source */
+		    arch_path,		/* Source */
 		    obj->full_path,	/* Target */
-		    last_error		/* Comment */
+		    core->archive_last_error		/* Comment */
 		);
 	    }
 	}
@@ -1707,8 +1826,6 @@ gint EDVArchDelete(
 	 */
 	sync();
 
-	DO_FREE_LOCALS
-	reenterent = FALSE;
-	return(status);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(status);
+#undef CLEANUP_RETURN
 }
