@@ -5,13 +5,12 @@
 #include "edv_types.h"
 
 
-extern const gchar *EDVArchDeleteGetError(void);
+extern const gchar *EDVArchDeleteGetError(edv_core_struct *core);
 
 extern gint EDVArchDelete(
 	edv_core_struct *core,
-	const gchar *arch_obj,			/* Archive */
-	GList *obj_list,			/* List of objects to delete
-						 * from the archive */
+	const gchar *arch_path,
+	GList *obj_list,			/* List of edv_archive_object_struct * objects */
 	const gchar *password,
 	GtkWidget *toplevel,
 	const gboolean show_progress, const gboolean interactive,
