@@ -69,7 +69,7 @@ static gint EDVArchExtractConfirmOverwrite(
 	edv_core_struct *core, GtkWidget *toplevel,
 	const gchar *src_path, const gchar *tar_path,
 	edv_archive_object_struct *src_obj_stat,
-	const struct stat *tar_lstat_buf
+	struct stat *tar_lstat_buf
 );
 
 /* Progress Dialog */
@@ -202,8 +202,6 @@ void EDVArchExtractCopyErrorMessage(
 	if(core == NULL)
 	    return;
 
-	core->archive_last_error = NULL;
-
 	g_free(core->archive_last_error_buf);
 	core->archive_last_error_buf = STRDUP(msg);
 
@@ -221,7 +219,7 @@ static gint EDVArchExtractConfirmOverwrite(
 	edv_core_struct *core, GtkWidget *toplevel,
 	const gchar *src_path, const gchar *tar_path,
 	edv_archive_object_struct *src_obj_stat,
-	const struct stat *tar_lstat_buf
+	struct stat *tar_lstat_buf
 )
 {
 	gchar *msg, *src_date, *tar_date;
