@@ -117,7 +117,7 @@ typedef struct {
 static int EDVArchExtractLibTarOpenLibZCB(const char *path, int oflags, int mode)
 {
 	const char *libz_oflags;
-	int fd;
+	gint fd;
 	gzFile zd;
 
 	switch(oflags & O_ACCMODE)
@@ -135,12 +135,17 @@ static int EDVArchExtractLibTarOpenLibZCB(const char *path, int oflags, int mode
 	    break;
 	}
 
-	fd = open(path, oflags, mode);
+	fd = (gint)open(path, oflags, mode);
 	if(fd < 0)
 	    return(-1);
 
-	if((oflags & O_CREAT) && fchmod(fd, mode))
+	if((oflags & O_CREAT) && (fchmod((int)fd, mode) != 0))
+	{
+	    const gint error_code = (gint)errno;
+	    close(fd);
+	    errno = (int)error_code;
 	    return(-1);
+	}
 
 	zd = gzdopen(fd, libz_oflags);
 	if(zd == NULL)
@@ -149,6 +154,7 @@ static int EDVArchExtractLibTarOpenLibZCB(const char *path, int oflags, int mode
 	    return(-1);
 	}
 
+	/* Return the gzFile descriptor as the descriptor */
 	return((int)zd);
 }
 # endif	/* HAVE_LIBZ */
@@ -160,6 +166,7 @@ static int EDVArchExtractLibTarOpenLibZCB(const char *path, int oflags, int mode
 static int EDVArchExtractLibTarOpenLibBZ2CB(const char *path, int oflags, int mode)
 {
 	const char *libbz2_oflags;
+	gint fd;
 	bz2_cb_data_struct *d;
 
 	switch(oflags & O_ACCMODE)
@@ -183,16 +190,18 @@ static int EDVArchExtractLibTarOpenLibBZ2CB(const char *path, int oflags, int mo
 	if(d == NULL)
 	    return(-1);
 
-	d->fd = open(path, oflags, mode);
-	if(d->fd < 0)
+	d->fd = fd = (gint)open(path, oflags, mode);
+	if(fd < 0)
 	{
+	    const gint error_code = (gint)errno;
 	    g_free(d);
+	    errno = (int)error_code;
 	    return(-1);
 	}
 
 	if(oflags & O_CREAT)
 	{
-	    if(fchmod(d->fd, mode) != 0)
+	    if(fchmod((int)fd, mode) != 0)
 	    {
 		const gint error_code = (gint)errno;
 		close(d->fd);
@@ -205,7 +214,7 @@ static int EDVArchExtractLibTarOpenLibBZ2CB(const char *path, int oflags, int mo
 	d->bz2d = BZ2_bzdopen(d->fd, libbz2_oflags);
 	if(d->bz2d == NULL)
 	{
-	    close(d->fd);
+	    close(fd);
 	    g_free(d);
 	    errno = ENOMEM;
 	    return(-1);
@@ -402,7 +411,8 @@ gint EDVArchExtractTapeArchive(
     %s\n\
 \n\
 %s.",
-		arch_path, g_strerror(error_code)
+		arch_path,
+		g_strerror(error_code)
 	    );
 	    EDVArchExtractCopyErrorMessage(core, msg);
 	    g_free(msg);
@@ -417,7 +427,8 @@ gint EDVArchExtractTapeArchive(
     %s\n\
 \n\
 %s.",
-		arch_path, g_strerror(error_code)
+		arch_path,
+		g_strerror(error_code)
 	    );
 	    EDVArchExtractCopyErrorMessage(core, msg);
 	    g_free(msg);
@@ -451,12 +462,11 @@ gint EDVArchExtractTapeArchive(
 	cur_time = (gulong)time(NULL);
 	if(TRUE)
 	{
-	    gint i;
 	    gchar *parent, *tar_path, *src_path;
 	    edv_object_type type;
 
 	    /* Begin reading each object in the Tape Archive */
-	    while((i = th_read(tar)) == 0)
+	    while(th_read(tar) == 0)
 	    {
 		/* Get the path of this object in the archive */
 		src_path = EDVArchExtractLibTarGetPath(tar);
@@ -903,7 +913,8 @@ From:\n\
     %s\n\
 \n\
 %s.",
-		    arch_path, g_strerror(error_code)
+		    arch_path,
+		    g_strerror(error_code)
 		);
 		EDVArchExtractCopyErrorMessage(core, msg);
 		g_free(msg);
