@@ -9,6 +9,7 @@
 #include "../include/prochandle.h"
 
 #include "guiutils.h"
+#include "pulist.h"
 #include "cdialog.h"
 #include "fb.h"
 #include "csd.h"
@@ -19,8 +20,8 @@
 
 #include "cfg.h"
 #include "url.h"
+
 #include "edv_types.h"
-#include "edv_obj.h"
 #include "edv_devices_list.h"
 #include "edv_recbin_index.h"
 #include "edv_archive_obj.h"
@@ -49,8 +50,8 @@
 #include "edv_cb.h"
 #include "edv_op.h"
 #include "edv_interps_op.h"
-#include "edv_open.h"
 #include "edv_utils.h"
+
 #include "edv_cfg_list.h"
 #include "config.h"
 
@@ -144,18 +145,18 @@ void EDVFileSelectorObjectDeletedCB(
 
 /* Write Protect Changed Emitters */
 void EDVWriteProtectChangedEmit(
-	edv_core_struct *core, gboolean state
+	edv_core_struct *core, const gboolean state
 );
 
 /* Object Emitters */
 void EDVObjectAddedEmit(
 	edv_core_struct *core, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVObjectModifiedEmit(
 	edv_core_struct *core, const gchar *path,
 	const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVObjectRemovedEmit(
 	edv_core_struct *core, const gchar *path
@@ -164,8 +165,8 @@ void EDVObjectRemovedEmit(
 /* Mount/Unmount Emitters */
 void EDVObjectMountEmit(
 	edv_core_struct *core,
-	gint dev_num, edv_device_struct *dev,
-	gboolean is_mounted
+	const gint dev_num, edv_device_struct *dev,
+	const gboolean is_mounted
 );
 
 /* Archive Emitters */
@@ -185,10 +186,13 @@ void EDVArchiveObjectRemovedEmit(
 
 /* Recycled Object Emitters */
 void EDVRecycledObjectAddedEmit(
-	edv_core_struct *core, guint index
+	edv_core_struct *core, const guint index
+);
+void EDVRecycledObjectModifiedEmit(
+        edv_core_struct *core, const guint index
 );
 void EDVRecycledObjectRemovedEmit(
-	edv_core_struct *core, guint index
+	edv_core_struct *core, const guint index
 );
 
 /* Reconfigure Emitters */
@@ -219,24 +223,25 @@ void EDVMimeTypeRemovedEmit(
 /* Device Emitters */
 void EDVDeviceAddedEmit(
 	edv_core_struct *core,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 );
 void EDVDeviceModifiedEmit(
 	edv_core_struct *core,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 );
 void EDVDeviceRemovedEmit(
-	edv_core_struct *core, gint dev_num
+	edv_core_struct *core,
+	const  gint dev_num
 );
 
 /* History Event Emitters */
 void EDVHistoryAddedEmit(
 	edv_core_struct *core,
-	gint h_num, edv_history_struct *h
+	const gint h_num, edv_history_struct *h
 );
 void EDVHistoryRemovedEmit(
 	edv_core_struct *core,
-	gint h_num
+	const gint h_num
 );
 
 
@@ -374,16 +379,16 @@ gint EDVManageTimeoutCB(gpointer data)
 	    return(FALSE);
 
 /* Removes the timeout ID and sets it to 0 */
-#define DO_REMOVE_TOID(_id_)	{		\
- if(*(_id_) > 0) {				\
-  gtk_timeout_remove(*(_id_));			\
-  *(_id_) = 0;					\
+#define REMOVE_TOID(_id_ptr_)	{		\
+ if(*(_id_ptr_) > 0) {				\
+  gtk_timeout_remove(*(_id_ptr_));		\
+  *(_id_ptr_) = 0;				\
  }						\
 }
 
 /* Removes all timeout callbacks and breaks out of the GTK main loop */
-#define DO_REMOVE_TIMEOUTS_AND_BREAK_MAIN {	\
- DO_REMOVE_TOID(&core->manage_toid);		\
+#define REMOVE_TIMEOUTS_AND_BREAK_MAIN {	\
+ REMOVE_TOID(&core->manage_toid);		\
 						\
  gtk_main_quit();				\
 }
@@ -392,7 +397,7 @@ gint EDVManageTimeoutCB(gpointer data)
  * this function need not be called again because a new timeout has
  * been set for this function
  */
-#define DO_RETURN_RESCHEDUAL	{		\
+#define RETURN_RESCHEDUAL	{		\
  core->manage_toid = gtk_timeout_add(		\
   1000l,		/* 1 second interval */	\
   EDVManageTimeoutCB, core			\
@@ -404,14 +409,14 @@ gint EDVManageTimeoutCB(gpointer data)
 /* Mark timeout callback to this function as no longer valid and
  * return FALSE to never call this function again
  */
-#define DO_RETURN_NO_RESCHEDUAL		{	\
+#define RETURN_NO_RESCHEDUAL		{	\
  core->manage_toid = 0;				\
 						\
  return(FALSE);					\
 }
 
 /* Returns TRUE, keeping the current timeout callback to this function */
-#define DO_RETURN_CURRENT_SCHEDUAL	{	\
+#define RETURN_CURRENT_SCHEDUAL	{		\
  return(TRUE);					\
 }
 
@@ -439,37 +444,37 @@ gint EDVManageTimeoutCB(gpointer data)
 	    if(CDialogIsQuery())
 	    {
 		CDialogBreakQuery();
-		DO_RETURN_CURRENT_SCHEDUAL
+		RETURN_CURRENT_SCHEDUAL;
 	    }
 	    if(FileBrowserIsQuery())
 	    {
 		FileBrowserBreakQuery();
-		DO_RETURN_CURRENT_SCHEDUAL
+		RETURN_CURRENT_SCHEDUAL;
 	    }
 	    if(ProgressDialogIsQuery())
 	    {
 		ProgressDialogBreakQuery(FALSE);
-		DO_RETURN_CURRENT_SCHEDUAL
+		RETURN_CURRENT_SCHEDUAL;
 	    }
 	    if(FSDIsQuery())
 	    {
 		FSDBreakQuery();
-		DO_RETURN_CURRENT_SCHEDUAL
+		RETURN_CURRENT_SCHEDUAL;
 	    }
 	    if(CSDIsQuery())
 	    {
 		CSDBreakQuery();
-		DO_RETURN_CURRENT_SCHEDUAL
+		RETURN_CURRENT_SCHEDUAL;
 	    }
 	    if(PDialogIsQuery())
 	    {
 		PDialogBreakQuery();
-		DO_RETURN_CURRENT_SCHEDUAL
+		RETURN_CURRENT_SCHEDUAL;
 	    }
 	    if(FPromptIsQuery())
 	    {
 		FPromptBreakQuery();
-		DO_RETURN_CURRENT_SCHEDUAL
+		RETURN_CURRENT_SCHEDUAL;
 	    }
 	    /* All dialogs not in query */
 
@@ -622,7 +627,7 @@ gint EDVManageTimeoutCB(gpointer data)
 		 * windows since we set the global marker for that
 		 * to FALSE
 		 */
-		DO_RETURN_CURRENT_SCHEDUAL
+		RETURN_CURRENT_SCHEDUAL;
 	    }
 
 
@@ -636,10 +641,10 @@ gint EDVManageTimeoutCB(gpointer data)
 	    /* Remove all timeout callbacks and break out of the GTK
 	     * main loop
 	     */
-	    DO_REMOVE_TIMEOUTS_AND_BREAK_MAIN
+	    REMOVE_TIMEOUTS_AND_BREAK_MAIN;
 
 	    /* Return and do not call this function again */
-	    DO_RETURN_NO_RESCHEDUAL
+	    RETURN_NO_RESCHEDUAL;
 	}
 
 
@@ -673,7 +678,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else
 	    {
-		/* Unmapped, so delete it */
+		/* Not mapped, delete it */
 		core->browser[i] = NULL;
 		EDVBrowserDelete(browser);
 		browser = NULL;
@@ -693,7 +698,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else
 	    {
-		/* Unmapped, so delete it */
+		/* Not mapped, delete it */
 		core->imbr[i] = NULL;
 		EDVImbrDelete(imbr);
 		imbr = NULL;
@@ -712,8 +717,10 @@ gint EDVManageTimeoutCB(gpointer data)
 	    {
 		if(arch_info_dlg->freeze_count <= 0)
 		{
+		    /* Not mapped? */
 		    if(!EDVArchiveInfoIsMapped(arch_info_dlg))
 		    {
+			/* Delete it */
 			EDVArchiveInfoDelete(arch_info_dlg);
 			archiver->arch_info_dlg = NULL;
 		    }
@@ -727,7 +734,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else
 	    {
-		/* Unmapped, so delete it */
+		/* Not mapped, delete it */
 		core->archiver[i] = NULL;
 		EDVArchiverDelete(archiver);
 		archiver = NULL;
@@ -737,14 +744,14 @@ gint EDVManageTimeoutCB(gpointer data)
 	recbin = core->recbin;
 	if(recbin != NULL)
 	{
-	    /* Initialized and mapped? */
+	    /* Mapped? */
 	    if(EDVRecBinIsMapped(recbin))
 	    {
 		all_windows_unmapped = FALSE;
 	    }
 	    else if(conserve_memory)
 	    {
-		/* Unmapped and need to conserve memory, so delete it */
+		/* Not mapped and need to conserve memory, delete it */
 		core->recbin = NULL;
 		EDVRecBinDelete(recbin);
 		recbin = NULL;
@@ -762,7 +769,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    {
 		/* Never delete the object operations dialog since
 		 * it holds the last used values that needs to be
-		 * preserved
+		 * preserved for the next use
 		 */
 	    }
 	}
@@ -777,9 +784,8 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else
 	    {
-		/* Never delete the find window since it may hold
-		 * dynamic data (i.e. find results) that needs to be
-		 * preserved
+		/* Never delete the find window since it holds data
+		 * that needs to be preserved for the next use
 		 */
 	    }
 	}
@@ -797,7 +803,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else
 	    {
-		/* Unmapped, so delete it */
+		/* Not mapped, delete it */
 		core->propdlg[i] = NULL;
 		EDVPropDlgDelete(propdlg);
 		propdlg = NULL;
@@ -814,7 +820,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else if(conserve_memory)
 	    {
-		/* Unmapped and need to conserve memory, so delete it */
+		/* Not mapped and need to conserve memory, delete it */
 		core->history_listwin = NULL;
 		EDVHistoryWinDelete(histwin);
 		histwin = NULL;
@@ -830,7 +836,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else if(conserve_memory)
 	    {
-		/* Unmapped and need to conserve memory, so delete it */
+		/* Not mapped and need to conserve memory, delete it */
 		core->run_dlg = NULL;
 		EDVRunDlgDelete(rundlg);
 		rundlg = NULL;
@@ -847,7 +853,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else if(conserve_memory)
 	    {
-		/* Unmapped and need to conserve memory, so delete it */
+		/* Not mapped and need to conserve memory, delete it */
 		core->device_listwin = NULL;
 		EDVDevicesListWinDelete(deviceswin);
 		deviceswin = NULL;
@@ -863,7 +869,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else if(conserve_memory)
 	    {
-		/* Unmapped and need to conserve memory, so delete it */
+		/* Not mapped and need to conserve memory, delete it */
 		core->mimetype_listwin = NULL;
 		EDVMimeTypesListWinDelete(mimetypeswin);
 		mimetypeswin = NULL;
@@ -879,7 +885,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else if(conserve_memory)
 	    {
-		/* Unmapped and need to conserve memory, so delete it */
+		/* Not mapped and need to conserve memory, delete it */
 		core->options_window = NULL;
 		EDVGenOptWinDelete(optwin);
 		optwin = NULL;
@@ -895,7 +901,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else if(conserve_memory)
 	    {
-		/* Unmapped and need to conserve memory, so delete it */
+		/* Not mapped and need to conserve memory, delete it */
 		core->customize_window = NULL;
 		EDVGenOptWinDelete(optwin);
 		optwin = NULL;
@@ -912,7 +918,7 @@ gint EDVManageTimeoutCB(gpointer data)
 	    }
 	    else
 	    {
-		/* Unmapped, so delete it */
+		/* Not mapped, delete it */
 		core->about_dlg = NULL;
 		AboutDlgDelete(aboutdlg);
 		aboutdlg = NULL;
@@ -929,10 +935,10 @@ gint EDVManageTimeoutCB(gpointer data)
 		/* Removes all timeout callbacks and breaks out of
 		 * one GTK main loop
 		 */
-		DO_REMOVE_TIMEOUTS_AND_BREAK_MAIN
+		REMOVE_TIMEOUTS_AND_BREAK_MAIN;
 
 		/* Return and do not call this function again */
-		DO_RETURN_NO_RESCHEDUAL
+		RETURN_NO_RESCHEDUAL;
 	    }
 	}
 
@@ -978,13 +984,13 @@ gint EDVManageTimeoutCB(gpointer data)
 	}
 
 
-	DO_RETURN_RESCHEDUAL
+	RETURN_RESCHEDUAL;
 
-#undef DO_RETURN_RESCHEDUAL
-#undef DO_RETURN_NO_RESCHEDUAL
-#undef DO_RETURN_CURRENT_SCHEDUAL
-#undef DO_REMOVE_TIMEOUTS_AND_BREAK_MAIN
-#undef DO_REMOVE_TOID
+#undef RETURN_RESCHEDUAL
+#undef RETURN_NO_RESCHEDUAL
+#undef RETURN_CURRENT_SCHEDUAL
+#undef REMOVE_TIMEOUTS_AND_BREAK_MAIN
+#undef REMOVE_TOID
 }
 
 
@@ -1263,15 +1269,19 @@ void EDVRefreshCB(GtkWidget *widget, gpointer data)
  */
 void EDVPurgeAllRecycledObjectsCB(GtkWidget *widget, gpointer data)
 {
+	GtkWidget *toplevel = (widget != NULL) ?
+	    gtk_widget_get_toplevel(widget) : NULL;
 	edv_core_struct *core = EDV_CORE(data);
 	if(core == NULL)
 	    return;
 
-	/* Map the Recycle Bin */
-	EDVMapRecBin(core);
-
-	/* Purge all the objects from the Recycle Bin */
-	EDVRecBinOPPurgeAll(core->recbin);
+	EDVPurgeAllRecycledObjects(
+	    core,
+	    FALSE,			/* Do not map the recycle bin */
+	    TRUE,			/* Show progress */
+	    TRUE,			/* Interactive */
+	    toplevel
+	);
 }
 
 /*
@@ -1647,7 +1657,7 @@ void EDVFileSelectorObjectDeletedCB(
  *	The state should be the new write protect state.
  */
 void EDVWriteProtectChangedEmit(
-	edv_core_struct *core, gboolean state
+	edv_core_struct *core, const gboolean state
 )
 {
 	gint i;
@@ -1701,7 +1711,7 @@ void EDVWriteProtectChangedEmit(
  */
 void EDVObjectAddedEmit(
 	edv_core_struct *core, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	gint i;
@@ -1757,7 +1767,7 @@ void EDVObjectAddedEmit(
 void EDVObjectModifiedEmit(
 	edv_core_struct *core, const gchar *path,
 	const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	gint i;
@@ -1867,8 +1877,8 @@ void EDVObjectRemovedEmit(edv_core_struct *core, const gchar *path)
  */
 void EDVObjectMountEmit(
 	edv_core_struct *core,
-	gint dev_num, edv_device_struct *dev,
-	gboolean is_mounted
+	const gint dev_num, edv_device_struct *dev,
+	const gboolean is_mounted
 )
 {
 	gint i;
@@ -2038,10 +2048,10 @@ void EDVArchiveObjectRemovedEmit(
 
 
 /*
- *	Emits a recycled object added signal to all relivant windows.
+ *	Emits a recycled object added signal.
  */
 void EDVRecycledObjectAddedEmit(
-	edv_core_struct *core, guint index
+	edv_core_struct *core, const guint index
 )
 {
 	gint i;
@@ -2064,7 +2074,7 @@ void EDVRecycledObjectAddedEmit(
 	EDVDevicesListWinUsageChangedCB(core->device_listwin);
 
 #if 1
-	/* Update number of recycled objects */
+	/* Update the number of recycled objects */
 	core->last_recbin_items = EDVRecBinIndexGetTotal(
 	    recbin_index_file
 	);
@@ -2117,13 +2127,85 @@ void EDVRecycledObjectAddedEmit(
 	EDVRecBinRecycledObjectAddedNotifyCB(
 	    core->recbin, index
 	);
+
+	/* Property Dialogs */
+	for(i = 0; i < core->total_propdlgs; i++)
+	    EDVPropDlgRecycledObjectAddedNotifyCB(
+		core->propdlg[i], index
+	    );
 }
 
 /*
- *	Emits a recycled object removed signal to all relivant windows.
+ *	Emits a recycled object modified signal.
+ */
+void EDVRecycledObjectModifiedEmit(
+	edv_core_struct *core, const guint index
+)
+{
+	gint i;
+	const gchar *recbin_index_file;
+	const cfg_item_struct *cfg_list;
+
+	if(core == NULL)
+	    return;
+
+	cfg_list = core->cfg_list;
+
+	recbin_index_file = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
+
+	/* Update the devices list */
+	EDVDevicesListUpdateStats(
+	    core->device, core->total_devices
+	);
+
+	/* Update the devices list window */
+	EDVDevicesListWinUsageChangedCB(core->device_listwin);
+
+	/* Update the number of recycled objects */
+	core->last_recbin_items = EDVRecBinIndexGetTotal(
+	    recbin_index_file
+	);
+
+	/* Begin emitting signal */
+
+	/* File Browsers */
+	for(i = 0; i < core->total_browsers; i++)
+	    EDVBrowserRecycledObjectModifiedNotifyCB(
+		core->browser[i], index
+	    );
+
+	/* Image Browsers */
+	for(i = 0; i < core->total_imbrs; i++)
+	    EDVImbrRecycledObjectModifiedNotifyCB(
+		core->imbr[i], index
+	    );
+
+	/* Archivers */
+	for(i = 0; i < core->total_archivers; i++)
+	    EDVArchiverRecycledObjectModifiedNotifyCB(
+		core->archiver[i], index
+	    );
+
+	/* Recycle Bin Desktop Icon */
+	EDVRecBinDeskIconUpdate(core->recbin_deskicon);
+
+	/* Recycle Bin */
+	EDVRecBinRecycledObjectModifiedNotifyCB(
+	    core->recbin, index
+	);
+
+	/* Property Dialogs */
+	for(i = 0; i < core->total_propdlgs; i++)
+	    EDVPropDlgRecycledObjectModifiedNotifyCB(
+		core->propdlg[i], index
+	    );
+}
+
+/*
+ *	Emits a recycled object removed signal.
  */
 void EDVRecycledObjectRemovedEmit(
-	edv_core_struct *core, guint index
+	edv_core_struct *core, const guint index
 )
 {
 	gint i;
@@ -2198,6 +2280,12 @@ void EDVRecycledObjectRemovedEmit(
 	EDVRecBinRecycledObjectRemovedNotifyCB(
 	    core->recbin, index
 	);
+
+	/* Property Dialogs */
+	for(i = 0; i < core->total_propdlgs; i++)
+	    EDVPropDlgRecycledObjectRemovedNotifyCB(
+		core->propdlg[i], index
+	    );
 }
 
 
@@ -2505,11 +2593,11 @@ void EDVMimeTypeRemovedEmit(
 
 
 /*
- *	Emits a device reference added signal.
+ *	Emits a device added signal.
  */
 void EDVDeviceAddedEmit(
 	edv_core_struct *core,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 )
 {
 	gint i;
@@ -2542,11 +2630,11 @@ void EDVDeviceAddedEmit(
 }
 
 /*
- *	Emits a device reference modified signal.
+ *	Emits a device modified signal.
  */
 void EDVDeviceModifiedEmit(
 	edv_core_struct *core,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 )
 {
 	gint i;
@@ -2579,10 +2667,11 @@ void EDVDeviceModifiedEmit(
 }
 
 /*
- *	Emits a device reference removed signal.
+ *	Emits a device removed signal.
  */
 void EDVDeviceRemovedEmit(
-	edv_core_struct *core, gint dev_num
+	edv_core_struct *core,
+	const gint dev_num
 )
 {
 	gint i;
@@ -2620,7 +2709,7 @@ void EDVDeviceRemovedEmit(
  */
 void EDVHistoryAddedEmit(
 	edv_core_struct *core,
-	gint h_num, edv_history_struct *h
+	const gint h_num, edv_history_struct *h
 )
 {
 	if(core == NULL)
@@ -2640,7 +2729,7 @@ void EDVHistoryAddedEmit(
  */
 void EDVHistoryRemovedEmit(
 	edv_core_struct *core,
-	gint h_num
+	const gint h_num
 )
 {
 	if(core == NULL)
