@@ -3,18 +3,14 @@
 #include <gtk/gtk.h>
 
 #include "../include/string.h"
-#include "../include/disk.h"
 
 #include "cdialog.h"
 
 #include "cfg.h"
 #include "edv_types.h"
-#include "edv_obj.h"
-#include "edv_recycled_obj.h"
-#include "edv_recbin_stat.h"
-#include "edv_utils.h"
 #include "endeavour2.h"
 #include "edv_confirm.h"
+#include "edv_utils.h"
 #include "edv_utils_gtk.h"
 #include "edv_cfg_list.h"
 #include "config.h"
@@ -32,49 +28,49 @@
 
 gint EDVConfirmLink(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects,
+	const gchar *src_path, const gint nobjs,
 	const gchar *tar_path
 );
 gint EDVConfirmMove(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects,
+	const gchar *src_path, const gint nobjs,
 	const gchar *tar_path
 );
 gint EDVConfirmCopy(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects,
+	const gchar *src_path, const gint nobjs,
 	const gchar *tar_path
 );
 gint EDVConfirmDelete(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects
+	const gchar *src_path, const gint nobjs
 );
 
 gint EDVConfirmArchiveAdd(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects,
+	const gchar *src_path, const gint nobjs,
 	const gchar *arch_path
 );
 gint EDVConfirmArchiveExtract(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects,
+	const gchar *src_path, const gint nobjs,
 	const gchar *tar_path
 );
 gint EDVConfirmArchiveDelete(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects
+	const gchar *src_path, const gint nobjs
 );
 
 gint EDVConfirmRecover(
 	edv_core_struct *core, GtkWidget *toplevel,
 	const gchar *src_path,
-	gint total_objects,
+	const gint nobjs,
 	const gchar *tar_path
 );
 gint EDVConfirmPurge(
 	edv_core_struct *core, GtkWidget *toplevel,
 	const gchar *src_path,
-	gint total_objects
+	const gint nobjs
 );
 
 gint EDVConfirmDND(
@@ -86,16 +82,16 @@ gint EDVConfirmDND(
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 static gchar *G_STRCAT(gchar *s, const gchar *s2)
@@ -119,13 +115,21 @@ static gchar *G_STRCAT(gchar *s, const gchar *s2)
 /*
  *	Confirm link.
  *
- *	Returns one of CDIALOG_RESPONSE_*.
- *	Confirmation will always be CDIALOG_RESPONSE_YES if configuration
- *	specifies no confirmation for this operation.
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	The src_path specifies the full path to the last source object.
+ *
+ *	The nobjs specifies total number of source objects.
+ *
+ *	The tar_path specifies the full path to the target location.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*. If the configuration
+ *	specifies no confirmation then CDIALOG_RESPONSE_YES will be
+ *	returned.
  */
 gint EDVConfirmLink(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects,
+	const gchar *src_path, const gint nobjs,
 	const gchar *tar_path
 )
 {
@@ -163,7 +167,7 @@ gint EDVConfirmLink(
 #endif
 	;
 
-	if((total_objects == 1) && (src_path != NULL))
+	if((nobjs == 1) && (src_path != NULL))
 	    msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El enlace:\n\
@@ -267,7 +271,7 @@ To:\n\
 \n\
     %s"
 #endif
-		, total_objects, tar_path
+		, nobjs, tar_path
 	    );
 
 	EDVPlaySoundQuestion(core);
@@ -288,13 +292,21 @@ To:\n\
 /*
  *      Confirm move.
  *
- *      Returns one of CDIALOG_RESPONSE_*.
- *      Confirmation will always be CDIALOG_RESPONSE_YES if configuration
- *      specifies no confirmation for this operation.
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	The src_path specifies the full path to the last source object.
+ *
+ *	The nobjs specifies total number of source objects.
+ *
+ *	The tar_path specifies the full path to the target location.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*. If the configuration
+ *	specifies no confirmation then CDIALOG_RESPONSE_YES will be
+ *	returned.
  */
 gint EDVConfirmMove(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects,
+	const gchar *src_path, const gint nobjs,
 	const gchar *tar_path
 )
 {
@@ -332,7 +344,7 @@ gint EDVConfirmMove(
 #endif
 	;
 
-	if((total_objects == 1) && (src_path != NULL))
+	if((nobjs == 1) && (src_path != NULL))
 	    msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Mueva:\n\
@@ -436,7 +448,7 @@ To:\n\
 \n\
     %s"
 #endif
-		, total_objects, tar_path
+		, nobjs, tar_path
 	    );
 
 	EDVPlaySoundQuestion(core);
@@ -457,13 +469,21 @@ To:\n\
 /*
  *      Confirm copy.
  *
- *      Returns one of CDIALOG_RESPONSE_*.
- *      Confirmation will always be CDIALOG_RESPONSE_YES if configuration
- *      specifies no confirmation for this operation.
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	The src_path specifies the full path to the last source object.
+ *
+ *	The nobjs specifies total number of source objects.
+ *
+ *	The tar_path specifies the full path to the target location.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*. If the configuration
+ *	specifies no confirmation then CDIALOG_RESPONSE_YES will be
+ *	returned.
  */
 gint EDVConfirmCopy(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects,
+	const gchar *src_path, const gint nobjs,
 	const gchar *tar_path
 )
 {
@@ -502,7 +522,7 @@ gint EDVConfirmCopy(
 #endif
 	;
 
-	if((total_objects == 1) && (src_path != NULL))
+	if((nobjs == 1) && (src_path != NULL))
 	    msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "La Copia:\n\
@@ -606,7 +626,7 @@ To:\n\
 \n\
     %s"
 #endif
-		, total_objects, tar_path
+		, nobjs, tar_path
 	    );
 
 	EDVPlaySoundQuestion(core);
@@ -627,36 +647,39 @@ To:\n\
 /*
  *      Confirm delete or purge.
  *
- *      Returns one of CDIALOG_RESPONSE_*.
+ *	The toplevel specifies the toplevel GtkWidget.
  *
- *      Confirmation will always be CDIALOG_RESPONSE_YES if configuration
- *      specifies no confirmation for this operation.
+ *	The src_path specifies the full path to the last source object.
+ *
+ *	The nobjs specifies total number of source objects.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*. If the configuration
+ *	specifies no confirmation then CDIALOG_RESPONSE_YES will be
+ *	returned.
  */
 gint EDVConfirmDelete(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects
+	const gchar *src_path, const gint nobjs
 )
 {
 	gint response;
 	const gchar *title;
 	gchar *msg;
-	edv_delete_method delete_method;
 	guint8 **icon_data = (guint8 **)icon_trash_32x32_xpm;
 	const cfg_item_struct *cfg_list;
+	edv_delete_method delete_method;
 
 	if(core == NULL)
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
 	cfg_list = core->cfg_list;
 
-	if(!CFGItemListGetValueI(
-	    cfg_list, EDV_CFG_PARM_CONFIRM_DELETE
-	))
+	if(!EDV_GET_B(EDV_CFG_PARM_CONFIRM_DELETE))
 	    return(CDIALOG_RESPONSE_YES);
 
 	/* Get the current delete method */
-	delete_method = (edv_delete_method)CFGItemListGetValueI(
-	    cfg_list, EDV_CFG_PARM_DELETE_METHOD
+	delete_method = (edv_delete_method)EDV_GET_I(
+	    EDV_CFG_PARM_DELETE_METHOD
 	);
 
 
@@ -682,7 +705,7 @@ gint EDVConfirmDelete(
 #endif
 	;
 
-	if((total_objects == 1) && (src_path != NULL))
+	if((nobjs == 1) && (src_path != NULL))
 	{
 	    mode_t m;
 	    struct stat lstat_buf;
@@ -690,12 +713,12 @@ gint EDVConfirmDelete(
 	    const gchar *name = g_basename(src_path);
 	    gchar *type_str;
 
-	    if(lstat(src_path, &lstat_buf))
+	    if(lstat((const char *)src_path, &lstat_buf))
 		memset(&lstat_buf, 0x00, sizeof(struct stat));
 
 	    m = lstat_buf.st_mode;
-	    type = EDVObjectGetTypeFromStatMode(m);
-	    type_str = STRDUP(EDVObjectGetTypeName(type));
+	    type = EDVStatModeToObjectType(m);
+	    type_str = STRDUP(EDVGetObjectTypeName(type));
 	    if(type_str != NULL)
 		strtolower(type_str);
 
@@ -789,7 +812,7 @@ Including any contents within that directory."
 #else
 "Delete %i selected objects?"
 #endif
-		, total_objects
+		, nobjs
 	    );
 
 	/* If the delete method is EDV_DELETE_METHOD_PURGE then
@@ -847,15 +870,23 @@ once they have been deleted!"
 }
 
 /*
- *      Confirm adding of disk object(s) to an archive.
+ *	Confirm add to archive.
  *
- *      Returns one of CDIALOG_RESPONSE_*.
- *      Confirmation will always be CDIALOG_RESPONSE_YES if configuration
- *      specifies no confirmation for this operation.
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	The src_path specifies the full path to the last source object.
+ *
+ *	The nobjs specifies total number of source objects.
+ *
+ *	The tar_path specifies the full path to the archive.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*. If the configuration
+ *	specifies no confirmation then CDIALOG_RESPONSE_YES will be
+ *	returned.
  */
 gint EDVConfirmArchiveAdd(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects,
+	const gchar *src_path, const gint nobjs,
 	const gchar *arch_path
 )
 {
@@ -863,7 +894,6 @@ gint EDVConfirmArchiveAdd(
 	const gchar *title;
 	gchar *msg;
 
-
 	if(core == NULL)
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
@@ -894,7 +924,7 @@ gint EDVConfirmArchiveAdd(
 #endif
 	;
 
-	if((total_objects == 1) && (src_path != NULL))
+	if((nobjs == 1) && (src_path != NULL))
 	    msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Agregue:\n\
@@ -998,7 +1028,7 @@ To Archive:\n\
 \n\
     %s"
 #endif
-		, total_objects, arch_path
+		, nobjs, arch_path
 	    );
 
 	EDVPlaySoundQuestion(core);
@@ -1017,16 +1047,23 @@ To Archive:\n\
 }
 
 /*
- *      Confirm extracting of archive object(s) to from an archive
- *	to the target disk object path.
+ *	Confirm extract from archive.
  *
- *      Returns one of CDIALOG_RESPONSE_*.
- *      Confirmation will always be CDIALOG_RESPONSE_YES if configuration
- *      specifies no confirmation for this operation.
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	The src_path specifies the path of the object in the archive.
+ *
+ *	The nobjs specifies total number of source objects.
+ *
+ *	The tar_path specifies the full path to the target location.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*. If the configuration
+ *	specifies no confirmation then CDIALOG_RESPONSE_YES will be
+ *	returned.
  */
 gint EDVConfirmArchiveExtract(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects,
+	const gchar *src_path, const gint nobjs,
 	const gchar *tar_path
 )
 {
@@ -1034,7 +1071,6 @@ gint EDVConfirmArchiveExtract(
 	const gchar *title;
 	gchar *msg;
 
-
 	if(core == NULL)
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
@@ -1065,7 +1101,7 @@ gint EDVConfirmArchiveExtract(
 #endif
 	;
 
-	if((total_objects == 1) && (src_path != NULL))
+	if((nobjs == 1) && (src_path != NULL))
 	    msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El Extracto:\n\
@@ -1169,7 +1205,7 @@ To:\n\
 \n\
     %s"
 #endif
-		, total_objects, tar_path
+		, nobjs, tar_path
 	    );
 
 	EDVPlaySoundQuestion(core);
@@ -1188,15 +1224,21 @@ To:\n\
 }
 
 /*
- *      Confirm delete archive object.
+ *	Confirm delete from archive.
  *
- *      Returns one of CDIALOG_RESPONSE_*.
- *      Confirmation will always be CDIALOG_RESPONSE_YES if configuration
- *      specifies no confirmation for this operation.
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	The src_path specifies the path of the object in the archive.
+ *
+ *	The nobjs specifies total number of source objects.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*. If the configuration
+ *	specifies no confirmation then CDIALOG_RESPONSE_YES will be
+ *	returned.
  */
 gint EDVConfirmArchiveDelete(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects
+	const gchar *src_path, const gint nobjs
 )
 {
 	gint response;
@@ -1233,7 +1275,7 @@ gint EDVConfirmArchiveDelete(
 #endif
 	;
 
-	if((total_objects == 1) && (src_path != NULL))
+	if((nobjs == 1) && (src_path != NULL))
 	    msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Borre:\n\
@@ -1337,7 +1379,7 @@ som de strket!"
 These objects in the archive cannot be recovered once\n\
 they have been deleted!"
 #endif
-		, total_objects
+		, nobjs
 	    );
 
 	EDVPlaySoundQuestion(core);
@@ -1357,16 +1399,24 @@ they have been deleted!"
 
 
 /*
- *	Confirm recovering of a recycled object.
+ *	Confirm recover.
  *
- *      Returns one of CDIALOG_RESPONSE_*.
- *      Confirmation will always be CDIALOG_RESPONSE_YES if configuration
- *      specifies no confirmation for this operation.
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	The src_path specifies the path to the recycled object.
+ *
+ *	The nobjs specifies total number of source objects.
+ *
+ *	The tar_path specifies the full path to the recovery location.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*. If the configuration
+ *	specifies no confirmation then CDIALOG_RESPONSE_YES will be
+ *	returned.
  */
 gint EDVConfirmRecover(
 	edv_core_struct *core, GtkWidget *toplevel,
 	const gchar *src_path,
-	gint total_objects,
+	const gint nobjs,
 	const gchar *tar_path
 )
 {
@@ -1374,21 +1424,19 @@ gint EDVConfirmRecover(
 	const gchar *title;
 	gchar *msg;
 	const gchar *recycled_index_file;
-
+	cfg_item_struct *cfg_list;
 
 	if(core == NULL)
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
-	if(!CFGItemListGetValueI(
-	    core->cfg_list, EDV_CFG_PARM_CONFIRM_RECOVER
-	))
+	cfg_list = core->cfg_list;
+
+	if(!EDV_GET_B(EDV_CFG_PARM_CONFIRM_RECOVER))
 	    return(CDIALOG_RESPONSE_YES);
 
 
-	/* Get path to recycled objects index file */
-	recycled_index_file = CFGItemListGetValueS(
-	    core->cfg_list, EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX
-	);
+	/* Get the path to recycled objects index file */
+	recycled_index_file = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
 
 
 	/* Format confirmation title and message */
@@ -1413,7 +1461,7 @@ gint EDVConfirmRecover(
 #endif
 	;
 
-	if((total_objects == 1) && (src_path != NULL))
+	if((nobjs == 1) && (src_path != NULL))
 	{
 	    msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1520,7 +1568,7 @@ To:\n\
 \n\
     %s"
 #endif
-		, total_objects, tar_path
+		, nobjs, tar_path
 	    );
 	}
 	else
@@ -1543,7 +1591,7 @@ To:\n\
 #else
 "Recover %i recycled objects?"
 #endif
-		, total_objects
+		, nobjs
 	    );
 	}
 
@@ -1563,35 +1611,40 @@ To:\n\
 }
 
 /*
- *      Confirm purge of a recycled object.
+ *	Confirm purge.
  *
- *      Returns one of CDIALOG_RESPONSE_*.
- *      Confirmation will always be CDIALOG_RESPONSE_YES if configuration
- *      specifies no confirmation for this operation.
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	The src_path specifies the path to the recycled object.
+ *
+ *	The nobjs specifies total number of source objects.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*. If the configuration
+ *	specifies no confirmation then CDIALOG_RESPONSE_YES will be
+ *	returned.
  */
 gint EDVConfirmPurge(
 	edv_core_struct *core, GtkWidget *toplevel,
-	const gchar *src_path, gint total_objects
+	const gchar *src_path, const gint nobjs
 )
 {
 	gint response;
 	const gchar *title;
 	gchar *msg;
 	const gchar *recycled_index_file;
+	cfg_item_struct *cfg_list;
 
 	if(core == NULL)
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
-	if(!CFGItemListGetValueI(
-	    core->cfg_list, EDV_CFG_PARM_CONFIRM_PURGE
-	))
+	cfg_list = core->cfg_list;
+
+	if(!EDV_GET_B(EDV_CFG_PARM_CONFIRM_PURGE))
 	    return(CDIALOG_RESPONSE_YES);
 
 
-	/* Get path to recycled objects index file */
-	recycled_index_file = CFGItemListGetValueS(
-	    core->cfg_list, EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX
-	);
+	/* Get the path to recycled objects index file */
+	recycled_index_file = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
 
 
 	/* Format confirmation title and message */
@@ -1616,7 +1669,7 @@ gint EDVConfirmPurge(
 #endif
 	;
 
-	if((total_objects == 1) && (src_path != NULL))
+	if((nobjs == 1) && (src_path != NULL))
 	{
 	    msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1707,7 +1760,7 @@ de renset!"
 You will not be able to recover these objects\n\
 once they have been purged!"
 #endif
-		, total_objects
+		, nobjs
 	    );
 	}
 
@@ -1728,8 +1781,21 @@ once they have been purged!"
 
 
 /*
- *	Calls appropriate confirmation based on the given GTK DND 
+ *	Calls the appropriate confirmation based on the GTK DND 
  *	information regarding the target type and the drag action.
+ *
+ *	The gdk_action specifies the drag action, which can be one
+ *	of GDK_ACTION_*.
+ *
+ *	The info specifies the DND data type.
+ *
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	The url_list specifies a GList of url_struct * URLs.
+ *
+ *	The tar_path specifies the target location.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*.
  */
 gint EDVConfirmDND(
 	edv_core_struct *core,
