@@ -17,20 +17,18 @@
 #include "../include/disk.h"
 
 #include "guiutils.h"
+#include "splash.h"
 #include "cdialog.h"
 #include "pulist.h"
 
 #include "cfg.h"
 #include "cfg_fio.h"
+
 #include "edv_types.h"
 #include "edv_id.h"
 #include "edv_pixmap.h"
 #include "edv_cursor.h"
-#include "edv_obj.h"
-#include "edv_recycled_obj.h"
 #include "edv_date.h"
-#include "edv_history.h"
-#include "edv_obj.h"
 #include "edv_recbin_index.h"
 #include "edv_device.h"
 #include "edv_devices_list.h"
@@ -55,11 +53,15 @@
 #include "edv_utils.h"
 #include "edv_utils_gtk.h"
 
+/* Instruct edv_cfg_list.h to #define EDV_CONFIGURATION_LIST */
 #define NEED_EDV_CFG_LIST_SOURCE
 #include "edv_cfg_list.h"
+
 #include "config.h"
 
 
+static gint EDVOpenProgressCB(gpointer data, gulong i, gulong n);
+
 static GList *EDVNewGListLength(const guint length, gpointer datas);
 static void EDVNewGListSetNthData(GList *glist, const guint n, gpointer data);
 
@@ -92,6 +94,21 @@ void EDVDelete(
 #define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
+/*
+ *	Any open function progress callback.
+ */
+static gint EDVOpenProgressCB(gpointer data, gulong i, gulong n)
+{
+	splash_struct *splash = SPLASH(data);
+	if(splash != NULL)
+	{
+	    SplashUpdate(splash);
+	}
+
+	return(0);
+}
+
+
 /*
  *	Creates a new GList of the specified length.
  */
@@ -413,7 +430,9 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	EDV_SET_B(EDV_CFG_PARM_STARTUP_RECBIN, FALSE);
 
 
-	/* File Browser Geometry */
+	/* File Browser
+	 *
+	 * Geometry */
 	EDV_SET_I(EDV_CFG_PARM_BROWSER_X, 0);
 	EDV_SET_I(EDV_CFG_PARM_BROWSER_Y, 0);
 	EDV_SET_I(EDV_CFG_PARM_BROWSER_WIDTH, EDV_DEF_BROWSER_WIDTH);
@@ -430,18 +449,29 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	glist = NULL;
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_GOTO_PARENT);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_GOTO_HOME);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_MOUNT);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_DIRECTORY_TREE_ORIGIN);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_REFRESH);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_COPY_PATH);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_PASTE);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_NEW_DIRECTORY);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_MOVE);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_COPY);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_LINK);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_RENAME);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_CHMOD);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_CHTIME);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_DELETE);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_PROPERTIES);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_DOWNLOAD);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_SEPARATOR);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_NEW_BROWSER);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_NEW_IMBR);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_NEW_ARCHIVER);
 	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_RECYCLE_BIN);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_RUN_TERMINAL);
 	intlist = CFGIntListNew(glist);
 	g_list_free(glist);
 	EDV_SET_INTLIST(EDV_CFG_PARM_BROWSER_TOOL_BAR, intlist);
@@ -449,7 +479,7 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 
 	EDV_SET_I(
 	    EDV_CFG_PARM_BROWSER_TOOL_BAR_DISPLAY,
-	    (gint)TOOLBAR_DISPLAY_PICTURES_AND_TEXT
+	    (gint)TOOLBAR_DISPLAY_PICTURES
 	);
 	EDV_SET_I(
 	    EDV_CFG_PARM_BROWSER_TOOL_BAR_RELIEF,
@@ -459,6 +489,7 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	EDV_SET_S(EDV_CFG_PARM_BROWSER_DIR_TREE_ORIGIN, "/");
 
 	EDV_SET_S(EDV_CFG_PARM_BROWSER_CONTENTS_LIST_FILTER, "*");
+	EDV_SET_B(EDV_CFG_PARM_BROWSER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS, FALSE);
 	EDV_SET_B(EDV_CFG_PARM_BROWSER_CONTENTS_HIDE_DIR_SIZE, FALSE);
 	EDV_SET_B(EDV_CFG_PARM_BROWSER_CONTENTS_HIDE_LINK_PERMISSIONS, FALSE);
 
@@ -547,7 +578,10 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	CFGAccelkeyListDelete(ak_list);
 
 
-	/* Image Browser Geometry */
+	/* Image Browser
+	 *
+	 * Geometry
+	 */
 	EDV_SET_I(EDV_CFG_PARM_IMBR_X, 0);
 	EDV_SET_I(EDV_CFG_PARM_IMBR_Y, 0);
 	EDV_SET_I(EDV_CFG_PARM_IMBR_WIDTH, EDV_DEF_IMBR_WIDTH);
@@ -567,19 +601,32 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	glist = NULL;
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_GOTO_PARENT);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_GOTO_HOME);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_MOUNT);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_REFRESH);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_CONTINUE);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_STOP);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_PRESENTATION_MODE);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_COPY_PATH);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_PASTE);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_NEW_DIRECTORY);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_MOVE);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_COPY);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_LINK);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_RENAME);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_CHMOD);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_CHTIME);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_DELETE);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_PROPERTIES);
-	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_SEPARATOR);
-	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_STOP);
-	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_CONTINUE);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_DOWNLOAD);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_SEPARATOR);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_NEW_BROWSER);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_NEW_IMBR);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_NEW_ARCHIVER);
 	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_RECYCLE_BIN);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_RUN_TERMINAL);
 	intlist = CFGIntListNew(glist);
 	g_list_free(glist);
 	EDV_SET_INTLIST(EDV_CFG_PARM_IMBR_TOOL_BAR, intlist);
@@ -587,7 +634,7 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 
 	EDV_SET_I(
 	    EDV_CFG_PARM_IMBR_TOOL_BAR_DISPLAY,
-	    (gint)TOOLBAR_DISPLAY_PICTURES_AND_TEXT
+	    (gint)TOOLBAR_DISPLAY_PICTURES
 	);
 	EDV_SET_I(
 	    EDV_CFG_PARM_IMBR_TOOL_BAR_RELIEF,
@@ -649,7 +696,10 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	EDV_SET_B(EDV_CFG_PARM_PRESENTATION_SLIDESHOW, FALSE);
 	EDV_SET_L(EDV_CFG_PARM_PRESENTATION_SLIDESHOW_DELAY, 3l);
 
-	/* Archiver Geometry */
+	/* Archiver
+	 *
+	 * Geometry
+	 */
 	EDV_SET_I(EDV_CFG_PARM_ARCHIVER_X, 0);
 	EDV_SET_I(EDV_CFG_PARM_ARCHIVER_Y, 0);
 	EDV_SET_I(EDV_CFG_PARM_ARCHIVER_WIDTH, EDV_DEF_ARCHIVER_WIDTH);
@@ -665,13 +715,15 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	/* Tool Bar */
 	glist = NULL;
 	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_OPEN);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_REFRESH);
 	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_SEPARATOR);
 	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_ADD);
 	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_EXTRACT);
 	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_EXTRACT_ALL);
 	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_DELETE);
 	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_SEPARATOR);
-	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_REFRESH);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_NEW);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_SEPARATOR);
 	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_COMMENT_AND_STATISTICS);
 	intlist = CFGIntListNew(glist);
 	g_list_free(glist);
@@ -710,6 +762,9 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	    EDV_ARCHIVER_CONTENTS_CLIST_COLUMNS_MAX,
 	    (gpointer)0
 	);
+	EDVNewGListSetNthData(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_INDEX, (gpointer)60
+	);
 	EDVNewGListSetNthData(glist,
 	    EDV_ARCHIVER_COLUMN_TYPE_NAME, (gpointer)150
 	);
@@ -764,6 +819,7 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	CFGIntListDelete(intlist);
 
 	EDV_SET_S(EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_FILTER, "*");
+	EDV_SET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_AUTO_RESIZE_COLUMNS, FALSE);
 
 	/* Accelerator Keys */
 	ak_list = EDVArchiverAccelkeysListNewDefault();
@@ -771,7 +827,10 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	CFGAccelkeyListDelete(ak_list);
 
 
-	/* Recycle Bin Geometry */
+	/* Recycle Bin
+	 *
+	 * Geometry
+	 */
 	EDV_SET_I(EDV_CFG_PARM_RECBIN_X, 0);
 	EDV_SET_I(EDV_CFG_PARM_RECBIN_Y, 0);
 	EDV_SET_I(EDV_CFG_PARM_RECBIN_WIDTH, EDV_DEF_RECBIN_WIDTH);
@@ -788,12 +847,17 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 
 	/* Tool Bar */
 	glist = NULL;
-	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_RECOVER);
-	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_SEPARATOR);
-	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_PURGE);
 	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_PURGE_ALL);
 	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_SEPARATOR);
-	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_REFRESH);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_RECOVER);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_PURGE);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_RENAME);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_CHMOD);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_CHTIME);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_PROPERTIES);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_SYNC_RECYCLE_BIN);
 	intlist = CFGIntListNew(glist);
 	g_list_free(glist);
 	EDV_SET_INTLIST(EDV_CFG_PARM_RECBIN_TOOL_BAR, intlist);
@@ -801,7 +865,7 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 
 	EDV_SET_I(
 	    EDV_CFG_PARM_RECBIN_TOOL_BAR_DISPLAY,
-	    (gint)TOOLBAR_DISPLAY_PICTURES_AND_TEXT
+	    (gint)TOOLBAR_DISPLAY_PICTURES
 	);
 	EDV_SET_I(
 	    EDV_CFG_PARM_RECBIN_TOOL_BAR_RELIEF,
@@ -830,6 +894,9 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	    EDV_RECBIN_CONTENTS_CLIST_COLUMNS_MAX,
 	    (gpointer)0
 	);
+	EDVNewGListSetNthData(glist,
+	    EDV_RECBIN_COLUMN_TYPE_INDEX, (gpointer)60
+	);
 	EDVNewGListSetNthData(glist,
 	    EDV_RECBIN_COLUMN_TYPE_NAME, (gpointer)150
 	);
@@ -866,9 +933,6 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	EDVNewGListSetNthData(glist,
 	    EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION, (gpointer)150
 	);
-	EDVNewGListSetNthData(glist,
-	    EDV_RECBIN_COLUMN_TYPE_INDEX, (gpointer)60
-	);
 	EDVNewGListSetNthData(glist,
 	    EDV_RECBIN_COLUMN_TYPE_CAPACITY_USED, (gpointer)85
 	);
@@ -878,6 +942,7 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	CFGIntListDelete(intlist);
 
 	EDV_SET_S(EDV_CFG_PARM_RECBIN_CONTENTS_LIST_FILTER, "*");
+	EDV_SET_B(EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS, FALSE);
 
 	/* Accelerator Keys */
 	ak_list = EDVRecBinAccelkeysListNewDefault();
@@ -895,8 +960,8 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	EDV_SET_S(EDV_CFG_PARM_FINDWIN_SEARCH_STRING, "");
 	/* Find Window Operation */
 	EDV_SET_I(
-	    EDV_CFG_PARM_FINDWIN_FIND_OP,
-	    (gint)EDV_FIND_WIN_FIND_OBJECT_NAME
+	    EDV_CFG_PARM_FIND_WIN_FIND_BY,
+	    (gint)EDV_FIND_WIN_FIND_BY_NAME
 	);
 	/* Find Window Case Sensitive */
 	EDV_SET_B(EDV_CFG_PARM_FINDWIN_CASE_SENSITIVE, FALSE);
@@ -933,34 +998,27 @@ static void EDVNewCreateStandardCursors(edv_core_struct *core)
 	GdkColor	c_fg = { 0, 0xffff, 0xffff, 0xffff },
 			c_bg = { 0, 0x0000, 0x0000, 0x0000 };
 
-#define APPEND_CURSOR(_cursor_)		{		\
- const gint i = MAX(core->total_cursors, 0);	\
- core->total_cursors = i + 1;			\
-							\
- core->cursor = (edv_cursor_struct **)g_realloc(	\
-  core->cursor,					\
-  core->total_cursors * sizeof(edv_cursor_struct *)	\
- );							\
- if(core->cursor == NULL) {				\
-  core->total_cursors = 0;				\
-  EDVCursorDelete(_cursor_);				\
- } else {						\
-  core->cursor[i] = (_cursor_);			\
- }							\
+#define APPEND_CURSOR(_cursor_)		{	\
+ if((_cursor_) != NULL) {			\
+  core->cursors_list = g_list_append(		\
+   core->cursors_list,				\
+   (_cursor_)					\
+  );						\
+ }						\
 }
-#define APPEND_CURSOR_PRESET(_code_,_gdk_type_)	{	\
- edv_cursor_struct *cursor = EDVCursorNewGDKPreset(	\
-  (_code_), (_gdk_type_)				\
- );							\
- APPEND_CURSOR(cursor);					\
+#define APPEND_CURSOR_PRESET(_code_,_gdk_type_)	{		\
+ edv_cursor_struct *cursor = EDVCursorNewFromGDKCursorType(	\
+  (_code_), (_gdk_type_)					\
+ );								\
+ APPEND_CURSOR(cursor);						\
 }
 #define APPEND_CURSOR_PIXMAP(_code_,_cm_,_tm_,_hx_,_hy_) {	\
- APPEND_CURSOR(EDVCursorNew(				\
-  (_code_),						\
-  gdk_cursor_new_from_pixmap(				\
-   (_cm_), (_tm_), &c_fg, &c_bg, (_hx_), (_hy_)		\
-  )							\
- ));							\
+ APPEND_CURSOR(EDVCursorNewFromGDKCursor(			\
+  (_code_),							\
+  gdk_cursor_new_from_pixmap(					\
+   (_cm_), (_tm_), &c_fg, &c_bg, (_hx_), (_hy_)			\
+  )								\
+ ));								\
 }
 
 	/* Begin creating cursors */
@@ -1217,15 +1275,33 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			*startup_full_path = NULL,
 			hostname[64 + 1];
 	cfg_item_struct	*cfg_list;
+	splash_struct *splash = NULL;
 	edv_core_struct *core;
 
 	if(error_rtn != NULL)
 	    *error_rtn = 0;
 
-#define CLEANUP_RETURN(_v_)	{		\
+#define CLEANUP_RETURN(_v_,_error_rtn_val_,_errno_val_) {	\
  g_free(cwd);					\
  g_free(startup_full_path);			\
 						\
+ /* Unmap and delete the splash as needed */	\
+ if(splash != NULL) {				\
+  SplashUnmap(					\
+   splash,					\
+   SPLASH_EFFECTS_FADE_BACKGROUND,		\
+   SPLASH_DEF_UNMAP_DURATION_MS			\
+  );						\
+  SplashDelete(splash);				\
+ }						\
+						\
+ /* Set the error return value */		\
+ if(error_rtn != NULL)				\
+  *error_rtn = (_error_rtn_val_);		\
+						\
+ /* Set the errno value */			\
+ errno = (int)(_errno_val_);			\
+						\
  return(_v_);					\
 }
 
@@ -1242,9 +1318,12 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 	core = EDV_CORE(g_malloc0(sizeof(edv_core_struct)));
 	if(core == NULL)
 	{
-	    if(error_rtn != NULL)
-		*error_rtn = -3;
-	    return(NULL);
+	    const gint error_code = (gint)errno;
+	    g_printerr(
+"EDVNew(): Unable to allocate memory for the core: %s.\n",
+		g_strerror(error_code)
+	    );
+	    CLEANUP_RETURN(NULL, -3, ENOMEM);
 	}
 
 	/* Set the initial runlevel at construct */
@@ -1321,8 +1400,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 	core->effective_user_id_str = NULL;
 	core->effective_user_id_host_str = NULL;
 
-	core->cursor = NULL;
-	core->total_cursors = 0;
+	core->cursors_list = NULL;
 
 	core->device = NULL;
 	core->total_devices = 0;
@@ -1396,9 +1474,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* No Splash? */
@@ -1608,9 +1684,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}		
 	    }
 	    /* Font name? */
@@ -1634,9 +1708,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Foreground color name? */
@@ -1660,9 +1732,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Background color name? */
@@ -1686,9 +1756,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Selected foreground color name? */
@@ -1712,9 +1780,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Selected background color name? */
@@ -1738,9 +1804,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Pointer cursor foreground color name? */
@@ -1764,9 +1828,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Pointer cursor background color name? */
@@ -1790,9 +1852,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Background pixmap path? */
@@ -1816,9 +1876,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Selected background pixmap path? */
@@ -1842,9 +1900,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 
@@ -1867,9 +1923,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Class? */
@@ -1891,9 +1945,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Title? */
@@ -1915,9 +1967,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 			arg
 		    );
 		    EDVDelete(core, FALSE);
-		    if(error_rtn != NULL)
-			*error_rtn = -2;
-		    CLEANUP_RETURN(NULL);
+		    CLEANUP_RETURN(NULL, -2, EINVAL);
 		}
 	    }
 	    /* Non-switch argument? */
@@ -2059,7 +2109,8 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 	{
 	    if(safe_mode)
 		g_print(
-"%s: Current configuration file version %i.%i.%i is different from the program version %s.\n",
+"%s: Current configuration file version %i.%i.%i is different from the\
+ program version %s.\n",
 		    core->cfg_file,
 		    old_version_major, old_version_minor, old_version_release,
 		    PROG_VERSION
@@ -2153,9 +2204,33 @@ InterPS command.\n",
 	    g_free(cmd);
 
 	    EDVDelete(core, FALSE);
-	    CLEANUP_RETURN(NULL);
+	    CLEANUP_RETURN(NULL, 0, 0);
 	}
 
+	/* Create the splash */
+	if(!no_splash)
+	{
+	    const gchar *data_dir = EDV_GET_S(EDV_CFG_PARM_DIR_GLOBAL);
+	    gchar *xpm_file = STRDUP(PrefixPaths(
+                data_dir, EDV_DEF_SPLASH_IMAGE_FILE
+            ));
+
+	    splash = SplashNew();
+	    SplashSetXPMFile(splash, xpm_file);
+	    SplashSetMessageJustification(splash, GTK_JUSTIFY_CENTER);
+	    SplashSetMessagePosition(splash, GTK_POS_BOTTOM);
+	    SplashUpdateMessage(splash, -1.0f, NULL);
+            SplashMap(
+                splash,
+                SPLASH_EFFECTS_FADE_BACKGROUND,
+		SPLASH_DEF_MAP_DURATION_MS,
+                GTK_WIN_POS_CENTER
+            );
+
+	    g_free(xpm_file);
+	}
+
+
 	/* (Re)create the InterPS lock link and remove any queued
 	 * interprocess commands
 	 */
@@ -2167,8 +2242,8 @@ InterPS command.\n",
 	    if(cfg_list != NULL)
 	    {
 		const gint error_code = (gint)errno;
-		const gchar *local_dir = CFGItemListGetValueS(
-		    cfg_list, EDV_CFG_PARM_DIR_LOCAL
+		const gchar *local_dir = EDV_GET_S(
+		    EDV_CFG_PARM_DIR_LOCAL
 		);
 		gchar *lock_link = g_strconcat(
 		    (local_dir != NULL) ? local_dir : "/",
@@ -2191,7 +2266,7 @@ InterPS command.\n",
 	    break;
 	}
 	EDVInterPSRemoveCommandsList(cfg_list);
-
+	SplashUpdate(splash);
 
 	/* Get the full path to the recycle bin index file */
 	recbin_index_file = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
@@ -2200,6 +2275,7 @@ InterPS command.\n",
 	core->last_recbin_items = EDVRecBinIndexGetTotal(
 	    recbin_index_file
 	);
+	SplashUpdate(splash);
 
 	/* Load the default font if specified */
 	if(!STRISEMPTY(core->font_name))
@@ -2209,13 +2285,15 @@ InterPS command.\n",
 
 	/* Create the RC styles */
 	EDVUpdateRCStyles(core);
+	SplashUpdate(splash);
 
 	/* Update the global tooltips state */
 	GUISetGlobalTipsState(EDV_GET_B(EDV_CFG_PARM_SHOW_TOOLTIPS));
+	SplashUpdate(splash);
 
 	/* Create the standard cursors */
 	EDVNewCreateStandardCursors(core);
-
+	SplashUpdate(splash);
 
 
 
@@ -2224,20 +2302,22 @@ InterPS command.\n",
 	 */
 	EDVDevicesListLoadFromSystem(
 	    &core->device, &core->total_devices,
-	    NULL, core
+	    EDVOpenProgressCB, splash
 	);
 	EDVDevicesListFileOpen(
 	    EDV_GET_S(EDV_CFG_PARM_FILE_DEVICES),
 	    &core->device, &core->total_devices,
-	    NULL, core
+	    EDVOpenProgressCB, splash
 	);
 	/* Get the device mount states & stats */
 	EDVDevicesListUpdateMountStates(
 	    core->device, core->total_devices
 	);
+	SplashUpdate(splash);
 	EDVDevicesListUpdateStats(
 	    core->device, core->total_devices
 	);
+	SplashUpdate(splash);
 
 
 	/* Open the MIME Types from the following files in the 
@@ -2251,7 +2331,7 @@ InterPS command.\n",
 	    EDV_GET_S(EDV_CFG_PARM_DIR_GLOBAL),
 	    &core->mimetype, &core->total_mimetypes,
 	    -1,			/* Append */
-	    NULL, core,
+	    EDVOpenProgressCB, splash,
 	    NULL, core,
 	    TRUE		/* Read only */
 	);
@@ -2261,7 +2341,7 @@ InterPS command.\n",
 	    -1,			/* Append */
 	    FALSE,		/* Do not update */
 	    FALSE,		/* Not only newer */
-	    NULL, core,
+	    EDVOpenProgressCB, splash,
 	    NULL, core,
 	    NULL, core,
 	    FALSE		/* Not read only */
@@ -2272,24 +2352,42 @@ InterPS command.\n",
 	    -1,			/* Append */
 	    FALSE,		/* Do not update */
 	    FALSE,		/* Not only newer */
-	    NULL, core,
+	    EDVOpenProgressCB, splash,
 	    NULL, core,
 	    NULL, core,
 	    TRUE		/* Read only */
 	);
+	SplashUpdate(splash);
 	/* Update the MIME Types class list index hints */
 	EDVUpdateMIMETypeHintIndices(core);
 /* TODO: Warn if no local or global MIME Types were opened */
+	SplashUpdate(splash);
 
 
 	/* Create the Users & Groups popup lists */
 	EDVUpdateIDPULists(core);
+	SplashUpdate(splash);
 
 	/* Create the Devices popup list */
 	EDVUpdateDevicesPUList(core);
+	SplashUpdate(splash);
 
 	/* Create the Open With popup list */
 	EDVUpdateOpenWithPUList(core);
+	SplashUpdate(splash);
+
+
+	/* Unmap the splash */
+	if(splash != NULL)
+	{
+	    SplashUnmap(
+		splash,
+		SPLASH_EFFECTS_FADE_BACKGROUND,
+		SPLASH_DEF_UNMAP_DURATION_MS
+	    );
+	    SplashDelete(splash);
+	    splash = NULL;
+	}
 
 
 #if !defined(DEBIAN)
@@ -2476,7 +2574,7 @@ by going to Settings->Options... and Settings->Customize...\n"
 	/* Set the runlevel to idle */
 	core->runlevel = EDV_RUNLEVEL_IDLE;
 
-	CLEANUP_RETURN(core);
+	CLEANUP_RETURN(core, 0, 0);
 #undef CLEANUP_RETURN
 }
 
@@ -2633,11 +2731,16 @@ void EDVDelete(
 	core->total_devices = 0;
 
 	/* Delete all the Cursors */
-	for(i = 0; i < core->total_cursors; i++)
-	    EDVCursorDelete(core->cursor[i]);
-	g_free(core->cursor);
-	core->cursor = NULL;
-	core->total_cursors = 0;
+	if(core->cursors_list != NULL)
+	{
+	    g_list_foreach(
+		core->cursors_list,
+		(GFunc)EDVCursorDelete,
+		NULL
+	    );
+	    g_list_free(core->cursors_list);
+	    core->cursors_list = NULL;
+	}
 
 
 	/* Delete the configuration list */
