@@ -1,5 +1,5 @@
 /*
-                      Endeavour Pointer Cursors
+		      Endeavour Pointer Cursors
  */
 
 #ifndef EDV_CURSOR_H
@@ -9,7 +9,7 @@
 
 
 typedef struct _edv_cursor_struct	edv_cursor_struct;
-#define EDV_CURSOR(p)	((edv_cursor_struct *)(p))
+#define EDV_CURSOR(p)			((edv_cursor_struct *)(p))
 
 
 /*
@@ -41,11 +41,18 @@ struct _edv_cursor_struct {
 };
 
 
-extern edv_cursor_struct *EDVCursorNew(
-	const edv_cursor_code code, GdkCursor *gdk_cursor
+extern edv_cursor_struct *EDVCursorNew(void);
+extern edv_cursor_struct *EDVCursorNewFromGDKCursor(
+	const edv_cursor_code code,
+	GdkCursor *gdk_cursor
 );
-extern edv_cursor_struct *EDVCursorNewGDKPreset(
-	const edv_cursor_code code, const GdkCursorType gdk_cursor_type
+extern edv_cursor_struct *EDVCursorNewFromGDKCursorType(
+	const edv_cursor_code code,
+	const GdkCursorType gdk_cursor_type
+);
+extern void EDVCursorSetGDKCursor(
+	edv_cursor_struct *cursor,
+	GdkCursor *gdk_cursor
 );
 extern void EDVCursorDelete(edv_cursor_struct *cursor);
 
