@@ -18,24 +18,33 @@ typedef enum {
 
 
 extern const gchar *EDVDateFormatString(
-	gulong t,		/* In systime seconds */
-	const gchar *format,	/* Can be NULL to just use ctime() */
-	edv_date_relativity relativity
+	const gulong t,
+	const gchar *format,
+	const edv_date_relativity relativity
 );
-extern const gchar *EDVDateStringDuration(gulong dt);
+extern const gchar *EDVDateStringDuration(const gulong dt);
 
 extern void EDVDateParseDateDMY(
 	const gchar *s,
-	gint *day, gint *mon, gint *year
+	gint *day, gint *month, gint *year
+);
+extern void EDVDateParseDateMDY(
+	const gchar *s,
+	gint *month, gint *day, gint *year
 );
 extern void EDVDateParseDateYMD(
 	const gchar *s,
-	gint *year, gint *mon, gint *day
+	gint *year, gint *month, gint *day
+);
+extern void EDVDateParseDate(
+	const gchar *s,
+	gint *year, gint *month, gint *day
 );
 extern void EDVDateParseTime(
 	const gchar *s,
-	gint *hour, gint *min, gint *sec
+	gint *hour, gint *minutes, gint *seconds
 );
+extern gulong EDVDateParseEPOCH(const gchar *s);
 
 
 #endif	/* EDVDATE_H */
