@@ -23,21 +23,16 @@
 #include "edv_types.h"
 #include "edv_device.h"
 #include "edv_devices_list.h"
+#include "edv_utils_gtk.h"
 
 
-static void EDVResizePixmap(
-	GdkPixmap *pixmap, GdkBitmap *mask,
-	gint width, gint height,
-	GdkPixmap **pixmap_rtn, GdkBitmap **mask_rtn
-);
-
 /* Mount State */
 void EDVDeviceUpdateMountStateFromSystem(edv_device_struct *d);
 void EDVDeviceUpdateMountState(edv_device_struct *d);
 
 /* Filesystem */
 guint32 EDVDeviceGetFSTypeFromName(const gchar *name);
-const gchar *EDVDeviceGetFSNameFromType(guint32 type);
+const gchar *EDVDeviceGetFSNameFromType(const guint32 type);
 
 /* Devices */
 edv_device_struct *EDVDeviceNew(
@@ -49,7 +44,8 @@ edv_device_struct *EDVDeviceNew(
 static void EDVDeviceLoadIconsNexus(
 	GdkPixmap **pixmap, GdkBitmap **mask,
 	guint8 ***data, const gchar **file,
-	gint req_width, gint req_height
+	const gint req_width, const gint req_height,
+	const gboolean allow_resize
 );
 void EDVDeviceLoadSmallIconsData(
 	edv_device_struct *d, guint8 ***data
@@ -80,118 +76,6 @@ void EDVDeviceDelete(edv_device_struct *d);
 #define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
-/*
- *      Resizes the pixmap and mask to the specified new size.
- */
-static void EDVResizePixmap(
-	GdkPixmap *pixmap, GdkBitmap *mask,
-	gint width, gint height,
-	GdkPixmap **pixmap_rtn, GdkBitmap **mask_rtn
-) 
-{
-	gint old_width, old_height;
-
-	if(pixmap_rtn != NULL)
-	    *pixmap_rtn = NULL;
-	if(mask_rtn != NULL)
-	    *mask_rtn = NULL;
-
-	if((pixmap == NULL) || (width <= 0) || (height <= 0))
-	    return;
-
-	gdk_window_get_size(pixmap, &old_width, &old_height);
-	if((old_width <= 0) || (old_height <= 0))
-	    return;
-
-	/* No change in size? */
-	if((old_width == width) && (old_height == height))
-	{
-	    if(pixmap_rtn != NULL)
-	    {
-		if(pixmap != NULL)
-		    gdk_pixmap_ref(pixmap);
-		*pixmap_rtn = pixmap;
-	    }
-	    if(mask_rtn != NULL)
-	    {
-		if(mask != NULL)
-		    gdk_bitmap_ref(mask);
-		*mask_rtn = mask;
-	    }
-	    return;
-	}
-
-	/* Resize pixmap */
-	if(pixmap_rtn != NULL)
-	{
-	    gint sw, sh, sbpl, tbpl;
-	    guint8 *tdata, *sdata;
-	    GdkGC *gc = GDK_GC_NEW();
-
-	    /* Get source RGBA data from the specified pixmap */
-	    sdata = gdk_get_rgba_image(
-		pixmap,
-		NULL,
-		&sw, &sh, &sbpl
-	    );
-	    if(sdata == NULL)
-	    {
-		GDK_GC_UNREF(gc);
-		return;
-	    }
-
-	    /* Create target RGBA data */
-	    tbpl = width * 4 * sizeof(guint8);
-	    tdata = (guint8 *)g_malloc(tbpl * height);
-	    if(tdata == NULL)
-	    {
-		g_free(sdata);
-		GDK_GC_UNREF(gc);
-		return;
-	    }
-
-	    /* Copy/resize source RGBA data to the target RGBA data */
-	    GUIImageBufferResize(
-		4,
-		sdata, sw, sh, sbpl,
-		tdata, width, height, tbpl,
-		NULL, NULL
-	    );
-	      
-	    g_free(sdata);
-
-	    /* Create target pixmap */
-	    *pixmap_rtn = GDK_PIXMAP_NEW(width, height);
-	    if(*pixmap_rtn == NULL)
-	    {
-		g_free(tdata);
-		GDK_GC_UNREF(gc)
-		return;
-	    }
-
-	    /* Put resized target RGBA data to the target pixmap */
-	    gdk_draw_rgb_32_image(
-		*pixmap_rtn, gc,
-		0, 0,
-		width, height,
-		GDK_RGB_DITHER_NORMAL,
-		tdata, tbpl
-	    );
-
-	    /* Resize mask */
-	    if(mask_rtn != NULL)
-		*mask_rtn = GUICreateBitmapFromDataRGBA(
-		    width, height, tbpl,
-		    tdata, 0x80,
-		    NULL
-		);
-
-	    g_free(tdata);
-	    GDK_GC_UNREF(gc);
-	}
-}
-
-
 /*
  *	Updates the mount state of the Device by checking with the
  *	system device's mount state.
@@ -227,7 +111,7 @@ void EDVDeviceUpdateMountStateFromSystem(edv_device_struct *d)
 #if defined(__FreeBSD__)
 	fp = (FILE *)1;		/* Mark the mount info file as opened */
 #elif defined(__SOLARIS__)
-	fp = FOpen("/etc/mnttab", "rb");
+	fp = fopen("/etc/mnttab", "rb");
 #else
 	fp = setmntent("/proc/mounts", "rb");
 #endif
@@ -307,7 +191,7 @@ void EDVDeviceUpdateMountStateFromSystem(edv_device_struct *d)
 #if defined(__FreeBSD__)
 	fp = NULL;	/* Mark the mount info file as closed */
 #elif defined(__SOLARIS__)
-	FClose(fp);
+	fclose(fp);
 	g_free(mt_ptr);
 #else
 	endmntent(fp);
@@ -360,7 +244,7 @@ guint32 EDVDeviceGetFSTypeFromName(const gchar *name)
  *	Returns a statically allocated string describing the
  *	filesystem's conical name.
  */
-const gchar *EDVDeviceGetFSNameFromType(guint32 type)
+const gchar *EDVDeviceGetFSNameFromType(const guint32 type)
 {
 	gint i;
 	const edv_fs_type_struct *fs_type;
@@ -455,27 +339,43 @@ edv_device_struct *EDVDeviceNew(
 }
 
 /*
- *	Loads the pixmap and mask pair from either xpm data or xpm file
- *	depending if data or file is NULL.
+ *	Loads the pixmap and mask pairs list.
  *
- *	Passing both data and file as NULL will only unref the existing icons
- *	(if any) and not load new ones. So this function can also be used 
- *	to just deallocate the icons.
+ *	The pixmap and mask specifies the pixmap and mask pairs list,
+ *	any existing (non NULL) pixmap and mask pairs in this list will 
+ *	be unref'ed.
+ *
+ *	The data specifies the XPM data. If data is not NULL then the
+ *	pixmap and mask pair will be loaded from the XPM data.
+ *
+ *	The file specifies the path to the XPM file. If file is not NULL
+ *	then the pixmap and mask pair will be loaded from the XPM file.
+ *
+ *	If both data and file are NULL then the existing pixmap and
+ *	mask pair will be unref'ed and no new pixmap and mask pair will
+ *	be loaded.
+ *
+ *	The req_width and req_height specifies the requested size in
+ *	pixels.
+ *
+ *	If allow_resize is TRHE then the pixmap and mask pair will be
+ *	resized to the requested size as needed.
  */
 static void EDVDeviceLoadIconsNexus(
 	GdkPixmap **pixmap, GdkBitmap **mask,
 	guint8 ***data, const gchar **file,
-	gint req_width, gint req_height
+	const gint req_width, const gint req_height,
+	const gboolean allow_resize
 )
 {
 	gint i;
 
-	/* Unload icons */
+	/* Unref all the existing pixmap and mask pairs in the list */
 	for(i = 0; i < EDV_DEVICE_TOTAL_ICON_STATES; i++)
 	{
-	    GDK_PIXMAP_UNREF(pixmap[i])
+	    GDK_PIXMAP_UNREF(pixmap[i]);
 	    pixmap[i] = NULL;
-	    GDK_BITMAP_UNREF(mask[i])
+	    GDK_BITMAP_UNREF(mask[i]);
 	    mask[i] = NULL;
 	}
 
@@ -485,20 +385,28 @@ static void EDVDeviceLoadIconsNexus(
 	    GdkBitmap *m;
 	    GdkPixmap *p;
 
-	    /* Load icons */
+	    /* Load each icon */
 	    for(i = 0; i < EDV_DEVICE_TOTAL_ICON_STATES; i++)
 	    {
 		p = GDK_PIXMAP_NEW_FROM_XPM_DATA(&m, data[i]);
 		if(p == NULL)
 		    continue;
 
-		EDVResizePixmap(
-		    p, m,
-		    req_width, req_height,
-		    &pixmap[i], &mask[i]
-		);
-		GDK_PIXMAP_UNREF(p)
-		GDK_BITMAP_UNREF(m)
+		if(allow_resize)
+		{
+		    EDVResizePixmap(
+			p, m,
+			req_width, req_height,
+			&pixmap[i], &mask[i]
+		    );
+		    GDK_PIXMAP_UNREF(p);
+		    GDK_BITMAP_UNREF(m);
+		}
+		else
+		{
+		    pixmap[i] = p;
+		    mask[i] = m;
+		}
 	    }
 	}
 	/* Load the icon if the XPM file is given */
@@ -507,20 +415,28 @@ static void EDVDeviceLoadIconsNexus(
 	    GdkBitmap *m;
 	    GdkPixmap *p;
 
-	    /* Load icons */
+	    /* Load each icon */
 	    for(i = 0; i < EDV_DEVICE_TOTAL_ICON_STATES; i++)
 	    {
 		p = GDK_PIXMAP_NEW_FROM_XPM_FILE(&m, file[i]);
 		if(p == NULL)
 		    continue;
 
-		EDVResizePixmap(
-		    p, m,
-		    req_width, req_height,
-		    &pixmap[i], &mask[i]
-		);
-		GDK_PIXMAP_UNREF(p)
-		GDK_BITMAP_UNREF(m)
+		if(allow_resize)
+		{
+		    EDVResizePixmap(
+			p, m,
+			req_width, req_height,
+			&pixmap[i], &mask[i]
+		    );
+		    GDK_PIXMAP_UNREF(p);
+		    GDK_BITMAP_UNREF(m);
+		}
+		else
+		{
+		    pixmap[i] = p;
+		    mask[i] = m;
+		}
 	    }
 	}
 
@@ -541,7 +457,7 @@ void EDVDeviceLoadSmallIconsData(
 	EDVDeviceLoadIconsNexus(
 	    d->small_pixmap, d->small_mask,
 	    data, NULL,
-	    20, 20
+	    20, 20, TRUE
 	);
 }
 
@@ -560,7 +476,7 @@ void EDVDeviceLoadMediumIconsData(
 	EDVDeviceLoadIconsNexus(
 	    d->medium_pixmap, d->medium_mask,
 	    data, NULL,
-	    32, 32
+	    32, 32, TRUE
 	);
 }
 
@@ -579,7 +495,7 @@ void EDVDeviceLoadLargeIconsData(
 	EDVDeviceLoadIconsNexus(
 	    d->large_pixmap, d->large_mask,
 	    data, NULL,
-	    48, 48
+	    48, 48, TRUE
 	);
 }
 
@@ -620,7 +536,7 @@ void EDVDeviceRealize(
 	    EDVDeviceLoadIconsNexus(
 		d->small_pixmap, d->small_mask,
 		NULL, path,
-		20, 20
+		20, 20, TRUE
 	    );
 
 	/* Get path array for medium icon file */
@@ -629,7 +545,7 @@ void EDVDeviceRealize(
 	    EDVDeviceLoadIconsNexus(
 		d->medium_pixmap, d->medium_mask,
 		NULL, path,
-		32, 32
+		32, 32, TRUE
 	    );
 
 	/* Get path for large icon file */
@@ -638,7 +554,7 @@ void EDVDeviceRealize(
 	    EDVDeviceLoadIconsNexus(
 		d->large_pixmap, d->large_mask,
 		NULL, path,
-		48, 48
+		48, 48, TRUE
 	    );
 
 	/* Mark the Device as realized */
