@@ -10,7 +10,7 @@
 #include "edv_device.h"
 
 
-extern const gchar *EDVDeviceUnmountGetError(void);
+extern const gchar *EDVDeviceMountGetError(edv_core_struct *core);
 
 extern gint EDVDeviceMount(
 	edv_core_struct *core, edv_device_struct *dev,
