@@ -47,7 +47,7 @@ edv_device_struct *EDVDevicesListMatchObject(
 void EDVDevicesListLoadFromSystem(
 	edv_device_struct ***list, gint *total,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
-	gpointer client_data
+	gpointer progress_data
 );
 
 /* Mount States */
@@ -68,13 +68,13 @@ void EDVDevicesListFileOpen(
 	const gchar *filename,
 	edv_device_struct ***list, gint *total,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
-	gpointer client_data
+	gpointer progress_data
 );
 void EDVDeviceListFileSave(
 	const gchar *filename,
 	edv_device_struct **list, const gint total,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
-	gpointer client_data
+	gpointer progress_data
 );
 
 
@@ -269,7 +269,7 @@ edv_device_struct *EDVDevicesListMatchObject(
 void EDVDevicesListLoadFromSystem(
 	edv_device_struct ***list, gint *total,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
-	gpointer client_data
+	gpointer progress_data
 )
 {
 	FILE *fp;
@@ -309,7 +309,7 @@ void EDVDevicesListLoadFromSystem(
 
 	/* Report initial progress */
 	if(progress_cb != NULL)
-	    progress_cb(client_data, 0l, file_size);
+	    progress_cb(progress_data, 0l, file_size);
 
 	/* Begin reading the system's devices list file */
 #if defined(__FreeBSD__)
@@ -328,7 +328,7 @@ void EDVDevicesListLoadFromSystem(
 	    if(progress_cb != NULL)
 	    {
 		if(progress_cb(
-		    client_data, (gulong)ftell(fp), file_size
+		    progress_data, (gulong)ftell(fp), file_size
 		))
 		    break;
 	    }
@@ -511,7 +511,7 @@ void EDVDevicesListLoadFromSystem(
 	/* Report the final progress */
 	if(progress_cb != NULL)
 	    progress_cb(
-		client_data, file_size, file_size
+		progress_data, file_size, file_size
 	    );
 }
 
@@ -629,7 +629,7 @@ void EDVDevicesListFileOpen(
 	const gchar *filename,
 	edv_device_struct ***list, gint *total,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
-	gpointer client_data
+	gpointer progress_data
 )
 {
 	gchar *parm;
@@ -656,7 +656,7 @@ void EDVDevicesListFileOpen(
 	/* Call progress callback */
 	if(progress_cb != NULL)
 	    progress_cb(
-		client_data, 0l, file_size
+		progress_data, 0l, file_size
 	    );
 
 	/* Begin file */
@@ -667,7 +667,7 @@ void EDVDevicesListFileOpen(
 	    if(progress_cb != NULL)
 	    {
 		if(progress_cb(
-		    client_data, (gulong)ftell(fp), file_size
+		    progress_data, (gulong)ftell(fp), file_size
 		))
 		    break;
 	    }
@@ -1054,7 +1054,7 @@ void EDVDeviceListFileSave(
 	const gchar *filename,
 	edv_device_struct **list, const gint total,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
-	gpointer client_data
+	gpointer progress_data
 )
 {
 	gint dev_num;
@@ -1084,7 +1084,7 @@ void EDVDeviceListFileSave(
 	/* Call progress callback */
 	if(progress_cb != NULL)
 	    progress_cb(
-		client_data, 0l, (gulong)total
+		progress_data, 0l, (gulong)total
 	    );
 
 	/* Iterate through all device structures */
@@ -1104,7 +1104,7 @@ void EDVDeviceListFileSave(
 	    if(progress_cb != NULL)
 	    {
 		if(progress_cb(
-		    client_data, (gulong)(dev_num + 1), (gulong)total
+		    progress_data, (gulong)(dev_num + 1), (gulong)total
 		))
 		    break;
 	    }
