@@ -31,7 +31,7 @@ extern edv_device_struct *EDVDevicesListMatchObject(
 extern void EDVDevicesListLoadFromSystem(
 	edv_device_struct ***list, gint *total,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
-	gpointer client_data
+	gpointer progress_data
 );
 
 /* Mount States */
@@ -52,13 +52,13 @@ extern void EDVDevicesListFileOpen(
 	const gchar *filename,
 	edv_device_struct ***list, gint *total,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
-	gpointer client_data
+	gpointer progress_data
 );
 extern void EDVDeviceListFileSave(
 	const gchar *filename,
 	edv_device_struct **list, const gint total,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
-	gpointer client_data
+	gpointer progress_data
 );
 
 
