@@ -9,6 +9,7 @@
 
 #include "cfg.h"
 #include "edv_types.h"
+#include "edv_date.h"
 #include "edv_obj.h"
 #include "edv_find_bar.h"
 #include "endeavour2.h"
@@ -21,56 +22,69 @@
 #include "images/icon_stop_20x20.xpm"
 
 
+/* Callbacks */
 static gint EDVFindBarProgressCB(
-	const gchar *path, gfloat progress, gpointer data
+	const gchar *path, const gfloat progress,
+	gpointer data
 );
 static void EDVFindBarMatchExcerptCB(
-	const gchar *path, const struct stat *lstat_buf,
-	const gchar *excerpt, gint line_index,
+	const gchar *path, struct stat *lstat_buf,
+	const gchar *excerpt, const gint line_index,
 	gpointer data
 );
 static void EDVFindBarMatchCB(
-	const gchar *path, const struct stat *lstat_buf, gpointer data
+	const gchar *path, struct stat *lstat_buf,
+	gpointer data
 );
 
-
 static void EDVFindBarFindCB(GtkWidget *widget, gpointer data);
 static void EDVFindBarStopCB(GtkWidget *widget, gpointer data);
 static gint EDVFindBarCrossingCB(
 	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
 );
 
-void EDVFindBarSetSearch(
-	edv_findbar_struct *fb, const gchar *s,
-	gboolean record_history
+static void EDVFindBarFindByChangedCB(
+        pulistbox_struct *pulistbox, gint i, gpointer data
 );
-edv_findbar_operation EDVFindBarCurrentFindOP(edv_findbar_struct *fb);
 
-edv_findbar_struct *EDVFindBarNew(
-	edv_core_struct *core, GtkWidget *parent,
-	const edv_findbar_role role,
+
+/* Find Bar */
+void EDVFindBarSetSearch(
+	edv_find_bar_struct *fb,
+	const gchar *s,
+	const gboolean record_history
+);
+edv_find_bar_find_by EDVFindBarCurrentFindBy(edv_find_bar_struct *fb);
+
+edv_find_bar_struct *EDVFindBarNew(
+	edv_core_struct *core,
+	GtkWidget *parent,
+	const edv_location_type location_type,
 	const gchar *(*get_location_cb)(
-		edv_findbar_struct *, gpointer
+		edv_find_bar_struct *,
+		gpointer
 	),
 	void (*start_cb)(
-		edv_findbar_struct *, gpointer
+		edv_find_bar_struct *,
+		gpointer
 	),
 	void (*end_cb)(
-		edv_findbar_struct *, gint, gpointer
+		edv_find_bar_struct *, const gint,
+		gpointer
 	),
 	void (*match_cb)(
-	    const gchar *, const struct stat *,
-	    const gchar *, gint,
+	    const gchar *, struct stat *,
+	    const gchar *, const gint,
 	    gpointer
 	),
 	void (*status_message_cb)(const gchar *, gpointer),
-	void (*status_progress_cb)(gfloat, gpointer),      
+	void (*status_progress_cb)(const gfloat, gpointer),
 	gpointer data
 );
-void EDVFindBarUpdateMenus(edv_findbar_struct *fb);
-void EDVFindBarMap(edv_findbar_struct *fb);
-void EDVFindBarUnmap(edv_findbar_struct *fb);
-void EDVFindBarDelete(edv_findbar_struct *fb);
+void EDVFindBarUpdateMenus(edv_find_bar_struct *fb);
+void EDVFindBarMap(edv_find_bar_struct *fb);
+void EDVFindBarUnmap(edv_find_bar_struct *fb);
+void EDVFindBarDelete(edv_find_bar_struct *fb);
 
 
 #define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
@@ -90,10 +104,11 @@ void EDVFindBarDelete(edv_findbar_struct *fb);
  *	functions.
  */
 static gint EDVFindBarProgressCB(
-	const gchar *path, gfloat progress, gpointer data
+	const gchar *path, const gfloat progress,
+	gpointer data
 )
 {
-	edv_findbar_struct *fb = EDV_FINDBAR(data);
+	edv_find_bar_struct *fb = EDV_FIND_BAR(data);
 	if(fb == NULL)
 	    return(0);
 
@@ -116,12 +131,12 @@ static gint EDVFindBarProgressCB(
  *      functions.
  */
 static void EDVFindBarMatchExcerptCB(
-	const gchar *path, const struct stat *lstat_buf,
-	const gchar *excerpt, gint line_index,
+	const gchar *path, struct stat *lstat_buf,
+	const gchar *excerpt, const gint line_index,
 	gpointer data
 )
 {
-	edv_findbar_struct *fb = EDV_FINDBAR(data);
+	edv_find_bar_struct *fb = EDV_FIND_BAR(data);
 	if(fb == NULL)
 	    return;
 
@@ -139,7 +154,8 @@ static void EDVFindBarMatchExcerptCB(
 }
 
 static void EDVFindBarMatchCB(
-	const gchar *path, const struct stat *lstat_buf, gpointer data
+	const gchar *path, struct stat *lstat_buf,
+	gpointer data
 )
 {
 	EDVFindBarMatchExcerptCB(path, lstat_buf, NULL, -1, data);
@@ -153,14 +169,14 @@ static void EDVFindBarMatchCB(
 static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 {
 	gboolean case_sensitive = FALSE;
-	edv_findbar_operation operation;
 	const gchar *s;
 	gchar *location, *search_string;
-	gint total_matches;
+	gint nmatches;
 	GtkWidget *w;
 	const cfg_item_struct *cfg_list;
+	edv_find_bar_find_by operation;
 	edv_core_struct *core;
-	edv_findbar_struct *fb = EDV_FINDBAR(data);
+	edv_find_bar_struct *fb = EDV_FIND_BAR(data);
 	if(fb == NULL)
 	    return;
 
@@ -168,37 +184,34 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	core = fb->core;
-	if(core == NULL)
-	    return;
-
 	cfg_list = core->cfg_list;
 
-
-	/* Reset values for upcomming find operation */
 	fb->freeze_count++;
+	fb->processing = TRUE;
+
+	/* Reset the find values */
 	fb->stop_count = 0;
 	EDVFindBarUpdateMenus(fb);
 
+	/* Get the operation */
+	operation = EDVFindBarCurrentFindBy(fb);
 
-	/* Get find operation */
-	operation = EDVFindBarCurrentFindOP(fb);
-
-	/* Get copy of location */
+	/* Get/copy the location */
 	s = NULL;
-	switch(fb->role)
+	switch(fb->location_type)
 	{
-	  case EDV_FINDBAR_ROLE_DISK_OBJECT:
-	  case EDV_FINDBAR_ROLE_ARCHIVE_OBJECT:
+	  case EDV_LOCATION_TYPE_VFS:
+	  case EDV_LOCATION_TYPE_ARCHIVE:
 	    if(fb->get_location_cb != NULL)
 		s = fb->get_location_cb(fb, fb->data);
 	    break;
-	  case EDV_FINDBAR_ROLE_RECYCLED_OBJECT:
+	  case EDV_LOCATION_TYPE_RECBIN:
 	    s = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
 	    break;
 	}
 	location = STRDUP((s != NULL) ? s : "/");
 
-	/* Get copy of search string */
+	/* Get/copy the search string */
 	s = NULL;
 	w = fb->search_combo;
 	if(w != NULL)
@@ -207,21 +220,29 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	    GtkEntry *entry = GTK_ENTRY(combo->entry);
 	    s = gtk_entry_get_text(entry);
 	}
-	search_string = STRDUP((s != NULL) ? s : "");
-	/* No wild cards in search string? */
-	if((strchr(search_string, '*') == NULL) &&
-	   (strchr(search_string, '?') == NULL) &&
-	   (operation == EDV_FINDBAR_FIND_OBJECT_NAME)
+	search_string = g_strdup((s != NULL) ? s : "");
+	if(search_string == NULL)
+	{
+	    g_free(location);
+	    fb->processing = FALSE;
+	    fb->freeze_count--;
+	    return;
+	}
+
+	/* No wild cards in the search string and finding by name? */
+	if((strchr((char *)search_string, '*') == NULL) &&
+	   (strchr((char *)search_string, '?') == NULL) &&
+	   (operation == EDV_FIND_BAR_FIND_BY_NAME)
 	)
 	{
 	    /* Tack on two '*' characters to the beginning and end of
 	     * the search string.
 	     */
-	    gchar *strptr = g_strdup_printf("*%s*", search_string);
+	    gchar *s = g_strdup_printf("*%s*", search_string);
 	    g_free(search_string);
-	    search_string = strptr;
+	    search_string = s;
 	}
-	/* Record search string history */
+	/* Record the search string history */
 	EDVFindBarSetSearch(fb, search_string, TRUE);
 
 	/* Case sensitive */
@@ -230,21 +251,22 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	);
 
 
-	/* Call start find callback to notify about start of find */
+	/* Notify about the start of the find */
 	if(fb->start_cb != NULL)
 	    fb->start_cb(fb, fb->data);
 
 
-	/* Perform find procedure by find operation code */
-	total_matches = 0;
+	/* Perform the search by the operation */
+	nmatches = 0;
 	switch(operation)
 	{
-	  case EDV_FINDBAR_FIND_OBJECT_NAME:
-	    switch(fb->role)
+	  case EDV_FIND_BAR_FIND_BY_NAME:
+	    switch(fb->location_type)
 	    {
-	      case EDV_FINDBAR_ROLE_DISK_OBJECT:
-		total_matches = EDVFindObjectByName(
-		    location, search_string,
+	      case EDV_LOCATION_TYPE_VFS:
+		nmatches = EDVFindObjectByName(
+		    location,
+		    search_string,
 		    FALSE,			/* Do not recurse */
 		    FALSE,			/* Do not follow links */
 		    case_sensitive,
@@ -253,9 +275,9 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 		);
 		break;
 
-	      case EDV_FINDBAR_ROLE_RECYCLED_OBJECT:
-		total_matches = EDVFindRecycledObjectByName(
-		    location,		/* Recycled objects index file */
+	      case EDV_LOCATION_TYPE_RECBIN:
+		nmatches = EDVFindRecycledObjectByName(
+		    location,			/* Recycled objects index file */
  		    search_string,
 		    case_sensitive,
 		    EDVFindBarProgressCB, fb,
@@ -263,10 +285,10 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 		);
 		break;
 
-	      case EDV_FINDBAR_ROLE_ARCHIVE_OBJECT:
-		total_matches = EDVFindArchiveObjectByName(
+	      case EDV_LOCATION_TYPE_ARCHIVE:
+		nmatches = EDVFindArchiveObjectByName(
 		    core,
-		    location,		/* Archive */
+		    location,			/* Archive */
 		    search_string,
 		    case_sensitive,
 		    EDVFindBarProgressCB, fb,
@@ -276,11 +298,11 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	    }
 	    break;
 
-	  case EDV_FINDBAR_FIND_OBJECT_CONTENT:
-	    switch(fb->role)
+	  case EDV_FIND_BAR_FIND_BY_CONTENT:
+	    switch(fb->location_type)
 	    {
-	      case EDV_FINDBAR_ROLE_DISK_OBJECT:
-		total_matches = EDVFindObjectByContent(
+	      case EDV_LOCATION_TYPE_VFS:
+		nmatches = EDVFindObjectByContent(
 		    location,
 		    search_string,
 		    FALSE,			/* Do not recurse */
@@ -291,9 +313,9 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 		);
 		break;
 
-	      case EDV_FINDBAR_ROLE_RECYCLED_OBJECT:
-		total_matches = EDVFindRecycledObjectByContent(
-		    location,		/* Recycled objects index file */
+	      case EDV_LOCATION_TYPE_RECBIN:
+		nmatches = EDVFindRecycledObjectByContent(
+		    location,			/* Recycled objects index file */
 		    search_string,
 		    case_sensitive,
 		    EDVFindBarProgressCB, fb,
@@ -301,9 +323,296 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 		);
 		break;
 
-	      case EDV_FINDBAR_ROLE_ARCHIVE_OBJECT:
-		/* Finding archive object by content is not supported yet */
-		total_matches = 0;
+	      case EDV_LOCATION_TYPE_ARCHIVE:
+		/* Not supported */
+		break;
+	    }
+	    break;
+
+	  case EDV_FIND_BAR_FIND_BY_SIZE_EQUAL_TO:
+	    switch(fb->location_type)
+	    {
+	      case EDV_LOCATION_TYPE_VFS:
+		nmatches = EDVFindObjectBySize(
+		    location,
+		    ATOL(search_string),	/* Size */
+		    FALSE,			/* Do not recurse */
+		    FALSE,			/* Do not follow links */
+		    EDV_FIND_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_RECBIN:
+		nmatches = EDVFindRecycledObjectBySize(
+		    location,			/* Recycled objects index file */
+		    ATOL(search_string),	/* Size */
+		    EDV_FIND_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_ARCHIVE:
+		nmatches = EDVFindArchiveObjectBySize(
+		    core,
+		    location,			/* Archive */
+		    ATOL(search_string),	/* Size */
+		    EDV_FIND_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	    }
+	    break;
+
+	  case EDV_FIND_BAR_FIND_BY_SIZE_NOT_EQUAL_TO:
+	    switch(fb->location_type)
+	    {
+	      case EDV_LOCATION_TYPE_VFS:
+		nmatches = EDVFindObjectBySize(
+		    location,
+		    ATOL(search_string),	/* Size */
+		    FALSE,			/* Do not recurse */
+		    FALSE,			/* Do not follow links */
+		    EDV_FIND_NOT_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_RECBIN:
+		nmatches = EDVFindRecycledObjectBySize(
+		    location,			/* Recycled objects index file */
+		    ATOL(search_string),	/* Size */
+		    EDV_FIND_NOT_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_ARCHIVE:
+		nmatches = EDVFindArchiveObjectBySize(
+		    core,
+		    location,			/* Archive */
+		    ATOL(search_string),	/* Size */
+		    EDV_FIND_NOT_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	    }
+	    break;
+
+	  case EDV_FIND_BAR_FIND_BY_SIZE_LESS_THAN:
+	    switch(fb->location_type)
+	    {
+	      case EDV_LOCATION_TYPE_VFS:
+		nmatches = EDVFindObjectBySize(
+		    location,
+		    ATOL(search_string),	/* Size */
+		    FALSE,			/* Do not recurse */
+		    FALSE,			/* Do not follow links */
+		    EDV_FIND_LESS_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_RECBIN:
+		nmatches = EDVFindRecycledObjectBySize(
+		    location,			/* Recycled objects index file */
+		    ATOL(search_string),	/* Size */
+		    EDV_FIND_LESS_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_ARCHIVE:
+		nmatches = EDVFindArchiveObjectBySize(
+		    core,
+		    location,			/* Archive */
+		    ATOL(search_string),	/* Size */
+		    EDV_FIND_LESS_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	    }
+	    break;
+
+	  case EDV_FIND_BAR_FIND_BY_SIZE_GREATER_THAN:
+	    switch(fb->location_type)
+	    {
+	      case EDV_LOCATION_TYPE_VFS:
+		nmatches = EDVFindObjectBySize(
+		    location,
+		    ATOL(search_string),	/* Size */
+		    FALSE,			/* Do not recurse */
+		    FALSE,			/* Do not follow links */
+		    EDV_FIND_GREATER_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_RECBIN:
+		nmatches = EDVFindRecycledObjectBySize(
+		    location,			/* Recycled objects index file */
+		    ATOL(search_string),	/* Size */
+		    EDV_FIND_GREATER_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_ARCHIVE:
+		nmatches = EDVFindArchiveObjectBySize(
+		    core,
+		    location,			/* Archive */
+		    ATOL(search_string),	/* Size */
+		    EDV_FIND_GREATER_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	    }
+	    break;
+
+	  case EDV_FIND_BAR_FIND_BY_MODIFY_TIME_EQUAL_TO:
+	    switch(fb->location_type)
+	    {
+	      case EDV_LOCATION_TYPE_VFS:
+		nmatches = EDVFindObjectByModifyTime(
+		    location,
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    FALSE,			/* Do not recurse */
+		    FALSE,			/* Do not follow links */
+		    EDV_FIND_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_RECBIN:
+		nmatches = EDVFindRecycledObjectByModifyTime(
+		    location,			/* Recycled objects index file */
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    EDV_FIND_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_ARCHIVE:
+		nmatches = EDVFindArchiveObjectByModifyTime(
+		    core,
+		    location,			/* Archive */
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    EDV_FIND_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	    }
+	    break;
+
+	  case EDV_FIND_BAR_FIND_BY_MODIFY_TIME_NOT_EQUAL_TO:
+	    switch(fb->location_type)
+	    {
+	      case EDV_LOCATION_TYPE_VFS:
+		nmatches = EDVFindObjectByModifyTime(
+		    location,
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    FALSE,			/* Do not recurse */
+		    FALSE,			/* Do not follow links */
+		    EDV_FIND_NOT_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_RECBIN:
+		nmatches = EDVFindRecycledObjectByModifyTime(
+		    location,			/* Recycled objects index file */
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    EDV_FIND_NOT_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_ARCHIVE:
+		nmatches = EDVFindArchiveObjectByModifyTime(
+		    core,
+		    location,			/* Archive */
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    EDV_FIND_NOT_EQUAL_TO,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	    }
+	    break;
+
+	  case EDV_FIND_BAR_FIND_BY_MODIFY_TIME_LESS_THAN:
+	    switch(fb->location_type)
+	    {
+	      case EDV_LOCATION_TYPE_VFS:
+		nmatches = EDVFindObjectByModifyTime(
+		    location,
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    FALSE,			/* Do not recurse */
+		    FALSE,			/* Do not follow links */
+		    EDV_FIND_LESS_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_RECBIN:
+		nmatches = EDVFindRecycledObjectByModifyTime(
+		    location,			/* Recycled objects index file */
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    EDV_FIND_LESS_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_ARCHIVE:
+		nmatches = EDVFindArchiveObjectByModifyTime(
+		    core,
+		    location,			/* Archive */
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    EDV_FIND_LESS_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	    }
+	    break;
+
+	  case EDV_FIND_BAR_FIND_BY_MODIFY_TIME_GREATER_THAN:
+	    switch(fb->location_type)
+	    {
+	      case EDV_LOCATION_TYPE_VFS:
+		nmatches = EDVFindObjectByModifyTime(
+		    location,
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    FALSE,			/* Do not recurse */
+		    FALSE,			/* Do not follow links */
+		    EDV_FIND_GREATER_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_RECBIN:
+		nmatches = EDVFindRecycledObjectByModifyTime(
+		    location,			/* Recycled objects index file */
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    EDV_FIND_GREATER_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
+		break;
+	      case EDV_LOCATION_TYPE_ARCHIVE:
+		nmatches = EDVFindArchiveObjectByModifyTime(
+		    core,
+		    location,			/* Archive */
+		    EDVDateParseEPOCH(search_string),	/* Time */
+		    EDV_FIND_GREATER_THAN,
+		    EDVFindBarProgressCB, fb,
+		    EDVFindBarMatchCB, fb
+		);
 		break;
 	    }
 	    break;
@@ -314,19 +623,19 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	if(fb->status_progress_cb != NULL)
 	    fb->status_progress_cb(0.0f, fb->data);
 
-	if(total_matches > 0)
+	if(nmatches > 0)
 	{
-	    gchar *buf = g_strdup_printf(
-		"Matched %i object%s",
-		total_matches,
-		(total_matches == 1) ? "" : "s"
+	    gchar *msg = g_strdup_printf(
+		"Matched %i %s",
+		nmatches,
+		(nmatches == 1) ? "object" : "objects"
 	    );
 	    if(fb->status_message_cb != NULL)
 		fb->status_message_cb(
-		    buf,
+		    msg,
 		    fb->data
 		);
-	    g_free(buf);
+	    g_free(msg);
 	}
 	else
 	{
@@ -337,7 +646,7 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 		);
 	}
 
-
+	fb->processing = FALSE;
 	fb->freeze_count--;
 
 	EDVFindBarUpdateMenus(fb);
@@ -345,7 +654,7 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 
 	/* Call end find callback to notify about end of find */
 	if(fb->end_cb != NULL)
-	    fb->end_cb(fb, total_matches, fb->data);
+	    fb->end_cb(fb, nmatches, fb->data);
 
 
 	g_free(location);
@@ -357,7 +666,7 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
  */
 static void EDVFindBarStopCB(GtkWidget *widget, gpointer data)
 {
-	edv_findbar_struct *fb = EDV_FINDBAR(data);
+	edv_find_bar_struct *fb = EDV_FIND_BAR(data);
 	if(fb == NULL)
 	    return;
 
@@ -365,8 +674,8 @@ static void EDVFindBarStopCB(GtkWidget *widget, gpointer data)
 }
 
 /*
- *      find bar widget "enter_notify_event" or "leave_notify_event"
- *      signal callback.
+ *	Any GtkWidget "enter_notify_event" or "leave_notify_event"
+ *	signal callback.
  */
 static gint EDVFindBarCrossingCB(
 	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
@@ -375,8 +684,8 @@ static gint EDVFindBarCrossingCB(
 	gint status = FALSE;
 	gint etype;
 	GtkWidget *w;
-	const gchar *mesg = NULL;
-	edv_findbar_struct *fb = EDV_FINDBAR(data);
+	const gchar *msg = NULL;
+	edv_find_bar_struct *fb = EDV_FIND_BAR(data);
 	if((widget == NULL) || (crossing == NULL) || (fb == NULL))
 	    return(status);
 
@@ -389,7 +698,7 @@ static gint EDVFindBarCrossingCB(
 	{
 	  case GDK_ENTER_NOTIFY:
 	    if(w == fb->case_sensitive_check)
-		mesg =
+		msg =
 #if defined(PROG_LANGUAGE_SPANISH)
 "Especifica si los iguales de cuerda no deben ser el casos sensibles ni"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -409,7 +718,7 @@ static gint EDVFindBarCrossingCB(
 #endif
 		;
 	    else if(w == fb->stop_btn)
-		mesg =
+		msg =
 #if defined(PROG_LANGUAGE_SPANISH)
 "Especifica si el proceso de la bsqueda debe recurse en subdirectorios"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -432,60 +741,80 @@ static gint EDVFindBarCrossingCB(
 	}
 
 	if(fb->status_message_cb != NULL)
-	    fb->status_message_cb(mesg, fb->data);
+	    fb->status_message_cb(msg, fb->data);
 
 	return(status);
 }
 
+
 /*
- *      Sets the search combo of the given find bar to the value of
- *      the string s.
- *
- *      If record_history is TRUE then the current value will be recorded
- *      on the combo's list before setting of the new value.
- *      Duplicate values will not be recorded.
+ *	Find by method changed callback.
  */
-void EDVFindBarSetSearch(
-	edv_findbar_struct *fb, const gchar *s,
-	gboolean record_history
+static void EDVFindBarFindByChangedCB(
+        pulistbox_struct *pulistbox, gint i, gpointer data
 )
 {
-	GtkCombo *combo;
-	gchar *new_s;
+        edv_find_bar_struct *fb = EDV_FIND_BAR(data);
+        if(fb == NULL)
+            return;
 
+        if(fb->freeze_count > 0)
+            return;
+
+	fb->freeze_count++;
+
+        EDVFindBarUpdateMenus(fb);
+
+	fb->freeze_count--;
+}
+
+
+/*
+ *	Sets the search string.
+ *
+ *	The s specifies the new search string.
+ *
+ *	If record_history is TRUE then the current search string will
+ *	be recorded on the search list history.
+ */
+void EDVFindBarSetSearch(
+	edv_find_bar_struct *fb,
+	const gchar *s,
+	const gboolean record_history
+)
+{
+	const gchar *cur_s;
+	gchar *new_s;
+	GtkCombo *combo;
 
 	if((fb == NULL) || (s == NULL))
 	    return;
 
-	combo = (GtkCombo *)fb->search_combo;
-	if(combo == NULL)
+	combo = GTK_COMBO(fb->search_combo);
+
+	/* Copy the search string */
+	new_s = STRDUP(s);
+	if(new_s == NULL)
 	    return;
 
-	/* Copy given path as the new path */
-	new_s = STRDUP(s);
-
 	/* Check for no change in value */
-	if(new_s != NULL)
+	cur_s = gtk_entry_get_text(GTK_ENTRY(combo->entry));
+	if(cur_s != NULL)
 	{
-	    const gchar *s = gtk_entry_get_text(GTK_ENTRY(combo->entry));
-	    if(s != NULL)
+	    /* No change in value? */
+	    if(!strcmp((const char *)cur_s, (const char *)new_s))
 	    {
-		/* No change in value? */
-		if(!strcmp(s, new_s))
-		{
-		    g_free(new_s);
-		    new_s = NULL;
-		    return;
-		}
+		g_free(new_s);
+		return;
 	    }
 	}
 
-	/* Get old value from combo's entry and record it on the list */
+	/* Get record the current search string on to the search
+	 * history list?
+	 */
 	if(record_history)
 	{
-	    gchar *old_s = STRDUP(
-		gtk_entry_get_text(GTK_ENTRY(combo->entry))
-	    );
+	    gchar *old_s = STRDUP(cur_s);
 	    if(old_s != NULL)
 	    {
 		GUIComboAddItem(GTK_WIDGET(combo), old_s);
@@ -493,30 +822,28 @@ void EDVFindBarSetSearch(
 	    }
 	}
 
-	/* Set new value on entry and deallocate coppied new_s */
-	if(new_s != NULL)
-	{
-	    gtk_entry_set_text(GTK_ENTRY(combo->entry), new_s);
-	    g_free(new_s);
-	}
+	/* Set the new search string */
+	gtk_entry_set_text(GTK_ENTRY(combo->entry), new_s);
+
+	g_free(new_s);
 }
 
 
 /*
- *      Returns the current find operation code, one of EDV_FINDBAR_FIND_*.
+ *	Gets the current find by method.
  */
-edv_findbar_operation EDVFindBarCurrentFindOP(edv_findbar_struct *fb)
+edv_find_bar_find_by EDVFindBarCurrentFindBy(edv_find_bar_struct *fb)
 {
 	pulist_struct *pulist;
 
 	if(fb == NULL)
-	    return(EDV_FINDBAR_FIND_OBJECT_NAME);
+	    return(EDV_FIND_BAR_FIND_BY_NAME);
 
-	pulist = PUListBoxGetPUList(fb->find_op_pulistbox);
+	pulist = PUListBoxGetPUList(fb->find_by_pulistbox);
 	if(pulist == NULL)
-	    return(EDV_FINDBAR_FIND_OBJECT_NAME);
+	    return(EDV_FIND_BAR_FIND_BY_NAME);
 
-	return((edv_findbar_operation)PUListGetItemData(
+	return((edv_find_bar_find_by)PUListGetItemData(
 	    pulist,
 	    PUListGetSelectedLast(pulist)
 	));
@@ -525,27 +852,31 @@ edv_findbar_operation EDVFindBarCurrentFindOP(edv_findbar_struct *fb)
 
 
 /*
- *	Create a new find bar.
+ *	Creates a new find bar.
  */
-edv_findbar_struct *EDVFindBarNew(
-	edv_core_struct *core, GtkWidget *parent,
-	const edv_findbar_role role,
+edv_find_bar_struct *EDVFindBarNew(
+	edv_core_struct *core,
+	GtkWidget *parent,
+	const edv_location_type location_type,
 	const gchar *(*get_location_cb)(
-		edv_findbar_struct *, gpointer
+		edv_find_bar_struct *,
+		gpointer
 	),
 	void (*start_cb)(
-		edv_findbar_struct *, gpointer
+		edv_find_bar_struct *,
+		gpointer
 	),
 	void (*end_cb)(
-		edv_findbar_struct *, gint, gpointer 
+		edv_find_bar_struct *, const gint,
+		gpointer
 	),
 	void (*match_cb)(
-	    const gchar *, const struct stat *,
-	    const gchar *, gint,
+	    const gchar *, struct stat *,
+	    const gchar *, const gint,
 	    gpointer
 	),
 	void (*status_message_cb)(const gchar *, gpointer),
-	void (*status_progress_cb)(gfloat, gpointer),
+	void (*status_progress_cb)(const gfloat, gpointer),
 	gpointer data
 )
 {
@@ -557,20 +888,21 @@ edv_findbar_struct *EDVFindBarNew(
 	GtkCombo *combo;
 	pulist_struct *pulist;
 	pulistbox_struct *pulistbox;
-	edv_findbar_struct *fb;
+	edv_find_bar_struct *fb;
 
 	if(core == NULL)
 	    return(NULL);
 
-	fb = EDV_FINDBAR(g_malloc0(sizeof(edv_findbar_struct)));
+	fb = EDV_FIND_BAR(g_malloc0(sizeof(edv_find_bar_struct)));
 	if(fb == NULL)
 	    return(NULL);
 
 	fb->toplevel = toplevel = gtk_hbox_new(FALSE, border_minor);
+	fb->processing = FALSE;
 	fb->freeze_count = 0;
 	fb->stop_count = 0;
 	fb->core = core;
-	fb->role = role;
+	fb->location_type = location_type;
 	fb->get_location_cb = get_location_cb;
 	fb->start_cb = start_cb;
 	fb->end_cb = end_cb;
@@ -616,55 +948,39 @@ edv_findbar_struct *EDVFindBarNew(
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 
-	fb->find_op_pulistbox = pulistbox = PUListBoxNew(
+	fb->find_by_pulistbox = pulistbox = PUListBoxNew(
 	    parent3,
-	    150, -1
+	    170, -1
 	);
+        PUListBoxSetChangedCB(
+            pulistbox,
+            EDVFindBarFindByChangedCB,
+            fb
+        );
 	pulist = PUListBoxGetPUList(pulistbox);
-        if(core->run_flags & EDV_RUN_SAFE_MODE)
-            PUListSetShadowStyle(pulist, PULIST_SHADOW_NONE);
-#if defined(PROG_LANGUAGE_SPANISH)
-	i = PUListAddItem(pulist, "Por Nombre de archivo");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
-	i = PUListAddItem(pulist, "Por Contenido");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
-#elif defined(PROG_LANGUAGE_FRENCH)
-	i = PUListAddItem(pulist, "Nom D'Objet");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
-	i = PUListAddItem(pulist, "Contenu D'Objet");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
-#elif defined(PROG_LANGUAGE_GERMAN)
-	i = PUListAddItem(pulist, "Wenden Sie Gegen Namen Ein");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
-	i = PUListAddItem(pulist, "Wenden Sie Gegen Inhalt Ein");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
-#elif defined(PROG_LANGUAGE_ITALIAN)
-	i = PUListAddItem(pulist, "Il Nome Di Oggetto");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
-	i = PUListAddItem(pulist, "Il Contenuto Di Oggetto");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
-#elif defined(PROG_LANGUAGE_DUTCH)
-	i = PUListAddItem(pulist, "Heb Bezwaar Naam");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
-	i = PUListAddItem(pulist, "Heb Bezwaar Inhoud");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
-#elif defined(PROG_LANGUAGE_PORTUGUESE)
-	i = PUListAddItem(pulist, "O Nome De Objeto");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
-	i = PUListAddItem(pulist, "O Contedo De Objeto");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
-#elif defined(PROG_LANGUAGE_NORWEGIAN)
-	i = PUListAddItem(pulist, "Protester Navn");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
-	i = PUListAddItem(pulist, "Protester Innhold");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
-#else
-	i = PUListAddItem(pulist, "Object Name");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
-	i = PUListAddItem(pulist, "Object Content");
-	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
-#endif
-	PUListBoxSetLinesVisible(pulistbox, i + 1);
+	if(core->run_flags & EDV_RUN_SAFE_MODE)
+	    PUListSetShadowStyle(pulist, PULIST_SHADOW_NONE);
+	i = PUListAddItem(pulist, "Name");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FIND_BAR_FIND_BY_NAME);
+	i = PUListAddItem(pulist, "Content");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FIND_BAR_FIND_BY_CONTENT);
+	i = PUListAddItem(pulist, "Size Equal To");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FIND_BAR_FIND_BY_SIZE_EQUAL_TO);
+	i = PUListAddItem(pulist, "Size Not Equal To");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FIND_BAR_FIND_BY_SIZE_NOT_EQUAL_TO);
+	i = PUListAddItem(pulist, "Size Less Than");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FIND_BAR_FIND_BY_SIZE_LESS_THAN);
+	i = PUListAddItem(pulist, "Size Greater Than");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FIND_BAR_FIND_BY_SIZE_GREATER_THAN);
+	i = PUListAddItem(pulist, "Date Modified On");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FIND_BAR_FIND_BY_MODIFY_TIME_EQUAL_TO);
+	i = PUListAddItem(pulist, "Date Modified Not On");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FIND_BAR_FIND_BY_MODIFY_TIME_NOT_EQUAL_TO);
+	i = PUListAddItem(pulist, "Date Modified Before");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FIND_BAR_FIND_BY_MODIFY_TIME_LESS_THAN);
+	i = PUListAddItem(pulist, "Date Modified After");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FIND_BAR_FIND_BY_MODIFY_TIME_GREATER_THAN);
+	PUListBoxSetLinesVisible(pulistbox, MIN((i + 1), 10));
 	PUListBoxMap(pulistbox);
 
 	/* Search string GtkCombo */
@@ -818,44 +1134,66 @@ edv_findbar_struct *EDVFindBarNew(
 /*
  *	Updates the Find Bar's widgets to reflect current values.
  */
-void EDVFindBarUpdateMenus(edv_findbar_struct *fb)
+void EDVFindBarUpdateMenus(edv_find_bar_struct *fb)
 {
-	gboolean sensitive;
+	gboolean sensitive, processing;
+	edv_find_bar_find_by find_by;
 	edv_core_struct *core;
 
 	if(fb == NULL)
 	    return;
 
+	processing = fb->processing;
+	find_by = EDVFindBarCurrentFindBy(fb);
 	core = fb->core;
 
-#define DO_SHOW				\
-{ if(w != NULL) gtk_widget_show(w); }
-#define DO_HIDE				\
-{ if(w != NULL) gtk_widget_hide(w); }
-#define DO_SET_CHECK_STATE		\
-{ GUIMenuItemSetCheck(w, state, FALSE); }
-
-	/* Update buttons */
-	sensitive = (fb->freeze_count > 0) ? TRUE : FALSE;
-	GTK_WIDGET_SET_SENSITIVE(fb->stop_btn, sensitive)
-
-	sensitive = (fb->freeze_count == 0) ? TRUE : FALSE;
-	GTK_WIDGET_SET_SENSITIVE(fb->search_combo, sensitive);
-	GTK_WIDGET_SET_SENSITIVE(fb->case_sensitive_check, sensitive);
-	GTK_WIDGET_SET_SENSITIVE(
-	    PUListBoxGetToplevel(fb->find_op_pulistbox),
+	/* Find By */
+	sensitive = !processing;
+	gtk_widget_set_sensitive(
+	    PUListBoxGetToplevel(fb->find_by_pulistbox),
 	    sensitive
 	);
 
-#undef DO_SHOW
-#undef DO_HIDE
-#undef DO_SET_CHECK_STATE
+	/* Search String */
+	sensitive = !processing;
+	gtk_widget_set_sensitive(fb->search_combo, sensitive);
+
+	/* Case Sensitive */
+	if(processing)
+	{
+	    sensitive = FALSE;
+	}
+	else
+	{
+            switch(find_by)
+            {
+              case EDV_FIND_BAR_FIND_BY_NAME:
+              case EDV_FIND_BAR_FIND_BY_CONTENT:
+                sensitive = TRUE;
+                break;
+              case EDV_FIND_BAR_FIND_BY_SIZE_EQUAL_TO:
+              case EDV_FIND_BAR_FIND_BY_SIZE_NOT_EQUAL_TO:
+              case EDV_FIND_BAR_FIND_BY_SIZE_LESS_THAN:
+              case EDV_FIND_BAR_FIND_BY_SIZE_GREATER_THAN:
+              case EDV_FIND_BAR_FIND_BY_MODIFY_TIME_EQUAL_TO:
+              case EDV_FIND_BAR_FIND_BY_MODIFY_TIME_NOT_EQUAL_TO:
+              case EDV_FIND_BAR_FIND_BY_MODIFY_TIME_LESS_THAN:
+              case EDV_FIND_BAR_FIND_BY_MODIFY_TIME_GREATER_THAN:
+                sensitive = FALSE;
+                break;
+            }
+	}
+	gtk_widget_set_sensitive(fb->case_sensitive_check, sensitive);
+
+	/* Stop */
+	sensitive = processing;
+	gtk_widget_set_sensitive(fb->stop_btn, sensitive);
 }
 
 /*
  *	Maps the Find Bar.
  */
-void EDVFindBarMap(edv_findbar_struct *fb)
+void EDVFindBarMap(edv_find_bar_struct *fb)
 {
 	if(fb == NULL)
 	    return;
@@ -866,7 +1204,7 @@ void EDVFindBarMap(edv_findbar_struct *fb)
 /*
  *	Unmaps the Find Bar.
  */
-void EDVFindBarUnmap(edv_findbar_struct *fb)
+void EDVFindBarUnmap(edv_find_bar_struct *fb)
 {
 	if(fb == NULL)
 	    return;
@@ -877,7 +1215,7 @@ void EDVFindBarUnmap(edv_findbar_struct *fb)
 /*
  *	Deletes the Find Bar.
  */
-void EDVFindBarDelete(edv_findbar_struct *fb)
+void EDVFindBarDelete(edv_find_bar_struct *fb)
 {
 	if(fb == NULL)
 	    return;
@@ -886,7 +1224,7 @@ void EDVFindBarDelete(edv_findbar_struct *fb)
 
 	fb->freeze_count++;
 
-	PUListBoxDelete(fb->find_op_pulistbox);
+	PUListBoxDelete(fb->find_by_pulistbox);
 	gtk_widget_destroy(fb->toplevel);
 
 	fb->freeze_count--;
