@@ -84,26 +84,26 @@ GtkWidget *EDVGenOptWinPageAppend(
 	edv_gen_opt_win_struct *optwin, GtkWidget *w
 );
 void EDVGenOptWinUpdateMenus(edv_gen_opt_win_struct *optwin);
-void EDVGenOptWinSetBusy(edv_gen_opt_win_struct *optwin, gboolean is_busy);
+void EDVGenOptWinSetBusy(edv_gen_opt_win_struct *optwin, const gboolean busy);
 gboolean EDVGenOptWinIsMapped(edv_gen_opt_win_struct *optwin);
 void EDVGenOptWinMap(edv_gen_opt_win_struct *optwin);
 void EDVGenOptWinUnmap(edv_gen_opt_win_struct *optwin);
 void EDVGenOptWinDelete(edv_gen_opt_win_struct *optwin);
 
 
-#define OPTWIN_WIDTH		640
-#define OPTWIN_HEIGHT		480
+#define OPTWIN_WIDTH			640
+#define OPTWIN_HEIGHT			480
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -158,7 +158,12 @@ static void OptWinOKCB(GtkWidget *widget, gpointer data)
 
 	optwin->freeze_count++;
 
-	EDVGenOptWinSetValues(optwin);
+	EDVGenOptWinSetValues(
+	    optwin,
+	    TRUE,			/* Show progress */
+	    TRUE,			/* Emit notify signal */
+	    TRUE			/* Save to disk */
+	);
 	EDVGenOptWinResetHasChanges(optwin, FALSE);
 	EDVGenOptWinUnmap(optwin);
 
@@ -179,7 +184,12 @@ static void OptWinApplyCB(GtkWidget *widget, gpointer data)
 
 	optwin->freeze_count++;
 
-	EDVGenOptWinSetValues(optwin);
+	EDVGenOptWinSetValues(
+	    optwin,
+	    TRUE,			/* Show progress */
+	    TRUE,			/* Emit notify signal */
+	    TRUE			/* Save to disk */
+	);
 	EDVGenOptWinResetHasChanges(optwin, FALSE);
 	EDVGenOptWinUpdateMenus(optwin);
 
@@ -1368,7 +1378,7 @@ void EDVGenOptWinUpdateMenus(edv_gen_opt_win_struct *optwin)
 /*
  *	Sets the Options Window as busy or ready.
  */
-void EDVGenOptWinSetBusy(edv_gen_opt_win_struct *optwin, gboolean is_busy)
+void EDVGenOptWinSetBusy(edv_gen_opt_win_struct *optwin, const gboolean busy)
 {
 #if 0
 	GdkCursor *cursor;
@@ -1383,7 +1393,7 @@ void EDVGenOptWinSetBusy(edv_gen_opt_win_struct *optwin, gboolean is_busy)
 	w = optwin->toplevel;
 	if(w != NULL)
 	{
-	    if(is_busy)
+	    if(busy)
 	    {
 		/* Increase busy count */
 		optwin->busy_count++;
