@@ -5,12 +5,15 @@
 #include "guiutils.h"
 #include "cdialog.h"
 #include "csd.h"
+#include "progressdialog.h"
 #include "style_edit.h"
 #include "stacklist.h"
 #include "keymap_list.h"
 #include "menucfg_list.h"
 
 #include "cfg.h"
+#include "cfg_fio.h"
+
 #include "edv_types.h"
 #include "edv_generic_options_win.h"
 #include "endeavour2.h"
@@ -19,33 +22,51 @@
 #include "config.h"
 #include "edv_cfg_list.h"
 
+#include "images/icon_select_32x32.xpm"
+
 
 static void OptWinFetchWidgetValueFromCFG(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	edv_gen_opt_wref_struct *wref
 );
 static void OptWinSetWidgetValueToCFG(
-	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
+	edv_core_struct *core,
+	edv_gen_opt_win_struct *optwin,
 	edv_gen_opt_wref_struct *wref
 );
 
 void EDVGenOptWinResetHasChanges(
-	edv_gen_opt_win_struct *optwin, const gboolean has_changes
+	edv_gen_opt_win_struct *optwin,
+	const gboolean has_changes
+);
+
+void EDVGenOptWinGetValues(
+	edv_gen_opt_win_struct *optwin,
+	const gboolean show_progress
+);
+
+static gint EDVGenOptWinSetValuesSaveCB(
+	gulong i, gulong m, gpointer data
+);
+void EDVGenOptWinSetValues(
+	edv_gen_opt_win_struct *optwin,
+	const gboolean show_progress,
+        const gboolean emit_notify_signal,
+	const gboolean save_to_disk
 );
-void EDVGenOptWinGetValues(edv_gen_opt_win_struct *optwin);
-void EDVGenOptWinSetValues(edv_gen_opt_win_struct *optwin);
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -1139,11 +1160,17 @@ static void OptWinSetWidgetValueToCFG(
 
 
 /*
- *	Resets all has_changes markers on all of the Option Window's
- *	Widget References and on the Options Window itself.
+ *	Resets all the has_changes markers on all of the widget
+ *	references on the Options Window.
+ *
+ *	The optwin specifies the Options Window.
+ *
+ *	The has_changes specifies the value to set the has_changes
+ *	value to.
  */
 void EDVGenOptWinResetHasChanges(
-	edv_gen_opt_win_struct *optwin, const gboolean has_changes
+	edv_gen_opt_win_struct *optwin,
+	const gboolean has_changes
 )
 {
 	GList *glist;
@@ -1172,10 +1199,17 @@ void EDVGenOptWinResetHasChanges(
 }
 
 /*
- *	Fetches values from the cfg list to the widgets specified
- *	by the Option Window's Widget References.
+ *	Gets the values from the configuration list to the widgets.
+ *
+ *	The optwin specifies the Options Window.
+ *
+ *	If show_progress is TRUE then the progress dialog will be
+ *	displayed during this call.
  */
-void EDVGenOptWinGetValues(edv_gen_opt_win_struct *optwin)
+void EDVGenOptWinGetValues(
+	edv_gen_opt_win_struct *optwin,
+	const gboolean show_progress
+)
 {
 	GList *glist;
 	edv_gen_opt_wref_struct *wref;
@@ -1185,8 +1219,6 @@ void EDVGenOptWinGetValues(edv_gen_opt_win_struct *optwin)
 	    return;
 
 	core = optwin->core;
-	if(core == NULL)
-	    return;
 
 	/* Iterate through the widget references list and get the
 	 * configuration values for each widget
@@ -1204,29 +1236,96 @@ void EDVGenOptWinGetValues(edv_gen_opt_win_struct *optwin)
 	}
 }
 
+
 /*
- *	Applies values from the widgets specified by the Option Window's
- *	Widget References to the cfg list.
+ *	Save configuration to file callback.
  */
-void EDVGenOptWinSetValues(edv_gen_opt_win_struct *optwin)
+static gint EDVGenOptWinSetValuesSaveCB(
+	gulong i, gulong m, gpointer data
+)
 {
+	edv_gen_opt_win_struct *optwin = EDV_GEN_OPT_WIN(data);
+	if(optwin == NULL)
+	    return(0);
+
+	if(m != 0l)
+	    ProgressDialogUpdate(
+		NULL, NULL, NULL, NULL,
+		(1.0f / 2.0f) + (((gfloat)i / (gfloat)m) / 2.0f),
+		EDV_DEF_PROGRESS_BAR_TICKS,
+		TRUE
+	    );
+	else
+	    ProgressDialogUpdate(
+		NULL, NULL, NULL, NULL,
+		(1.0f / 2.0f) + (0.0f / 2.0f),
+		EDV_DEF_PROGRESS_BAR_TICKS,
+		TRUE
+	    );
+
+	if(ProgressDialogStopCount() > 0)
+	    return(-1);
+	else
+	    return(0);
+}
+
+/*
+ *	Sets the values from the widgets to the configuration list.
+ *
+ *	The optwin specifies the Options Window.
+ *
+ *	If show_progress is TRUE then the progress dialog will be
+ *	displayed during this call.
+ *
+ *	If emit_notify_signal is TRUE then a write protect changed
+ *	and reconfigured signals will be emitted.
+ *
+ *	If save_to_disk is TRUE then the configuration will be
+ *	saved to disk.
+ */
+void EDVGenOptWinSetValues(
+	edv_gen_opt_win_struct *optwin,
+	const gboolean show_progress,
+        const gboolean emit_notify_signal,
+	const gboolean save_to_disk
+)
+{
+	gboolean user_aborted;
+	gint i, nwrefs;
 	GList *glist;
+	GtkWidget *toplevel;
+	cfg_item_struct *cfg_list;
 	edv_gen_opt_wref_struct *wref;
 	edv_core_struct *core;
 
 	if(optwin == NULL)
 	    return;
 
+	toplevel = optwin->toplevel;
 	core = optwin->core;
-	if(core == NULL)
-	    return;
+	cfg_list = core->cfg_list;
+
+	/* Map the progress dialog? */
+	if(show_progress)
+	{
+	    ProgressDialogSetTransientFor(toplevel);
+	    ProgressDialogMap(
+                "Applying Values",
+		"Applying Values...",
+		(const guint8 **)icon_select_32x32_xpm,
+		"Stop"
+	    );
+	}
+
+	user_aborted = FALSE;
+	nwrefs = g_list_length(optwin->wrefs_list);
 
 	/* Iterate through the widget references list and set the
 	 * configuration values from each widget's value
 	 */
-	for(glist = optwin->wrefs_list;
+	for(glist = optwin->wrefs_list, i = 0;
 	    glist != NULL;
-	    glist = g_list_next(glist)
+	    glist = g_list_next(glist), i++
 	)
 	{
 	    wref = EDV_GEN_OPT_WREF(glist->data);
@@ -1234,8 +1333,63 @@ void EDVGenOptWinSetValues(edv_gen_opt_win_struct *optwin)
 		continue;
 
 	    OptWinSetWidgetValueToCFG(core, optwin, wref);
+
+	    if(show_progress)
+	    {
+		gfloat v = (gfloat)(i + 1) / (gfloat)nwrefs;
+		if(save_to_disk)
+		    v = (0.0f / 2.0f) + (v / 2.0f);
+
+		ProgressDialogUpdate(
+		    NULL, NULL, NULL, NULL,
+		    v,
+		    EDV_DEF_PROGRESS_BAR_TICKS,
+		    TRUE
+		);
+		if(ProgressDialogStopCount() > 0)
+		{
+		    user_aborted = TRUE;
+		    break;
+		}
+	    }
 	}
 
-	/* Send out reconfigured signal to all resources */
-	EDVReconfiguredEmit(core);
+	/* Save the configuration to disk? */
+	if(save_to_disk && !STRISEMPTY(core->cfg_file))
+	{
+	    const gchar *path = core->cfg_file;
+	    if(show_progress)
+	    {
+		CFGFileSaveProgress(
+		    path,
+		    cfg_list,
+		    EDVGenOptWinSetValuesSaveCB,
+		    optwin
+		);
+	    }
+	    else
+	    {
+		CFGFileSave(path, cfg_list);
+	    }
+	}
+
+	/* Emit the notify signals? */
+	if(emit_notify_signal)
+	{
+	    /* Notify about the change in the write protect */
+	    EDVWriteProtectChangedEmit(
+		core,
+		EDV_GET_B(EDV_CFG_PARM_WRITE_PROTECT)
+	    );
+
+	    /* Notify about the change in the configuration */
+	    EDVReconfiguredEmit(core);
+	}
+
+	/* Unmap the progress dialog? */
+        if(show_progress)
+        {
+	    ProgressDialogBreakQuery(TRUE);
+	    ProgressDialogSetTransientFor(NULL);
+	}
 }
