@@ -7,11 +7,7 @@
 #include "edv_history.h"
 
 
-extern edv_history_struct *EDVHistoryListAppend(
-	edv_history_struct ***list, gint *total,
-	gint *n, const gint max
-);
-
+/* File IO */
 extern GList *EDVHistoryListOpen(
 	const gchar *path,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
