@@ -18,6 +18,10 @@ extern gint EDVInterPSMakeLock(
 );
 extern void EDVInterPSRemoveLock(const cfg_item_struct *cfg_list);
 
+extern void EDVInterPSSendCommandNotify(
+	const cfg_item_struct *cfg_list,
+	const gint p
+);
 extern gboolean EDVInterPSHaveCommand(const cfg_item_struct *cfg_list);
 extern void EDVInterPSSendCommandsList(
 	const cfg_item_struct *cfg_list,
