@@ -1,5 +1,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+#include "guiutils.h"
 #include "tlist.h"
 #include "edv_list_cb.h"
 #include "cfg.h"
@@ -28,33 +29,21 @@ gint EDVTListMotionEventCB(
 );
 
 
-
-#ifndef GDK_BUTTON1
-# define GDK_BUTTON1	1
-#endif
-#ifndef GDK_BUTTON2
-# define GDK_BUTTON2	2
-#endif
-#ifndef GDK_BUTTON3
-# define GDK_BUTTON3	3
-#endif
-
-
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
-
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
-
 static gboolean	do_scroll;
 static gint	pointer_x_last,
 		pointer_y_last;
 
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
+
 
 /*
  *	GtkCList "key_press_event" or "key_release_event" signal
@@ -73,29 +62,29 @@ gint EDVCListKeyEventCB(
 	if((clist == NULL) || (key == NULL) || (core == NULL))
 	    return(status);
 
-#define SIGNAL_EMIT_STOP	{		\
+#define SIGNAL_EMIT_STOP(_w_)	{		\
  gtk_signal_emit_stop_by_name(			\
-  GTK_OBJECT(widget),				\
+  GTK_OBJECT(_w_),				\
   press ?					\
    "key_press_event" : "key_release_event"	\
  );						\
 }
 
-#define DO_ADJ_CLAMP_EMIT	{		\
- if(adj->value > (adj->upper - adj->page_size))	\
-  adj->value = adj->upper - adj->page_size;	\
- if(adj->value < adj->lower)                    \
-  adj->value = adj->lower;                      \
- gtk_signal_emit_by_name(                       \
-  GTK_OBJECT(adj), "value_changed"              \
- );                                             \
+#define ADJ_CLAM_EMIT(_adj_)	{			\
+ if((_adj_)->value > ((_adj_)->upper - (_adj_)->page_size))	\
+  (_adj_)->value = (_adj_)->upper - (_adj_)->page_size;	\
+ if((_adj_)->value < (_adj_)->lower)			\
+  (_adj_)->value = (_adj_)->lower;			\
+ gtk_signal_emit_by_name(				\
+  GTK_OBJECT(_adj_), "value_changed"			\
+ );							\
 }
 
-#define DO_CLIST_FOCUS_ROW_CLAMP        {       \
- if(clist->focus_row >= clist->rows)            \
-  clist->focus_row = clist->rows - 1;           \
- if(clist->focus_row < 0)                       \
-  clist->focus_row = 0;                         \
+#define CLIST_FOCUS_ROW_CLAMP(_clist_)	{	\
+ if((_clist_)->focus_row >= (_clist_)->rows)	\
+  (_clist_)->focus_row = (_clist_)->rows - 1;	\
+ if((_clist_)->focus_row < 0)			\
+  (_clist_)->focus_row = 0;			\
 }
 
 	selection_mode = clist->selection_mode;
@@ -114,7 +103,7 @@ gint EDVCListKeyEventCB(
 		{
 		    gtk_clist_freeze(clist);
 		    adj->value -= adj->step_increment;
-		    DO_ADJ_CLAMP_EMIT
+		    ADJ_CLAM_EMIT(adj);
 		    gtk_clist_thaw(clist);
 		}
 	    }
@@ -127,7 +116,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_freeze(clist);
 
 		    clist->focus_row--;
-		    DO_CLIST_FOCUS_ROW_CLAMP
+		    CLIST_FOCUS_ROW_CLAMP(clist);
 
 		    if(gtk_clist_row_is_visible(
 			clist, clist->focus_row) != GTK_VISIBILITY_FULL
@@ -157,7 +146,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_thaw(clist);
 		}
 	    }
-	    SIGNAL_EMIT_STOP
+	    SIGNAL_EMIT_STOP(widget);
 	    status = TRUE;
 	    break;
 
@@ -171,7 +160,7 @@ gint EDVCListKeyEventCB(
 		{
 		    gtk_clist_freeze(clist);
 		    adj->value += adj->step_increment;
-		    DO_ADJ_CLAMP_EMIT
+		    ADJ_CLAM_EMIT(adj);
 		    gtk_clist_thaw(clist);
 		}
 	    }
@@ -185,7 +174,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_freeze(clist);
 
 		    clist->focus_row++;
-		    DO_CLIST_FOCUS_ROW_CLAMP
+		    CLIST_FOCUS_ROW_CLAMP(clist);
 
 		    if(gtk_clist_row_is_visible(
 			clist, clist->focus_row) != GTK_VISIBILITY_FULL
@@ -215,7 +204,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_thaw(clist);
 		}
 	    }
-	    SIGNAL_EMIT_STOP
+	    SIGNAL_EMIT_STOP(widget);
 	    status = TRUE;
 	    break;
 
@@ -235,12 +224,12 @@ gint EDVCListKeyEventCB(
 			adj->value = adj->lower;
 		    else
 			adj->value -= adj->step_increment;
-		    DO_ADJ_CLAMP_EMIT
+		    ADJ_CLAM_EMIT(adj);
 
 		    gtk_clist_thaw(clist);
 		}
 	    }
-	    SIGNAL_EMIT_STOP
+	    SIGNAL_EMIT_STOP(widget);
 	    status = TRUE;
 	    break;
 
@@ -260,12 +249,12 @@ gint EDVCListKeyEventCB(
 			adj->value = adj->upper - adj->page_size;
 		    else
 			adj->value += adj->step_increment;
-		    DO_ADJ_CLAMP_EMIT
+		    ADJ_CLAM_EMIT(adj);
 
 		    gtk_clist_thaw(clist);
 		}
 	    }
-	    SIGNAL_EMIT_STOP
+	    SIGNAL_EMIT_STOP(widget);
 	    status = TRUE;
 	    break;
 
@@ -280,7 +269,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_freeze(clist);
 
 		    adj->value -= adj->page_increment;
-		    DO_ADJ_CLAMP_EMIT
+		    ADJ_CLAM_EMIT(adj);
 
 		    gtk_clist_thaw(clist);
 		}
@@ -300,7 +289,7 @@ gint EDVCListKeyEventCB(
 		    clist->focus_row -= (gint)MAX(
 			(adj->page_increment / row_height), 1.0f
 		    );
-		    DO_CLIST_FOCUS_ROW_CLAMP
+		    CLIST_FOCUS_ROW_CLAMP(clist);
 
 		    if(gtk_clist_row_is_visible(
 			clist, clist->focus_row) != GTK_VISIBILITY_FULL
@@ -332,7 +321,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_thaw(clist);
 		}
 	    }
-	    SIGNAL_EMIT_STOP
+	    SIGNAL_EMIT_STOP(widget);
 	    status = TRUE;
 	    break;
 
@@ -347,7 +336,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_freeze(clist);
 
 		    adj->value += adj->page_increment;
-		    DO_ADJ_CLAMP_EMIT
+		    ADJ_CLAM_EMIT(adj);
 
 		    gtk_clist_thaw(clist);
 		}
@@ -355,7 +344,7 @@ gint EDVCListKeyEventCB(
 	    else
 	    {
 		/* Move focus row down one page step */
-		gint row_height = (GTK_CLIST_ROW_HEIGHT_SET(clist) ?
+		const gint row_height = (GTK_CLIST_ROW_HEIGHT_SET(clist) ?
 		    clist->row_height : EDV_LIST_ROW_SPACING) + 1;
 		const GtkAdjustment *adj = clist->vadjustment;
 		if(press && (row_height > 0) && (adj != NULL))
@@ -367,7 +356,7 @@ gint EDVCListKeyEventCB(
 		    clist->focus_row += (gint)MAX(
 			(adj->page_increment / row_height), 1.0f
 		    );
-		    DO_CLIST_FOCUS_ROW_CLAMP
+		    CLIST_FOCUS_ROW_CLAMP(clist);
 
 		    if(gtk_clist_row_is_visible(
 			clist, clist->focus_row) != GTK_VISIBILITY_FULL
@@ -399,7 +388,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_thaw(clist);
 		}
 	    }
-	    SIGNAL_EMIT_STOP
+	    SIGNAL_EMIT_STOP(widget);
 	    status = TRUE;
 	    break;
 
@@ -414,7 +403,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_freeze(clist);
 
 		    adj->value = adj->lower;
-		    DO_ADJ_CLAMP_EMIT
+		    ADJ_CLAM_EMIT(adj);
 
 		    gtk_clist_thaw(clist);
 		}
@@ -429,7 +418,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_freeze(clist);
 
 		    clist->focus_row = 0;
-		    DO_CLIST_FOCUS_ROW_CLAMP
+		    CLIST_FOCUS_ROW_CLAMP(clist);
 
 		    if(gtk_clist_row_is_visible(
 			clist, clist->focus_row) != GTK_VISIBILITY_FULL
@@ -461,7 +450,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_thaw(clist);
 		}
 	    }
-	    SIGNAL_EMIT_STOP
+	    SIGNAL_EMIT_STOP(widget);
 	    status = TRUE;
 	    break;
 
@@ -476,7 +465,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_freeze(clist);
 
 		    adj->value = adj->upper - adj->page_size;
-		    DO_ADJ_CLAMP_EMIT
+		    ADJ_CLAM_EMIT(adj);
 
 		    gtk_clist_thaw(clist);
 		}
@@ -491,7 +480,7 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_freeze(clist);
 
 		    clist->focus_row = clist->rows - 1;
-		    DO_CLIST_FOCUS_ROW_CLAMP
+		    CLIST_FOCUS_ROW_CLAMP(clist);
 
 		    if(gtk_clist_row_is_visible(
 			clist, clist->focus_row) != GTK_VISIBILITY_FULL
@@ -523,14 +512,14 @@ gint EDVCListKeyEventCB(
 		    gtk_clist_thaw(clist);
 		}
 	    }
-	    SIGNAL_EMIT_STOP
+	    SIGNAL_EMIT_STOP(widget);
 	    status = TRUE;
 	    break;
 	}
 
 	return(status);
-#undef DO_CLIST_FOCUS_ROW_CLAMP
-#undef DO_ADJ_CLAMP_EMIT
+#undef CLIST_FOCUS_ROW_CLAMP
+#undef ADJ_CLAM_EMIT
 #undef SIGNAL_EMIT_STOP
 }
 
@@ -551,9 +540,9 @@ gint EDVCListButtonEventCB(
 
 	cfg_list = core->cfg_list;
 
-#define SIGNAL_EMIT_STOP	{		\
+#define SIGNAL_EMIT_STOP(_w_)	{		\
  gtk_signal_emit_stop_by_name(			\
-  GTK_OBJECT(widget),				\
+  GTK_OBJECT(_w_),				\
   (button->type == GDK_BUTTON_PRESS) ?		\
    "button_press_event" : "button_release_event"\
  );						\
@@ -596,7 +585,7 @@ gint EDVCListButtonEventCB(
 		    pointer_x_last = x;
 		    pointer_y_last = y;
 
-		    SIGNAL_EMIT_STOP
+		    SIGNAL_EMIT_STOP(widget);
 		    status = TRUE;
 		}
 		break;
@@ -618,7 +607,7 @@ gint EDVCListButtonEventCB(
 		    pointer_x_last = 0;
 		    pointer_y_last = 0;
 
-		    SIGNAL_EMIT_STOP
+		    SIGNAL_EMIT_STOP(widget);
 		    status = TRUE;
 		}
 		break;
@@ -646,18 +635,18 @@ gint EDVCListMotionEventCB(
 
 	cfg_list = core->cfg_list;
 
-#define SIGNAL_EMIT_STOP	{		\
+#define SIGNAL_EMIT_STOP(_w_)	{		\
  gtk_signal_emit_stop_by_name(			\
-  GTK_OBJECT(widget), "motion_notify_event"	\
+  GTK_OBJECT(_w_), "motion_notify_event"	\
  );						\
 }
 
-#define DO_SCROLL(dx,dy)	{		\
- GtkAdjustment *adj = clist->hadjustment;	\
- if((adj != NULL) && ((dx) != 0)) {		\
+#define CLIST_SCROLL(_clist_,_dx_,_dy_)	{	\
+ GtkAdjustment *adj = (_clist_)->hadjustment;	\
+ if((adj != NULL) && ((_dx_) != 0)) {		\
   if((adj->upper - adj->page_size) > adj->lower) { \
    adj->value = CLIP(				\
-    adj->value - (dx),				\
+    adj->value - (_dx_),			\
     adj->lower, adj->upper - adj->page_size	\
    );						\
    gtk_signal_emit_by_name(			\
@@ -665,11 +654,11 @@ gint EDVCListMotionEventCB(
    );						\
   }						\
  }						\
- adj = clist->vadjustment;			\
- if((adj != NULL) && ((dy) != 0)) {		\
+ adj = (_clist_)->vadjustment;			\
+ if((adj != NULL) && ((_dy_) != 0)) {		\
   if((adj->upper - adj->page_size) > adj->lower) { \
    adj->value = CLIP(				\
-    adj->value - (dy),				\
+    adj->value - (_dy_),			\
     adj->lower, adj->upper - adj->page_size	\
    );						\
    gtk_signal_emit_by_name(			\
@@ -706,16 +695,16 @@ gint EDVCListMotionEventCB(
 		    pointer_y_last = (gint)motion->y;
 		}
 
-		DO_SCROLL(dx, dy);
+		CLIST_SCROLL(clist, dx, dy);
 
-		SIGNAL_EMIT_STOP
+		SIGNAL_EMIT_STOP(widget);
 		status = TRUE;
 	    }
 	    break;
 	}
 
 	return(status);
-#undef DO_SCROLL
+#undef CLIST_SCROLL
 #undef SIGNAL_EMIT_STOP
 }
 
@@ -743,12 +732,12 @@ gint EDVTListButtonEventCB(
 
 	cfg_list = core->cfg_list;
 
-#define SIGNAL_EMIT_STOP        {               \
- gtk_signal_emit_stop_by_name(                  \
-  GTK_OBJECT(widget),                           \
-  (button->type == GDK_BUTTON_PRESS) ?          \
+#define SIGNAL_EMIT_STOP(_w_)	{		\
+ gtk_signal_emit_stop_by_name(			\
+  GTK_OBJECT(_w_),				\
+  (button->type == GDK_BUTTON_PRESS) ?		\
    "button_press_event" : "button_release_event"\
- );                                             \
+ );						\
 }
 
 	switch((gint)button->type)
@@ -786,7 +775,7 @@ gint EDVTListButtonEventCB(
 		    pointer_x_last = x;
 		    pointer_y_last = y;
 
-		    SIGNAL_EMIT_STOP
+		    SIGNAL_EMIT_STOP(widget);
 		    status = TRUE;
 		}
 		break;
@@ -806,7 +795,7 @@ gint EDVTListButtonEventCB(
 		    pointer_x_last = 0;
 		    pointer_y_last = 0;
 
-		    SIGNAL_EMIT_STOP
+		    SIGNAL_EMIT_STOP(widget);
 		    status = TRUE;
 		}
 		break;
@@ -836,43 +825,37 @@ gint EDVTListMotionEventCB(
 
 	core = EDV_CORE(imbr->core);
 	tlist = imbr->tlist;
-	if((core == NULL) || (tlist == NULL))
-	    return(status);
-
 	cfg_list = core->cfg_list;
 
-#define SIGNAL_EMIT_STOP        {               \
- gtk_signal_emit_stop_by_name(                  \
-  GTK_OBJECT(widget), "motion_notify_event"     \
- );                                             \
+#define SIGNAL_EMIT_STOP(_w_)	{		\
+ gtk_signal_emit_stop_by_name(			\
+  GTK_OBJECT(_w_), "motion_notify_event"	\
+ );						\
 }
 
-#define DO_SCROLL(dx,dy)        {               \
- if(tlist->flags & TLIST_HORIZONTAL) {		\
-  GtkAdjustment *adj = tlist->hadj;		\
-  if((adj != NULL) && ((dx) != 0)) {		\
-   if((adj->upper - adj->page_size) > adj->lower) { \
-    adj->value = CLIP(				\
-     adj->value - (dx),				\
-     adj->lower, adj->upper - adj->page_size	\
-    );						\
-    gtk_signal_emit_by_name(			\
-     GTK_OBJECT(adj), "value_changed"		\
-    );						\
-   }						\
+#define CLIST_SCROLL(_tlist_,_dx_,_dy_)	{	\
+ GtkAdjustment *adj = (_tlist_)->hadj;		\
+ if((adj != NULL) && ((_dx_) != 0)) {		\
+  if((adj->upper - adj->page_size) > adj->lower) { \
+   adj->value = CLIP(				\
+    adj->value - (_dx_),			\
+    adj->lower, adj->upper - adj->page_size	\
+   );						\
+   gtk_signal_emit_by_name(			\
+    GTK_OBJECT(adj), "value_changed"		\
+   );						\
   }						\
- } else {					\
-  GtkAdjustment *adj = tlist->vadj;		\
-  if((adj != NULL) && ((dy) != 0)) {		\
-   if((adj->upper - adj->page_size) > adj->lower) { \
-    adj->value = CLIP(				\
-     adj->value - (dy),				\
-     adj->lower, adj->upper - adj->page_size	\
-    );						\
-    gtk_signal_emit_by_name(			\
-     GTK_OBJECT(adj), "value_changed"		\
-    );						\
-   }						\
+ }						\
+ adj = (_tlist_)->vadj;				\
+ if((adj != NULL) && ((_dy_) != 0)) {		\
+  if((adj->upper - adj->page_size) > adj->lower) { \
+   adj->value = CLIP(				\
+    adj->value - (_dy_),			\
+    adj->lower, adj->upper - adj->page_size	\
+   );						\
+   gtk_signal_emit_by_name(			\
+    GTK_OBJECT(adj), "value_changed"		\
+   );						\
   }						\
  }						\
 }
@@ -904,15 +887,15 @@ gint EDVTListMotionEventCB(
 		    pointer_y_last = (gint)motion->y;
 		}
 
-		DO_SCROLL(dx, dy);
+		CLIST_SCROLL(tlist, dx, dy);
 
-		SIGNAL_EMIT_STOP
+		SIGNAL_EMIT_STOP(widget);
 		status = TRUE;
 	    }
 	    break;
 	}
 
 	return(status);
-#undef DO_SCROLL
+#undef CLIST_SCROLL
 #undef SIGNAL_EMIT_STOP
 }
