@@ -77,7 +77,8 @@ void EDVMimeTypesListFileOpen(
 	const gchar *path,
 	edv_mime_type_struct ***list, gint *total,
 	const gint insert_index,
-	const gboolean update, const gboolean only_newer,
+	const gboolean update,
+	const gboolean only_newer,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
 	gpointer progress_data,
 	void (*added_cb)(const gint, edv_mime_type_struct *, gpointer),
@@ -842,11 +843,21 @@ void EDVMimeTypesListSystemFileOpen(
 ) {							\
  gint mt_num;						\
 							\
+ if(progress_cb != NULL) {				\
+  if(progress_cb(progress_data, 0l, 0l)) {		\
+   g_free(icons_dir);					\
+   return;						\
+  }							\
+ }							\
+							\
  /* Create a new MIME Type */				\
- m = EDVMimeTypeNew(					\
-  EDV_MIME_TYPE_CLASS_SYSTEM, (_val_),			\
-  (_type_), (_desc_)					\
- );							\
+ m = EDVMimeTypeNew();					\
+ if(m != NULL) {					\
+  m->type = EDV_MIME_TYPE_CLASS_SYSTEM;			\
+  m->value = STRDUP(_val_);				\
+  m->type = STRDUP(_type_);				\
+  m->description = STRDUP(_desc_);			\
+ }							\
 							\
  /* Insert/append the MIME Type to the list */		\
  mt_num = EDVMimeTypesListInsert(			\
@@ -1179,7 +1190,8 @@ void EDVMimeTypesListFileOpen(
 	const gchar *path,
 	edv_mime_type_struct ***list, gint *total,
 	const gint insert_index,
-	const gboolean update, const gboolean only_newer,
+	const gboolean update,
+	const gboolean only_newer,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
 	gpointer progress_data,
 	void (*added_cb)(const gint, edv_mime_type_struct *, gpointer),
@@ -1259,7 +1271,13 @@ void EDVMimeTypesListFileOpen(
 
 		/* Create a new MIME Type */
 		if(mt == NULL)
-		    mt = EDVMimeTypeNew(mt_class, NULL, NULL, NULL);
+		{
+		    mt = EDVMimeTypeNew();
+		    if(mt != NULL)
+		    {
+			mt->mt_class = mt_class;
+		    }
+		}
 		if(mt != NULL)
 		{
 		    /* Mark as read only? */
