@@ -20,6 +20,42 @@ extern edv_mime_type_struct *EDVMimeTypesListMatchPath(
 	const gchar *path
 );
 
+/* Insert, Append, Remove */
+extern gint EDVMimeTypesListInsert(
+	edv_mime_type_struct ***list, gint *total,
+	const gint i,
+	edv_mime_type_struct *m
+);
+extern gint EDVMimeTypesListAppend(
+	edv_mime_type_struct ***list, gint *total,
+	edv_mime_type_struct *m
+);
+extern void EDVMimeTypesListRemove(
+	edv_mime_type_struct ***list, gint *total,
+	const gint i
+);
+extern void EDVMimeTypesListClear(
+	edv_mime_type_struct ***list, gint *total
+);
+
+/* DDE Buffer */
+extern GList *EDVMimeTypesListFromDDEBuffer(
+	edv_mime_type_struct **list, const gint total,
+	const guint8 *buf, const gint buf_len
+);
+extern guint8 *EDVMimeTypesListToDDEBuffer(
+	edv_mime_type_struct **list, const gint total,
+	GList *selection_list,
+	gint *buf_len_rtn
+);
+extern GList *EDVMimeTypeCommandsListFromDDEBuffer(
+	const guint8 *buf, const gint buf_len
+);
+extern guint8 *EDVMimeTypeCommandsListToDDEBuffer(
+	GList *commands_list,
+	gint *buf_len_rtn
+);
+
 /* Mailcap format import/export */
 extern void EDVMimeTypesListMailcapImport(
 	const gchar *path,
@@ -64,6 +100,7 @@ extern void EDVMimeTypesListMediaTypesExport(
 
 /* Endeavour MIME Types format reading and writing */
 extern void EDVMimeTypesListSystemFileOpen(
+	const gchar *data_path,
 	edv_mime_type_struct ***list, gint *total,
 	const gint insert_index,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
