@@ -426,17 +426,16 @@ void EDVMimeTypesListMailcapImport(
 
 		    mt_num = cur_insert_index;
 
-		    /* Shift pointers */
+		    /* Shift the pointers */
 		    for(i = (*total) - 1; i > mt_num; i--)
 			(*list)[i] = (*list)[i - 1];
 
 		    /* Create the new MIME Type */
-		    (*list)[mt_num] = mt = EDVMimeTypeNew(
-		        EDV_MIME_TYPE_CLASS_FORMAT,
-		        NULL,		/* Value */
-		        NULL,		/* Type */
-		        NULL		/* Description */
-		    );
+		    (*list)[mt_num] = mt = EDVMimeTypeNew();
+		    if(mt != NULL)
+		    {
+			mt->mt_class = EDV_MIME_TYPE_CLASS_FORMAT;
+		    }
 
 		    cur_insert_index++;	/* Account for the shift in position */
 	        }
@@ -458,12 +457,11 @@ void EDVMimeTypesListMailcapImport(
 		    }
 
 		    /* Create the new MIME Type */
-		    (*list)[mt_num] = mt = EDVMimeTypeNew(
-		        EDV_MIME_TYPE_CLASS_FORMAT,
-		        NULL,		/* Value */
-		        NULL,		/* Type */
-		        NULL		/* Description */
-		    );
+		    (*list)[mt_num] = mt = EDVMimeTypeNew();
+		    if(mt != NULL)
+		    {
+			mt->mt_class = EDV_MIME_TYPE_CLASS_FORMAT;
+		    }
 
 		    cur_insert_index = -1;
 	        }
