@@ -85,28 +85,28 @@ void EDVMountBarUnmap(edv_mount_bar_struct *mb);
 void EDVMountBarDelete(edv_mount_bar_struct *mb);
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
- *	Mount Bar any GtkWidget "enter_notify_event" or
- *	"leave_notify_event" signal callback.
+ *	Any GtkWidget "enter_notify_event" or "leave_notify_event"
+ *	signal callback.
  */
 static gint EDVMountBarCrossingCB(
 	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
 )
 {
 	gint status = FALSE;
-	const gchar *mesg = NULL;
+	const gchar *msg = NULL;
 	edv_mount_bar_struct *mb = EDV_MOUNT_BAR(data);
 	if((widget == NULL) || (crossing == NULL) || (mb == NULL))
 	    return(status);
@@ -114,7 +114,7 @@ static gint EDVMountBarCrossingCB(
 	if(crossing->type == GDK_ENTER_NOTIFY)
 	{
 	    if(mb->mount_btn == widget)
-		mesg =
+		msg =
 #if defined(PROG_LANGUAGE_SPANISH)
 "Mount/unmount dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -134,7 +134,7 @@ static gint EDVMountBarCrossingCB(
 #endif
 		;
 	    else if(mb->eject_btn == widget)
-		mesg =
+		msg =
 #if defined(PROG_LANGUAGE_SPANISH)
 "Expulse medios del dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -154,7 +154,7 @@ static gint EDVMountBarCrossingCB(
 #endif
 		;
 	    else if(mb->refresh_btn == widget)
-		mesg =
+		msg =
 #if defined(PROG_LANGUAGE_SPANISH)
 "Refresque toda estadstica de dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -174,7 +174,7 @@ static gint EDVMountBarCrossingCB(
 #endif
 		;
 	    else if(mb->goto_btn == widget)
-		mesg =
+		msg =
 #if defined(PROG_LANGUAGE_SPANISH)
 "Vaya a montar sendero"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -194,11 +194,11 @@ static gint EDVMountBarCrossingCB(
 #endif
 		;
 	    else if(mb->properties_btn == widget)
-		mesg =
+		msg =
 "Modify the properties of the mount path"
 		;
 	    else if(mb->fsck_btn == widget)
-		mesg =
+		msg =
 #if defined(PROG_LANGUAGE_SPANISH)
 "Verifique el sistema del archivo de dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -218,9 +218,9 @@ static gint EDVMountBarCrossingCB(
 #endif
 		;
 	    else if(mb->devices_list_btn == widget)
-		mesg = "Devices list";
+		msg = "Devices list";
 	    else if(mb->tools_btn == widget)
-		mesg =
+		msg =
 #if defined(PROG_LANGUAGE_SPANISH)
 "Corra el programa de instrumentos de dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -240,7 +240,7 @@ static gint EDVMountBarCrossingCB(
 #endif
 		;
 	    else if(mb->format_btn == widget)
-		mesg =
+		msg =
 #if defined(PROG_LANGUAGE_SPANISH)
 "Formatear los medios en el dispositivo"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -265,7 +265,7 @@ static gint EDVMountBarCrossingCB(
 
 	if(mb->status_message_cb != NULL)
 	    mb->status_message_cb(
-		mesg,			/* Message */
+		msg,			/* Message */
 		mb->data		/* Data */
 	    );
 
@@ -273,7 +273,7 @@ static gint EDVMountBarCrossingCB(
 }
 
 /*
- *	Mount Bar device GtkDrawingArea event signal callback.
+ *	Device GtkDrawingArea event signal callback.
  */
 static gint EDVMountBarDeviceEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
@@ -291,8 +291,6 @@ static gint EDVMountBarDeviceEventCB(
 	    return(status);
 
 	core = mb->core;
-	if(core == NULL)
-	    return(status);
 
 	switch((gint)event->type)
 	{
@@ -323,9 +321,9 @@ static gint EDVMountBarDeviceEventCB(
 	    press = (key->type == GDK_KEY_PRESS) ? TRUE : FALSE;
  	    keyval = key->keyval;
 	    state = key->state;
-#define DO_STOP_KEY_SIGNAL_EMIT	{		\
+#define STOP_KEY_SIGNAL_EMIT(_w_) {		\
  gtk_signal_emit_stop_by_name(			\
-  GTK_OBJECT(widget),				\
+  GTK_OBJECT(_w_),				\
   press ?					\
    "key_press_event" : "key_release_event"	\
  );						\
@@ -343,7 +341,7 @@ static gint EDVMountBarDeviceEventCB(
 		{
 		    EDVMountBarMountCB(NULL, mb);
 		}
-		DO_STOP_KEY_SIGNAL_EMIT
+		STOP_KEY_SIGNAL_EMIT(widget);
 		status = TRUE;
 		break;
 
@@ -353,19 +351,20 @@ static gint EDVMountBarDeviceEventCB(
 	      case GDK_KP_Page_Up:
 		if(press)
 		{
+		    const gint ndevices = core->total_devices;
 		    gint i = mb->selected_dev_num;
-		    edv_device_struct *dev;
+		    edv_device_struct *dev, **devices_list = core->device;
 
 		    /* Current selection in bounds? */
-		    if((i >= 0) && (i < core->total_devices))
+		    if((i >= 0) && (i < ndevices))
 		    {
-			/* Check previous device and see if it is selectable.
-			 * Iterate on to previous device if the current is
-			 * not selectable.
+			/* Check the previous device and see if it is
+			 * selectable, iterate on to previous device
+			 * if the current device is not selectable
 			 */
 			for(i--; i >= 0; i--)
 			{
-			    dev = core->device[i];
+			    dev = devices_list[i];
 			    if(dev == NULL)
 				continue;
 			    if(EDV_DEVICE_IS_UNLISTED(dev))
@@ -381,9 +380,9 @@ static gint EDVMountBarDeviceEventCB(
 			/* Current selection is out of bounds, so select
 			 * the first valid device
 			 */
-			for(i = 0; i < core->total_devices; i++)
+			for(i = 0; i < ndevices; i++)
 			{
-			    dev = core->device[i];
+			    dev = devices_list[i];
 			    if(dev == NULL)
 				continue;
 			    if(EDV_DEVICE_IS_UNLISTED(dev))
@@ -394,7 +393,7 @@ static gint EDVMountBarDeviceEventCB(
 		    }
 		    EDVMountBarUpdateMenus(mb);
 		}
-		DO_STOP_KEY_SIGNAL_EMIT
+		STOP_KEY_SIGNAL_EMIT(widget);
 		status = TRUE;
 		break;
 
@@ -445,7 +444,7 @@ static gint EDVMountBarDeviceEventCB(
 		    }
 		    EDVMountBarUpdateMenus(mb);
 		}
-		DO_STOP_KEY_SIGNAL_EMIT
+		STOP_KEY_SIGNAL_EMIT(widget);
 		status = TRUE;
 		break;
 
@@ -472,7 +471,7 @@ static gint EDVMountBarDeviceEventCB(
 			EDVMountBarUpdateMenus(mb);
 		    }
 		}
-		DO_STOP_KEY_SIGNAL_EMIT
+		STOP_KEY_SIGNAL_EMIT(widget);
 		status = TRUE;
 		break;
 
@@ -499,10 +498,11 @@ static gint EDVMountBarDeviceEventCB(
 			EDVMountBarUpdateMenus(mb);
 		    }
 		}
-		DO_STOP_KEY_SIGNAL_EMIT
+		STOP_KEY_SIGNAL_EMIT(widget);
 		status = TRUE;
 		break;
 	    }
+#undef STOP_KEY_SIGNAL_EMIT
 	    break;
 
 	  case GDK_BUTTON_PRESS:
@@ -511,19 +511,22 @@ static gint EDVMountBarDeviceEventCB(
 		gtk_widget_grab_focus(widget);
 	    switch(button->button)
 	    {
-	      case 1:
+	      case GDK_BUTTON1:
 		EDVMountBarMapPUListCB(mb->map_btn, mb);
 		status = TRUE;
 		break;
 	    }
 	    break;
+
+	  case GDK_BUTTON_RELEASE:
+	    break;
 	}
 
 	return(status);
 }
 
 /*
- *	Mount Bar stats GtkDrawingArea event signal callback.
+ *	Stats GtkDrawingArea event signal callback.
  */
 static gint EDVMountBarStatsEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
@@ -538,8 +541,6 @@ static gint EDVMountBarStatsEventCB(
 	    return(status);
 
 	core = mb->core;
-	if(core == NULL)
-	    return(status);
 
 	switch((gint)event->type)
 	{
@@ -588,6 +589,9 @@ static gint EDVMountBarStatsEventCB(
 		break;
 	    }
 	    break;
+
+	  case GDK_BUTTON_RELEASE:
+	    break;
 	}
 
 	return(status);
@@ -608,9 +612,10 @@ static void EDVMountBarMapPUListCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	core = mb->core;
-	pulist = (core != NULL) ? core->devices_pulist : NULL;
+	pulist = core->devices_pulist;
 	if(pulist == NULL)
 	    return;
+
 	if(PUListIsQuery(pulist))
 	    return;
 
@@ -633,7 +638,7 @@ static void EDVMountBarMapPUListCB(GtkWidget *widget, gpointer data)
 
 	gtk_widget_grab_focus(mb->dev_da);
 
-	/* Get device index number from the selected value */
+	/* Get the device index number from the selected value */
 	dev_num = (gint)PUListGetDataFromValue(pulist, value);
 	dev = ((dev_num >= 0) && (dev_num < core->total_devices)) ?
 	    core->device[dev_num] : NULL;
@@ -660,9 +665,6 @@ static void EDVMountBarMountCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	core = mb->core;
-	if(core == NULL)
-	    return;
-
 	dev_num = mb->selected_dev_num;
 	if((dev_num >= 0) && (dev_num < core->total_devices))
 	{
@@ -689,9 +691,6 @@ static void EDVMountBarEjectCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	core = mb->core;
-	if(core == NULL)
-	    return;
-
 	dev_num = mb->selected_dev_num;
 	if((dev_num >= 0) && (dev_num < core->total_devices))
 	{
@@ -718,9 +717,6 @@ static void EDVMountBarGoToCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	core = mb->core;
-	if(core == NULL)
-	    return;
-
 	dev_num = mb->selected_dev_num;
 	if((dev_num >= 0) && (dev_num < core->total_devices))
 	{
@@ -743,9 +739,10 @@ static void EDVMountBarGoToCB(GtkWidget *widget, gpointer data)
  */
 static void EDVMountBarPropertiesCB(GtkWidget *widget, gpointer data)
 {
+	struct stat lstat_buf;
 	gint dev_num;
 	const gchar *mount_path;
-	struct stat lstat_buf;
+	GtkWidget *toplevel;
 	edv_object_struct *obj;
 	edv_device_struct *dev;
 	edv_core_struct *core;
@@ -753,6 +750,7 @@ static void EDVMountBarPropertiesCB(GtkWidget *widget, gpointer data)
 	if(mb == NULL)
 	    return;
 
+	toplevel = gtk_widget_get_toplevel(mb->toplevel);
 	core = mb->core;
 
 	/* Get the selected device */
@@ -787,11 +785,13 @@ static void EDVMountBarPropertiesCB(GtkWidget *widget, gpointer data)
 	}
 	EDVObjectUpdateLinkFlags(obj);
 
-	EDVNewPropertiesDialogPage(
-	    core, obj,
+	/* Create a new properties dialog for the object and map it */
+	EDVNewPropertiesDialogVFSPage(
+	    core,
+	    obj,
 	    "Device",
-	    gtk_widget_get_toplevel(mb->toplevel)
-	); 
+	    toplevel
+	);
 
 	EDVObjectDelete(obj);
 }
@@ -802,17 +802,15 @@ static void EDVMountBarPropertiesCB(GtkWidget *widget, gpointer data)
 static void EDVMountBarFSCKCB(GtkWidget *widget, gpointer data)
 {
 	gint dev_num;
+	GtkWidget *toplevel;
 	edv_device_struct *dev;
 	edv_core_struct *core;
 	edv_mount_bar_struct *mb = EDV_MOUNT_BAR(data);
 	if(mb == NULL)
 	    return;
 
+	toplevel = gtk_widget_get_toplevel(mb->toplevel);
 	core = mb->core;
-	if(core == NULL)
-	    return;
-
-	/* Get the selected device */
 	dev_num = mb->selected_dev_num;
 	dev = ((dev_num >= 0) && (dev_num < core->total_devices)) ?
 	    core->device[dev_num] : NULL;
@@ -820,9 +818,7 @@ static void EDVMountBarFSCKCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	/* Run the device check */
-	EDVRunDeviceCheck(
-	    core, dev, gtk_widget_get_toplevel(mb->toplevel)
-	);
+	EDVRunDeviceCheck(core, dev, toplevel);
 }
 
 /*
@@ -831,17 +827,15 @@ static void EDVMountBarFSCKCB(GtkWidget *widget, gpointer data)
 static void EDVMountBarToolsCB(GtkWidget *widget, gpointer data)
 {
 	gint dev_num;
+	GtkWidget *toplevel;
 	edv_device_struct *dev;
 	edv_core_struct *core;
 	edv_mount_bar_struct *mb = EDV_MOUNT_BAR(data);
 	if(mb == NULL)
 	    return;
 
+	toplevel = gtk_widget_get_toplevel(mb->toplevel);
 	core = mb->core;
-	if(core == NULL)
-	    return;
-
-	/* Get the selected device */
 	dev_num = mb->selected_dev_num;
 	dev = ((dev_num >= 0) && (dev_num < core->total_devices)) ?
 	    core->device[dev_num] : NULL;
@@ -849,9 +843,7 @@ static void EDVMountBarToolsCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	/* Run the device tools */
-	EDVRunDeviceTools(
-	    core, dev, gtk_widget_get_toplevel(mb->toplevel)
-	);
+	EDVRunDeviceTools(core, dev, toplevel);
 }
 
 /*
@@ -860,27 +852,24 @@ static void EDVMountBarToolsCB(GtkWidget *widget, gpointer data)
 static void EDVMountBarFormatCB(GtkWidget *widget, gpointer data)
 {
 	gint dev_num;
+	GtkWidget *toplevel;
 	edv_device_struct *dev;
 	edv_core_struct *core;
 	edv_mount_bar_struct *mb = EDV_MOUNT_BAR(data);
 	if(mb == NULL)
 	    return;
 
+	toplevel = gtk_widget_get_toplevel(mb->toplevel);
 	core = mb->core;
-	if(core == NULL)
-	    return;
-
-	/* Get the selected device */
 	dev_num = mb->selected_dev_num;
 	dev = ((dev_num >= 0) && (dev_num < core->total_devices)) ?
 	    core->device[dev_num] : NULL;
 	if(dev == NULL)
 	    return;
 
+
 	/* Run the device format */
-	EDVRunDeviceFormat(
-	    core, dev, gtk_widget_get_toplevel(mb->toplevel)
-	);
+	EDVRunDeviceFormat(core, dev, toplevel);
 }
 
 /*
@@ -888,16 +877,16 @@ static void EDVMountBarFormatCB(GtkWidget *widget, gpointer data)
  */
 static void EDVMountBarDevicesListCB(GtkWidget *widget, gpointer data)
 {
+	GtkWidget *toplevel;
         edv_core_struct *core;
         edv_mount_bar_struct *mb = EDV_MOUNT_BAR(data);
         if(mb == NULL)
             return;
 
+	toplevel = gtk_widget_get_toplevel(mb->toplevel);
         core = mb->core;
-        if(core == NULL)
-            return;
 
-	EDVMapDevicesListWin(core, gtk_widget_get_toplevel(mb->toplevel));
+	EDVMapDevicesListWin(core, toplevel);
 }
 
 
@@ -915,8 +904,6 @@ static void EDVMountBarRefreshStatsCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	core = mb->core;
-	if(core == NULL)
-	    return;
 
 	/* Refresh all device mount states and device stats, then get
 	 * device path or mount path that matches the given disk
@@ -933,7 +920,6 @@ static void EDVMountBarRefreshStatsCB(GtkWidget *widget, gpointer data)
 }
 
 
-
 /*
  *	Draws the Mount Bar's device GtkDrawingArea.
  */
@@ -955,9 +941,6 @@ static void EDVMountBarDeviceDraw(edv_mount_bar_struct *mb)
 	    return;
 
 	w = mb->dev_da;
-	if(w == NULL)
-	    return;
-
 	state = GTK_WIDGET_STATE(w);
 	has_focus = GTK_WIDGET_HAS_FOCUS(w) ||
 	    GTK_WIDGET_HAS_FOCUS(mb->map_btn);
@@ -1075,9 +1058,6 @@ static void EDVMountBarStatsDraw(edv_mount_bar_struct *mb)
 
 	w = mb->stats_da;
 	core = mb->core;
-	if((w == NULL) || (core == NULL))
-	    return;
-
 	state = GTK_WIDGET_STATE(w);
 	window = w->window;
 	style = gtk_widget_get_style(w);
@@ -1240,8 +1220,6 @@ static void EDVMountBarSetStats(edv_mount_bar_struct *mb)
 	    return;
 
 	core = mb->core;
-	if(core == NULL)
-	    return;
 
 	/* Get the selected device */
 	dev_num = mb->selected_dev_num;
