@@ -202,7 +202,7 @@ static gchar *EDVObjCreateGenerateNewPath(
 	    return(NULL);
 
 	/* Get the type string from the type code */
-	type_str = STRDUP(EDVObjectGetTypeName(type));
+	type_str = STRDUP(EDVGetObjectTypeName(type));
 	if(type_str == NULL)
 	    return(NULL);
 
@@ -461,7 +461,7 @@ gint EDVObjCreateFileQueryName(
 		const gint error_code = (gint)errno;
 		gchar *msg = g_strconcat(
 		    "Unable to create a new ",
-		    EDVObjectGetTypeNameLower(EDV_OBJECT_TYPE_FILE),
+		    EDVGetObjectTypeNameLower(EDV_OBJECT_TYPE_FILE),
 		    ", ",
 		    g_strerror(error_code),
 		    ".",
@@ -498,7 +498,7 @@ gint EDVObjCreateFileQueryName(
 	    const gint error_code = (gint)errno;
 	    gchar *msg = g_strconcat(
 		"Unable to create a new ",
-		EDVObjectGetTypeNameLower(EDV_OBJECT_TYPE_FILE),
+		EDVGetObjectTypeNameLower(EDV_OBJECT_TYPE_FILE),
 		", ",
 		g_strerror(error_code),
 		".",
@@ -519,7 +519,7 @@ gint EDVObjCreateFileQueryName(
 	/* Record history */
 	EDVAppendHistory(
 	    core,
-	    EDV_HISTORY_DISK_OBJECT_CREATE,
+	    EDV_HISTORY_VFS_OBJECT_CREATE,
 	    time_start, (gulong)time(NULL),
 	    status,
 	    parent_path,			/* Source */
@@ -623,7 +623,7 @@ static gint EDVObjCreateNexus(
 	    {
 		gchar *msg = g_strconcat(
 		    "Unable to create a new ",
-		    EDVObjectGetTypeNameLower(type),
+		    EDVGetObjectTypeNameLower(type),
 		    ", ",
 		    g_strerror(error_code),
 		    ".",
@@ -693,7 +693,7 @@ static gint EDVObjCreateNexus(
 		const gint error_code = (gint)errno;
 		gchar *msg = g_strconcat(
 		    "Unable to create a new ",
-		    EDVObjectGetTypeNameLower(type),
+		    EDVGetObjectTypeNameLower(type),
 		    ", ",
 		    g_strerror(error_code),
 		    ".",
@@ -719,7 +719,7 @@ static gint EDVObjCreateNexus(
 		const gint error_code = (gint)errno;
 		gchar *msg = g_strconcat(
 		    "Unable to create a new ",
-		    EDVObjectGetTypeNameLower(type),
+		    EDVGetObjectTypeNameLower(type),
 		    ", ",
 		    g_strerror(error_code),
 		    ".",
@@ -738,7 +738,7 @@ static gint EDVObjCreateNexus(
 		const gint error_code = (gint)errno;
 		gchar *msg = g_strconcat(
 		    "Unable to create a new ",
-		    EDVObjectGetTypeNameLower(type),
+		    EDVGetObjectTypeNameLower(type),
 		    ", ",
 		    g_strerror(error_code),
 		    ".",
@@ -775,7 +775,7 @@ static gint EDVObjCreateNexus(
 		const gint error_code = (gint)errno;
 		gchar *msg = g_strconcat(
 		    "Unable to create a new ",
-		    EDVObjectGetTypeNameLower(type),
+		    EDVGetObjectTypeNameLower(type),
 		    ", ",
 		    g_strerror(error_code),
 		    ".",
@@ -809,7 +809,7 @@ static gint EDVObjCreateNexus(
 		const gint error_code = (gint)errno;
 		gchar *msg = g_strconcat(
 		    "Unable to create a new ",
-		    EDVObjectGetTypeNameLower(type),
+		    EDVGetObjectTypeNameLower(type),
 		    ", ",
 		    g_strerror(error_code),
 		    ".",
@@ -843,7 +843,7 @@ static gint EDVObjCreateNexus(
 		const gint error_code = (gint)errno;
 		gchar *msg = g_strconcat(
 		    "Unable to create a new ",
-		    EDVObjectGetTypeNameLower(type),
+		    EDVGetObjectTypeNameLower(type),
 		    ", ",
 		    g_strerror(error_code),
 		    ".",
@@ -876,7 +876,7 @@ static gint EDVObjCreateNexus(
 		const gint error_code = (gint)errno;
 		gchar *msg = g_strconcat(
 		    "Unable to create a new ",
-		    EDVObjectGetTypeNameLower(type),
+		    EDVGetObjectTypeNameLower(type),
 		    ", ",
 		    g_strerror(error_code),
 		    ".",
@@ -908,7 +908,7 @@ static gint EDVObjCreateNexus(
 	/* Record history */
 	EDVAppendHistory(
 	    core,
-	    EDV_HISTORY_DISK_OBJECT_CREATE,
+	    EDV_HISTORY_VFS_OBJECT_CREATE,
 	    time_start, (gulong)time(NULL),
 	    status,
 	    path,				/* Source */
