@@ -11,6 +11,7 @@
 
 #include "guiutils.h"
 #include "cdialog.h"
+#include "progressdialog.h"
 
 #include "cfg.h"
 #include "cfg_fio.h"
@@ -24,6 +25,7 @@
 #include "edv_mime_type.h"
 #include "edv_mime_types_list.h"
 #include "edv_recycled_obj.h"
+#include "edv_recbin_purge.h"
 #include "edv_recbin_index.h"
 #include "browser.h"
 #include "browser_dir_tree.h"
@@ -47,6 +49,7 @@
 #include "mime_types_list_win.h"
 #include "about_dlg.h"
 #include "endeavour2.h"
+#include "edv_confirm.h"
 #include "edv_cb.h"
 #include "edv_help.h"
 #include "edv_op.h"
@@ -83,13 +86,39 @@ gint EDVNewArchiver(
 	const gchar *password
 );
 
-gint EDVNewPropertiesDialogPage(
-	edv_core_struct *core, edv_object_struct *obj,
+static gint EDVNewPropertiesDialogNexus(
+	edv_core_struct *core,
+	gint *existing_dialogs
+);
+static void EDVNewPropertiesDialogSelectPageMove(
+	edv_core_struct *core,
+	edv_propdlg_struct *d,
+	const gchar *page_name,
+	const gint existing_dialogs,
+	GtkWidget *toplevel
+);
+gint EDVNewPropertiesDialogVFSPage(
+	edv_core_struct *core,
+	edv_object_struct *obj,
 	const gchar *page_name,
 	GtkWidget *toplevel
 );
-gint EDVNewPropertiesDialog(
-	edv_core_struct *core, edv_object_struct *obj,
+gint EDVNewPropertiesDialogVFS(
+	edv_core_struct *core,
+	edv_object_struct *obj,
+	GtkWidget *toplevel
+);
+gint EDVNewPropertiesDialogRecycledPage(
+	edv_core_struct *core,
+	edv_recycled_object_struct *obj,
+	const gchar *page_name,
+	GtkWidget *toplevel
+);
+gint EDVNewPropertiesDialogArchivePage(
+	edv_core_struct *core,
+	edv_archive_object_struct *obj,
+	const gchar *arch_path,
+	const gchar *page_name,
 	GtkWidget *toplevel
 );
 
@@ -222,6 +251,20 @@ void EDVClearRunHistory(
 	GtkWidget *toplevel
 );
 
+/* Recycle Bin Size Check */
+void EDVRecycleBinSizeCheck(
+	edv_core_struct *core,
+	GtkWidget *toplevel
+);
+
+/* Purge Recycle Bin */
+void EDVPurgeAllRecycledObjects(
+	edv_core_struct *core,
+	const gboolean map_recbin,
+	const gboolean show_progress,
+	const gboolean interactive,
+	GtkWidget *toplevel
+);
 
 /* Network */
 void EDVInternetDownloadObject(
@@ -232,12 +275,6 @@ void EDVInternetDownloadObject(
 );
 
 
-/* Recycle Bin Size Check */
-void EDVRecycleBinSizeCheck(
-	edv_core_struct *core, GtkWidget *toplevel
-);
-
-
 #define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
 #define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
 #define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
@@ -368,7 +405,12 @@ gint EDVNewWindow(
 		}
 		EDVObjectUpdateLinkFlags(obj);
 	    }
-	    EDVNewPropertiesDialogPage(core, obj, extra, NULL);
+	    EDVNewPropertiesDialogVFSPage(
+		core,
+		obj,
+		extra,				/* Page */
+		NULL
+	    );
 	    EDVObjectDelete(obj);
 	}
 	/* Options Window */
@@ -815,44 +857,31 @@ gint EDVNewArchiver(
 	}
 }
 
+
 /*
- *	Creates a new Properties Dialog.
+ *	Allocates a new properties dialog entry in the list.
  *
- *	The new dialog will be added to the core and mapped.
+ *	Does not create the actual properties dialog.
  *
- *	The obj specifies the object that is to be displayed on the
- *	dialog. The specified object will not be modified or deleted by
- *	this call.
- *
- *	The page_name specifies the name of the page to switch to
- *	after the dialog has been mapped.
- *
- *	Returns the index of the new Properties Dialog or -1 on
+ *	Returns the properties dialog index in the list or NULL on
  *	error.
  */
-gint EDVNewPropertiesDialogPage(
-	edv_core_struct *core, edv_object_struct *obj,
-	const gchar *page_name,
-	GtkWidget *toplevel
+static gint EDVNewPropertiesDialogNexus(
+	edv_core_struct *core,
+	gint *existing_dialogs
 )
 {
-	gint i, existing_windows = 0;
-	edv_propdlg_struct *propdlg;
-	cfg_item_struct *cfg_list;
+	gint i;
 
-	if(core == NULL)
-	    return(-1);
-
-	cfg_list = core->cfg_list;
-
-	/* Count existing windows */
+	/* Count the number of existing dialogs */
+	*existing_dialogs = 0;
 	for(i = 0; i < core->total_propdlgs; i++)
 	{
 	    if(core->propdlg[i] != NULL)
-		existing_windows++;
+		*existing_dialogs = (*existing_dialogs) + 1;
 	}
 
-	/* Look for available pointer in the array */
+	/* Look for an available pointer in the list */
 	for(i = 0; i < core->total_propdlgs; i++)
 	{
 	    if(core->propdlg[i] == NULL)
@@ -877,80 +906,303 @@ gint EDVNewPropertiesDialogPage(
 	    core->propdlg[i] = NULL;
 	}
 
-	/* Create new property window */
-	core->propdlg[i] = propdlg = EDVPropDlgNew(core, obj);
-	if(propdlg != NULL)
-	{
-	    GtkNotebook *notebook = GTK_NOTEBOOK(propdlg->notebook);
-
-	    /* Select tab? */
-	    if((page_name != NULL) && (notebook != NULL))
-	    {
-		gint	page_num = -1,
-			total_pages = g_list_length(notebook->first_tab);
-
-		/* Check which tab is to be switched to by matching
-		 * its name
-		 */
-		if(!g_strcasecmp(page_name, "General"))
-		    page_num = 0;
-		else if(!g_strcasecmp(page_name, "Details"))
-		    page_num = MAX(total_pages - 1, 1);
-		else if(!g_strcasecmp(page_name, "Link"))
-		    page_num = 1;
-		else if(!g_strcasecmp(page_name, "Device"))
-		    page_num = 1;
-		else if(!g_strcasecmp(page_name, "Device Node"))
-		    page_num = (total_pages >= 4) ? 2 : 1;
-
-		/* Matched page to be switched to? */
-		if(page_num > -1)
-		    gtk_notebook_set_page(notebook, page_num);
-	    }
-
-	    /* Shift window position if there are existing windows */
-	    if(existing_windows > 0)
-	    {
-		gint	offset_x = CFGItemListGetValueI(
-			    cfg_list,
-			    EDV_CFG_PARM_WINDOW_CASCADE_OFFSET_X
-			) * existing_windows,
-			offset_y = CFGItemListGetValueI(
-			    cfg_list,
-			    EDV_CFG_PARM_WINDOW_CASCADE_OFFSET_Y
-			) * existing_windows;
-		EDVCenterWindowToWindowOffset(
-		    toplevel, propdlg->toplevel,
-		    offset_x, offset_y
-		);
-	    }
-	    else
-	    {
-		EDVCenterWindowToWindow(
-		    toplevel, propdlg->toplevel
-		);
-	    }
-
-	    EDVPropDlgMap(propdlg);
-	    EDVPropDlgSetHasChanges(propdlg, FALSE);
-	    EDVPropDlgUpdateMenus(propdlg);
-
-	    return(i);
-	}
-	else
-	{
-	    return(-1);
-	}
+	return(i);
 }
 
-gint EDVNewPropertiesDialog(
-	edv_core_struct *core, edv_object_struct *obj,
+/*
+ *	Selects the page on the properties dialog, shifts the
+ *	dialog based on the number of existing dialogs, and
+ *	maps the dialog relative to the toplevel GtkWidget.
+ */
+static void EDVNewPropertiesDialogSelectPageMove(
+	edv_core_struct *core,
+	edv_propdlg_struct *d,
+	const gchar *page_name,
+	const gint existing_dialogs,
 	GtkWidget *toplevel
 )
 {
-	return(
-	    EDVNewPropertiesDialogPage(core, obj, NULL, toplevel)
+	cfg_item_struct *cfg_list = core->cfg_list;
+	GtkNotebook *notebook = GTK_NOTEBOOK(d->notebook);
+
+	/* Select tab? */
+	if((page_name != NULL) && (notebook != NULL))
+	{
+	    gint	page_num = -1,
+			total_pages = g_list_length(notebook->first_tab);
+
+	    /* Check which tab is to be switched to by matching
+	     * its name
+	     */
+	    if(!g_strcasecmp(page_name, "General"))
+		page_num = 0;
+	    else if(!g_strcasecmp(page_name, "Details"))
+		page_num = MAX(total_pages - 1, 1);
+	    else if(!g_strcasecmp(page_name, "Link"))
+		page_num = 1;
+	    else if(!g_strcasecmp(page_name, "Device"))
+		page_num = 1;
+	    else if(!g_strcasecmp(page_name, "Device Node"))
+		page_num = (total_pages >= 4) ? 2 : 1;
+
+	    /* Matched page to be switched to? */
+	    if(page_num > -1)
+		gtk_notebook_set_page(notebook, page_num);
+	}
+
+	/* Shift window position if there are existing windows */
+	if(existing_dialogs > 0)
+	{
+	    const gint	offset_x =
+		EDV_GET_I(EDV_CFG_PARM_WINDOW_CASCADE_OFFSET_X) * existing_dialogs,
+			offset_y =
+		EDV_GET_I(EDV_CFG_PARM_WINDOW_CASCADE_OFFSET_Y) * existing_dialogs;
+
+	    EDVCenterWindowToWindowOffset(
+		toplevel, d->toplevel,
+		offset_x, offset_y
+	    );
+	}
+	else
+	{
+	    EDVCenterWindowToWindow(toplevel, d->toplevel);
+	}
+
+	EDVPropDlgMap(d);
+	EDVPropDlgSetHasChanges(d, FALSE);
+	EDVPropDlgUpdateMenus(d);
+
+}
+
+/*
+ *	Creates a new Properties Dialog.
+ *
+ *	The new dialog will be added to the core and mapped.
+ *
+ *	The obj specifies the object that is to be displayed on the
+ *	dialog. The specified object will not be modified or deleted by
+ *	this call.
+ *
+ *	The page_name specifies the name of the page to switch to
+ *	after the dialog has been mapped.
+ *
+ *	Returns the index of the new Properties Dialog or -1 on
+ *	error.
+ */
+gint EDVNewPropertiesDialogVFSPage(
+	edv_core_struct *core,
+	edv_object_struct *obj,
+	const gchar *page_name,
+	GtkWidget *toplevel
+)
+{
+	gint i, existing_dialogs;
+	edv_propdlg_struct *d;
+
+	if(core == NULL)
+	    return(-1);
+
+	/* Allocate a new properties dialog entry in the list */
+	i = EDVNewPropertiesDialogNexus(core, &existing_dialogs);
+	if(i < 0)
+	    return(i);
+
+	/* Create a new properties dialog and add it to the list */
+	core->propdlg[i] = d = EDVPropDlgNew(
+	    core,
+	    EDV_LOCATION_TYPE_VFS,
+	    obj,
+	    0,				/* No recycled object index */
+	    NULL			/* No archive path */
 	);
+	if(d == NULL)
+	    return(-1);
+
+	/* Select the page, move, and map the properties dialog */
+	EDVNewPropertiesDialogSelectPageMove(
+	    core,
+	    d,
+	    page_name,
+	    existing_dialogs,
+	    toplevel
+	);
+
+	return(i);
+}
+
+gint EDVNewPropertiesDialogVFS(
+	edv_core_struct *core,
+	edv_object_struct *obj,
+	GtkWidget *toplevel
+)
+{
+	return(EDVNewPropertiesDialogVFSPage(
+	    core,
+	    obj,
+	    NULL,				/* Default page */
+	    toplevel
+	));
+}
+
+gint EDVNewPropertiesDialogRecycledPage(
+	edv_core_struct *core,
+	edv_recycled_object_struct *obj,
+	const gchar *page_name,
+	GtkWidget *toplevel
+)
+{
+	gint i, existing_dialogs;
+	guint index = 0;
+	edv_object_struct *obj2 = NULL;
+	edv_propdlg_struct *d;
+
+	if(core == NULL)
+	    return(-1);
+
+	/* Allocate a new properties dialog entry in the list */
+	i = EDVNewPropertiesDialogNexus(core, &existing_dialogs);
+	if(i < 0)
+	    return(i);
+
+	/* Copy/convert the recycled object to a regular object */
+	if(obj != NULL)
+	{
+	    index = obj->index;
+
+	    obj2 = EDVObjectNew();
+	    if(obj2 != NULL)
+	    {
+		obj2->type = obj->type;
+		obj2->name = STRDUP(obj->name);
+		obj2->full_path = g_strconcat(
+		    obj->original_path,
+		    G_DIR_SEPARATOR_S,
+		    obj->name,
+		    NULL
+		);
+		obj2->device_index = 0l;
+		obj2->index = 0l;
+		obj2->size = obj->size;
+		obj2->link_target = STRDUP(obj->link_target);
+		obj2->link_flags = EDV_OBJECT_LINK_VALID;
+		obj2->permissions = obj->permissions;
+		obj2->access_time = obj->access_time;
+		obj2->modify_time = obj->modify_time;
+		obj2->change_time = obj->change_time;
+		obj2->owner_id = obj->owner_id;
+		obj2->group_id = obj->group_id;
+		obj2->device_type = 0;
+		obj2->block_size = 0l;
+		obj2->blocks = 0l;
+		obj2->hard_links = 0;
+		obj2->ext_props_list = NULL;
+	    }
+	}
+
+	/* Create a new properties dialog and add it to the list */
+	core->propdlg[i] = d = EDVPropDlgNew(
+	    core,
+	    EDV_LOCATION_TYPE_RECBIN,
+	    obj2,
+	    index,			/* Recycled object index */
+	    NULL			/* No archive path */
+	);
+
+	/* Delete the coppied/converted regular object */
+	EDVObjectDelete(obj2);
+
+	if(d == NULL)
+	    return(-1);
+
+	/* Select the page, move, and map the properties dialog */
+	EDVNewPropertiesDialogSelectPageMove(
+	    core,
+	    d,
+	    page_name,
+	    existing_dialogs,
+	    toplevel
+	);
+
+	return(i);
+}
+
+gint EDVNewPropertiesDialogArchivePage(
+	edv_core_struct *core,
+	edv_archive_object_struct *obj,
+	const gchar *arch_path,
+	const gchar *page_name,
+	GtkWidget *toplevel
+)
+{
+	gint i, existing_dialogs;
+	edv_object_struct *obj2 = NULL;
+	edv_propdlg_struct *d;
+
+	if(core == NULL)
+	    return(-1);
+
+	/* Allocate a new properties dialog entry in the list */
+	i = EDVNewPropertiesDialogNexus(core, &existing_dialogs);
+	if(i < 0)
+	    return(i);
+
+	/* Copy/convert the archive object to a regular object */
+	if(obj != NULL)
+	{
+	    obj2 = EDVObjectNew();
+	    if(obj2 != NULL)
+	    {
+		obj2->type = obj->type;
+		obj2->name = STRDUP(obj->name);
+		obj2->full_path = STRDUP(obj->full_path);
+		obj2->device_index = 0l;
+		obj2->index = 0l;
+		obj2->size = obj->size;
+		obj2->link_target = STRDUP(obj->link_target);
+		obj2->link_flags = EDV_OBJECT_LINK_VALID;
+		obj2->permissions = obj->permissions;
+		obj2->access_time = obj->access_time;
+		obj2->modify_time = obj->modify_time;
+		obj2->change_time = obj->change_time;
+		obj2->owner_id = EDVUIDNameToUID(
+		    core->uids_list, obj->owner_name
+		);
+		obj2->group_id = EDVGIDNameToGID(
+		    core->gids_list, obj->group_name
+		);
+		obj2->device_type = obj->device_type;
+		obj2->block_size = 0l;
+		obj2->blocks = 0l;
+		obj2->hard_links = 0;
+		obj2->ext_props_list = NULL;
+	    }
+	}
+
+	/* Create a new properties dialog and add it to the list */
+	core->propdlg[i] = d = EDVPropDlgNew(
+	    core,
+	    EDV_LOCATION_TYPE_ARCHIVE,
+	    obj2,
+	    0,				/* No recycled object index */
+	    arch_path			/* Archive path */
+	);
+
+	/* Delete the coppied/converted regular object */
+	EDVObjectDelete(obj2);
+
+	if(d == NULL)
+	    return(-1);
+
+	/* Select the page, move, and map the properties dialog */
+	EDVNewPropertiesDialogSelectPageMove(
+	    core,
+	    d,
+	    page_name,
+	    existing_dialogs,
+	    toplevel
+	);
+
+	return(i);
 }
 
 
@@ -1394,6 +1646,10 @@ void EDVMapRecBin(edv_core_struct *core)
 	if(recbin == NULL)
 	    return;
 
+	/* Unmap the Recycle Bin if it is already mapped */
+	if(EDVRecBinIsMapped(recbin))
+	    EDVRecBinUnmap(recbin);
+
 	toplevel = recbin->toplevel;
 
 	/* Need to map it immediatly after it is created so that it does
@@ -1405,7 +1661,7 @@ void EDVMapRecBin(edv_core_struct *core)
 	EDVRecBinSetBusy(recbin, TRUE);
 	GUIBlockInput(toplevel, TRUE);
 
-	clist = (GtkCList *)recbin->contents_clist;
+	clist = GTK_CLIST(recbin->contents_clist);
 	if(clist != NULL)
 	{
 	    gtk_clist_freeze(clist);
@@ -1431,19 +1687,20 @@ void EDVMapHistoryListWin(
 {
 	edv_history_win_struct *lw;
 
-
 	if(core == NULL)
 	    return;
 
 	/* Get pointer to history list window, create it as needed */
 	lw = core->history_listwin;
 	if(lw == NULL)
-	    core->history_listwin = lw = EDVHistoryWinNew(
-		core
-	    );
+	    core->history_listwin = lw = EDVHistoryWinNew(core);
 	if(lw == NULL)
 	    return;
 
+	/* Unmap the History Window if it is already mapped */
+	if(EDVHistoryWinIsMapped(lw))
+	    EDVHistoryWinUnmap(lw);
+
 	EDVCenterWindowToWindow(toplevel, lw->toplevel);
 
 	EDVHistoryWinSetBusy(lw, TRUE);
@@ -1475,17 +1732,19 @@ void EDVMapOptionsWinPage(
 	/* Get the Options Window, creating it as needed */
 	optwin = core->options_window;
 	if(optwin == NULL)
-	    core->options_window = optwin = EDVCreateOptionsWindow(
-		core
-	    );
+	    core->options_window = optwin = EDVCreateOptionsWindow(core);
 	if(optwin == NULL)
 	    return;
 
+	/* Unmap the Options Window if it is already mapped */
+	if(EDVGenOptWinIsMapped(optwin))
+	    EDVGenOptWinUnmap(optwin);
+
 	/* Center the Options Window to the specified toplevel window */
 	EDVCenterWindowToWindow(toplevel, optwin->toplevel);
 
 	/* Get the values from the configuration */
-	EDVGenOptWinGetValues(optwin);
+	EDVGenOptWinGetValues(optwin, FALSE);
 
 	/* Page specified? */
 	if(!STRISEMPTY(page_name))
@@ -1536,23 +1795,26 @@ void EDVMapCustomizeWin(
 		recbin_num;
 	const gchar *page_name;
 	edv_gen_opt_win_struct *optwin;
+
 	if(core == NULL)
 	    return;
 
 	/* Get the Customize Window, creating it as needed */
 	optwin = core->customize_window;
 	if(optwin == NULL)
-	    core->customize_window = optwin = EDVCustomizeWindowNew(
-		core
-	    );
+	    core->customize_window = optwin = EDVCustomizeWindowNew(core);
 	if(optwin == NULL)
 	    return;
 
+	/* Unmap the Customize Window if it is already mapped */
+	if(EDVGenOptWinIsMapped(optwin))
+	    EDVGenOptWinUnmap(optwin);
+
 	/* Center the Customize Window to the specified toplevel window */
 	EDVCenterWindowToWindow(toplevel, optwin->toplevel);
 
 	/* Get the values from the configuration */
-	EDVGenOptWinGetValues(optwin);
+	EDVGenOptWinGetValues(optwin, FALSE);
 
 	/* Match the given toplevel with the corresponding window */
 	if(EDVMatchWindowFromToplevel(
@@ -1621,12 +1883,14 @@ void EDVMapDevicesListWin(
 	/* Get pointer to devices list window, create it as needed */
 	lw = core->device_listwin;
 	if(lw == NULL)
-	    core->device_listwin = lw = EDVDevicesListWinNew(
-		core
-	    );
+	    core->device_listwin = lw = EDVDevicesListWinNew(core);
 	if(lw == NULL)
 	    return;
 
+	/* Unmap the Devices List Window if it is already mapped */
+	if(EDVDevicesListWinIsMapped(lw))
+	    EDVDevicesListWinUnmap(lw);
+
 	EDVCenterWindowToWindow(toplevel, lw->toplevel);
 	EDVDevicesListSetBusy(lw, TRUE);
 	EDVDevicesListWinMap(lw);
@@ -1654,12 +1918,14 @@ void EDVMapMIMETypesListWin(
 	/* Get pointer to MIME Types list window, create it as needed */
 	lw = core->mimetype_listwin;
 	if(lw == NULL)
-	    core->mimetype_listwin = lw = EDVMimeTypesListWinNew(
-		core
-	    );
+	    core->mimetype_listwin = lw = EDVMimeTypesListWinNew(core);
 	if(lw == NULL)
 	    return;
 
+	/* Unmap the MIME Types List Window if it is already mapped */
+	if(EDVMimeTypesListWinIsMapped(lw))
+	    EDVMimeTypesListWinUnmap(lw);
+
 	EDVCenterWindowToWindow(toplevel, lw->toplevel);
 	EDVMimeTypesListWinSetBusy(lw, TRUE);
 	EDVMimeTypesListWinMap(lw);
@@ -1681,13 +1947,15 @@ void EDVMapRunDialogCommand(
 	GtkWidget *toplevel
 )
 {
+	cfg_item_struct *cfg_list;
 	edv_run_dlg_struct *dlg;
 
-
 	if(core == NULL)
 	    return;
 
-	/* Create run dialog as needed */
+	cfg_list = core->cfg_list;
+
+	/* Get the Run Dialog, create it as needed */
 	dlg = core->run_dlg;
 	if(dlg == NULL)
 	{
@@ -1697,11 +1965,22 @@ void EDVMapRunDialogCommand(
 	if(dlg == NULL)
 	    return;
 
-	/* Set command as needed */
+	/* Unmap the Run Dialog if it is already mapped */
+	if(EDVRunDlgIsMapped(dlg))
+	    EDVRunDlgUnmap(dlg);
+
+	/* Move the run dialog to its last position */
+	gtk_widget_set_uposition(
+	    dlg->toplevel,
+	    EDV_GET_I(EDV_CFG_PARM_RUNDLG_X),
+	    EDV_GET_I(EDV_CFG_PARM_RUNDLG_Y)
+	);
+
+	/* Set the command as needed */
 	if(!STRISEMPTY(command))
 	    EDVRunDlgSetCommand(dlg, command);
 
-	/* Set working directory as needed */
+	/* Set the working directory as needed */
 	if(!STRISEMPTY(working_dir))
 	    EDVRunDlgSetWorkingDir(dlg, working_dir);
 
@@ -1733,6 +2012,11 @@ void EDVMapFindWin(edv_core_struct *core, const gchar *location)
 	if(fw == NULL)
 	    return;
 
+	/* Unmap the Find Window if it is already mapped */
+	if(EDVFindWinIsMapped(fw))
+	    EDVFindWinUnmap(fw);
+
+	/* Set the reference window */
 	EDVFindWinSetReferenceWindow(
 	    fw,
 	    -1,
@@ -1741,10 +2025,13 @@ void EDVMapFindWin(edv_core_struct *core, const gchar *location)
 	    -1
 	);
 
+	/* Clear the location */
 	if(!STRISEMPTY(location))
 	    EDVFindWinSetLocation(fw, location, FALSE);
 
 	EDVFindWinUpdateMenus(fw);
+
+	/* Map the Find Window */
 	EDVFindWinMap(fw);
 }
 
@@ -1768,6 +2055,10 @@ void EDVMapBrowserFindWin(
 	if(fw == NULL)
 	    return;
 
+	/* Unmap the Find Window if it is already mapped */
+	if(EDVFindWinIsMapped(fw))
+	    EDVFindWinUnmap(fw);
+
 	/* Get this File Browser's index */
 	for(i = 0; i < core->total_browsers; i++)
 	{
@@ -1821,6 +2112,10 @@ void EDVMapImbrFindWin(
 	if(fw == NULL)
 	    return;
 
+	/* Unmap the Find Window if it is already mapped */
+	if(EDVFindWinIsMapped(fw))
+	    EDVFindWinUnmap(fw);
+
 	/* Get this Image Browser's index */
 	for(i = 0; i < core->total_imbrs; i++)
 	{
@@ -1874,6 +2169,10 @@ void EDVMapArchiverFindWin(
 	if(fw == NULL)
 	    return;
 
+	/* Unmap the Find Window if it is already mapped */
+	if(EDVFindWinIsMapped(fw))
+	    EDVFindWinUnmap(fw);
+
 	/* Get this Archiver's index */
 	for(i = 0; i < core->total_archivers; i++)
 	{
@@ -1914,7 +2213,7 @@ void EDVMapRecBinFindWin(
 	edv_core_struct *core, edv_recbin_struct *recbin
 )
 {
-	const gchar *recycled_index_file;
+	const gchar *index_path;
 	gchar *recycled_dir;
 	const cfg_item_struct *cfg_list;
 	edv_find_win_struct *fw;
@@ -1931,23 +2230,27 @@ void EDVMapRecBinFindWin(
 	if(fw == NULL)
 	    return;
 
+	/* Unmap the Find Window if it is already mapped */
+	if(EDVFindWinIsMapped(fw))
+	    EDVFindWinUnmap(fw);
+
 	/* Set the Recycle Bin as the Find Window's reference */
 	EDVFindWinSetReferenceWindow(
 	    fw,
 	    -1,
 	    -1,
-	    0,		/* First and only recycle bin */
+	    0,		/* First and only Recycle Bin */
 	    -1
 	);
 
 	/* Get the path to the Recycled Objects Index File */
-	recycled_index_file = EDV_GET_S(
+	index_path = EDV_GET_S(
 	    EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX
 	);
 
 	/* Get the path to the Recycled Objects Directory */
-	recycled_dir = (recycled_index_file != NULL) ?
-	    g_dirname(recycled_index_file) : NULL;
+	recycled_dir = (index_path != NULL) ?
+	    g_dirname(index_path) : NULL;
 
 	/* Set initial location of find window to be the Recycled
 	 * Objects Directory
@@ -1979,13 +2282,17 @@ void EDVAboutPage(
 	if(core == NULL)
 	    return;
 
-	/* Get the About Dialog (create it as needed) */
+	/* Get the About Dialog, create it as needed */
 	d = core->about_dlg;
 	if(d == NULL)
 	    core->about_dlg = d = AboutDlgNew(core);
 	if(d == NULL)
 	    return;
 
+	/* Unmap the About Dialog if it is already mapped */
+	if(AboutDlgIsMapped(d))
+	    AboutDlgUnmap(d);
+
 	/* Select tab */
 	notebook = GTK_NOTEBOOK(d->notebook);
 	if(!STRISEMPTY(page_name) && (notebook != NULL))
@@ -2008,7 +2315,7 @@ void EDVAboutPage(
 		gtk_notebook_set_page(notebook, page_num);
 	}
 
-	/* Map dialog */
+	/* Map the About Dialog */
 	AboutDlgMap(d);
 }
 
@@ -2546,14 +2853,14 @@ void EDVRefresh(edv_core_struct *core)
 	optwin = core->options_window;
 	if(EDVGenOptWinIsMapped(optwin))
 	{
-	    EDVGenOptWinGetValues(optwin);
+	    EDVGenOptWinGetValues(optwin, FALSE);
 	}
 
 	/* Customize Window */
 	optwin = core->customize_window;
 	if(EDVGenOptWinIsMapped(optwin))
 	{
-	    EDVGenOptWinGetValues(optwin);
+	    EDVGenOptWinGetValues(optwin, FALSE);
 	}   
 
 
@@ -2811,16 +3118,18 @@ void EDVClearErrorMessages(edv_core_struct *core)
 	    return;
 
 	core->archive_last_error = NULL;
-	core->device_last_error = NULL;
-	core->obj_last_error = NULL;
-	core->recbin_last_error = NULL;
-
 	g_free(core->archive_last_error_buf);
 	core->archive_last_error_buf = NULL;
+
+	core->device_last_error = NULL;
 	g_free(core->device_last_error_buf);
 	core->device_last_error_buf = NULL;
+
+	core->obj_last_error = NULL;
 	g_free(core->obj_last_error_buf);
 	core->obj_last_error_buf = NULL;
+
+	core->recbin_last_error = NULL;
 	g_free(core->recbin_last_error_buf);
 	core->recbin_last_error_buf = NULL;
 }
@@ -2840,14 +3149,7 @@ void EDVClearHistoryEvents(
 	if(core == NULL)
 	    return;
 
-	/* Map History List Window */
-	EDVMapHistoryListWin(core, toplevel);
-
-	/* Clear history events by using the History List Window
-	 * to delet the history events log file, the History List
-	 * Window will also be cleared
-	 */
-	EDVHistoryWinClear(core->history_listwin);
+	EDVHistoryWinClear(core, core->history_listwin, toplevel);
 }
 
 /*
@@ -2931,9 +3233,9 @@ all the windows?\n",
 	    GUIComboSetList(browser->location_combo, NULL);
 	}
 
-	/* Delete File Browser Locations History File */
-	path = CFGItemListGetValueS(
-	    cfg_list, EDV_CFG_PARM_FILE_BROWSER_LOCATION_HISTORY
+	/* Delete the File Browser Locations History File */
+	path = EDV_GET_S(
+	    EDV_CFG_PARM_FILE_BROWSER_LOCATION_HISTORY
 	);
 	if(!STRISEMPTY(path))
 	{
@@ -2942,7 +3244,7 @@ all the windows?\n",
 	}
 
 
-	/* Clear Image Browser Locations List */
+	/* Clear the Image Browser Locations List */
 	for(i = 0; i < core->total_imbrs; i++)
 	{
 	    imbr = core->imbr[i];
@@ -2952,9 +3254,9 @@ all the windows?\n",
 	    GUIComboSetList(imbr->location_combo, NULL);
 	}
 
-	/* Delete Image Browser Locations History File */
-	path = CFGItemListGetValueS(
-	    cfg_list, EDV_CFG_PARM_FILE_IMBR_LOCATION_HISTORY
+	/* Delete the Image Browser Locations History File */
+	path = EDV_GET_S(
+	    EDV_CFG_PARM_FILE_IMBR_LOCATION_HISTORY
 	);
 	if(!STRISEMPTY(path))
 	{
@@ -2963,7 +3265,7 @@ all the windows?\n",
 	}
 
 
-	/* Clear Archiver Locations List */
+	/* Clear the Archiver Locations List */
 	for(i = 0; i < core->total_archivers; i++)
 	{
 	    archiver = core->archiver[i];
@@ -2973,9 +3275,9 @@ all the windows?\n",
 	    GUIComboSetList(archiver->location_combo, NULL);
 	}
 
-	/* Delete Image Browser Locations History File */
-	path = CFGItemListGetValueS(
-	    cfg_list, EDV_CFG_PARM_FILE_ARCHIVER_LOCATION_HISTORY
+	/* Delete the Image Browser Locations History File */
+	path = EDV_GET_S(
+	    EDV_CFG_PARM_FILE_ARCHIVER_LOCATION_HISTORY
 	);
 	if(!STRISEMPTY(path))
 	{
@@ -3069,6 +3371,329 @@ void EDVClearRunHistory(
 }
 
 
+/*
+ *	Tabulates the total size of all the recycled objects in the
+ *	recycle bin and checks if it has exceeded the size in which
+ *	to warn the user and warns the user if the size has been
+ *	exceeded.
+ */
+void EDVRecycleBinSizeCheck(
+	edv_core_struct *core,
+	GtkWidget *toplevel
+)
+{
+	const gchar *index_path;
+	gulong recbin_size_warn, total_size;
+	const cfg_item_struct *cfg_list;
+	edv_recbin_index_struct *rbi_ptr;
+	edv_recycled_object_struct *obj;
+
+	if(core == NULL)
+	    return;
+
+	cfg_list = core->cfg_list;
+
+	/* Get path to the recycled objects index file */
+	index_path = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
+	if(index_path == NULL)
+	    return;
+
+	/* Get the recycle bin size warning size */
+	recbin_size_warn = EDV_GET_UL(EDV_CFG_PARM_RECBIN_SIZE_WARN);
+
+	/* If the warning size is 0 then no warning should ever be
+	 * given
+	 */
+	if(recbin_size_warn == 0l)
+	    return;
+
+	/* Calculate the size of all the recycled objects in the
+	 * recycle bin
+	 */
+	total_size = 0l;
+	rbi_ptr = EDVRecBinIndexOpen(index_path);
+	if(rbi_ptr != NULL)
+	{
+	    while(!EDVRecBinIndexNext(rbi_ptr))
+	    {
+		obj = rbi_ptr->obj;
+		if(obj == NULL)
+		    continue;
+
+		total_size += obj->size;
+	    }
+	    EDVRecBinIndexClose(rbi_ptr);
+	}
+
+	/* Has the total size meet or exceeded the recycle bin warn
+	 * size?
+	 */
+	if(total_size >= recbin_size_warn)
+	{
+	    gchar	*total_size_s = STRDUP(EDVSizeStrDelim(total_size)),
+			*recbin_size_warn_s = STRDUP(EDVSizeStrDelim(
+			    recbin_size_warn
+			)),
+			*msg = g_strdup_printf(
+#if defined(PROG_LANGUAGE_SPANISH)
+"El tamao del cajn de la recirculacin es ahora %s bytes,\n\
+ha excedido al usuario el tamao especificado de\n\
+%s bytes en que este advertir deber ser mostrado.\n\
+\n\
+Al purge todos los objetos existentes de recycled, van\n\
+primero al Cajn de Reciclaje y entonces van a\n\
+File->Purge All.",
+#elif defined(PROG_LANGUAGE_FRENCH)
+"La taille du recycle l'huche est maintenant %s bytes,\n\
+il a dpass l'utilisateur la taille spcifie de\n\
+%s bytes  qui cet avertissement devrait tre montr.\n\
+\n\
+Purger tout l'existant recycl objets, premirement va\n\
+au Recycle Huche et alors va File->Purge All.",
+#else
+"The size of the recycle bin is now %s bytes,\n\
+it has exceeded the user specified size of %s bytes\n\
+at which this warning is to be shown.\n\
+\n\
+To purge all the existing recycled objects, first\n\
+go to the Recycle Bin and then go to File->Purge All.",
+#endif
+		total_size_s, recbin_size_warn_s
+	    );
+
+	    EDVPlaySoundWarning(core);
+	    CDialogSetTransientFor(toplevel);
+	    CDialogGetResponseIconData(
+#ifdef PROG_LANGUAGE_ENGLISH
+		"Recycle Bin Size Warning",
+#endif
+#ifdef PROG_LANGUAGE_SPANISH
+		"Advertir De Cajn De Reciclaje",
+#endif
+#ifdef PROG_LANGUAGE_FRENCH
+		"Recycler l'Avertissement d'Huche",
+#endif
+		msg, NULL,
+		(guint8 **)icon_trash_32x32_xpm,
+		CDIALOG_BTNFLAG_OK,
+		CDIALOG_BTNFLAG_OK
+	    );
+	    g_free(msg);
+	    g_free(total_size_s);
+	    g_free(recbin_size_warn_s);
+	    CDialogSetTransientFor(NULL);
+	}
+}
+
+
+/*
+ *	Purges all the recycled objects in the recycle bin.
+ */
+void EDVPurgeAllRecycledObjects(
+	edv_core_struct *core,
+	const gboolean map_recbin,
+	const gboolean show_progress,
+	const gboolean interactive,
+	GtkWidget *toplevel
+)
+{
+        gboolean yes_to_all = FALSE;
+        gint status, nobjs, nobjs_purged = 0;
+        guint index;
+        const gchar *error_msg, *index_path;
+        GList *glist, *index_list = NULL;
+        cfg_item_struct *cfg_list;
+	edv_recbin_struct *recbin;
+        edv_recbin_index_struct *rbi_ptr;
+
+	if(core == NULL)
+	    return;
+
+#define CLEANUP_RETURN	{	\
+ g_list_free(index_list);	\
+				\
+ return;			\
+}
+
+        cfg_list = core->cfg_list;
+
+	/* Map the recycle bin? */
+	if(map_recbin)
+	{
+	    /* Create the Recycle Bin as needed and map it */
+	    EDVMapRecBin(core);
+
+	    /* Get the pointer to the Recycle Bin so we know that is
+	     * has been mapped
+	     */
+	    recbin = core->recbin;
+
+	    /* If the toplevel GtkWidget is not specified then set the
+	     * toplevel GtkWidget as the Recycle Bin's toplevel
+	     * GtkWidget
+	     */
+	    if((toplevel == NULL) && (recbin != NULL))
+		toplevel = recbin->toplevel;
+	}
+	else
+	{
+	    recbin = NULL;
+	}
+
+        /* Get the path to the recycled objects index file */
+        index_path = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
+        if(index_path == NULL)
+	{
+	    CLEANUP_RETURN;
+	}
+
+        /* Get the list of recycled objects */
+        rbi_ptr = EDVRecBinIndexOpen(index_path);
+        if(rbi_ptr != NULL)
+        {
+            while(!EDVRecBinIndexNext(rbi_ptr))
+            {
+                if(rbi_ptr->index != 0)
+                    index_list = g_list_append(
+                        index_list,
+                        (gpointer)rbi_ptr->index
+                    );
+            }
+            EDVRecBinIndexClose(rbi_ptr);
+        }
+
+        /* No recycled objects to purge? */
+        if(index_list == NULL)
+	{
+	    CLEANUP_RETURN;
+	}
+
+        nobjs = g_list_length(index_list);
+
+        EDVRecBinSetBusy(recbin, TRUE);
+
+        /* Confirm purge */
+	if(interactive)
+	{
+	    const gint response = EDVConfirmPurge(
+		core, toplevel,
+		NULL,
+		nobjs
+	    );
+	    switch(response)
+            {
+              case CDIALOG_RESPONSE_YES:
+              case CDIALOG_RESPONSE_YES_TO_ALL:
+                break;
+
+              default:
+                EDVRecBinSetBusy(recbin, FALSE);
+                CLEANUP_RETURN;
+                break;
+            }
+	}
+
+        /* Iterate through the list of recycled objects and purge
+         * each one
+         *
+         * Note that EDVRecBinPurgeAll() is not used here because
+         * it does not allow the reporting of each recycled object
+         * purged during the purge
+         */
+        status = 0;
+        for(glist = index_list;
+            glist != NULL;
+            glist = g_list_next(glist)
+        )
+        {
+            index = (guint)glist->data;
+
+            /* Purge this recycled object */
+            status = EDVRecBinPurge(
+                core,
+                index,                  /* Recycled object to purge */
+                toplevel,
+                (nobjs > 0) ?
+                    ((gfloat)nobjs_purged / (gfloat)nobjs) : -1.0f,
+                TRUE,                   /* Show progress */
+                TRUE,                   /* Interactive */
+                &yes_to_all
+            );
+
+            /* Check for errors */
+            error_msg = EDVRecBinPurgeGetError(core);
+            if(!STRISEMPTY(error_msg))
+            {
+                /* Report the error */
+                EDVPlaySoundError(core);
+                EDVMessageError(
+                    "Purge Recycled Object Error",
+                    error_msg,
+                    NULL,
+                    toplevel
+                );
+            }
+
+            /* Was the recycled object purged successfully? */
+            if(status == 0)
+            {
+                /* Notify about this recycled object being purged */
+                EDVRecycledObjectRemovedEmit(core, index);
+                nobjs_purged++;
+            }
+
+            /* User aborted? */
+            if(status == -4)
+                break;
+        }
+
+        /* If no errors occured or no user abort then call
+         * EDVRecBinPurgeAll() to remove any stray recycled object
+         * files and the recycled objects index file
+         */
+        if(status == 0)
+        {
+            /* Remove any stray recycled object files and the recycled
+             * objects index file
+             */
+            status = EDVRecBinPurgeAll(
+                core,
+                toplevel,
+                FALSE,                  /* Do not show progress */
+                TRUE,                   /* Interactive */
+                &yes_to_all
+            );
+
+            /* Check for errors */
+            error_msg = EDVRecBinPurgeGetError(core);
+            if(!STRISEMPTY(error_msg))
+            {
+                /* Report the error */
+                EDVPlaySoundError(core);
+                EDVMessageError(
+                    "Purge Recycled Object Error",
+                    error_msg,
+                    NULL,
+                    toplevel
+                );
+            }
+        }
+
+        /* Unmap the progress dialog */
+        ProgressDialogBreakQuery(TRUE);
+        ProgressDialogSetTransientFor(NULL);
+
+        /* Play the "completed" sound on success */
+        if(status == 0)
+            EDVPlaySoundCompleted(core);
+
+        EDVRecBinSetBusy(recbin, FALSE);
+
+        CLEANUP_RETURN;
+#undef CLEANUP_RETURN
+}
+
+
 /*
  *	Calls the Endeavour Download Front End program to download the
  *	given URL described in dnd_obj to the directory target_path.
@@ -3118,7 +3743,7 @@ to Settings->Options->Programs.",
 	    gint p;
 	    gchar *url_str, *cmd;
 
-	    /* Format url */
+	    /* Format the url */
 	    if(url == NULL)
 		url_str = STRDUP("");
 	    else if(url->port > 0)
@@ -3145,20 +3770,22 @@ to Settings->Options->Programs.",
 		    url->path
 		);
 
-	    /* Format command, the program should accept arguments being
-	     * the first argument(s) are the URLs to download and the
-	     * last argument is the destination path
+	    /* Format the command
+	     *
+	     * The program must accept arguments where the first
+	     * argument(s) are the URLs to download and the last
+	     * argument is the destination path
 	     */
 	    cmd = g_strdup_printf(
-		"%s %s %s \"%s\" \"%s\"",
+		"\"%s\"%s%s \"%s\" \"%s\"",
 		prog,
-		"-b",
-		confirm ? "-c" : "",
+		" -b",
+		confirm ? " -c" : "",
 		url_str, target_path
 	    );
 
 	    /* Execute the download command */
-	    p = Exec(cmd);
+	    p = (int)Exec((const char *)cmd);
 	    if(p <= 0)
 	    {
 		const gint error_code = (gint)errno;
@@ -3168,7 +3795,8 @@ to Settings->Options->Programs.",
     %s\n\
 \n\
 %s.",
-		    cmd, g_strerror(error_code)
+		    cmd,
+		    g_strerror(error_code)
 		);
 		EDVPlaySoundError(core);
 		EDVMessageError(
@@ -3186,124 +3814,3 @@ Settings->Options->Programs.",
 	    g_free(url_str);
 	}
 }
-
-
-/*
- *	Tabulates the total size of all objects in the recycled objects
- *	directory and checks if it has exceeded the configuration
- *	specified recycle bin size warn size. If it has exceeded then
- *	the user will be warned.
- */
-void EDVRecycleBinSizeCheck(
-	edv_core_struct *core, GtkWidget *toplevel
-)
-{
-	const gchar *recycled_index_file;
-	const cfg_item_struct *cfg_list;
-	edv_recbin_index_struct *rbi_ptr;
-	edv_recycled_object_struct *obj;
-	gulong recbin_size_warn = 0, total_size = 0;
-
-
-	if(core == NULL)
-	    return;
-
-	cfg_list = core->cfg_list;
-
-	/* Get path to recycled objects index file */
-	recycled_index_file = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
-	if(recycled_index_file == NULL)
-	    return;
-
-	/* Get recycle bin size warn */
-	recbin_size_warn = EDV_GET_UL(EDV_CFG_PARM_RECBIN_SIZE_WARN);
-	/* If the warn size is 0, then this implies no warning should
-	 * be given (in which case do not bother to check anything)
-	 */
-	if(recbin_size_warn == 0)
-	    return;
-
-	/* Get recycled objects directory index pointer used to iterate
-	 * through all recycled objects
-	 */
-	rbi_ptr = EDVRecBinIndexOpen(recycled_index_file);
-	while(!EDVRecBinIndexNext(rbi_ptr))
-	{
-	    /* Get recycled object obtained from the recycled objects
-	     * directory index and do not modify it
-	     */
-	    obj = rbi_ptr->obj;
-	    if(obj == NULL)
-		continue;
-
-	    /* Increase total size of recycled objects by this recycled
-	     * object
-	     */
-	    total_size += obj->size;
-	}
-	EDVRecBinIndexClose(rbi_ptr);
-	rbi_ptr = NULL;
-
-
-	/* At this point the total size of all recycled objects has been
-	 * obtained. Now check if total_size reaches or exceeds the
-	 * configuration set size to warn
-	 */
-	if(total_size >= recbin_size_warn)
-	{
-	    gchar	*total_size_s = STRDUP(EDVSizeStrDelim(total_size)),
-			*recbin_size_warn_s = STRDUP(EDVSizeStrDelim(
-			    recbin_size_warn
-			)),
-			*msg = g_strdup_printf(
-#ifdef PROG_LANGUAGE_ENGLISH
-"The size of the recycle bin is now %s bytes,\n\
-it has exceeded the user specified size of %s bytes\n\
-at which this warning is to be shown.\n\
-\n\
-To purge all the existing recycled objects, first\n\
-go to the Recycle Bin and then go to File->Purge All.",
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-"El tamao del cajn de la recirculacin es ahora %s bytes,\n\
-ha excedido al usuario el tamao especificado de\n\
-%s bytes en que este advertir deber ser mostrado.\n\
-\n\
-Al purge todos los objetos existentes de recycled, van\n\
-primero al Cajn de Reciclaje y entonces van a\n\
-File->Purge All.",
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-"La taille du recycle l'huche est maintenant %s bytes,\n\
-il a dpass l'utilisateur la taille spcifie de\n\
-%s bytes  qui cet avertissement devrait tre montr.\n\
-\n\
-Purger tout l'existant recycl objets, premirement va\n\
-au Recycle Huche et alors va File->Purge All.",
-#endif
-		total_size_s, recbin_size_warn_s
-	    );
-
-	    EDVPlaySoundWarning(core);
-	    CDialogSetTransientFor(toplevel);
-	    CDialogGetResponseIconData(
-#ifdef PROG_LANGUAGE_ENGLISH
-		"Recycle Bin Size Warning",
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-		"Advertir De Cajn De Reciclaje",
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-		"Recycler l'Avertissement d'Huche",
-#endif
-		msg, NULL,
-		(guint8 **)icon_trash_32x32_xpm,
-		CDIALOG_BTNFLAG_OK,
-		CDIALOG_BTNFLAG_OK
-	    );
-	    g_free(msg);
-	    g_free(total_size_s);
-	    g_free(recbin_size_warn_s);
-	    CDialogSetTransientFor(NULL);
-	}
-}
