@@ -92,18 +92,23 @@ static gchar *EDVOpenStripExt(const gchar *s)
 	if(s == NULL)
 	    return(NULL);
 
-	/* Get the name */
-	name = strrchr(s, G_DIR_SEPARATOR);
+	/* Get the name portion which starts after the directory
+	 * deliminator (if any)
+	 */
+	name = (const gchar *)strrchr((const char *)s, G_DIR_SEPARATOR);
 	if(name != NULL)
 	    name++;
 	else
 	    name = s;
 
-	/* Get the extension */
+	/* If the name starts with a '.' character (hidden names) then
+	 * seek past the '.' character
+	 */
 	if(*name == '.') 
-	    ext = (gchar *)strchr((char *)name + 1, '.');
-	else
-	    ext = (gchar *)strchr((char *)name, '.');
+	    name++;
+
+	/* Get the extension */
+	ext = (const gchar *)strchr((const char *)name, '.');
 
 	/* No extension? */
 	if(ext == NULL)
@@ -112,6 +117,9 @@ static gchar *EDVOpenStripExt(const gchar *s)
 	/* Get the path without the extension */
 	len = (gint)(ext - s);
 	path_wo_ext = (gchar *)g_malloc((len + 1) * sizeof(gchar));
+	if(path_wo_ext == NULL)
+	    return(NULL);
+
 	if(len > 0)
 	    memcpy(
 		path_wo_ext,
@@ -129,7 +137,6 @@ static gchar *EDVOpenStripExt(const gchar *s)
 	}
 
 	return(path_wo_ext);
-
 }
 
 /*
@@ -145,7 +152,7 @@ static gboolean EDVOpenIsFileExecutable(const gchar *path)
 	    return(FALSE);
 
 	/* Get the destination stats */
-	if(stat(path, &stat_msg))
+	if(stat((const char *)path, &stat_msg))
 	    return(FALSE);
 
 	m = stat_msg.st_mode;
