@@ -12,6 +12,10 @@
 #include "edv_types.h"
 
 
+extern gchar *EDVOpenFormatCommand(
+        edv_core_struct *core, const gchar *cmd, GList *paths_list
+);
+
 extern gint EDVOpen(
 	edv_core_struct *core,
 	GList *paths_list,
@@ -30,5 +34,14 @@ extern gint EDVOpenWith(
 	gchar **stdout_path_rtn, gchar **stderr_path_rtn
 );
 
+extern gint EDVOpenCommand(
+        edv_core_struct *core,
+        GList *paths_list,
+        const gchar *command,
+        GtkWidget *toplevel,
+        const gboolean verbose,
+        gchar **stdout_path_rtn, gchar **stderr_path_rtn
+);
+
 
 #endif	/* EDV_OPEN_H */
