@@ -62,13 +62,18 @@ static void EDVRecBinDeleteCopyErrorMessage(
 );
 
 static gboolean EDVRecBinNoDeleteCheck(
-	edv_core_struct *core, GtkWidget *toplevel,
-	const gboolean interactive, gboolean *yes_to_all,
-	const gchar *path, struct stat *stat_buf
+	edv_core_struct *core,
+	GtkWidget *toplevel,
+	const gboolean interactive,
+	gboolean *yes_to_all,
+	const gchar *path,
+	struct stat *stat_buf
 );
 
 static void EDVRecBinDeleteMapProgressDialog(
-	const gchar *label, gfloat progress_value, GtkWidget *toplevel,
+	const gchar *label,
+	const gfloat progress_value,
+	GtkWidget *toplevel,
 	const gboolean force_remap,
 	const edv_delete_method delete_method
 );
@@ -82,8 +87,10 @@ static guint EDVRecBinDeleteObjectIterate(
 	const gchar *path,
 	GList **index_list_rtn,
 	GtkWidget *toplevel,
-	const gboolean show_progress, const gboolean interactive,
-	gboolean *yes_to_all, gint *status,
+	const gboolean show_progress,
+	const gboolean interactive,
+	gboolean *yes_to_all,
+	gint *status,
 	const edv_delete_method delete_method
 );
 gint EDVRecBinDeleteObject(
@@ -91,7 +98,8 @@ gint EDVRecBinDeleteObject(
 	const gchar *path,
 	GList **index_list_rtn,
 	GtkWidget *toplevel,
-	const gboolean show_progress, const gboolean interactive,
+	const gboolean show_progress,
+	const gboolean interactive,
 	gboolean *yes_to_all
 );
 
@@ -145,9 +153,12 @@ static void EDVRecBinDeleteCopyErrorMessage(
  *	Returns TRUE if the object may not be deleted.
  */
 static gboolean EDVRecBinNoDeleteCheck(
-	edv_core_struct *core, GtkWidget *toplevel,
-	const gboolean interactive, gboolean *yes_to_all,
-	const gchar *path, struct stat *stat_buf
+	edv_core_struct *core,
+	GtkWidget *toplevel,
+	const gboolean interactive,
+	gboolean *yes_to_all,
+	const gchar *path,
+	struct stat *stat_buf
 )
 {
 typedef struct {
@@ -163,7 +174,6 @@ typedef struct {
 	no_delete_struct *nd_ptr = NULL;
 	no_delete_struct no_delete_list[] = EDV_NO_DELETE_LIST;
 
-
 	/* Check for valid inputs, return TRUE if they are invalid to
 	 * prevent calling operation from proceeding
 	 */
@@ -513,7 +523,7 @@ Object is the user's home directory.\n"
 	{
 	    if(interactive)
 	    {
-		gchar *buf = g_strdup_printf(
+		gchar *msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "El \"%s\" objetivo no se puede borrar, la razn:\n\
 \n\
@@ -575,10 +585,10 @@ Object is part of the recycled objects system.\n"
 #else
 "Delete Failed"
 #endif
-		    , buf, NULL,
+		    , msg, NULL,
 		    toplevel
 		);
-		g_free(buf);
+		g_free(msg);
 	    }
 
 	    g_free(parent_path);
@@ -596,7 +606,9 @@ Object is part of the recycled objects system.\n"
  *      Maps the progress dialog as needed in animation mode for deleting.
  */
 static void EDVRecBinDeleteMapProgressDialog(
-	const gchar *label, gfloat progress_value, GtkWidget *toplevel,
+	const gchar *label,
+	const gfloat progress_value,
+	GtkWidget *toplevel,
 	const gboolean force_remap,
 	const edv_delete_method delete_method
 )
@@ -752,8 +764,10 @@ static guint EDVRecBinDeleteObjectIterate(
 	const gchar *path,
 	GList **index_list_rtn,
 	GtkWidget *toplevel,
-	const gboolean show_progress, const gboolean interactive,
-	gboolean *yes_to_all, gint *status,
+	const gboolean show_progress,
+	const gboolean interactive,
+	gboolean *yes_to_all,
+	gint *status,
 	const edv_delete_method delete_method
 )
 {
@@ -763,7 +777,6 @@ static guint EDVRecBinDeleteObjectIterate(
 	gchar **strv;
 	struct stat lstat_buf, stat_buf;
 
-
 	/* Error or user aborted from prior call? */
 	if(*status != 0)
 	    return(0);
@@ -889,13 +902,18 @@ and may not be deleted.",
 		if(child_path == NULL)
 		    FREE_AND_CONTINUE
 
-
 		/* Delete this object and all its children */
 		index = EDVRecBinDeleteObjectIterate(
-		    core, recycled_index_file, child_path,
+		    core,
+		    recycled_index_file,
+		    child_path,
 		    index_list_rtn,
-		    toplevel, show_progress, interactive,
-		    yes_to_all, status, delete_method
+		    toplevel,
+		    show_progress,
+		    interactive,
+		    yes_to_all,
+		    status,
+		    delete_method
 		);
 		/* Above return index is ignored */
 
@@ -911,15 +929,13 @@ and may not be deleted.",
 	if(*status != 0)
 	    return(0);
 
-	/* Update progress to display the path of this object that is
-	 * about to be deleted?
-	 */
+	/* Map the progress dialog? */
 	if(show_progress)
 	{
 	    gchar *p1 = EDVShortenPath(
 		path, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 	    );
-	    gchar *buf = g_strdup_printf(
+	    gchar *msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Borrar:\n\
 \n\
@@ -957,10 +973,10 @@ and may not be deleted.",
 	    );
 
 	    EDVRecBinDeleteMapProgressDialog(
-		buf, 0.0f, toplevel, FALSE, delete_method
+		msg, 0.0f, toplevel, FALSE, delete_method
 	    );
 
-	    g_free(buf);
+	    g_free(msg);
 	    g_free(p1);
 
 	    if(ProgressDialogStopCount() > 0)
@@ -1042,46 +1058,39 @@ and may not be deleted.",
 	    gulong cur_time = time(NULL);
 	    const mode_t m = lstat_buf.st_mode;
 
-	    /* Create a new tempory recycled object */
+	    /* Create a new recycled object */
 	    edv_recycled_object_struct *obj = EDVRecycledObjectNew();
 	    if(obj == NULL)
 		return(0);
 
-	    /* Set values from the object to new recycled object */
-	    obj->name = STRDUP(g_basename(path));
-
+	    /* Get this object's location */
 	    parent_path = g_dirname(path);
 	    if(parent_path == NULL)
 		parent_path = STRDUP("/");
-	    obj->original_path = STRDUP(parent_path);
 
+	    /* Set the values from this object to the new recycled object */
+	    obj->name = STRDUP(g_basename(path));
+	    obj->original_path = STRDUP(parent_path);
 	    obj->deleted_time = cur_time;
 
-	    obj->type = EDVObjectGetTypeFromStatMode(m);
-
+	    obj->type = EDVStatModeToObjectType(m);
+	    obj->size = (gulong)lstat_buf.st_size;
 #ifdef S_ISLNK
 	    if(S_ISLNK(m))
 		obj->link_target = EDVGetLinkTarget(path);
 #endif
-
-	    obj->permissions = EDVObjectGetPermissionsFromStatMode(m);
-
+	    obj->permissions = EDVStatModeToEDVPermissions(m);
 	    obj->access_time = (gulong)lstat_buf.st_atime;
 	    obj->modify_time = (gulong)lstat_buf.st_mtime;
 	    obj->change_time = (gulong)lstat_buf.st_ctime;
-
 	    obj->owner_id = (gint)lstat_buf.st_uid;
 	    obj->group_id = (gint)lstat_buf.st_gid;
 
-	    obj->size = (gulong)lstat_buf.st_size;
-
-	    /* Add this object to the recycled objects index file */
+	    /* Add an entry to the recycled objects index file */
 	    index = EDVRecBinIndexAdd(recycled_index_file, obj);
 	    if(index != 0)
 	    {
-		/* Remove the actual disk object and place it into the
-		 * recycled objects directory
-		 */
+		/* Recycle this object */
 		*status = EDVRecBinDiskObjectDelete(
 		    recycled_index_file,
 		    index,
@@ -1111,7 +1120,7 @@ and may not be deleted.",
 		    EDVRecBinIndexRemove(recycled_index_file, index);
 		    index = 0;
 		}
-		/* Successfully deleted object */
+		/* Successfully deleted the object */
 		else
 		{
 		    /* Append this index to the index list return */
@@ -1123,11 +1132,12 @@ and may not be deleted.",
 	    }
 	    else
 	    {
-		core->recbin_last_error = "Unable to generate a new recycled object index.";
+		core->recbin_last_error =
+"Unable to generate a new recycled object index.";
 		*status = -1;
 	    }
 
-	    /* Delete the tempory recycled object */
+	    /* Delete the recycled object */
 	    EDVRecycledObjectDelete(obj);
 
 	    g_free(parent_path);
@@ -1144,16 +1154,34 @@ and may not be deleted.",
  *	recycle bin, otherwise the object will be put into the recycle
  *	bin.
  *
- *	If index_list_rtn is not NULL then it will contain a list of
- *	indices of objects added to the recycle bin. The calling
- *	function must delete this list.
+ *	The path specifies the full path to the object to delete.
+ *
+ *	The index_list_rtn specifies a pointer to a GList * that will
+ *	be set to a list of guint indices describing all of the
+ *	objects deleted. If index_list_rtn is NULL then no list will
+ *	be returned. The calling function must delete the returned
+ *	list.
+ *
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	If show_progress is TRUE then the progress dialog will be
+ *	shown during this operation.
+ *
+ *	If interactive is TRUE then the user will be notified and
+ *	queried if any problems arise.
+ *
+ *	The yes_to_all specifies a pointer to the preinitialized
+ *	current gboolean "yes to all" value. This value may be
+ *	set to TRUE during this call if the user responds with
+ *	"yes to all" to a query.
  */
 gint EDVRecBinDeleteObject(
 	edv_core_struct *core,
-	const gchar *path,              /* Disk object to delete */
+	const gchar *path,
 	GList **index_list_rtn,
-	GtkWidget *toplevel,            /* Can be NULL */
-	const gboolean show_progress, const gboolean interactive,
+	GtkWidget *toplevel,
+	const gboolean show_progress,
+	const gboolean interactive,
 	gboolean *yes_to_all
 )
 {
@@ -1177,9 +1205,10 @@ gint EDVRecBinDeleteObject(
 	    return(-1);
 	}
 
-#define DO_FREE_LOCALS	{	\
- g_free(lsrc_obj);		\
- lsrc_obj = NULL;		\
+#define CLEANUP_RETURN(_v_)	{	\
+ g_free(lsrc_obj);			\
+					\
+ return(_v_);				\
 }
 
 	cfg_list = core->cfg_list;
@@ -1191,8 +1220,7 @@ gint EDVRecBinDeleteObject(
 	if(recycled_index_file == NULL)
 	{
 	    core->recbin_last_error = "Unable to get the recycled objects index file.";
-	    DO_FREE_LOCALS
-	    return(-1);
+	    CLEANUP_RETURN(-1);
 	}
 
 	/* Get delete method, so we know if we should just move the
@@ -1209,8 +1237,7 @@ gint EDVRecBinDeleteObject(
 	if(lsrc_obj == NULL)
 	{
 	    core->recbin_last_error = "Memory allocation error.";
-	    DO_FREE_LOCALS
-	    return(-3);
+	    CLEANUP_RETURN(-3);
 	}
 
 
@@ -1218,25 +1245,30 @@ gint EDVRecBinDeleteObject(
 
 	/* Delete this object */
 	index = EDVRecBinDeleteObjectIterate(
-	    core, recycled_index_file, lsrc_obj,
+	    core,
+	    recycled_index_file,
+	    lsrc_obj,
 	    index_list_rtn,
-	    toplevel, show_progress, interactive,
-	    yes_to_all, &status, delete_method
+	    toplevel,
+	    show_progress,
+	    interactive,
+	    yes_to_all,
+	    &status,
+	    delete_method
 	);
 
 	/* Record history */
 	EDVAppendHistory(
 	    core,
-	    EDV_HISTORY_DISK_OBJECT_DELETE,
-	    time_start, (gulong)time(NULL),
+	    EDV_HISTORY_VFS_OBJECT_DELETE,
+	    time_start,
+	    (gulong)time(NULL),
 	    status,
-	    lsrc_obj,
-	    NULL,		/* No target */
-	    core->recbin_last_error
+	    lsrc_obj,			/* Source */
+	    NULL,			/* No target */
+	    core->recbin_last_error	/* Comments */
 	);
 
-	DO_FREE_LOCALS
-
-	return(status);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(status);
+#undef CLEANUP_RETURN
 }
