@@ -11,7 +11,7 @@
 #include "edv_recycled_obj.h"
 
 
-extern const gchar *EDVRecBinDeleteObjectGetError(void);
+extern const gchar *EDVRecBinDeleteObjectGetError(edv_core_struct *core);
 
 extern gint EDVRecBinDeleteObject(
 	edv_core_struct *core,
