@@ -1,11 +1,12 @@
 /*
-                             Recycle Bin Index
+                       Recycle Bin Index File IO
  */
 
 #ifndef EDV_RECBIN_INDEX_H
 #define EDV_RECBIN_INDEX_H
 
 #include <stdio.h>
+#include <sys/stat.h>
 #include <glib.h>
 #include "edv_recycled_obj.h"
 
@@ -19,8 +20,7 @@ typedef struct _edv_recbin_index_struct	edv_recbin_index_struct;
  */
 struct _edv_recbin_index_struct {
 
-	FILE		*fp;		/* Handle to opened recycle bin index
-					 * file */
+	FILE		*fp;		/* Handle to the opened index file */
 
 	guint		index;		/* Current recycled object's index */
 
@@ -28,11 +28,27 @@ struct _edv_recbin_index_struct {
 						 * statistics of the current
 						 * recycled object */
 
+	/* Statistics */
+	struct stat	stat_buf;
+	gulong		current_position,	/* Current position of fp
+						 * in bytes */
+			total_size;		/* Total size of the index
+						 * file in bytes */
+
 };
 
 
+/* Error Message */
 extern const gchar *EDVRecBinIndexGetError(void);
 
+/* Get Paths */
+extern gchar *EDVRecBinIndexGetRecycleBinDirectory(const gchar *index_path);
+extern gchar *EDVRecBinIndexGetRecycledObjectPath(
+        const gchar *index_path,
+        const guint index
+);
+
+
 /* Get Index List & Total */
 extern gint EDVRecBinIndexGetTotal(const gchar *index_path);
 extern GList *EDVRecBinIndexGetList(const gchar *index_path);
@@ -43,27 +59,34 @@ extern edv_recbin_index_struct *EDVRecBinIndexOpen(
 );
 extern gint EDVRecBinIndexNext(edv_recbin_index_struct *rbi_ptr);
 extern void EDVRecBinIndexClose(edv_recbin_index_struct *rbi_ptr);
+extern gulong EDVRecBinIndexPosition(edv_recbin_index_struct *rbi_ptr);
+extern gfloat EDVRecBinIndexPositionCoeff(edv_recbin_index_struct *rbi_ptr);
 
-/* Index Adding & Removing */
+/* Index Entry Adding, Setting, and Removing */
 extern guint EDVRecBinIndexAdd(
-	const gchar *index_path,
-	edv_recycled_object_struct *obj
+	const gchar *index_path,	/* Recycle bin index file */
+	edv_recycled_object_struct *obj	/* Values */
+);
+extern gint EDVRecBinIndexSet(
+	const gchar *index_path,	/* Recycle bin index file */
+	const guint index,		/* Index of the recycled object */
+	edv_recycled_object_struct *obj	/* Values */
 );
 extern gint EDVRecBinIndexRemove(
-	const gchar *index_path,
+	const gchar *index_path,	/* Recycle bin index file */
 	const guint index		/* Index of the recycled object */
 );
 
 /* Get Recycled Object From Index */
 extern gint EDVRecBinObjectGetFromIndexFile(
-        const gchar *index_path,
+	const gchar *index_path,	/* Recycle bin index file */
 	const guint index,		/* Index of the recycled object */
-        edv_recycled_object_struct *obj	/* Storage */
+	edv_recycled_object_struct *obj	/* Storage */
 );
 
 /* Deleting, Recovering, and Purging */
 extern gint EDVRecBinDiskObjectDelete(
-	const gchar *index_path,
+	const gchar *index_path,	/* Recycle bin index file */
 	const guint index,		/* Add to the recycled index file
 					 * under this index */
 	const gchar *path,		/* Object to delete */
@@ -71,7 +94,7 @@ extern gint EDVRecBinDiskObjectDelete(
 	gpointer data
 );
 extern gint EDVRecBinDiskObjectRecover(
-	const gchar *index_path,
+	const gchar *index_path,	/* Recycle bin index file */
 	const guint index,		/* Index of the recycled object */
 	const gchar *path,		/* Alternate recovery location (can
 					 * be NULL) */
@@ -79,13 +102,13 @@ extern gint EDVRecBinDiskObjectRecover(
 	gpointer data
 );
 extern gint EDVRecBinDiskObjectPurge(
-	const gchar *index_path,
+	const gchar *index_path,	/* Recycle bin index file */
 	const guint index,		/* Index of the recycled object */
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
 	gpointer data
 );
 extern gint EDVRecBinDiskObjectPurgeAll(
-	const gchar *index_path,    /* Recycle bin index file */
+	const gchar *index_path,	/* Recycle bin index file */
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
 	gpointer data
 );
