@@ -69,16 +69,18 @@ static gint EDVRecBinPurgeProgressCB(
 
 gint EDVRecBinPurge(
 	edv_core_struct *core,
-	const guint index,		/* Index of the recycled object */
+	const guint index,
 	GtkWidget *toplevel,
-	const gfloat progress_value,	/* Can be -1.0 */
-	gboolean show_progress, gboolean interactive,
+	const gfloat progress_value,
+	const gboolean show_progress,
+	const gboolean interactive,
 	gboolean *yes_to_all
 );
 gint EDVRecBinPurgeAll(
 	edv_core_struct *core,
-	GtkWidget *toplevel,		/* Can be NULL */
-	gboolean show_progress, gboolean interactive,
+	GtkWidget *toplevel,
+	const gboolean show_progress,
+	const gboolean interactive,
 	gboolean *yes_to_all
 );
 
@@ -276,25 +278,35 @@ static gint EDVRecBinPurgeProgressCB(
 
 
 /*
- *	Purges the given recycled object specified by index from the
- *	recycled objects directory.
+ *	Purges the recycled object.
  *
- *	If and only if the progress_value is non negative, then the 
- *	progress dialog will be updated with an internally calculated
- *	value, otherwise the given progress_value is passed to the
- *	progress dialog.
+ *	The index specifies the recycled object to purge.
+ *
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	The progress_value specifies the progress value to display
+ *	on the progress dialog if show_progress is TRUE. If
+ *	progress_value is negative then the progress dialog will
+ *	be updated with an internally calculated value.
+ *
+ *	If show_progress is TRUE then the progress dialog will be
+ *	shown during this operation.
+ *
+ *	If interactive is TRUE then the user will be notified and
+ *	queried if any problems arise.
  */
 gint EDVRecBinPurge(
 	edv_core_struct *core,
-	const guint index,		/* Index of the recycled object */
+	const guint index,
 	GtkWidget *toplevel,
-	const gfloat progress_value,	/* Can be -1.0 */
-	gboolean show_progress, gboolean interactive,
+	const gfloat progress_value,
+	const gboolean show_progress,
+	const gboolean interactive,
 	gboolean *yes_to_all
 )
 {
 	static gint status;
-	const gchar *recycled_index_file;
+	const gchar *index_path;
 	gulong time_start = (gulong)time(NULL);
 	edv_recycled_object_struct *obj = NULL;
 	const cfg_item_struct *cfg_list;
@@ -308,25 +320,27 @@ gint EDVRecBinPurge(
 	    return(-2);
 	}
 
-#define DO_FREE_LOCALS	{	\
- EDVRecycledObjectDelete(obj);	\
+#define CLEANUP_RETURN(_v_)	{	\
+ EDVRecycledObjectDelete(obj);		\
+					\
+ return(_v_);				\
 }
 
 	cfg_list = core->cfg_list;
 
 	/* Get path to recycled objects index file */
-	recycled_index_file = EDV_GET_S(
+	index_path = EDV_GET_S(
 	    EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX
 	);
-	if(recycled_index_file == NULL)
+	if(index_path == NULL)
 	{
-	    DO_FREE_LOCALS
-	    core->recbin_last_error = "Unable to get the recycled objects index file.";
-	    return(-1);
+	    core->recbin_last_error =
+"Unable to get the recycled objects index file.";
+	    CLEANUP_RETURN(-1);
 	}
 
 	/* Get the statistics of recycled object */
-	obj = EDVRecBinObjectStat(recycled_index_file, index);
+	obj = EDVRecBinObjectStat(index_path, index);
 
 	/* Map the progress dialog? */
 	if(show_progress)
@@ -402,9 +416,8 @@ gint EDVRecBinPurge(
 		    core, progress_value
 		))
 		{
-		    DO_FREE_LOCALS
 		    status = -4;
-		    return(status);
+		    CLEANUP_RETURN(status);
 		}
 	    }
 	}
@@ -412,7 +425,7 @@ gint EDVRecBinPurge(
 
 	/* Remove the recycled object from the recycle bin */
 	status = EDVRecBinDiskObjectPurge(
-	    recycled_index_file,
+	    index_path,
 	    index,
 	    ((progress_value < 0.0f) && show_progress) ?
 		EDVRecBinPurgeProgressCB : NULL,
@@ -448,7 +461,7 @@ gint EDVRecBinPurge(
 	     * index file
 	     */
 	    EDVRecBinIndexRemove(
-		recycled_index_file, index
+		index_path, index
 	    );
 	}
 
@@ -458,37 +471,44 @@ gint EDVRecBinPurge(
 	    EDV_HISTORY_RECYCLED_OBJECT_PURGE,
 	    time_start, (gulong)time(NULL),
 	    status,
-	    (obj != NULL) ? obj->name : NULL,
-	    NULL,		/* No target */
-	    core->recbin_last_error
+	    (obj != NULL) ? obj->name : NULL,	/* Source */
+	    NULL,				/* No target */
+	    core->recbin_last_error		/* Comment */
 	);
 
-	DO_FREE_LOCALS
-
-	return(status);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(status);
+#undef CLEANUP_RETURN
 }
 
-
 /*
- *      Purges all recycled objects from the recycled objects directory
- *	including the recycled objects index file.
+ *	Purges all the recycled objects from the recycle bin.
  *
- *      If and only if the progress_value is non negative, then the
- *      progress dialog will be updated with an internally calculated
- *      value, otherwise the given progress_value is passed to the
- *      progress dialog.
+ *	The index specifies the recycled object to purge.
+ *
+ *	The toplevel specifies the toplevel GtkWidget.
+ *
+ *	If show_progress is TRUE then the progress dialog will be
+ *	shown during this operation.
+ *
+ *	If interactive is TRUE then the user will be notified and
+ *	queried if any problems arise.
+ *
+ *	The yes_to_all specifies a pointer to the preinitialized
+ *	current gboolean "yes to all" value. This value may be
+ *	set to TRUE during this call if the user responds with
+ *	"yes to all" to a query.
  */
 gint EDVRecBinPurgeAll(
 	edv_core_struct *core,
-	GtkWidget *toplevel,            /* Can be NULL */
-	gboolean show_progress, gboolean interactive,
+	GtkWidget *toplevel,
+	const gboolean show_progress,
+	const gboolean interactive,
 	gboolean *yes_to_all
 )
 {
-	static gint status;
-	const gchar *recycled_index_file;
 	const gulong time_start = (gulong)time(NULL);
+	gint status;
+	const gchar *index_path;
 	const cfg_item_struct *cfg_list;
 
 	/* Clear the last error message */
@@ -500,21 +520,21 @@ gint EDVRecBinPurgeAll(
 	    return(-2);
 	}
 
-#define DO_FREE_LOCALS  \
-{ \
+#define CLEANUP_RETURN(_v_)	{	\
+					\
+ return(_v_);				\
 }
 
 	cfg_list = core->cfg_list;
 
 	/* Get path to recycled objects index file */
-	recycled_index_file = EDV_GET_S(
+	index_path = EDV_GET_S(
 	    EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX
 	);
-	if(recycled_index_file == NULL)
+	if(index_path == NULL)
 	{
-	    DO_FREE_LOCALS
 	    core->recbin_last_error = "Unable to get the recycled objects index file.";
-	    return(-1);
+	    CLEANUP_RETURN(-1);
 	}
 
 
@@ -566,7 +586,7 @@ la raccolta differenziata...\n"
 	 * including the recycled objects index file.
 	 */
 	status = EDVRecBinDiskObjectPurgeAll(
-	    recycled_index_file, 
+	    index_path, 
 	    show_progress ? EDVRecBinPurgeProgressCB : NULL,
 	    core
 	);
@@ -588,13 +608,11 @@ la raccolta differenziata...\n"
 	    EDV_HISTORY_RECYCLED_OBJECT_PURGE_ALL,
 	    time_start, (gulong)time(NULL),
 	    status,
-	    NULL,		/* No source */
-	    NULL,		/* No target */
-	    core->recbin_last_error
+	    NULL,			/* No source */
+	    NULL,			/* No target */
+	    core->recbin_last_error	/* Comment */
 	);
 
-	DO_FREE_LOCALS
-
-	return(status);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(status);
+#undef CLEANUP_RETURN
 }
