@@ -15,16 +15,18 @@ extern const gchar *EDVRecBinPurgeGetError(edv_core_struct *core);
 
 extern gint EDVRecBinPurge(
 	edv_core_struct *core,
-	const guint index,		/* Index of the recycled object */
+	const guint index,
 	GtkWidget *toplevel,
-	const gfloat progress_value,	/* Can be -1.0 */
-	gboolean show_progress, gboolean interactive,
+	const gfloat progress_value,
+	const gboolean show_progress,
+	const gboolean interactive,
 	gboolean *yes_to_all
 );
 extern gint EDVRecBinPurgeAll(
 	edv_core_struct *core,
 	GtkWidget *toplevel,
-	gboolean show_progress, gboolean interactive,
+	const gboolean show_progress,
+	const gboolean interactive,
 	gboolean *yes_to_all
 );
 
