@@ -17,9 +17,10 @@ extern gint EDVRecBinRecover(
 	edv_core_struct *core,
 	const guint index,
 	const gchar *alternate_recovery_path,
-	gchar **new_obj_rtn,
+	gchar **new_path_rtn,
 	GtkWidget *toplevel,
-	gboolean show_progress, gboolean interactive,
+	const gboolean show_progress,
+	const gboolean interactive,
 	gboolean *yes_to_all
 );
 
