@@ -11,7 +11,7 @@
 
 
 extern edv_recycled_object_struct *EDVRecBinObjectStat(
-	const gchar *filename,
+	const gchar *index_path,
 	const guint index
 );
 
