@@ -49,8 +49,9 @@ static void EDVRecBinSyncIndexFile(
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all, gint *status,
 	void (*status_message_cb)(const gchar *, gpointer),
+	gpointer status_message_data,
 	void (*status_progress_cb)(gfloat, gpointer),
-	gpointer data
+	gpointer status_progress_data
 );
 static void EDVRecBinSyncObjects(
 	edv_core_struct *core,
@@ -60,8 +61,9 @@ static void EDVRecBinSyncObjects(
 	gboolean show_progress, gboolean interactive,
 	gboolean *yes_to_all, gint *status,
 	void (*status_message_cb)(const gchar *, gpointer),
+	gpointer status_message_data,
 	void (*status_progress_cb)(gfloat, gpointer),
-	gpointer data
+	gpointer status_progress_data
 );
 
 gint EDVRecBinSync(
@@ -70,63 +72,71 @@ gint EDVRecBinSync(
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all,
 	void (*status_message_cb)(const gchar *, gpointer),
+	gpointer status_message_data,
 	void (*status_progress_cb)(gfloat, gpointer),
-	gpointer data
+	gpointer status_progress_data
 );
 
 
-#define STATUS_MESSAGE(_s_)	{		\
+#define STATUS_MESSAGE(_msg_)	{		\
  if(status_message_cb != NULL)			\
-  status_message_cb((_s_), data);		\
+  status_message_cb(				\
+   (_msg_),					\
+   status_message_data				\
+  );						\
 }
-#define STATUS_PROGRESS(_f_)	{		\
+#define STATUS_PROGRESS(_vf_)	{		\
  if(status_progress_cb != NULL)			\
-  status_progress_cb((_f_), data);		\
+  status_progress_cb(				\
+   (_vf_),					\
+   status_progress_data				\
+  );						\
 }
 
-#define MESSAGE_ERROR(t,s)	{	\
- if(interactive) {			\
-  EDVPlaySoundError(core);		\
-  EDVMessageError(			\
-   (t), (s), NULL, toplevel		\
-  );					\
+#define MESSAGE_ERROR(_title_,_msg_)	{	\
+ if(interactive) {				\
+  EDVPlaySoundError(core);			\
+  EDVMessageError(				\
+   (_title_), (_msg_), NULL, toplevel		\
+  );						\
 } }
 
-#define MESSAGE_WARNING(t,s)	{	\
- if(interactive) {			\
-  EDVPlaySoundWarning(core);	\
-  EDVMessageWarning(			\
-   (t), (s), NULL, toplevel		\
-  );					\
+#define MESSAGE_WARNING(_title_,_msg_)	{	\
+ if(interactive) {				\
+  EDVPlaySoundWarning(core);			\
+  EDVMessageWarning(				\
+   (_title_), (_msg_), NULL, toplevel		\
+  );						\
 } }
 
-#define MESSAGE(t,s)	{		\
- if(interactive) {			\
- EDVPlaySoundInfo(core);		\
- CDialogSetTransientFor(toplevel);	\
- CDialogGetResponseIconData(		\
-  (t), (s), NULL,			\
-  (guint8 **)icon_trash_32x32_xpm,	\
-  CDIALOG_BTNFLAG_OK,			\
-  CDIALOG_BTNFLAG_OK			\
- );					\
- CDialogSetTransientFor(NULL);		\
+#define MESSAGE(_title_,_msg_)	{		\
+ if(interactive) {				\
+ EDVPlaySoundInfo(core);			\
+ CDialogSetTransientFor(toplevel);		\
+ CDialogGetResponseIconData(			\
+  (_title_), (_msg_), NULL,			\
+  (guint8 **)icon_trash_32x32_xpm,		\
+  CDIALOG_BTNFLAG_OK,				\
+  CDIALOG_BTNFLAG_OK				\
+ );						\
+ CDialogSetTransientFor(NULL);			\
 } }
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
- *	Checks if all the characters in s are digits.
+ *	Checks if all the characters in the string are digits.
  *
  *	If the string is empty or NULL then FALSE will be returned.
  */
@@ -146,8 +156,9 @@ static gboolean EDVRecBinSyncIsStrAllDigits(const gchar *s)
 }
 
 /*
- *	Scans the index file, fixes it as needed, and removes refering
- *	indices to non-existant recycled objects.
+ *	Scans the index file, fixes it as needed, and removes any
+ *	entries with indicies refering to non-existant recycled
+ *	objects.
  *
  *	Inputs assumed valid.
  */
@@ -159,18 +170,20 @@ static void EDVRecBinSyncIndexFile(
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all, gint *status,
 	void (*status_message_cb)(const gchar *, gpointer),
+	gpointer status_message_data,
 	void (*status_progress_cb)(gfloat, gpointer),
-	gpointer data
+	gpointer status_progress_data
 )
 {
+	struct stat lstat_buf;
 	guint index;
 	gchar *recycled_obj_path;
-	GList *missing_idx = NULL, *missing_name = NULL;
+	GList	*missing_indices_list = NULL,
+		*missing_names_list = NULL;
 	edv_recbin_index_struct *rbi_ptr = EDVRecBinIndexOpen(
 	    index_path
 	);
 	const edv_recycled_object_struct *obj;
-	struct stat lstat_buf;
 
 	/* Unable to open the recycle bin index file? */
 	if(rbi_ptr == NULL)
@@ -178,7 +191,7 @@ static void EDVRecBinSyncIndexFile(
 	    const gchar *error_msg = EDVRecBinIndexGetError();
 	    if(error_msg != NULL)
 	    {
-		gchar *s = g_strdup_printf(
+		gchar *msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Incapaz de abrir el archivo del ndice de cajn de recirculacin:\n\
 \n\
@@ -232,9 +245,9 @@ static void EDVRecBinSyncIndexFile(
 		);
 		MESSAGE_ERROR(
 "Recycle Bin Error",
-		    s
+		    msg
 		);
-		g_free(s);
+		g_free(msg);
 	    }
 	    if(*status == 0)
 		*status = -1;
@@ -244,14 +257,16 @@ static void EDVRecBinSyncIndexFile(
 	STATUS_MESSAGE(
 "Reading recycle bin index file..."
 	);
-	STATUS_PROGRESS(-1.0f);
 
-	/* Iterate through all the recycled objects referenced by the
-	 * recycle bin index file
+	/* Iterate through all the recycled objects referenced in
+	 * the recycle bin index file
 	 */
 	while(!EDVRecBinIndexNext(rbi_ptr))
 	{
-	    STATUS_PROGRESS(-1.0f);
+	    STATUS_PROGRESS(
+		(0 / 4) +
+		(EDVRecBinIndexPositionCoeff(rbi_ptr) / 4)
+	    );
 
 	    index = rbi_ptr->index;
 	    obj = rbi_ptr->obj;
@@ -262,25 +277,58 @@ static void EDVRecBinSyncIndexFile(
 		recbin_path, G_DIR_SEPARATOR, index
 	    );
 	    /* Does not exist? */
-	    if(lstat(recycled_obj_path, &lstat_buf))
+	    if(lstat((const char *)recycled_obj_path, &lstat_buf))
 	    {
-		missing_idx = g_list_append(
-		    missing_idx, (gpointer)index
+		missing_indices_list = g_list_append(
+		    missing_indices_list,
+		    (gpointer)index
 		);
-		missing_name = g_list_append(
-		    missing_name, STRDUP(obj->name)
+		missing_names_list = g_list_append(
+		    missing_names_list,
+		    STRDUP(obj->name)
 		);
 	    }
+#ifdef S_ISREG
 	    /* Is not a regular file? */
 	    else if(!S_ISREG(lstat_buf.st_mode))
 	    {
-		missing_idx = g_list_append(
-		    missing_idx, (gpointer)index
+		missing_indices_list = g_list_append(
+		    missing_indices_list,
+		    (gpointer)index
 		);
-		missing_name = g_list_append(
-		    missing_name, STRDUP(obj->name)
+		missing_names_list = g_list_append(
+		    missing_names_list,
+		    STRDUP(obj->name)
 		);
 	    }
+#endif
+	    else
+	    {
+		const mode_t m = lstat_buf.st_mode;
+
+		/* Not owned by user? */
+		if((gint)lstat_buf.st_uid != core->effective_user_id)
+		{
+		    /* Attempt to chown it to the user */
+		    lchown(
+			(const char *)recycled_obj_path,
+			core->effective_user_id,
+			lstat_buf.st_gid
+		    );
+		}
+
+		/* Not proper permissions? */
+		if(!(m & S_IRUSR) || !(m & S_IWUSR) || (m & S_IXUSR) ||
+		   (m & S_IRGRP) || (m & S_IWGRP) || (m & S_IXGRP) ||
+		   (m & S_IROTH) || (m & S_IWOTH) || (m & S_IXOTH)
+		)
+		{
+		    chmod(
+			(const char *)recycled_obj_path,
+			S_IRUSR | S_IWUSR
+		    );
+		}
+	    }
 
 	    g_free(recycled_obj_path);
 	}
@@ -293,25 +341,28 @@ static void EDVRecBinSyncIndexFile(
 	 * refered to by their index numbers, begin querying user for
 	 * their removal
 	 */
-	if(missing_idx != NULL)
+	if(missing_indices_list != NULL)
 	{
 	    gboolean got_cancel = FALSE;
 	    gint response;
 	    guint index;
 	    const gchar *name;
-	    GList	*glist_idx = missing_idx,
-			*glist_name = missing_name;
+	    GList	*glist_idx = missing_indices_list,
+			*glist_name = missing_names_list;
 	    gint i = 0, m = g_list_length(glist_idx);
 
 	    STATUS_MESSAGE(
 "Handling missing objects..."
 	    );
-	    STATUS_PROGRESS(0.0f);
 
 	    /* Iterate through the missing index list */
 	    while(glist_idx != NULL)
 	    {
-		STATUS_PROGRESS((m > 0) ? (gfloat)i / (gfloat)m : 0.0f);
+		if(m > 0)
+		    STATUS_PROGRESS(
+			(1 / 4) +
+			(((gfloat)i / (gfloat)m) / 4)
+		    );
 
 		index = (guint)glist_idx->data;
 		name = (const gchar *)glist_name->data;
@@ -319,7 +370,7 @@ static void EDVRecBinSyncIndexFile(
 		/* Query user for removal of this index */
 		if(interactive && !(*yes_to_all))
 		{
-		    gchar *s = g_strdup_printf(
+		    gchar *msg = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Refered objetivo reciclado de \"%s\" a por el ndice:\n\
 \n\
@@ -380,53 +431,53 @@ Does not exist, do you want to remove its reference from the index file?"
 		    response = CDialogGetResponse(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Perder Recicl se Opone",
-s,
+msg,
 "Mencion un objeto en los objetos reciclados indexa el\n\
 archivo no existe, usted quiere quitar la referencia al no\n\
 objeto de existant de los objetos reciclados indexa el\n\
 archivo?",
 #elif defined(PROG_LANGUAGE_FRENCH)
 "Manquer A Recycl L'Objet",
-s,
+msg,
 "Un referenced d'objet dans le fichier d'index d'objets\n\
 recycl n'existe pas, voulez-vous enlever la rfrence \n\
 l'objet de non-existant du fichier d'index d'objets recycl?",
 #elif defined(PROG_LANGUAGE_GERMAN)
 "Verpassen Hat Objekt Wiederverwertet",
-s,
+msg,
 "Ablegt ein objekt auf in den wiederverwerteten objekten akte,\n\
 sie die verweisung zum nicht-existant objekt vom wiederverwerteten\n\
 objekten index nicht hat verwiesen indiziert existiert wollen\n\
 herausnehmen?",
 #elif defined(PROG_LANGUAGE_ITALIAN)
 "Mancare Ha Riciclato L'Oggetto",
-s,
+msg,
 "Un referenced di oggetto nel file di indice di oggetti riciclato\n\
 non esiste, lei vuole togliere il riferimento all'oggetto di\n\
 non-existant dal file di indice di oggetti riciclato?",
 #elif defined(PROG_LANGUAGE_DUTCH)
 "Missen Recyclde Voorwerp",
-s,
+msg,
 "In niet de gerecyclde voorwerpen indexeer dossier bestaat, een\n\
 voorwerp verwees naar u wil verwijderen de referentie aan het\n\
 niete-existant voorwerp van het gerecycld voorwerpen index\n\
 dossier?",
 #elif defined(PROG_LANGUAGE_PORTUGUESE)
 "Ausente Que Recicla Objeto",
-s,
+msg,
 "Um referenced de objeto no arquivo reciclado de ndice de objetos\n\
 no existe, quer retirar a referncia ao objeto de no-existant do\n\
 arquivo reciclado de ndice de objetos?",
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Mangling Resirkuleredd Objekt",
-s,
+msg,
 "En objektreferanse i de resirkuleredde objektene registrerer\n\
 arkiv ikke finnes, gjr De fjerner referanseen til\n\
 ikke--existantobjektet fra det resirkuleredde\n\
 objektindeksarkiv?",
 #else
 "Non-Existant Recycled Object",
-s,
+msg,
 "An object referenced in the recycled objects index file\n\
 does not exist, do you want to remove the reference to\n\
 the non-existant object from the recycled objects index\n\
@@ -441,7 +492,7 @@ file?",
 			CDIALOG_BTNFLAG_YES
 		    );
 		    CDialogSetTransientFor(NULL);
-		    g_free(s);
+		    g_free(msg);
 		}
 		else
 		{
@@ -481,12 +532,15 @@ file?",
 	}
 
 	STATUS_MESSAGE(NULL);
-	STATUS_PROGRESS(0.0f);
 
 	/* Delete list of index of missing recycled objects */
-	g_list_free(missing_idx);
-	g_list_foreach(missing_name, (GFunc)g_free, NULL);
-	g_list_free(missing_name);
+	if(missing_indices_list != NULL)
+	    g_list_free(missing_indices_list);
+	if(missing_names_list != NULL)
+	{
+	    g_list_foreach(missing_names_list, (GFunc)g_free, NULL);
+	    g_list_free(missing_names_list);
+	}
 }
 
 
@@ -505,8 +559,9 @@ static void EDVRecBinSyncObjects(
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all, gint *status,
 	void (*status_message_cb)(const gchar *, gpointer),
+	gpointer status_message_data,
 	void (*status_progress_cb)(gfloat, gpointer),
-	gpointer data
+	gpointer status_progress_data
 )
 {
 	gint i, strc;
@@ -528,14 +583,17 @@ static void EDVRecBinSyncObjects(
 	    STATUS_MESSAGE(
 "Reading recycle bin index file..."
 	    );
-	    STATUS_PROGRESS(-1.0f);
 
 	    /* Get the list of indices */
 	    while(!EDVRecBinIndexNext(rbi_ptr))
 	    {
-		STATUS_PROGRESS(-1.0f);
+		STATUS_PROGRESS(
+		    (2 / 4) +
+		    (EDVRecBinIndexPositionCoeff(rbi_ptr) / 4)
+		);
 		idx_list = g_list_append(
-		    idx_list, (gpointer)rbi_ptr->index
+		    idx_list,
+		    (gpointer)rbi_ptr->index
 		);
 	    }
 
@@ -546,7 +604,6 @@ static void EDVRecBinSyncObjects(
 	STATUS_MESSAGE(
 "Checking for inert objects..."
 	);
-	STATUS_PROGRESS(0.0f);
 
 	/* Get the listing of every object in the recycled bin
 	 * directory
@@ -554,7 +611,10 @@ static void EDVRecBinSyncObjects(
 	strv = GetDirEntNames2(recbin_path, &strc);
 	for(i = 0; i < strc; i++)
 	{
-	    STATUS_PROGRESS((strc > 0) ? (gfloat)i / (gfloat)strc : 0.0f);
+	    STATUS_PROGRESS(
+		(3 / 4) +
+		(((gfloat)i / (gfloat)strc) / 4)
+	    );
 
 	    obj_name = strv[i];
 	    if(STRISEMPTY(obj_name))
@@ -864,13 +924,15 @@ To:\n\
 		if(in_list)
 		{
 		    /* Object belongs in the recycled objects directory */
-		    gchar *path = g_strdup_printf(
-			"%s%c%s",
-			recbin_path, G_DIR_SEPARATOR, obj_name
+		    gchar *path = g_strconcat(
+			recbin_path,
+			G_DIR_SEPARATOR_S,
+			obj_name,
+			NULL
 		    );
 
 		    /* Set permissions */
-		    if(chmod(path, S_IRUSR | S_IWUSR))
+		    if(chmod((const char *)path, S_IRUSR | S_IWUSR))
 		    {
 			const gint error_code = (gint)errno;
 			const gchar *error_msg = g_strerror(error_code);
@@ -1174,7 +1236,6 @@ To:\n\
 
 
 	STATUS_MESSAGE(NULL);
-	STATUS_PROGRESS(0.0f);
 
 	/* Delete the indices list */
 	g_list_free(idx_list);
@@ -1186,7 +1247,6 @@ To:\n\
 }
 
 
-
 /*
  *	Compacts the recycled objects and fixes any errors in the
  *	recycle bin.
@@ -1197,22 +1257,27 @@ gint EDVRecBinSync(
 	const gboolean show_progress, const gboolean interactive,
 	gboolean *yes_to_all,
 	void (*status_message_cb)(const gchar *, gpointer),
+	gpointer status_message_data,
 	void (*status_progress_cb)(gfloat, gpointer),
-	gpointer data
+	gpointer status_progress_data
 )
 {
-	gint status = 0;
+	mode_t m;
+	struct stat stat_buf;
 	gboolean lyes_to_all = FALSE;
+	gint status = 0;
 	const gchar *index_path;
 	gchar *recbin_path = NULL;
-	gulong time_start = (gulong)time(NULL);
-	struct stat stat_buf;
-	const cfg_item_struct *cfg_list;
+	const gulong time_start = (gulong)time(NULL);
+	cfg_item_struct *cfg_list;
 
-#define POSTOP_AND_RETURN(rtn_val)	{	\
+#define CLEANUP_RETURN(rtn_val)	{		\
  /* Report the final progress */		\
  if(status_progress_cb != NULL)			\
-  status_progress_cb(1.0f, data);		\
+  status_progress_cb(				\
+   1.0f,					\
+   status_progress_data				\
+  );						\
 						\
  g_free(recbin_path);				\
 						\
@@ -1224,8 +1289,7 @@ gint EDVRecBinSync(
 	    yes_to_all = &lyes_to_all;
 
 	/* Report the initial progress */
-	if(status_progress_cb != NULL)
-	    status_progress_cb(0.0f, data);
+	STATUS_PROGRESS(0.0f);
 
 	/* Check for invalid input values */
 	if(core == NULL)
@@ -1236,7 +1300,7 @@ gint EDVRecBinSync(
 	    );
 	    if(status == 0)
 		status = -2;
-	    POSTOP_AND_RETURN(status);
+	    CLEANUP_RETURN(status);
 	}
 
 	/* Clear the last error message */
@@ -1244,131 +1308,348 @@ gint EDVRecBinSync(
 
 	cfg_list = core->cfg_list;
 
-	/* Get path to the recycle bin index file */
+	/* Get the path to the recycle bin index file */
 	index_path = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
 	if(STRISEMPTY(index_path))
 	{
-	    MESSAGE_ERROR(
+	    /* Recycle bin index file was not set in the configuration
+	     * so attempt to set it
+	     *
+	     * Obtain the location of the local data directory
+	     */
+	    gint response;
+	    gchar	*msg,
+			*new_index_path,
+			*data_path = STRDUP(EDV_GET_S(EDV_CFG_PARM_DIR_LOCAL));
+	    if(STRISEMPTY(data_path))
+	    {
+		/* Local data directory not set, attempt to set it */
+		const gchar *home_dir = (core->home_dir != NULL) ?
+		    core->home_dir : g_getenv(ENV_VAR_NAME_HOME);
+		if(home_dir == NULL)
+		    home_dir = "";
+
+		/* Generate the new local data directory path */
+		g_free(data_path);
+		data_path = g_strconcat(
+		    home_dir,
+		    G_DIR_SEPARATOR_S,
+		    EDV_DEF_LOCAL_DATA_DIR,
+		    NULL
+		);
+
+		/* Confirm set */
+		msg = g_strdup_printf(
+"The local data directory was not set in the configuration,\n\
+would you like to set it to:\n\
+\n\
+    %s",
+		    data_path
+		);
+		EDVPlaySoundWarning(core);
+		CDialogSetTransientFor(toplevel);
+		response = CDialogGetResponse(
+"Local Data Directory Path Not Set",
+		    msg,
+		    NULL,
+		    CDIALOG_ICON_WARNING,
+		    CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO,
+		    CDIALOG_BTNFLAG_YES
+		);
+		g_free(msg);
+		CDialogSetTransientFor(NULL);
+		if(response != CDIALOG_RESPONSE_YES)
+		{
+		    g_free(data_path);
+		    if(status == 0)
+			status = -5;
+		    CLEANUP_RETURN(status);
+		}
+
+		/* Set the new local data directory path */
+		EDV_SET_S(EDV_CFG_PARM_DIR_LOCAL, data_path);
+	    }
+
+	    /* Unable to obtain or set the local data directory? */
+	    if(STRISEMPTY(data_path))
+	    {
+		g_free(data_path);
+		MESSAGE_ERROR(
 "Recycle Bin Error",
-"Recycled objects index file is not defined"
+"Unable to obtain or generate the local data directory path"
+		);
+		if(status == 0)
+		    status = -1;
+		CLEANUP_RETURN(status);
+	    }
+
+	    /* Generate the new index file path */
+	    new_index_path = g_strconcat(
+		data_path,
+		G_DIR_SEPARATOR_S,
+		EDV_DEF_RECYCLED_INDEX_FILE,
+		NULL
 	    );
-	    if(status == 0)
-		status = -1;
-	    POSTOP_AND_RETURN(status);
+
+	    /* Unable to generate the index file path? */
+	    if(STRISEMPTY(new_index_path))
+	    {
+		g_free(new_index_path);
+		g_free(data_path);
+		MESSAGE_ERROR(
+"Recycle Bin Error",
+"Unable to obtain or generate the index file path"
+		);
+		if(status == 0)
+		    status = -1;
+		CLEANUP_RETURN(status);
+	    }
+
+	    /* Confirm set */
+	    msg = g_strdup_printf(
+"The recycled objects index file path was not set in the\n\
+configuration, would you like to set it to:\n\
+\n\
+    %s",
+		new_index_path
+	    );
+	    EDVPlaySoundWarning(core);
+	    CDialogSetTransientFor(toplevel);
+	    response = CDialogGetResponse(
+"Index File Path Not Set",
+		msg,
+		NULL,
+		CDIALOG_ICON_WARNING,
+		CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO,
+		CDIALOG_BTNFLAG_YES
+	    );
+	    g_free(msg);
+	    CDialogSetTransientFor(NULL);
+	    if(response != CDIALOG_RESPONSE_YES)
+	    {
+		g_free(data_path);
+		g_free(new_index_path);
+		if(status == 0)
+		    status = -5;
+		CLEANUP_RETURN(status);
+	    }
+
+	    /* Set the new index file path */
+	    EDV_SET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX, new_index_path);
+
+	    g_free(new_index_path);
+	    g_free(data_path);
+
+	    /* Reget the path to the recycle bin index file */
+	    index_path = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
+	    if(STRISEMPTY(index_path))
+	    {
+		MESSAGE_ERROR(
+"Recycle Bin Error",
+"Unable to obtain or generate the index file path"
+		);
+		if(status == 0)
+		    status = -1;
+		CLEANUP_RETURN(status);
+	    }
 	}
 
-	/* Get the recycle bin directory */
-	recbin_path = g_dirname(index_path);
+	/* Get the recycle bin directory path from the index file path */
+	recbin_path = EDVRecBinIndexGetRecycleBinDirectory(index_path);
 	if(STRISEMPTY(recbin_path))
 	{
+	    gchar *msg = g_strdup_printf(
+"Unable to determine the recycle bin directory path\n\
+from the index file path:\n\
+\n\
+    %s",
+		index_path
+	    );
 	    MESSAGE_ERROR(
 "Recycle Bin Error",
-"Unable to determine recycle bin directory"
+		msg
 	    );
+	    g_free(msg);
 	    if(status == 0)
 		status = -1;
-	    POSTOP_AND_RETURN(status);
+	    CLEANUP_RETURN(status);
 	}
 
 
 	/* Begin checking for errors */
 
 	/* Create the recycle bin directory as needed */
-	if(stat((char *)recbin_path, &stat_buf))
+	if(stat((const char *)recbin_path, &stat_buf))
 	{
-	    if(rmkdir((char *)recbin_path, S_IRUSR | S_IWUSR | S_IXUSR))
+	    /* Create the recycle bin directory */
+	    if(rmkdir(
+		(const char *)recbin_path,
+		S_IRUSR | S_IWUSR | S_IXUSR)
+	    )
 	    {
-		gchar *s = g_strdup_printf(
+		const gint error_code = (gint)errno;
+		gchar *msg = g_strdup_printf(
 "Unable to create the recycle bin directory:\n\
 \n\
     %s\n\
 \n\
-Unable to continue with the operation since the recycle\n\
-bin directory does not exist and it could not be\n\
-created.\n\
-\n\
-Check if you have write permission to the above\n\
-location.",
-		    recbin_path
+%s.",
+		    recbin_path,
+		    g_strerror(error_code)
 		);
 		MESSAGE_ERROR(
 "Create Directory Error",
-s
+		    msg
 		);
-		g_free(s);
+		g_free(msg);
 		if(status == 0)
 		    status = -1;
-		POSTOP_AND_RETURN(status);
+		CLEANUP_RETURN(status);
+	    }
+
+	    /* Get the newly created recycle bin directory's statistics */
+	    if(stat((const char *)recbin_path, &stat_buf))
+	    {
+		const gint error_code = (gint)errno;
+		gchar *msg = g_strdup_printf(
+"Unable to create the recycle bin directory:\n\
+\n\
+    %s\n\
+\n\
+%s.",
+		    recbin_path,
+		    g_strerror(error_code)
+		);
+		MESSAGE_ERROR(
+"Create Directory Error",
+		    msg
+		);
+		g_free(msg);
+		if(status == 0)
+		    status = -1;
+		CLEANUP_RETURN(status);
 	    }
 	}
+
+	/* Check if the recycle bin directory not a directory */
 #ifdef S_ISDIR
-	else if(!S_ISDIR(stat_buf.st_mode))
+	if(!S_ISDIR(stat_buf.st_mode))
 #else
-	else if(TRUE)
+	if(TRUE)
 #endif
 	{
-	    gchar *s = g_strdup_printf(
+	    /* The recycle bin directory not a directory
+	     *
+	     * Query the user to move the object elsewhere
+	     */
+	    struct stat lstat_buf;
+	    gint response;
+	    gchar *safe_bad_recbin_path, *msg;
+
+	    /* Generate a new name for the object */
+	    safe_bad_recbin_path = g_strconcat(
+		recbin_path,
+		".oth",
+		NULL
+	    );
+	    if(!lstat((const char *)safe_bad_recbin_path, &lstat_buf))
+	    {
+		gint i;
+		for(i = 0; i < (guint16)-1; i++)
+		{
+		    g_free(safe_bad_recbin_path);
+		    safe_bad_recbin_path = g_strdup_printf(
+			"%s.%i",
+			recbin_path,
+			i
+		    );
+		    if(lstat((const char *)safe_bad_recbin_path, &lstat_buf))
+			break;
+		}
+	    }
+
+	    /* Query the user */
+	    msg = g_strdup_printf(
 "Recycle bin directory path:\n\
 \n\
     %s\n\
 \n\
-Is not a directory, the recycle bin directory must be\n\
-a directory object.\n\
+Is not a directory.\n\
 \n\
-Try moving the object found at the above location to\n\
-a different location or change the recycle bin\n\
-directory's location.",
-		recbin_path
+The recycle bin directory must be a directory object.\n\
+\n\
+Move this object to:\n\
+\n\
+%s\n\
+\n\
+To allow the recycle bin directory to be created as a\n\
+directory?",
+		recbin_path,
+		safe_bad_recbin_path
 	    );
-	    MESSAGE_ERROR(
-"Recycle Bin Error",
-		s
+            EDVPlaySoundWarning(core);
+            CDialogSetTransientFor(toplevel);
+            response = CDialogGetResponse(
+"Unvalid Recycle Bin Directory",
+		msg,
+		NULL,
+		CDIALOG_ICON_WARNING,
+                CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_NO,
+		CDIALOG_BTNFLAG_YES
 	    );
-	    g_free(s);
-	    if(status == 0)
-		status = -1;
-	    POSTOP_AND_RETURN(status);
-	}
-
-	/* Update permissions on recycle bin directory */
-	if(chmod((char *)recbin_path, S_IRUSR | S_IWUSR | S_IXUSR))
-	{
-	    const gint error_code = (gint)errno;
-	    const gchar *error_msg = g_strerror(error_code);
-	    gchar *s = g_strdup_printf(
-"Unable to set the permissions on recycle bin directory:\n\
+            g_free(msg);
+            CDialogSetTransientFor(NULL);
+	    if(response == CDIALOG_RESPONSE_YES)
+	    {
+		/* Move this object */
+		if(rename(
+		    (const char *)recbin_path,
+		    (const char *)safe_bad_recbin_path
+		))
+		{
+		    /* Move failed */
+		    const gint error_code = (gint)errno;
+		    gchar *msg = g_strdup_printf(
+"Unable to move:\n\
 \n\
     %s\n\
 \n\
-%s.\n\
+To:\n\
 \n\
-This may pose a security concearn since other users\n\
-may be able to access the recycled objects.",
-		recbin_path, error_msg
-	    );
-	    MESSAGE_ERROR(
-"Change Mode Error",
-		s
-	    );
-	    g_free(s);
-
-	    if(status == 0)
-		status = -1;
-
-	    POSTOP_AND_RETURN(status);
+    %s\n\
+\n\
+%s.",
+			recbin_path,
+			safe_bad_recbin_path,
+			g_strerror(error_code)
+		    );
+		    MESSAGE_ERROR(
+"Move Failed",
+			msg
+		    );
+		    g_free(msg);
+		    g_free(safe_bad_recbin_path);
+		    if(status == 0)
+			status = -1;
+		    CLEANUP_RETURN(status);
+		}
+	    }
+	    g_free(safe_bad_recbin_path);
+	    CLEANUP_RETURN(status);
 	}
 
-
-	/* Does the recycled objects index file exists? */
-	if(!access((const char *)index_path, F_OK) && (status != -4))
+	/* Update the owner of the recycle bin directory */
+	if((gint)stat_buf.st_uid != core->effective_user_id)
 	{
-	    /* Update the permissions on the recycled objects index file */
-	    if(chmod((const char *)index_path, S_IRUSR | S_IWUSR))
+	    if(chown(
+		(const char *)recbin_path,
+		core->effective_user_id,
+		stat_buf.st_gid
+	    ))
 	    {
 		const gint error_code = (gint)errno;
-		const gchar *error_msg = g_strerror(error_code);
-		gchar *s = g_strdup_printf(
-"Unable to set permissions on the index file:\n\
+		gchar *msg = g_strdup_printf(
+"Unable to take ownership of the recycle bin directory:\n\
 \n\
     %s\n\
 \n\
@@ -1376,18 +1657,161 @@ may be able to access the recycled objects.",
 \n\
 This may pose a security concearn since other users\n\
 may be able to access the recycled objects.",
-		    index_path, error_msg
+		    recbin_path,
+		    g_strerror(error_code)
+		);
+		MESSAGE_ERROR(
+"Change Owner Error",
+		    msg
+		);
+		g_free(msg);
+		if(status == 0)
+		    status = -1;
+		CLEANUP_RETURN(status);
+	    }
+	}
+
+	m = stat_buf.st_mode;
+
+	/* Update the permissions on the recycle bin directory */
+	if(!(m & S_IRUSR) || !(m & S_IWUSR) || !(m & S_IXUSR) ||
+	   (m & S_IRGRP) ||  (m & S_IWGRP) ||  (m & S_IXGRP) ||
+	   (m & S_IROTH) ||  (m & S_IWOTH) ||  (m & S_IXOTH)
+	)
+	{
+	    if(chmod(
+		(const char *)recbin_path,
+		S_IRUSR | S_IWUSR | S_IXUSR
+	    ))
+	    {
+		const gint error_code = (gint)errno;
+		gchar *msg = g_strdup_printf(
+"Unable to set the permissions on the recycle bin directory:\n\
+\n\
+    %s\n\
+\n\
+%s.\n\
+\n\
+This may pose a security concearn since other users\n\
+may be able to access the recycled objects.",
+		    recbin_path,
+		    g_strerror(error_code)
 		);
 		MESSAGE_ERROR(
 "Change Mode Error",
-		    s
+		    msg
 		);
-		g_free(s);
-
+		g_free(msg);
 		if(status == 0)
 		    status = -1;
+		CLEANUP_RETURN(status);
+	    }
+	}
 
-		POSTOP_AND_RETURN(status);
+
+	/* Get the recycled objects index file's statistics */
+	if(stat((const char *)index_path, &stat_buf))
+	{
+	    /* Unable to get the recycled objects index file's
+	     * statistics
+	     *
+	     * Report error only if it was not because it does not
+	     * exist
+	     */
+	    const gint error_code = (gint)errno;
+#ifdef ENOENT
+	    if(error_code != ENOENT)
+	    {
+		gchar *msg = g_strdup_printf(
+"Unable to obtain the statistics of the index file:\n\
+\n\
+    %s\n\
+\n\
+%s.",
+		    index_path,
+		    g_strerror(error_code)
+		);
+		MESSAGE_ERROR(
+"Recycle Bin Error",
+		    msg
+		);
+		g_free(msg);
+		if(status == 0)
+		    status = -1;
+		CLEANUP_RETURN(status);
+	    }
+#endif
+	}
+	else
+	{
+	    /* Recycled objects index file exists
+	     *
+	     * Update the owner of the recycle bin directory
+	     */
+	    if((gint)stat_buf.st_uid != core->effective_user_id)
+	    {
+		if(chown(
+		    (const char *)index_path,
+		    core->effective_user_id,
+		    stat_buf.st_gid
+		))
+		{
+		    const gint error_code = (gint)errno;
+		    gchar *msg = g_strdup_printf(
+"Unable to take ownership of the index file:\n\
+\n\
+    %s\n\
+\n\
+%s.\n\
+\n\
+This may pose a security concearn since other users\n\
+may be able to access the recycled objects.",
+			index_path,
+			g_strerror(error_code)
+		    );
+		    MESSAGE_ERROR(
+"Change Owner Error",
+			msg
+		    );
+		    g_free(msg);
+		    if(status == 0)
+			status = -1;
+		    CLEANUP_RETURN(status);
+		}
+	    }
+
+	    m = stat_buf.st_mode;
+
+	    /* Update the permissions on the index file */
+	    if(!(m & S_IRUSR) || !(m & S_IWUSR) || (m & S_IXUSR) ||
+	       (m & S_IRGRP) || (m & S_IWGRP) || (m & S_IXGRP) ||
+	       (m & S_IROTH) || (m & S_IWOTH) || (m & S_IXOTH)
+	    )
+	    {
+		if(chmod((const char *)index_path, S_IRUSR | S_IWUSR))
+		{
+		    const gint error_code = (gint)errno;
+		    gchar *msg = g_strdup_printf(
+"Unable to set the permissions on the index file:\n\
+\n\
+    %s\n\
+\n\
+%s.\n\
+\n\
+This may pose a security concearn since other users\n\
+may be able to access the recycled objects.",
+			index_path,
+			g_strerror(error_code)
+		    );
+		    MESSAGE_ERROR(
+"Change Mode Error",
+			msg
+		    );
+		    g_free(msg);
+		    if(status == 0)
+			status = -1;
+		    CLEANUP_RETURN(status);
+		}
 	    }
 
 	    /* Check for indices that refer to non-existant recycled
@@ -1400,13 +1824,13 @@ may be able to access the recycled objects.",
 		show_progress, interactive,
 		yes_to_all, &status,
 		status_message_cb,
+		status_message_data,
 		status_progress_cb,
-		data
+		status_progress_data
 	    );
 	}
 
 
-
 	/* Recycled objects index file exists? */
 	if(status != -4)
 	{
@@ -1420,15 +1844,16 @@ may be able to access the recycled objects.",
 		show_progress, interactive,
 		yes_to_all, &status,
 		status_message_cb,
+		status_message_data,
 		status_progress_cb,
-		data
+		status_progress_data
 	    );
 	}
 
 
 
 	/* Errors found? */
-	if(status && (status != -4))
+	if((status != 0) && (status != -4))
 	{
 	    MESSAGE(
 "Recycle Bin Sync Results",
@@ -1443,13 +1868,14 @@ The recycle bin has been compacted."
 	EDVAppendHistory(
 	    core,
 	    EDV_HISTORY_SYNC_RECBIN,
-	    time_start, (gulong)time(NULL),
+	    time_start,
+	    (gulong)time(NULL),
 	    status,
-	    index_path,	/* Source */
-	    NULL,		/* Target */
-	    core->recbin_last_error
+	    NULL,			/* No source */
+	    NULL,			/* No target */
+	    core->recbin_last_error	/* Comments */
 	);
 
-	POSTOP_AND_RETURN(status);
-#undef POSTOP_AND_RETURN
+	CLEANUP_RETURN(status);
+#undef CLEANUP_RETURN
 }
