@@ -23,11 +23,12 @@ extern gint EDVRecBinSync(
 		const gchar *,		/* Message */
 		gpointer		/* Data */
 	),
+	gpointer status_message_data,
 	void (*status_progress_cb)(
 		gfloat,			/* Progress */
 		gpointer		/* Data */
 	),
-	gpointer data
+	gpointer status_progress_data
 );
 
 
