@@ -47,6 +47,8 @@ void EDVStatusBarProgress(
 
 
 #define STATUS_BAR_HEIGHT		26
+#define STATUS_BAR_PROGRESS_BAR_WIDTH	100
+#define STATUS_BAR_PROGRESS_BAR_HEIGHT	(STATUS_BAR_HEIGHT - 6)
 
 
 #define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
@@ -77,16 +79,17 @@ static gint EDVStatusBarButtonEventCB(
 	    return(status);
 
 	core = sb->core;
-	if(core == NULL)
-	    return(status);
-
 	cfg_list = core->cfg_list;
 
 	EDVStatusBarSetBusy(sb, TRUE);
 
-	/* Check which widget this event is for */
+	/* Check which widget this event is for
+	 *
+	 * Write protect enabled
+	 */
 	if(widget == sb->write_protect_enabled_eb)
 	{
+	    /* Disable master write protect */
 	    EDV_SET_B(
 		EDV_CFG_PARM_WRITE_PROTECT,
 		FALSE
@@ -94,8 +97,10 @@ static gint EDVStatusBarButtonEventCB(
 	    EDVWriteProtectChangedEmit(core, FALSE);
 	    status = TRUE;
 	}
+	/* Write protect disabled */
 	else if(widget == sb->write_protect_disabled_eb)
 	{
+	    /* Enable master write protect */
 	    EDV_SET_B(
 		EDV_CFG_PARM_WRITE_PROTECT,
 		TRUE
@@ -103,8 +108,10 @@ static gint EDVStatusBarButtonEventCB(
 	    EDVWriteProtectChangedEmit(core, TRUE);
 	    status = TRUE;
 	}
+	/* Delete method recycle */
 	else if(widget == sb->delete_method_recycle_eb)
 	{
+	    /* Set the delete method to purge on delete */
 	    EDV_SET_I(
 		EDV_CFG_PARM_DELETE_METHOD,
 		EDV_DELETE_METHOD_PURGE
@@ -112,8 +119,10 @@ static gint EDVStatusBarButtonEventCB(
 	    EDVReconfiguredEmit(core);
 	    status = TRUE;
 	}
+	/* Delete method purge */
 	else if(widget == sb->delete_method_purge_eb)
 	{
+	    /* Set the delete method to recycle */
 	    EDV_SET_I(
 		EDV_CFG_PARM_DELETE_METHOD,
 		EDV_DELETE_METHOD_RECYCLE
@@ -143,10 +152,10 @@ static gint EDVStatusBarCrossingEventCB(
 
 	etype = (gint)crossing->type;
 
-
-	/* Check which widget this event is for */
-
-	/* Write protect enabled */
+	/* Check which widget this event is for
+	 *
+	 * Write protect enabled
+	 */
 	if(widget == sb->write_protect_enabled_eb)
 	{
 	    const gchar *msg = NULL;
@@ -306,6 +315,7 @@ edv_status_bar_struct *EDVStatusBarNew(
 	edv_core_struct *core, GtkWidget *parent
 )
 {
+	const gint border_minor = 2;
 	GtkStyle *style;
 	GtkWidget *w, *parent2, *parent3, *toplevel;
 	GtkAdjustment *adj;
@@ -330,10 +340,13 @@ edv_status_bar_struct *EDVStatusBarNew(
 	gtk_widget_set_usize(w, -1, STATUS_BAR_HEIGHT);
 	gtk_frame_set_shadow_type(GTK_FRAME(w), GTK_SHADOW_OUT);
 	gtk_container_border_width(GTK_CONTAINER(w), 0);
-	if(GTK_IS_BOX(parent))
-	    gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
-	else if(GTK_IS_CONTAINER(parent))
-	    gtk_container_add(GTK_CONTAINER(parent), w);
+	if(parent != NULL)
+	{
+	    if(GTK_IS_BOX(parent))
+		gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
+	    else if(GTK_IS_CONTAINER(parent))
+		gtk_container_add(GTK_CONTAINER(parent), w);
+	}
 	style = gtk_widget_get_style(w);
 	parent2 = w;
 
@@ -343,7 +356,6 @@ edv_status_bar_struct *EDVStatusBarNew(
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Write protect enabled/disabled */
 	/* Write protect enabled GtkEventBox */
 	sb->write_protect_enabled_eb = w = gtk_event_box_new();
 	gtk_widget_add_events(
@@ -366,9 +378,11 @@ edv_status_bar_struct *EDVStatusBarNew(
 	gtk_table_attach(
 	    GTK_TABLE(parent2), w,
 	    0, 1, 0, 1,
-	    0, 0,
-	    2, 0
+	    0,
+	    0,
+	    border_minor, 0
 	);
+	gtk_table_set_col_spacing(GTK_TABLE(parent2), 0, 0);
 	GUISetWidgetTip(
 	    w,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -422,8 +436,9 @@ edv_status_bar_struct *EDVStatusBarNew(
 	gtk_table_attach(
 	    GTK_TABLE(parent2), w,
 	    0, 1, 0, 1,
-	    0, 0,
-	    2, 0
+	    0,
+	    0,
+	    border_minor, 0
 	);
 	GUISetWidgetTip(
 	    w,
@@ -458,7 +473,6 @@ edv_status_bar_struct *EDVStatusBarNew(
 	gtk_widget_show(w);
 
 
-	/* Delete method */
 	/* Delete method recycle GtkEventBox */
 	sb->delete_method_recycle_eb = w = gtk_event_box_new();
 	gtk_widget_add_events(
@@ -481,9 +495,11 @@ edv_status_bar_struct *EDVStatusBarNew(
 	gtk_table_attach(
 	    GTK_TABLE(parent2), w,
 	    1, 2, 0, 1,
-	    0, 0,
-	    2, 0
+	    0,
+	    0,
+	    border_minor, 0
 	);
+	gtk_table_set_col_spacing(GTK_TABLE(parent2), 1, 1);
 	GUISetWidgetTip(
 	    w,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -538,8 +554,9 @@ edv_status_bar_struct *EDVStatusBarNew(
 	gtk_table_attach(
 	    GTK_TABLE(parent2), w,
 	    1, 2, 0, 1,
-	    0, 0,
-	    2, 0 
+	    0,
+	    0,
+	    border_minor, 0 
 	);
 	GUISetWidgetTip(
 	    w,
@@ -573,13 +590,22 @@ edv_status_bar_struct *EDVStatusBarNew(
 	gtk_widget_show(w);
 
 
-	/* GtkProgressBar */
+	/* GtkProgressBar
+	 *
+	 * The GtkAdjustment range is from 1.0 to 100.0 (in units of
+	 * percent), 0.0 is used as "no value" (so that no progress
+	 * is shown)
+	 */
 	adj = (GtkAdjustment *)gtk_adjustment_new(
 	    0.0f, 1.0f, 100.0f,
 	    0.0f, 0.0f, 0.0f
 	);
 	sb->progress_bar = w = gtk_progress_bar_new_with_adjustment(adj);
-	gtk_widget_set_usize(w, 100, 20);
+	gtk_widget_set_usize(
+	    w,
+	    STATUS_BAR_PROGRESS_BAR_WIDTH,
+	    STATUS_BAR_PROGRESS_BAR_HEIGHT
+	);
 	gtk_progress_bar_set_orientation(
 	    GTK_PROGRESS_BAR(w), GTK_PROGRESS_LEFT_TO_RIGHT
 	);
@@ -593,21 +619,25 @@ edv_status_bar_struct *EDVStatusBarNew(
 	    GTK_TABLE(parent2), w,
 	    2, 3, 0, 1,
 	    0,
-	    GTK_SHRINK,
-	    0, 0
+	    0,
+	    0, 1
 	);
+	gtk_table_set_col_spacing(GTK_TABLE(parent2), 2, 0);
 	gtk_widget_show(w);
 
 	/* Label GtkFrame */
-	w = gtk_frame_new(NULL);
+	sb->label_frame = w = gtk_frame_new(NULL);
 	gtk_frame_set_shadow_type(GTK_FRAME(w), GTK_SHADOW_IN);
-	gtk_container_border_width(GTK_CONTAINER(w), 1);
 	gtk_table_attach(
 	    GTK_TABLE(parent2), w,
 	    3, 4, 0, 1,
 	    GTK_SHRINK | GTK_EXPAND | GTK_FILL,
-	    GTK_FILL,
-	    0, 0
+	    GTK_SHRINK | GTK_EXPAND | GTK_FILL,
+	    1,		/* Use X padding as 1 so that both sides get
+			 * padded since this is the last column and
+			 * the right edge needs padding that can only
+			 * be set this way */
+	    1
 	);
 	gtk_widget_show(w);
 	parent3 = w;
@@ -620,7 +650,7 @@ edv_status_bar_struct *EDVStatusBarNew(
 	/* GtkLabel */
 	sb->label = w = gtk_label_new("");
 	gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
-	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 2);
+	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, border_minor);
 	gtk_widget_show(w);
 
 	sb->freeze_count--;
@@ -767,6 +797,9 @@ void EDVStatusBarUnmap(edv_status_bar_struct *sb)
 	    return;
 
 	gtk_widget_hide(sb->toplevel);
+
+	/* Reset the last progress position */
+	sb->progress_pos_last = -1.0f;
 }
 
 /*
@@ -798,6 +831,9 @@ void EDVStatusBarMessage(
 	if(sb == NULL)
 	    return;
 
+	if(!GTK_WIDGET_MAPPED(sb->toplevel))
+	    return;
+
 	gtk_label_set_text(
 	    GTK_LABEL(sb->label),
 	    (msg != NULL) ? msg : ""
@@ -826,6 +862,9 @@ void EDVStatusBarProgress(
 	if(sb == NULL)
 	    return;
 
+	if(!GTK_WIDGET_MAPPED(sb->toplevel))
+	    return;
+
 	progress_bar = GTK_PROGRESS_BAR(sb->progress_bar);
 	progress = GTK_PROGRESS(progress_bar);
 
@@ -846,9 +885,9 @@ void EDVStatusBarProgress(
 	    gtk_progress_set_show_text(progress, FALSE);
 	    gtk_progress_set_value(progress, value);
 
-	    /* Reset last progress position to -1.0, indicating that
-	     * there is no known last position since we are doing
-	     * activity mode
+	    /* Reset the last progress position to -1.0, indicating
+	     * that there is no known last position since we are
+	     * doing activity mode
 	     */
 	    sb->progress_pos_last = -1.0f;
 	}
@@ -859,15 +898,15 @@ void EDVStatusBarProgress(
 	    if(value > 1.0f)
 		value = 1.0f;
 
-	    /* Reset last progress position if it is greater than the
-	     * given value, implying the progress has warped back to
-	     * the beginning
+	    /* Reset the last progress position if it is greater than
+	     * the specified value, implying that the progress has
+	     * warped back to the beginning
 	     */
 	    if(sb->progress_pos_last > value)
 		sb->progress_pos_last = -1.0f;
 
-	    /* Has value not sufficiently changed? (less than 0.01
-	     * change in value)
+	    /* Has the value not sufficiently changed? (less than
+	     * 0.01 change in value)
 	     */
 	    if((sb->progress_pos_last > 0.0f) &&
 	       ((value - sb->progress_pos_last) < 0.01f)
