@@ -17,7 +17,7 @@ typedef struct _edv_status_bar_struct	edv_status_bar_struct;
 
 
 /*
- *	Status Bar:
+ *	Status Bar
  */
 struct _edv_status_bar_struct {
 
@@ -26,12 +26,13 @@ struct _edv_status_bar_struct {
 			busy_count;
 	edv_core_struct	*core;
 
-	GtkWidget	*write_protect_enabled_eb,
+	GtkWidget	*write_protect_enabled_eb,	/* GtkEventBox */
 			*write_protect_disabled_eb,
 			*delete_method_recycle_eb,
 			*delete_method_purge_eb,
-			*progress_bar,	/* GtkProgressBar */
-			*label;		/* GtkLabel */
+			*progress_bar,		/* GtkProgressBar */
+			*label_frame,		/* GtkFrame */
+			*label;			/* GtkLabel */
 
 	gfloat		progress_pos_last;
 
