@@ -27,6 +27,21 @@
 extern char **environ;
 
 
+/* String Substitution */
+gchar *EDVStrSub(
+	const gchar *fmt, const gchar *token, const gchar *val  
+);
+void EDVStrEvaluateTokenHexToChar(gchar *s);
+
+/* Type */
+edv_object_type EDVStatModeToObjectType(const mode_t m);
+mode_t EDVObjectTypeToStatType(const edv_object_type type);
+
+/* Type Name */
+const gchar *EDVGetObjectTypeName(const edv_object_type type);
+const gchar *EDVGetObjectTypeNameLower(const edv_object_type type);
+
+/* Sizes */
 const gchar *EDVSizeStrDelim(const gulong i);
 const gchar *EDVSizeStrDelimChar(const gulong i, const gchar delim_char);
 const gchar *EDVSizeStrFormat(
@@ -37,11 +52,12 @@ const gchar *EDVSizeStrFormat(
 	const gboolean allow_unit_conversion
 );
 
-gchar *EDVStrSub(
-	const gchar *fmt, const gchar *token, const gchar *val  
-);
-void EDVStrEvaluateTokenHexToChar(gchar *s);
+/* Permissions */
+edv_permission_flags EDVStatModeToEDVPermissions(const mode_t m);
+mode_t EDVEDVPermissionsToStatMode(const edv_permission_flags permissions);
+gchar *EDVGetPermissionsString(const edv_permission_flags permissions);
 
+/* Paths */
 void EDVSimplifyPath(gchar *path);
 gboolean EDVIsParentPath(const gchar *parent, const gchar *child);
 static gboolean EDVIsExtensionIterate(
@@ -68,9 +84,11 @@ gchar *EDVGetLinkTarget(const gchar *path);
 gchar *EDVGetLinkTargetFull(const gchar *path);
 gboolean EDVIsLinkInfinatelyRecursive(const gchar *path);
 
+/* Device Numbers */
 void EDVGetDeviceNumbers(const gint rdev, gint *major_rtn, gint *minor_rtn);
 gint EDVFormatDeviceNumbers(const gint major, const gint minor);
 
+/* Processes */
 gboolean EDVProcessIsRunning(const gint pid);
 
 static void EDVSystemWaitCB(gint s);
@@ -87,6 +105,7 @@ gint EDVSystemShellBlock(
 	gint *status
 ); 
 
+/* GList File IO */
 GList *EDVOpenFileGList(const gchar *path, const gint max_lines);
 void EDVSaveFileGList(const gchar *path, GList *lines_list);
 
@@ -121,6 +140,296 @@ static gchar *G_STRCAT(gchar *s, const gchar *s2)
 }
 
 
+/*
+ *	Substitutes a format string containing tokens for values.
+ *
+ *	The fmt specifies the format string.
+ *
+ *	The token specifies the token string.
+ *
+ *	The val specifies the value string to replace each token
+ *	string encountered in the format string.
+ *
+ *	Returns a dynamically allocated string describing the
+ *	substituted format string or NULL on error.
+ */
+gchar *EDVStrSub(
+	const gchar *fmt, const gchar *token, const gchar *val  
+)
+{
+	return((gchar *)strsub(
+	    (const char *)fmt,
+	    (const char *)token,
+	    (const char *)val
+	));
+}
+
+/*
+ *	Evaluates all occurances of "%HH" by replacing them with
+ *	a single character described by HH in hexidecimal value.
+ *
+ *	The s specifies the string to replace.
+ */
+void EDVStrEvaluateTokenHexToChar(gchar *s)
+{
+	if(s == NULL)
+	    return;
+
+	/* Iterate through the string and evaluate all tokens */
+	while(*s != '\0')
+	{
+	    if(*s == '%')
+	    {
+		guint i;
+		gchar *s1, *s2, hex_str[3];
+
+		/* Get the two characters after the token character
+		 * and store them in hex_str
+		 *
+		 * Break if the end of the string
+		 * is encountered
+		 */
+		s++;
+		if(*s == '\0')
+		    break;
+
+		hex_str[0] = *s;
+
+		s++;
+		if(*s == '\0')
+		    break;
+
+		hex_str[1] = *s;
+		hex_str[2] = '\0';
+
+		/* Convert the hex value described in hex_str into
+		 * its intended character value
+		 */
+		sscanf(hex_str, "%x", &i);
+
+		/* Seek back to the token start position */
+		s -= 2;
+
+		/* Replace the token with the intended character */
+		*s = (gchar)i;
+
+		/* Delete the two characters after the token start
+		 * position
+		 */
+		for(s1 = s + 1,
+		    s2 = s + 3;
+		    *s2 != '\0';
+		    s1++,
+		    s2++
+		)
+		    *s1 = *s2;
+
+		*s1 = '\0';
+	    }
+	    s++;
+	}
+}
+
+
+/*
+ *	Converts the stat() mode_t type to edv_object_type type.
+ *
+ *	The m specifies the stat() mode_t type value. Only the
+ *	bit pertaining to the type in m is checked, all other bits
+ *	are ignored.
+ *
+ *	Returns the edv_object_type type value or
+ *	EDV_OBJECT_TYPE_UNKNOWN on failed match.
+ */
+edv_object_type EDVStatModeToObjectType(const mode_t m)
+{
+#ifdef S_ISREG
+        if(S_ISREG(m))
+#else
+# warning "S_ISREG was not #defined, there will be no way to check for a regular file"
+        if(TRUE)
+#endif
+            return(EDV_OBJECT_TYPE_FILE);
+#ifdef S_ISDIR
+        else if(S_ISDIR(m))
+            return(EDV_OBJECT_TYPE_DIRECTORY);
+#endif
+#ifdef S_ISLNK
+        else if(S_ISLNK(m))
+            return(EDV_OBJECT_TYPE_LINK);
+#endif
+#ifdef S_ISCHR
+        else if(S_ISCHR(m))
+            return(EDV_OBJECT_TYPE_DEVICE_CHARACTER);
+#endif
+#ifdef S_ISBLK
+        else if(S_ISBLK(m))
+            return(EDV_OBJECT_TYPE_DEVICE_BLOCK);
+#endif
+#ifdef S_ISFIFO
+        else if(S_ISFIFO(m))
+            return(EDV_OBJECT_TYPE_FIFO);
+#endif
+#ifdef S_ISSOCK
+        else if(S_ISSOCK(m))
+            return(EDV_OBJECT_TYPE_SOCKET);
+#endif
+        else
+            return(EDV_OBJECT_TYPE_FILE);
+}
+
+/*
+ *	Converts the edv_object_type type to stat() mode_t type.
+ *
+ *	The type specifies the edv_object_type which must be one of
+ *	EDV_OBJECT_TYPE_*.
+ *
+ *	Returns the mode_t type value or 0 on failed match.
+ */
+mode_t EDVObjectTypeToStatType(const edv_object_type type)
+{
+        switch(type)
+        {
+          case EDV_OBJECT_TYPE_UNKNOWN:
+            break;
+          case EDV_OBJECT_TYPE_FILE:
+#ifdef S_IFREG
+            return(S_IFREG);
+#else
+# warning "S_IFREG was not #defined, there will be no way to describe a regular file"
+#endif
+            break;
+          case EDV_OBJECT_TYPE_DIRECTORY:
+#ifdef S_IFDIR
+            return(S_IFDIR);
+#endif
+            break;
+          case EDV_OBJECT_TYPE_LINK:
+#ifdef S_IFLNK
+            return(S_IFLNK);
+#endif
+            break;
+          case EDV_OBJECT_TYPE_FIFO:
+#if defined(S_IFFIFO)
+            return(S_IFFIFO);
+#elif defined(S_IFIFO)
+            return(S_IFIFO);
+#endif
+            break;
+          case EDV_OBJECT_TYPE_DEVICE_BLOCK:
+#ifdef S_IFBLK
+            return(S_IFBLK);
+#endif
+            break;
+          case EDV_OBJECT_TYPE_DEVICE_CHARACTER:
+#ifdef S_IFCHR
+            return(S_IFCHR);
+#endif
+            break;
+          case EDV_OBJECT_TYPE_SOCKET:
+#ifdef S_IFSOCK
+            return(S_IFSOCK);
+#endif
+            break;
+          case EDV_OBJECT_TYPE_ERROR:
+            break;
+        }
+
+        return(0);
+}
+
+/*
+ *	Converts the edv_object_type type to a string name.
+ *
+ *	The type specifies the edv_object_type which must be one of
+ *	EDV_OBJECT_TYPE_*.
+ *
+ *	Returns a statically allocated string describing the type
+ *	name.
+ */
+const gchar *EDVGetObjectTypeName(const edv_object_type type)
+{
+        switch(type)
+        {
+          case EDV_OBJECT_TYPE_UNKNOWN:
+            return("Unknown");
+            break;
+          case EDV_OBJECT_TYPE_FILE:
+            return("File");
+            break;
+          case EDV_OBJECT_TYPE_DIRECTORY:
+            return("Directory");
+            break;
+          case EDV_OBJECT_TYPE_LINK:
+            return("Link");
+            break;
+          case EDV_OBJECT_TYPE_FIFO:
+            return("FIFO Pipe");
+            break;
+          case EDV_OBJECT_TYPE_DEVICE_BLOCK:
+            return("Block Device");
+            break;
+          case EDV_OBJECT_TYPE_DEVICE_CHARACTER:
+            return("Character Device");
+            break;
+          case EDV_OBJECT_TYPE_SOCKET:
+            return("Socket");
+            break;
+          case EDV_OBJECT_TYPE_ERROR:
+            return("Error");
+            break;
+        }
+
+        return("Unknown");
+}
+
+/*
+ *	Converts the edv_object_type type to a string name in
+ *	lowercase.
+ *
+ *	The type specifies the edv_object_type which must be one of
+ *	EDV_OBJECT_TYPE_*.
+ *
+ *	Returns a statically allocated string describing the type
+ *	name in lowercase.
+ */
+const gchar *EDVGetObjectTypeNameLower(const edv_object_type type)
+{
+        switch(type)
+        {
+          case EDV_OBJECT_TYPE_UNKNOWN:
+            return("unknown");
+            break;
+          case EDV_OBJECT_TYPE_FILE:
+            return("file");
+            break;
+          case EDV_OBJECT_TYPE_DIRECTORY:
+            return("directory");
+            break;
+          case EDV_OBJECT_TYPE_LINK:
+            return("link");
+            break;
+          case EDV_OBJECT_TYPE_FIFO:
+            return("FIFO pipe");
+            break;
+          case EDV_OBJECT_TYPE_DEVICE_BLOCK:
+            return("block device");
+            break;
+          case EDV_OBJECT_TYPE_DEVICE_CHARACTER:
+            return("character device");
+            break;
+          case EDV_OBJECT_TYPE_SOCKET:
+            return("socket");
+            break;
+          case EDV_OBJECT_TYPE_ERROR:
+            return("error");
+            break;
+        }
+
+        return("unknown");
+}
+
+
 /*
  *	Creates a string describing the value with ',' deliminators.
  *
@@ -200,7 +509,7 @@ const gchar *EDVSizeStrDelimChar(const gulong i, const gchar delim_char)
  *	Formats a string describing the size with the specified
  *	format.
  *
- *      The size specifies the size in bytes.
+ *	The size specifies the size in bytes.
  *
  *	The size_format specifies the format.
  *
@@ -214,7 +523,7 @@ const gchar *EDVSizeStrDelimChar(const gulong i, const gchar delim_char)
  *	specifies a size format other than bytes. Otherwise FALSE
  *	forces the returned string to describe the size in bytes.
  *
- *      Returns a statically allocated string.
+ *	Returns a statically allocated string.
  */
 const gchar *EDVSizeStrFormat(
 	const gulong size,
@@ -347,93 +656,122 @@ const gchar *EDVSizeStrFormat(
 
 
 /*
- *	Substitutes a format string containing tokens for values.
+ *	Converts the stat() mode_t permissions to edv_permission_flags
+ *	permissions.
  *
- *	The fmt specifies the format string.
+ *	The m specifies the stat() mode_t permissions.
  *
- *	The token specifies the token string.
- *
- *	The val specifies the value string to replace each token
- *	string encountered in the format string.
- *
- *	Returns a dynamically allocated string describing the
- *	substituted format string or NULL on error.
+ *	Returns the edv_permission_flags permissions.
  */
-gchar *EDVStrSub(
-	const gchar *fmt, const gchar *token, const gchar *val  
-)
+edv_permission_flags EDVStatModeToEDVPermissions(const mode_t m)
 {
-	return((gchar *)strsub(
-	    (const char *)fmt,
-	    (const char *)token,
-	    (const char *)val
-	));
+        edv_permission_flags p = 0x00000000;
+
+        if(m & S_IXUSR)
+            p |= EDV_PERMISSION_UEXECUTE;
+        if(m & S_IRUSR)
+            p |= EDV_PERMISSION_UREAD;
+        if(m & S_IWUSR)
+            p |= EDV_PERMISSION_UWRITE;
+
+        if(m & S_IXGRP)
+            p |= EDV_PERMISSION_GEXECUTE;
+        if(m & S_IRGRP)
+            p |= EDV_PERMISSION_GREAD;
+        if(m & S_IWGRP)
+            p |= EDV_PERMISSION_GWRITE;
+
+        if(m & S_IXOTH)
+            p |= EDV_PERMISSION_AEXECUTE;
+        if(m & S_IROTH)
+            p |= EDV_PERMISSION_AREAD;
+        if(m & S_IWOTH)
+            p |= EDV_PERMISSION_AWRITE;
+
+        if(m & S_ISUID)
+            p |= EDV_PERMISSION_SETUID;
+        if(m & S_ISGID)
+            p |= EDV_PERMISSION_SETGID;
+        if(m & S_ISVTX)
+            p |= EDV_PERMISSION_STICKY;
+
+        return(p);
 }
 
 /*
- *	Evaluates all occurances of "%HH" by replacing them with
- *	a single character described by HH in hexidecimal value.
+ *	Converts the edv_permission_flags permissions to stat() mode_t
+ *	permissions.
  *
- *	The s specifies the string to replace.
+ *	The permissions specifies the edv_permission_flags, which can
+ *	be any of EDV_PERMISSION_*.
+ *
+ *	Returns the stat() mode_t permissions.
  */
-void EDVStrEvaluateTokenHexToChar(gchar *s)
+mode_t EDVEDVPermissionsToStatMode(const edv_permission_flags permissions)
 {
-	if(s == NULL)
-	    return;
+        mode_t m = 0;
 
-	/* Iterate through the string and evaluate all tokens */
-	while(*s != '\0')
-	{
-	    if(*s == '%')
-	    {
-		guint i;
-		gchar *s1, *s2, hex_str[3];
+        if(permissions & EDV_PERMISSION_UEXECUTE)
+            m |= S_IXUSR;
+        if(permissions & EDV_PERMISSION_UREAD)
+            m |= S_IRUSR;
+        if(permissions & EDV_PERMISSION_UWRITE)
+            m |= S_IWUSR;
 
-		/* Get the two characters after the token character
-		 * and store them in hex_str
-		 *
-		 * Break if the end of the string
-		 * is encountered
-		 */
-		s++;
-		if(*s == '\0')
-		    break;
+        if(permissions & EDV_PERMISSION_GEXECUTE)
+            m |= S_IXGRP;
+        if(permissions & EDV_PERMISSION_GREAD)
+            m |= S_IRGRP;
+        if(permissions & EDV_PERMISSION_GWRITE)
+            m |= S_IWGRP;
 
-		hex_str[0] = *s;
+        if(permissions & EDV_PERMISSION_AEXECUTE)
+            m |= S_IXOTH;
+        if(permissions & EDV_PERMISSION_AREAD)
+            m |= S_IROTH;
+        if(permissions & EDV_PERMISSION_AWRITE)
+            m |= S_IWOTH;
 
-		s++;
-		if(*s == '\0')
-		    break;
+        if(permissions & EDV_PERMISSION_SETUID)
+            m |= S_ISUID;
+        if(permissions & EDV_PERMISSION_SETGID)
+            m |= S_ISGID;
+        if(permissions & EDV_PERMISSION_STICKY)
+            m |= S_ISVTX;
 
-		hex_str[1] = *s;
-		hex_str[2] = '\0';
+        return(m);
+}
 
-		/* Convert the hex value described in hex_str into
-		 * its intended character value
-		 */
-		sscanf(hex_str, "%x", &i);
-
-		/* Seek back to the token start position */
-		s -= 2;
-
-		/* Replace the token with the intended character */
-		*s = (gchar)i;
-
-		/* Delete the two characters after the token start
-		 * position
-		 */
-		for(s1 = s + 1,
-		    s2 = s + 3;
-		    *s2 != '\0';
-		    s1++,
-		    s2++
-		)
-		    *s1 = *s2;
-
-		*s1 = '\0';
-	    }
-	    s++;
-	}
+/*
+ *	Converts the edv_permission_flags permissions to a string
+ *	description.
+ *
+ *	The permissions specifies the edv_permission_flags, which can
+ *	be any of EDV_PERMISSION_*.
+ *
+ *	Returns a dynamically allocated string describing the
+ *	permissions.
+ */
+gchar *EDVGetPermissionsString(const edv_permission_flags permissions)
+{
+        return(g_strdup_printf(
+            "%c%c%c%c%c%c%c%c%c",
+            (permissions & EDV_PERMISSION_UREAD) ? 'r' : '-',
+            (permissions & EDV_PERMISSION_UWRITE) ? 'w' : '-',
+            (permissions & EDV_PERMISSION_SETUID) ?
+                'S' :
+                ((permissions & EDV_PERMISSION_UEXECUTE) ? 'x' : '-'),
+            (permissions & EDV_PERMISSION_GREAD) ? 'r' : '-',
+            (permissions & EDV_PERMISSION_GWRITE) ? 'w' : '-',
+            (permissions & EDV_PERMISSION_SETGID) ?
+                'G' :
+                ((permissions & EDV_PERMISSION_GEXECUTE) ? 'x' : '-'),
+            (permissions & EDV_PERMISSION_AREAD) ? 'r' : '-',
+            (permissions & EDV_PERMISSION_AWRITE) ? 'w' : '-',
+            (permissions & EDV_PERMISSION_STICKY) ?
+                'T' :
+                ((permissions & EDV_PERMISSION_AEXECUTE) ? 'x' : '-')
+        ));
 }
 
 
@@ -862,7 +1200,7 @@ gchar *EDVCompletePath(
 }
 
 /*
- *      Generates a relative path from a starting path to a
+ *	Generates a relative path from a starting path to a
  *	destination path.
  *
  *	The start_path specifies the starting path. The start_path
@@ -1621,18 +1959,14 @@ gint EDVSystemShellBlock(
 
 
 /*
- *	Reads a list of strings from a file.
+ *	Opens a GList of gchar * strings from a file.
  *
- *	The path specifies the file to read from.
+ *	The path specifies the full path to the file to open from.
  *
  *	If max_lines is positive then no more than max_lines will be
  *	read from the file.
  *
- *	Returns a GList of gchar * strings describing each line or
- *	NULL on error. Each string describes a newline deliminated
- *	line from the file (without the newline character stored in
- *	the string). The calling function must delete the GList of
- *	gchar * strings.
+ *	Returns a dynamically allocated GList of gchar * strings.
  */
 GList *EDVOpenFileGList(const gchar *path, const gint max_lines)
 {
@@ -1677,12 +2011,12 @@ GList *EDVOpenFileGList(const gchar *path, const gint max_lines)
 }
 
 /*
- *	Writes a list of strings to a file.
+ *	Saves the GList of gchar * strings to a file.
+ * 
+ *	The path specifies the full path to the file to save to.
  *
- *	The path specifies the file to write to.
- *
- *	The lines_list specifies the GList of gchar * strings. A
- *	newline character will be written between each string.
+ *	The lines_list specifies a GList of gchar * strings to
+ *	write to the file.
  */
 void EDVSaveFileGList(const gchar *path, GList *lines_list)
 {
