@@ -825,27 +825,35 @@ GtkWidget *EDVNewPixmapWidget(
 
 
 /*
- *	Returns the GdkCursor specified by cursor_code or NULL on
- *	error or failed match.
+ *	Gets the GdkCursor from the cursors by the edv_cursor_code.
+ *
+ *	The code specifies the edv_cursor_code, which can be one of
+ *	EDV_CURSOR_CODE_*.
+ *
+ *	Returns the GdkCursor or NULL on error.
  */
 GdkCursor *EDVGetCursor(
-	edv_core_struct *core, const edv_cursor_code code
+	edv_core_struct *core,
+	const edv_cursor_code code
 )
 {
-	gint i;
-	edv_cursor_struct *cur;
+	GList *glist;
+	edv_cursor_struct *cursor;
 
 	if(core == NULL)
 	    return(NULL);
 
-	for(i = 0; i < core->total_cursors; i++)
+	for(glist = core->cursors_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    cur = core->cursor[i];
-	    if(cur == NULL)
+	    cursor = EDV_CURSOR(glist->data);
+	    if(cursor == NULL)
 		continue;
 
-	    if(cur->code == code)
-		return(cur->cursor);
+	    if(cursor->code == code)
+		return(cursor->cursor);
 	}
 
 	return(NULL);
@@ -1253,7 +1261,7 @@ gboolean EDVIsObjectNameValid(const gchar *name)
  *
  *	For a name to be considered "hidden", the first character
  *	must be a '.' and the second character must not be null or
- *	another '.' character.
+ *	another '.' character (to avoid "." and ".." names).
  */
 gboolean EDVIsObjectNameHidden(const gchar *name)
 {
@@ -1846,15 +1854,11 @@ gint EDVMatchObjectIcon(
 	 */
 	if((mimetype != NULL) && !got_match)
 	{
-	    const gchar	*value, *name;
+	    const gchar	*name = (path != NULL) ? g_basename(path) : NULL,
+			*value;
 	    edv_mime_type_struct *m;
 
-	    if((path != NULL) ? g_path_is_absolute(path) : FALSE)
-		name = g_basename(path);
-	    else
-		name = path;
-
-	    /* Iterate through MIME Types list */
+	    /* Iterate through the MIME Types list */
 	    for(i = 0; i < total_mimetypes; i++)
 	    {
 		m = mimetype[i];
@@ -1972,7 +1976,7 @@ gint EDVMatchObjectIcon(
 		   !STRISEMPTY(m->type)
 		)
 		{
-		    if(!strcmp(m->type, mime_type_str))
+		    if(!strcmp((const char *)m->type, (const char *)mime_type_str))
 		    {
 			GET_MIMETYPE_ICONS(m);
 			got_match = TRUE;
@@ -2052,21 +2056,23 @@ gint EDVMatchObjectTypeString(
 	gchar **type_str
 )
 {
+	const gboolean is_file = (type == EDV_OBJECT_TYPE_FILE) ? TRUE : FALSE;
 	gboolean got_match = FALSE;
 	gint i;
 	gchar *ltype_str = NULL;
-	const gchar *name, *ext = NULL;
+#if 0
+	const gchar	*name = (path != NULL) ? g_basename(path) : NULL,
+			*ext = NULL;
+#else
+	const gchar *name = (path != NULL) ? g_basename(path) : NULL;
+#endif
 	edv_mime_type_struct *m;
 
 	if(type_str != NULL)
 	    *type_str = NULL;
 
-	if((path != NULL) ? g_path_is_absolute(path) : FALSE)
-	    name = g_basename(path);
-	else
-	    name = path;
-
-	/* Parse extension from the specified name */
+#if 0
+	/* Parse the extension from the specified name */
 	if(name != NULL)
 	{
 	    const gchar *s = name;
@@ -2080,7 +2086,7 @@ gint EDVMatchObjectTypeString(
 	    /* Seek to extension (if any), include the '.' as the first
 	     * character if an extension is found
 	     */
-	    ext = strchr(s, '.');
+	    ext = (const gchar *)strchr((const char *)s, '.');
 	    if(ext != NULL)
 	    {
 		/* Extension must have atleast one character after it */
@@ -2088,11 +2094,19 @@ gint EDVMatchObjectTypeString(
 		    ext = NULL;
 	    }
 	}
+#endif
+
+	/* First check if the object is a link */
+	if(type == EDV_OBJECT_TYPE_LINK)
+	{
+	    ltype_str = EDV_MIME_TYPE_TYPE_INODE_LINK;
+	    got_match = TRUE;
+	}
 
 	/* Check the MIME Types list for a MIME Type that matches
 	 * this object object
 	 */
-	if(mimetype != NULL)
+	if(!got_match && (mimetype != NULL))
 	{
 	    const gchar *value;
 
@@ -2113,7 +2127,7 @@ gint EDVMatchObjectTypeString(
 		  case EDV_MIME_TYPE_CLASS_SYSTEM:
 		    break;
 		  case EDV_MIME_TYPE_CLASS_FORMAT:
-		    if((name != NULL) && !got_match)
+		    if((name != NULL) && !got_match && is_file)
 		    {
 			if(EDVIsExtension(name, value))
 			{
