@@ -10,7 +10,6 @@
 #include "cfg.h"
 #include "pulist.h"
 #include "edv_types.h"
-#include "edv_cursor.h"
 #include "edv_device.h"
 #include "edv_mime_type.h"
 #include "obj_op_dlg.h"
@@ -209,8 +208,7 @@ struct _edv_core_struct {
 	gchar		*effective_user_id_host_str;	/* user@hostname */
 
 	/* Cursors list */
-	edv_cursor_struct	**cursor;
-	gint			total_cursors;
+	GList		*cursors_list;
 
 	/* Devices list */
 	edv_device_struct	**device;
