@@ -573,9 +573,9 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 
 	/* GtkHBox for the capacity */
 	w = gtk_hbox_new(FALSE, border_minor);
-        gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
-        gtk_widget_show(w);
-        parent6 = w;
+	gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
+	gtk_widget_show(w);
+	parent6 = w;
 
 	w = gtk_label_new(
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -587,7 +587,7 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 #endif
 	);
 	gtk_box_pack_start(GTK_BOX(parent6), w, FALSE, FALSE, 0);
-        gtk_widget_show(w);
+	gtk_widget_show(w);
 
 	fm->capacity_pulistbox = pulistbox = PUListBoxNew(
 	    parent6,
@@ -659,9 +659,9 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 
 	/* GtkHBox for filesystem types list */
 	w = gtk_hbox_new(FALSE, border_minor);
-        gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
-        gtk_widget_show(w);
-        parent6 = w;
+	gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
+	gtk_widget_show(w);
+	parent6 = w;
 
 	w = gtk_label_new(
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -673,14 +673,14 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 #endif
 	);
 	gtk_box_pack_start(GTK_BOX(parent6), w, FALSE, FALSE, 0);
-        gtk_widget_show(w);
+	gtk_widget_show(w);
 
-        fm->filesystem_type_pulistbox = pulistbox = PUListBoxNew(
-            parent6,
-            80, -1  
-        );
-        GUISetWidgetTip(
-            pulistbox->da,
+	fm->filesystem_type_pulistbox = pulistbox = PUListBoxNew(
+	    parent6,
+	    80, -1  
+	);
+	GUISetWidgetTip(
+	    pulistbox->da,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Escoja el tipo de sistema de archivo para ser creado en los medios"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -688,9 +688,9 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 #else
 "Select the type of file system to be created on the media"
 #endif
-        );
-        PUListBoxMap(pulistbox);
-        pulist = PUListBoxGetPUList(pulistbox);
+	);
+	PUListBoxMap(pulistbox);
+	pulist = PUListBoxGetPUList(pulistbox);
 	i = PUListAddItem(pulist, EDV_FS_TYPE_MSDOS_NAME);
 	PUListBoxSelect(pulistbox, i);
 	i = PUListAddItem(pulist, EDV_FS_TYPE_EXT2_NAME);
@@ -901,8 +901,17 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 	parent3 = w;
 
 	fm->output_text = w = gtk_text_new(NULL, NULL);
-	editable = (GtkEditable *)w;
-	text = (GtkText *)w;
+	editable = GTK_EDITABLE(w);
+	text = GTK_TEXT(w);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "button_press_event",
+	    GTK_SIGNAL_FUNC(FormatManagerTextEventCB), fm
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "button_release_event",
+	    GTK_SIGNAL_FUNC(FormatManagerTextEventCB), fm
+	);
+	text->default_tab_width = 8;
 	gtk_text_set_editable(text, FALSE);
 	gtk_text_set_word_wrap(text, TRUE);
 	gtk_table_attach(
@@ -912,6 +921,7 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 	    GTK_EXPAND | GTK_SHRINK | GTK_FILL,
 	    0, 0
 	);
+	GUIEditableEndowPopupMenu(w, GUI_EDITABLE_POPUP_MENU_READ_ONLY);
 	fm->colormap = colormap = gtk_widget_get_colormap(w);
 	if(colormap != NULL)
 	    gdk_colormap_ref(colormap);
@@ -930,29 +940,23 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 	gtk_widget_show(parent4);
 
 
-	/* Allocate colors */
+	/* Allocate the colors */
 	c = &fm->error_color;
-	c->red = 1.0 * (guint16)-1;
-	c->green = 0.0 * (guint16)-1;
-	c->blue = 0.0 * (guint16)-1;
+	c->red = (guint16)(1.0f * (guint16)-1);
+	c->green = (guint16)(0.0f * (guint16)-1);
+	c->blue = (guint16)(0.0f * (guint16)-1);
 	gdk_colormap_alloc_color(colormap, c, TRUE, TRUE);
 
 
 
 
-
-
-
-
-
-
-	/* Vbox for buttons */
+	/* Buttons GtkVBox */
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Vbox for clear button */
+	/* Clear button GtkVBox */
 	w = gtk_vbox_new(FALSE, border_minor);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
