@@ -81,7 +81,9 @@ int main(int argc, char *argv[])
 	signal(SIGCONT, FormatManagerSignalCB);
 	signal(SIGPIPE, FormatManagerSignalCB);
 
-#define DO_FREE_LOCALS	{	\
+#define CLEANUP_RETURN(_v_)	{	\
+					\
+ return(_v_);				\
 }
 
 	/* Parse arguments */
@@ -100,8 +102,7 @@ int main(int argc, char *argv[])
 	    )
 	    {
 		g_print("%s", PROG_HELP_MESG);
-		DO_FREE_LOCALS
-		return(0);
+		CLEANUP_RETURN(0);
 	    }
 	    /* Version */
 	    else if(!g_strcasecmp(arg, "--version") ||
@@ -109,8 +110,7 @@ int main(int argc, char *argv[])
 	    )
 	    {
 		g_print("%s %s\n%s", PROG_NAME, PROG_VERSION, PROG_COPYRIGHT);
-		DO_FREE_LOCALS
-		return(0);
+		CLEANUP_RETURN(0);
 	    }
 	    /* Auto start */
 	    else if(!g_strcasecmp(arg, "--start") ||
@@ -147,8 +147,7 @@ int main(int argc, char *argv[])
 "-%c: Unsupported argument.\n",
 			    c  
 			);
-			DO_FREE_LOCALS
-			return(2);
+			CLEANUP_RETURN(2);
 		    }
 		    v++;
 		}
@@ -164,8 +163,7 @@ int main(int argc, char *argv[])
 "%s: Unsupported argument.\n",
 		    arg
 		);
-		DO_FREE_LOCALS
-		return(2);
+		CLEANUP_RETURN(2);
 	    }
 	}
 
@@ -177,8 +175,7 @@ int main(int argc, char *argv[])
 	    if(!gtk_init_check(&argc, &argv))
 	    {
 		g_printerr("Unable to initialize GTK.\n");
-		DO_FREE_LOCALS
-		return(1);
+		CLEANUP_RETURN(1);
 	    }
 	    initialized_gtk = TRUE;
 	}
@@ -334,8 +331,6 @@ program again.",
 	/* Reset the DND Icon */
 	GUIDNDSetDragIcon(NULL, NULL, 0, 0);
 
-	DO_FREE_LOCALS
-
-	return(0);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(0);
+#undef CLEANUP_RETURN
 }
