@@ -22,6 +22,9 @@
 gint FSCKManagerButtonPressEventCB(
 	GtkWidget *widget, GdkEventButton *button, gpointer data
 );
+gint FSCKManagerTextEventCB(
+	GtkWidget *widget, GdkEvent *event, gpointer data
+);
 gint FSCKManagerDiskIconExposeCB(
 	GtkWidget *widget, GdkEventExpose *expose, gpointer data
 );
@@ -136,6 +139,136 @@ gint FSCKManagerButtonPressEventCB(
 	return(status);
 }
 
+/*
+ *	GtkText event signal callback.
+ */
+gint FSCKManagerTextEventCB(
+	GtkWidget *widget, GdkEvent *event, gpointer data
+)
+{
+	gint status = FALSE;
+	gint etype;
+	GdkEventConfigure *configure;
+	GdkEventButton *button;
+	GtkText *text;
+	fsck_manager_struct *fm = FSCK_MANAGER(data);
+	if((widget == NULL) || (event == NULL) || (fm == NULL))
+	    return(status);
+
+	etype = (gint)event->type;
+	text = GTK_TEXT(widget);  
+
+	switch(etype)
+	{
+	  case GDK_CONFIGURE:
+	    configure = (GdkEventConfigure *)event;
+/*
+	    if(widget->window != NULL)
+	    {
+		GdkWindow *window = widget->window;
+		gdk_window_set_cursor(
+		    window,
+		    (tv->busy_count > 0) ?
+			tv->busy_cur : tv->text_cur
+		);
+		status = TRUE;
+	    }
+ */
+	    break;
+
+	  case GDK_BUTTON_PRESS:
+	    button = (GdkEventButton *)event;
+	    switch(button->button)
+	    {
+	      case GDK_BUTTON4:
+		/* Scroll up */
+		if(text->vadj != NULL)
+		{
+		    GtkAdjustment *adj = text->vadj;
+		    const gfloat inc = MAX(
+			(0.25f * adj->page_size),
+			adj->step_increment
+		    );
+		    gfloat v = adj->value - inc;
+		    if(v > (adj->upper - adj->page_size))
+			v = adj->upper - adj->page_size;
+		    if(v < adj->lower)
+			v = adj->lower;
+		    gtk_adjustment_set_value(adj, v);
+		}
+		/* Need to mark the GtkText button as 0 or else it will
+		 * keep marking
+		 */
+		GTK_TEXT(widget)->button = 0;
+		gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_press_event"
+		);
+		status = TRUE;
+		break;
+
+	      case GDK_BUTTON5:
+		/* Scroll down */
+		if(text->vadj != NULL)
+		{
+		    GtkAdjustment *adj = text->vadj;
+		    const gfloat inc = MAX(
+			(0.25f * adj->page_size),
+			adj->step_increment
+		    );
+		    gfloat v = adj->value + inc;
+		    if(v > (adj->upper - adj->page_size))
+			v = adj->upper - adj->page_size;
+		    if(v < adj->lower)
+			v = adj->lower;
+		    gtk_adjustment_set_value(adj, v);
+		}
+		/* Need to mark the GtkText button as 0 or else it will
+		 * keep marking
+		 */
+		text->button = 0;
+		gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_press_event"
+		);
+		status = TRUE;
+		break;
+	    }
+	    break;
+
+	  case GDK_BUTTON_RELEASE:
+	    button = (GdkEventButton *)event;
+	    switch(button->button)
+	    {
+	      case GDK_BUTTON4:
+		/* Need to mark the GtkText button as 0 or else it will
+		 * keep marking
+		 */
+		text->button = 0;
+		gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_release_event"
+		);
+		status = TRUE;
+		break;
+	      case GDK_BUTTON5:
+		/* Need to mark the GtkText button as 0 or else it will
+		 * keep marking
+		 */
+		text->button = 0;
+		gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_release_event"
+		);
+		status = TRUE;
+		break;
+	    }
+	    break;
+	}
+
+	return(status);
+}
+
 /*
  *	Redraws FSCK Manager's disk animation icon.
  */
