@@ -766,8 +766,17 @@ tiempo que verifica)"
 	parent3 = w;
 
 	fm->output_text = w = gtk_text_new(NULL, NULL);
-	editable = (GtkEditable *)w;
-	text = (GtkText *)w;
+	editable = GTK_EDITABLE(w);
+	text = GTK_TEXT(w);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "button_press_event",
+	    GTK_SIGNAL_FUNC(FSCKManagerTextEventCB), fm
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "button_release_event",
+	    GTK_SIGNAL_FUNC(FSCKManagerTextEventCB), fm
+	);
+	text->default_tab_width = 8;
 	gtk_text_set_editable(text, FALSE);
 	gtk_text_set_word_wrap(text, TRUE);
 	gtk_table_attach(
@@ -777,6 +786,7 @@ tiempo que verifica)"
 	    GTK_EXPAND | GTK_SHRINK | GTK_FILL,
 	    0, 0
 	);
+        GUIEditableEndowPopupMenu(w, GUI_EDITABLE_POPUP_MENU_READ_ONLY);
 	fm->colormap = colormap = gtk_widget_get_colormap(w);
 	if(colormap != NULL)
 	    gdk_colormap_ref(colormap);
