@@ -217,6 +217,10 @@ typedef enum {
 { if((_p_) != NULL) gdk_font_ref(_p_); }
 #define GDK_FONT_UNREF(_p_)	\
 { if((_p_) != NULL) gdk_font_unref(_p_); }
+#define GDK_FONT_GET_FONT_NAME_SIZE(_p_)	(	\
+ ((_p_) != NULL) ?					\
+  (((_p_)->ascent + (_p_)->descent) - 2) : 0		\
+)
 #define GDK_COLORMAP_REF(_p_)	\
 { if((_p_) != NULL) gdk_colormap_ref(_p_); }
 #define GDK_COLORMAP_UNREF(_p_)	\
@@ -575,10 +579,15 @@ extern gchar *GUIDDEGetString(
 
 
 /* Drag & Drop Utilities */
+extern void GUIDNDSetSrcTypes(
+	GtkWidget *w,
+	const GtkTargetEntry *types_list, const gint ntypes,
+	const GdkDragAction actions,
+	const GdkModifierType buttons
+);
 extern void GUIDNDSetSrc(
 	GtkWidget *w,
-	const GtkTargetEntry *target_entry,
-	const gint ntarget_entries,
+	const GtkTargetEntry *types_list, const gint ntypes,
 	const GdkDragAction actions,
 	const GdkModifierType buttons,
 	void (*drag_begin_cb)(
@@ -603,8 +612,7 @@ extern void GUIDNDSetSrc(
 );
 extern void GUIDNDSetTar(
 	GtkWidget *w,
-	const GtkTargetEntry *target_entry,
-	const gint ntarget_entries,
+	const GtkTargetEntry *types_list, const gint ntypes,
 	const GdkDragAction actions,
 	const GdkDragAction default_action_same,
 	const GdkDragAction default_action,
@@ -617,6 +625,13 @@ extern void GUIDNDSetTar(
 	),
 	gpointer drag_data_received_data
 );
+extern void GUIDNDSetTarTypes(
+	GtkWidget *w,
+	const GtkTargetEntry *types_list, const gint ntypes,
+	const GdkDragAction actions,
+	const GdkDragAction default_action_same,
+	const GdkDragAction default_action
+);
 extern void GUIDNDSetDragIcon(
 	GdkPixmap *pixmap, GdkBitmap *mask,
 	const gint hot_x, const gint hot_y
