@@ -37,8 +37,12 @@ Usage: hedit [path] [options] [GUI_options]\n\
                                 the position must be a positive integer\n\
                                 value or -1 for end of the data.\n\
         -a                      Same as --address.\n\
+\n\
+        --view-font-name <s>    Sets the view font. This font must be a\n\
+                                fixed-width font.\n\
+\n\
         --help                  Prints (this) help screen and exits.\n\
-        --version               Prints version information and exits.\n\
+        --version               Prints the version information and exits.\n\
 \n\
     The [GUI_options] can be any options standard to your GUI,\n\
     consult your GUI's manual for available options.\n\
@@ -46,11 +50,11 @@ Usage: hedit [path] [options] [GUI_options]\n\
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
 #define PROG_HELP_MESG	"\
-El uso: hedit <file> [options] [GUI_options]\n\
+El uso: hedit [path] [options] [GUI_options]\n\
 \n\
-    <file> specifies the file to edit.\n\
+    The [path] pecifies the path to the file to open at startup.\n\
 \n\
-    [options] puede ser cualquiera de lo Siguiente:\n\
+    The [options] puede ser cualquiera de lo Siguiente:\n\
 \n\
         --address <address>     La posicin fija de la direccin en inicio.\n\
         --help                  Pantalla de ayuda de Impresiones (esto) de ayuda y salidas.\n\
@@ -62,11 +66,11 @@ El uso: hedit <file> [options] [GUI_options]\n\
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 #define PROG_HELP_MESG  "\
-Usage: hedit <file> [options] [GUI_options]\n\
+Usage: hedit [path] [options] [GUI_options]\n\
 \n\
-    <file> specifies the file to edit.\n\
+    The [path] pecifies the path to the file to open at startup.\n\
 \n\
-    [options] peut tre n'importe quel du suivre:\n\
+    The [options] peut tre n'importe quel du suivre:\n\
 \n\
         --address <address>     L'adresse initiale au dmarrage.\n\
         --help                  Affiche (ceci) cran d'aide et sort.\n\
@@ -78,6 +82,12 @@ Usage: hedit <file> [options] [GUI_options]\n\
 #endif
 
 
+/*
+ *	Widget Names:
+ */
+#define HEDIT_TOPLEVEL_WIDGET_NAME	"hedit"
+#define HEDIT_HVIEW_WIDGET_NAME		"hedit-hex-view"
+
 
 /*
  *      Drag and drop target type names and info values:
