@@ -15,9 +15,9 @@
 #include "../cdialog.h"
 #include "../fb.h"
 #include "../pdialog.h"
-#include "../lib/endeavour2.h"
+#include "../ascii_chart_dlg.h"
 #include "../hview.h"
-#include "ascii_chart_dlg.h"
+#include "../lib/endeavour2.h"
 #include "config.h"
 
 #include "../images/icon_edit_48x48.xpm"
@@ -74,9 +74,24 @@ typedef struct {
 #define HEDIT(p)	((hedit_struct *)(p))
 
 
-static void HViewSignalCB(int s);
+/* Callbacks */
+static void HEditSignalCB(int s);
+
+static void HEditFileSelectorCreatedCB(
+        const gchar *path, gpointer data
+);
+static void HEditFileSelectorModifiedCB(
+        const gchar *old_path,
+        const gchar *new_path,
+        gpointer data
+);
+static void HEditFileSelectorDeletedCB(
+        const gchar *path, gpointer data
+);
+
 static gint HEditDeleteEventCB(GtkWidget *widget, GdkEvent *event, gpointer data);
 static gint HEditKeyEventCB(GtkWidget *widget, GdkEventKey *key, gpointer data);
+
 static void HEditHViewChangedCB(hview_struct *hv, gpointer data);
 static void HEditHViewSelectCB(
 	hview_struct *hv, int start_pos, int end_pos, gpointer data
@@ -84,11 +99,13 @@ static void HEditHViewSelectCB(
 static void HEditHViewEditModeChangedCB(
 	hview_struct *hv, hview_edit_mode edit_mode, gpointer data
 );
+
 static void HEditDNDDragReceivedCB(
 	GtkWidget *widget, GdkDragContext *dc, gint x, gint y,
 	GtkSelectionData *selection_data, guint info, guint t,
 	gpointer data
 );
+
 static void HEditNewCB(GtkWidget *widget, gpointer data);
 static void HEditOpenCB(GtkWidget *widget, gpointer data);
 static void HEditSaveCB(GtkWidget *widget, gpointer data);
@@ -188,7 +205,7 @@ saved, do you want to save those changes?", \
 /*
  *	UNIX signal handler.
  */
-static void HViewSignalCB(int s)
+static void HEditSignalCB(int s)
 {
 	switch(s)
 	{
@@ -200,6 +217,46 @@ static void HViewSignalCB(int s)
 	}
 }
 
+
+/*
+ *      File selector created callback.
+ */
+static void HEditFileSelectorCreatedCB(
+        const gchar *path, gpointer data
+)
+{
+        edv_context_struct *ctx = EDV_CONTEXT(data);
+        EDVNotifyQueueObjectAdded(ctx, path);
+        EDVContextFlush(ctx);
+}
+
+/*
+ *      File selector changed callback.
+ */
+static void HEditFileSelectorModifiedCB(
+        const gchar *old_path,
+        const gchar *new_path,
+        gpointer data
+)
+{
+        edv_context_struct *ctx = EDV_CONTEXT(data);
+        EDVNotifyQueueObjectModified(ctx, old_path, new_path);
+        EDVContextFlush(ctx);
+}
+
+/*
+ *      File selector deleted callback.
+ */
+static void HEditFileSelectorDeletedCB(
+        const gchar *path, gpointer data
+)
+{
+        edv_context_struct *ctx = EDV_CONTEXT(data);
+        EDVNotifyQueueObjectRemoved(ctx, path);
+        EDVContextFlush(ctx);
+}
+
+
 /*
  *	Hex Editor toplevel GtkWindow "delete_event" callback.
  */
@@ -1899,7 +1956,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 	    DO_ADD_MENU_ITEM_LABEL
 
 	    icon = NULL;
-	    label = "ASCII Chart";
+	    label = "ASCII Chart...";
 	    accel_key = GDK_F10;
 	    accel_mods = 0;
 	    func_cb = HEditASCIIChartCB;
@@ -2079,22 +2136,22 @@ int main(int argc, char *argv[])
 
 	/* Set up signal callbacks */
 #ifdef SIGINT
-	signal(SIGINT, HViewSignalCB);
+	signal(SIGINT, HEditSignalCB);
 #endif
 #ifdef SIGTERM
-	signal(SIGTERM, HViewSignalCB);
+	signal(SIGTERM, HEditSignalCB);
 #endif
 #ifdef SIGSEGV
-	signal(SIGSEGV, HViewSignalCB);
+	signal(SIGSEGV, HEditSignalCB);
 #endif
 #ifdef SIGSTOP
-	signal(SIGSTOP, HViewSignalCB);
+	signal(SIGSTOP, HEditSignalCB);
 #endif
 #ifdef SIGCONT
-	signal(SIGCONT, HViewSignalCB);
+	signal(SIGCONT, HEditSignalCB);
 #endif
 #ifdef SIGPIPE
-	signal(SIGPIPE, HViewSignalCB);
+	signal(SIGPIPE, HEditSignalCB);
 #endif
 
 	/* Handle for arguments */
@@ -2232,19 +2289,30 @@ int main(int argc, char *argv[])
 	    initialized_gtk = TRUE;
 	}
 
-	/* Initialize GDK RGB buffers system */
+	/* Initialize the GDK RGB buffers system */
 	gdk_rgb_init();
 
-	/* Initialize dialogs */
+	/* Initialize the dialogs */
 	FPromptInit();
 	CDialogInit();
 	FileBrowserInit();
 	PDialogInit();
 
-	/* Initialize Endeavour context */
+	/* Initialize the Endeavour context */
 	ctx = EDVContextNew();
 	EDVContextLoadConfigurationFile(ctx, NULL);
 
+        /* Set the file selector callbacks */
+        FileBrowserSetObjectCreatedCB(
+            HEditFileSelectorCreatedCB, ctx
+        );
+        FileBrowserSetObjectModifiedCB(
+            HEditFileSelectorModifiedCB, ctx
+        );
+        FileBrowserSetObjectDeletedCB(
+            HEditFileSelectorDeletedCB, ctx
+        );
+
 
 	/* Begin creating the HEdit window */
 	he = HEDIT(g_malloc0(sizeof(hedit_struct)));
