@@ -109,36 +109,44 @@ void EDVImbrMountBarGoToCB(
 
 /* Find Bar Callbacks */
 const gchar *EDVImbrFindBarLocationCB(
-	edv_findbar_struct *fb, gpointer data
+	edv_find_bar_struct *fb,
+	gpointer data
+);
+void EDVImbrFindBarStartCB(
+	edv_find_bar_struct *fb,
+	gpointer data
 );
-void EDVImbrFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 void EDVImbrFindBarEndCB(
-	edv_findbar_struct *fb, gint total_matches, gpointer data
+	edv_find_bar_struct *fb,
+	const gint nmatches,
+	gpointer data
 );
 void EDVImbrFindBarMatchCB(
-	const gchar *path, const struct stat *lstat_buf,
-	const gchar *excerpt, gint line_index,
+	const gchar *path,
+	struct stat *lstat_buf,
+	const gchar *excerpt,
+	const gint line_index,
 	gpointer data
 );
 
 /* Status Bar Callbacks */
 void EDVImbrStatusMessageCB(const gchar *message, gpointer data);
-void EDVImbrStatusProgressCB(gfloat progress, gpointer data);
+void EDVImbrStatusProgressCB(const gfloat progress, gpointer data);
 
 /* Write Protect Changed Callback */
 void EDVImbrWriteProtectChangedCB(
-	edv_imbr_struct *imbr, gboolean state
+	edv_imbr_struct *imbr, const gboolean state
 );
 
 /* Object Callbacks */
 void EDVImbrObjectAddedNotifyCB(
 	edv_imbr_struct *imbr, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVimbrObjectModifiedNotifyCB(
 	edv_imbr_struct *imbr, const gchar *path,
 	const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVImbrObjectRemovedNotifyCB(
 	edv_imbr_struct *imbr, const gchar *path
@@ -147,16 +155,19 @@ void EDVImbrObjectRemovedNotifyCB(
 /* Mount/Unmount Callback */
 void EDVImbrMountNotifyCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev,
-	gboolean is_mounted
+	const gint dev_num, edv_device_struct *dev,
+	const gboolean is_mounted
 );
 
 /* Recycled Object Callbacks */
 void EDVImbrRecycledObjectAddedNotifyCB(
-	edv_imbr_struct *imbr, guint index
+	edv_imbr_struct *imbr, const guint index
+);
+void EDVImbrRecycledObjectModifiedNotifyCB(
+	edv_imbr_struct *imbr, const guint index
 );
 void EDVImbrRecycledObjectRemovedNotifyCB(
-	edv_imbr_struct *imbr, guint index
+	edv_imbr_struct *imbr, const guint index
 );
 
 /* Reconfigured Callback */
@@ -165,27 +176,29 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr);
 /* MIME Type Callbacks */
 void EDVImbrMimeTypeAddedCB(
 	edv_imbr_struct *imbr,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 );
 void EDVImbrMimeTypeModifiedCB(
 	edv_imbr_struct *imbr,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 );
 void EDVImbrMimeTypeRemovedCB(
-	edv_imbr_struct *imbr, gint mt_num
+	edv_imbr_struct *imbr,
+	const gint mt_num
 );
 
 /* Device Callbacks */
 void EDVImbrDeviceAddedCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 );
 void EDVImbrDeviceModifiedCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 );
 void EDVImbrDeviceRemovedCB(
-	edv_imbr_struct *imbr, gint dev_num
+	edv_imbr_struct *imbr,
+	const gint dev_num
 );
 
 
@@ -202,7 +215,7 @@ void EDVImbrDeviceRemovedCB(
 
 
 /*
- *	Image Browser command "destroy" signal callback.
+ *	Command "destroy" signal callback.
  */
 void EDVImbrCmdDestroyCB(gpointer data)
 {
@@ -218,7 +231,7 @@ void EDVImbrCmdDestroyCB(gpointer data)
 }
 
 /*
- *	Image Browser thumbs list "destroy" signal callback.
+ *	Thumbs list "destroy" signal callback.
  */
 void EDVImbrTListItemDestroyCB(gpointer data)
 {
@@ -227,7 +240,7 @@ void EDVImbrTListItemDestroyCB(gpointer data)
 
 
 /*
- *	Image Browser toplevel GtkWidget "delete_event" signal callback.
+ *	Toplevel GtkWidget "delete_event" signal callback.
  */
 gint EDVImbrDeleteEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
@@ -246,7 +259,7 @@ gint EDVImbrDeleteEventCB(
 }
 
 /*
- *	Image Browser "key_press_event" or "key_release_event" signal
+ *	Any GtkWidget "key_press_event" or "key_release_event" signal
  *	callback.
  */
 gint EDVImbrKeyEventCB(
@@ -265,16 +278,13 @@ gint EDVImbrKeyEventCB(
 	if((widget == NULL) || (key == NULL) || (imbr == NULL))
 	    return(status);
 
-	if(imbr->processing)
-	    return(status);
-
-	tlist = imbr->tlist;
-	core = imbr->core;
-	if((tlist == NULL) || (core == NULL))
+	if(imbr->processing || (imbr->freeze_count > 0))
 	    return(status);
 
 	w = imbr->toplevel;
 	focus_widget = GTK_WINDOW(w)->focus_widget;
+	tlist = imbr->tlist;
+	core = imbr->core;
 	cfg_list = core->cfg_list;
 
 	etype = key->type;
@@ -282,7 +292,6 @@ gint EDVImbrKeyEventCB(
 	keyval = key->keyval;
 	state = key->state;
 
-/* Stop emit of signal */
 #define STOP_SIGNAL_EMISSION(_w_)	{	\
  gtk_signal_emit_stop_by_name(			\
   GTK_OBJECT(_w_),				\
@@ -333,9 +342,9 @@ gint EDVImbrKeyEventCB(
 		 */
 		if(isalnum((int)keyval) && is_press)
 		{
-                    const gboolean backwards = (state & GDK_MOD1_MASK) ? TRUE : FALSE;
-                    const gint start_thumb_num = (backwards) ?
-                        (tlist->total_thumbs - 1) : 0;
+		    const gboolean backwards = (state & GDK_MOD1_MASK) ? TRUE : FALSE;
+		    const gint start_thumb_num = (backwards) ?
+			(tlist->total_thumbs - 1) : 0;
 
 		    TListFreeze(tlist);
 		    EDVTListSeekCharacter(
@@ -353,12 +362,13 @@ gint EDVImbrKeyEventCB(
 	    }
 	}
 
-	return(status);
 #undef STOP_SIGNAL_EMISSION
+
+	return(status);
 }
 
 /*
- *	Image Browser GtkWidget "button_press_event" signal callback.
+ *	Any GtkWidget "button_press_event" signal callback.
  */
 gint EDVImbrButtonPressEventCB(
 	GtkWidget *widget, GdkEventButton *button, gpointer data
@@ -374,7 +384,7 @@ gint EDVImbrButtonPressEventCB(
 	if((widget == NULL) || (button == NULL) || (imbr == NULL))
 	    return(status);
 
-	if(imbr->processing)
+	if(imbr->processing || (imbr->freeze_count > 0))
 	    return(status);
 
 	tlist = imbr->tlist;
@@ -383,7 +393,10 @@ gint EDVImbrButtonPressEventCB(
 	etype = (gint)button->type;
 	state = button->state;
 
-	/* Event occured on the thumbs list? */
+	/* Check which widget this event is for
+	 *
+	 * Thumbs List
+	 */
 	if(widget == tlist->list_da)
 	{
 	    gint	thumb_num = -1, total_selected_thumbs = 0,
@@ -413,7 +426,7 @@ gint EDVImbrButtonPressEventCB(
 	    /* Handle by button number */
 	    switch(button->button)
 	    {
-	      case 3:
+	      case GDK_BUTTON3:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 		    /* Select item before mapping menu? */
@@ -444,7 +457,7 @@ gint EDVImbrButtonPressEventCB(
 		status = TRUE;
 		break;
 
-	      case 2:
+	      case GDK_BUTTON2:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 		    if(thumb_num > -1)
@@ -453,7 +466,7 @@ gint EDVImbrButtonPressEventCB(
 		status = TRUE;
 		break;
 
-	      case 1:
+	      case GDK_BUTTON1:
 		/* Double click? */
 		if(etype == GDK_2BUTTON_PRESS)
 		{
@@ -470,12 +483,12 @@ gint EDVImbrButtonPressEventCB(
 		break;
 	    }
 	}
-	/* Event occured on the image viewer? */
+	/* ImgView */
 	else if(widget == (GtkWidget *)ImgViewGetViewWidget(imbr->imgview))
 	{
 	    switch(button->button)
 	    {
-	      case 3:
+	      case GDK_BUTTON3:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 #if 0
@@ -495,7 +508,7 @@ gint EDVImbrButtonPressEventCB(
 		status = TRUE;
 		break;
 
-	      case 1:
+	      case GDK_BUTTON1:
 		/* Double click? */
 		if(etype == GDK_2BUTTON_PRESS)
 		{
@@ -714,13 +727,34 @@ void EDVImbrTListSelectCB(
 			break;
 		    }
 
-		    /* Set status bar message */
+		    /* Set the status bar message */
 		    if(nselected > 1)
-			s = g_strdup_printf(
-			    "%s objects selected",
-			    EDVSizeStrDelim(nselected)
+		    {
+			gulong total_size = 0l;
+			edv_object_struct *obj;
+			GList *glist = tlist->selection;
+			while(glist != NULL)
+			{
+			    obj = EDV_OBJECT(TListGetThumbData(
+				tlist, (gint)glist->data
+			    ));
+			    if(obj != NULL)
+				total_size += obj->size;
+			    glist = g_list_next(glist);
+			}
+			g_free(size_str);
+			size_str = g_strdup_printf(
+			    "%s %s",
+			    EDVSizeStrDelim(total_size),
+			    (total_size == 1l) ? "byte" : "bytes"
 			);
-		    else if(!strcmp(obj->name, ".."))
+			s = g_strdup_printf(
+			    "%s objects selected (totaling %s)",
+			    EDVSizeStrDelim(nselected),
+			    size_str
+			);
+		    }
+		    else if(!strcmp((const char *)obj->name, ".."))
 			s = g_strdup_printf(
 			    "Parent directory selected"
 			);
@@ -814,11 +848,33 @@ void EDVImbrTListUnselectCB(
 
 	    /* Update the status bar message */
 	    if(nselected > 0)
-		s = g_strdup_printf(
-		    "%s %s selected",
-		    EDVSizeStrDelim(nselected),
-		    (nselected == 1) ? "object" : "objects"
+	    {
+		gchar *size_str;
+		gulong total_size = 0l;
+		edv_object_struct *obj;
+		GList *glist = tlist->selection;
+		while(glist != NULL)
+		{
+		    obj = EDV_OBJECT(TListGetThumbData(
+			tlist, (gint)glist->data
+		    ));
+		    if(obj != NULL)
+			total_size += obj->size;
+		    glist = g_list_next(glist);
+		}
+		size_str = g_strdup_printf(
+		    "%s %s",
+		    EDVSizeStrDelim(total_size),
+		    (total_size == 1l) ? "byte" : "bytes"
 		);
+		s = g_strdup_printf(
+		    "%s %s selected (totaling %s)",
+		    EDVSizeStrDelim(nselected),
+		    (nselected == 1) ? "object" : "objects",
+		    size_str
+		);
+		g_free(size_str);
+	    }
 	    else
 		s = STRDUP("No objects selected");
 	    EDVStatusBarMessage(
@@ -1547,7 +1603,8 @@ extern void EDVImbrMountBarGoToCB(
  *	Find Bar get current location callback.
  */
 const gchar *EDVImbrFindBarLocationCB(
-	edv_findbar_struct *fb, gpointer data
+	edv_find_bar_struct *fb,
+	gpointer data
 )
 {
 	return(EDVImbrCurrentLocation(EDV_IMBR(data)));
@@ -1556,7 +1613,7 @@ const gchar *EDVImbrFindBarLocationCB(
 /*
  *	Find Bar start find callback.
  */
-void EDVImbrFindBarStartCB(edv_findbar_struct *fb, gpointer data)
+void EDVImbrFindBarStartCB(edv_find_bar_struct *fb, gpointer data)
 {
 	tlist_struct *tlist;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
@@ -1564,8 +1621,6 @@ void EDVImbrFindBarStartCB(edv_findbar_struct *fb, gpointer data)
 	    return;
 
 	tlist = imbr->tlist;
-	if(tlist == NULL)
-	    return;
 
 	EDVImbrSetBusy(imbr, TRUE);
 
@@ -1580,7 +1635,9 @@ void EDVImbrFindBarStartCB(edv_findbar_struct *fb, gpointer data)
  *	Find Bar end find callback.
  */
 void EDVImbrFindBarEndCB(
-	edv_findbar_struct *fb, gint total_matches, gpointer data
+	edv_find_bar_struct *fb,
+	const gint nmatches,
+	gpointer data
 )
 {
 	edv_imbr_struct *imbr = EDV_IMBR(data);
@@ -1595,8 +1652,10 @@ void EDVImbrFindBarEndCB(
  *	Find Bar match callback.
  */
 void EDVImbrFindBarMatchCB(
-	const gchar *path, const struct stat *lstat_buf,
-	const gchar *excerpt, gint line_index,
+	const gchar *path,
+	struct stat *lstat_buf,
+	const gchar *excerpt,
+	const gint line_index,
 	gpointer data
 )
 {
@@ -1607,8 +1666,6 @@ void EDVImbrFindBarMatchCB(
 	    return;
 
 	tlist = imbr->tlist;
-	if(tlist == NULL)
-	    return;
 
 	thumb_num = EDVImbrTListFindThumbByPath(imbr, path);
 	if((thumb_num >= 0) && (thumb_num < tlist->total_thumbs))
@@ -1635,7 +1692,7 @@ void EDVImbrStatusMessageCB(const gchar *message, gpointer data)
 /*
  *	Status progress callback.
  */
-void EDVImbrStatusProgressCB(gfloat progress, gpointer data)
+void EDVImbrStatusProgressCB(const gfloat progress, gpointer data)
 {
 	edv_imbr_struct *imbr = EDV_IMBR(data);
 	if(imbr == NULL)
@@ -1649,7 +1706,7 @@ void EDVImbrStatusProgressCB(gfloat progress, gpointer data)
  *	Write protect changed callback.
  */
 void EDVImbrWriteProtectChangedCB(
-	edv_imbr_struct *imbr, gboolean state
+	edv_imbr_struct *imbr, const gboolean state
 )
 {
 	if(imbr == NULL)
@@ -1666,7 +1723,7 @@ void EDVImbrWriteProtectChangedCB(
  */
 void EDVImbrObjectAddedNotifyCB(
 	edv_imbr_struct *imbr, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	if((imbr == NULL) || STRISEMPTY(path))
@@ -1695,7 +1752,7 @@ void EDVImbrObjectAddedNotifyCB(
 void EDVImbrObjectModifiedNotifyCB(
 	edv_imbr_struct *imbr, const gchar *path,
 	const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	gchar *cur_path;
@@ -1793,8 +1850,8 @@ void EDVImbrObjectRemovedNotifyCB(
  */
 void EDVImbrMountNotifyCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev,
-	gboolean is_mounted
+	const gint dev_num, edv_device_struct *dev,
+	const gboolean is_mounted
 )
 {
 	gchar *cur_loc, *mount_path;
@@ -1838,19 +1895,44 @@ void EDVImbrMountNotifyCB(
  *	Recycled object added callback.
  */
 void EDVImbrRecycledObjectAddedNotifyCB(
-	edv_imbr_struct *imbr, guint index
+	edv_imbr_struct *imbr, const guint index
 )
 {
 	edv_core_struct *core;
 
+	if(imbr == NULL)
+	    return;
+
+	if(imbr->processing)
+	    return;
+
+	core = imbr->core;
+
+	/* There is not much interest when a recycled object has been
+	 * added or removed. Only the menus need to be updated if there
+	 * is a change in the number of recycled objects
+	 */
+	if(core->last_recbin_items != imbr->last_recbin_items)
+	    EDVImbrUpdateMenus(imbr);
+}
+
+/*
+ *	Recycled object modified callback.
+ */
+void EDVImbrRecycledObjectModifiedNotifyCB(
+	edv_imbr_struct *imbr, const guint index
+)
+{
+	edv_core_struct *core;
 
 	if(imbr == NULL)
 	    return;
 
-	core = imbr->core;
-	if(core == NULL)
+	if(imbr->processing)
 	    return;
 
+	core = imbr->core;
+
 	/* There is not much interest when a recycled object has been
 	 * added or removed. Only the menus need to be updated if there
 	 * is a change in the number of recycled objects
@@ -1863,7 +1945,7 @@ void EDVImbrRecycledObjectAddedNotifyCB(
  *	Recycled object removed callback.
  */
 void EDVImbrRecycledObjectRemovedNotifyCB(
-	edv_imbr_struct *imbr, guint index
+	edv_imbr_struct *imbr, const guint index
 )
 {
 	edv_core_struct *core;
@@ -1871,10 +1953,11 @@ void EDVImbrRecycledObjectRemovedNotifyCB(
 	if(imbr == NULL)
 	    return;
 
-	core = imbr->core;
-	if(core == NULL)
+	if(imbr->processing)
 	    return;
 
+	core = imbr->core;
+
 	/* There is not much interest when a recycled object has been
 	 * added or removed. Only the menus need to be updated if there
 	 * is a change in the number of recycled objects
@@ -1898,7 +1981,6 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr)
 	tlist_struct *tlist;
 	imgview_struct *iv;
 
-
 	if(imbr == NULL)
 	    return;
 
@@ -1906,25 +1988,19 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr)
 	    return;
 
 	core = imbr->core;
-	if(core == NULL)
-	    return;
-
 	cfg_list = core->cfg_list;
 	standard_rcstyle = core->standard_rcstyle;
 	lists_rcstyle = core->lists_rcstyle;
 
-
 	/* Reset last state markers so that resources get explicitly
 	 * checked due to reconfigure
 	 */
 	imbr->last_recbin_items = -1;
 	imbr->last_write_protect_state = -1;
 
-
 	/* Get copy of current location path */
 	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
-
 	/* Begin updating */
 
 	/* Update the title */
@@ -2118,17 +2194,13 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr)
 	    gtk_widget_modify_style_recursive(w, standard_rcstyle);
 
 
-	/* Update menus */
 	EDVImbrUpdateMenus(imbr);
 
+        /* Notify GTK about possible size changes (such as the tool
+         * bar resizing)
+         */
+        gtk_widget_queue_resize(imbr->toplevel);
 
-	/* Notify the Image Browser's toplevel widget to resize */
-	w = imbr->toplevel;
-	if(w != NULL)
-	    gtk_widget_queue_resize(w);
-
-
-	/* Delete copy of current location path */
 	g_free(cur_loc);
 }
 
@@ -2138,7 +2210,7 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr)
  */
 void EDVImbrMimeTypeAddedCB(
 	edv_imbr_struct *imbr,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 )
 {
 	/* Treat a MIME Type added the same as it would be for a MIME
@@ -2153,7 +2225,7 @@ void EDVImbrMimeTypeAddedCB(
  */
 void EDVImbrMimeTypeModifiedCB(
 	edv_imbr_struct *imbr,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 )
 {
 	gchar *cur_loc;
@@ -2168,8 +2240,6 @@ void EDVImbrMimeTypeModifiedCB(
 
 	tlist = imbr->tlist;
 	core = imbr->core;
-	if((tlist == NULL) || (core == NULL))
-	    return;
 
 	/* Get current location */
 	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
@@ -2186,7 +2256,8 @@ void EDVImbrMimeTypeModifiedCB(
  *	MIME Type removed callback.
  */
 void EDVImbrMimeTypeRemovedCB(
-	edv_imbr_struct *imbr, gint mt_num
+	edv_imbr_struct *imbr,
+	const gint mt_num
 )
 {
 	gchar *cur_loc;
@@ -2201,13 +2272,11 @@ void EDVImbrMimeTypeRemovedCB(
 
 	tlist = imbr->tlist;
 	core = imbr->core;
-	if((tlist == NULL) || (core == NULL))
-	    return;
 
-	/* Get current location */
+	/* Get the current location */
 	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
-	/* Realize listing */
+	/* Realize the listing */
 	TListFreeze(tlist);
 	EDVImbrTListRealizeListing(imbr);
 	TListThaw(tlist);
@@ -2221,7 +2290,7 @@ void EDVImbrMimeTypeRemovedCB(
  */
 void EDVImbrDeviceAddedCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 )
 {
 	/* Treat a device added the same as it would be for a device
@@ -2235,7 +2304,7 @@ void EDVImbrDeviceAddedCB(
  */
 void EDVImbrDeviceModifiedCB(
 	edv_imbr_struct *imbr,
-	gint dev_num, edv_device_struct *dev
+	const gint dev_num, edv_device_struct *dev
 )
 {
 	gchar *cur_loc;
@@ -2250,18 +2319,15 @@ void EDVImbrDeviceModifiedCB(
 
 	tlist = imbr->tlist;
 	core = imbr->core;
-	if((tlist == NULL) || (core == NULL))
-	    return;
 
-	/* Get current location */
+	/* Get the current location */
 	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
-	/* Realize listing */
+	/* Realize the listing */
 	TListFreeze(tlist);
 	EDVImbrTListRealizeListing(imbr);
 	TListThaw(tlist);
 
-	/* Update menus */
 	EDVImbrUpdateMenus(imbr);
 
 	g_free(cur_loc);
@@ -2271,7 +2337,8 @@ void EDVImbrDeviceModifiedCB(
  *	Device removed callback.
  */
 void EDVImbrDeviceRemovedCB(
-	edv_imbr_struct *imbr, gint dev_num
+	edv_imbr_struct *imbr,
+	const gint dev_num
 )
 {
 	gchar *cur_loc;
@@ -2287,10 +2354,8 @@ void EDVImbrDeviceRemovedCB(
 
 	tlist = imbr->tlist;
 	core = imbr->core;
-	if((tlist == NULL) || (core == NULL))
-	    return;
 
-	/* Get current location */
+	/* Get the current location */
 	cur_loc = STRDUP(EDVImbrCurrentLocation(imbr));
 
 	/* Check if the Mount Bar is currently referencing this device,
@@ -2307,12 +2372,11 @@ void EDVImbrDeviceRemovedCB(
 	     */
 	}
 
-	/* Realize listing */
+	/* Realize the listing */
 	TListFreeze(tlist);
 	EDVImbrTListRealizeListing(imbr);
 	TListThaw(tlist);
 
-	/* Update menus */
 	EDVImbrUpdateMenus(imbr);
 
 	g_free(cur_loc);
