@@ -238,19 +238,21 @@ static void EDVImbrDragDataReceivedNexus(
 {
 	gint initial_confirmation_result, nurls;
 	gchar *parent_path;
-	GList *url_list;
+	GList *urls_list;
 	GtkWidget *toplevel = imbr->toplevel;
 	const url_struct *url;
 
-#define DO_FREE_LOCALS	{		\
+#define CLEANUP_RETURN	{		\
  g_free(parent_path);			\
 					\
- if(url_list != NULL) {			\
+ if(urls_list != NULL) {		\
   g_list_foreach(			\
-   url_list, (GFunc)URLDelete, NULL	\
+   urls_list, (GFunc)URLDelete, NULL	\
   );					\
-  g_list_free(url_list);		\
+  g_list_free(urls_list);		\
  }					\
+					\
+ return;				\
 }
 
 	/* Get copy of parent_path as the object's full path if the
@@ -280,16 +282,16 @@ static void EDVImbrDragDataReceivedNexus(
 	}
 
 	/* Decode the DDE buffer into a list of URLs */
-	url_list = URLDecode(
+	urls_list = URLDecode(
 	    (const guint8 *)selection_data->data,
 	    selection_data->length
 	);
-	nurls = g_list_length(url_list);
+	nurls = g_list_length(urls_list);
 
 	/* External drag source checks go here, for example sources
 	 * that have a url with a http or ftp protocol
 	 */
-	url = (url_list != NULL) ? URL(url_list->data) : NULL;
+	url = (urls_list != NULL) ? URL(urls_list->data) : NULL;
 	if((url != NULL) ? !STRISEMPTY(url->protocol) : FALSE)
 	{
 	    const gchar *protocol = url->protocol;
@@ -303,8 +305,7 @@ static void EDVImbrDragDataReceivedNexus(
 		);
 
 		/* Do not continue with standard dnd handling */
-		DO_FREE_LOCALS
-		return;
+		CLEANUP_RETURN;
 	    }
 	}
 
@@ -314,7 +315,7 @@ static void EDVImbrDragDataReceivedNexus(
 	 */
 	initial_confirmation_result = EDVConfirmDND(
 	    core, (gint)dc->action, info,
-	    toplevel, url_list,
+	    toplevel, urls_list,
 	    parent_path
 	);
 	/* User confirmed and dnd target type is a disk object? */
@@ -337,7 +338,7 @@ static void EDVImbrDragDataReceivedNexus(
 	    imbr->processing = TRUE;
 
 	    /* Iterate through URL list */
-	    for(glist = url_list;
+	    for(glist = urls_list;
 		glist != NULL;
 		glist = g_list_next(glist)
 	    )
@@ -389,22 +390,23 @@ static void EDVImbrDragDataReceivedNexus(
 		    break;
 		}
 
-		/* Check for and report any errors */
+		/* Check for errors */
 		if(error_msg == NULL)
-		    error_msg = EDVObjectOPGetError();
+		    error_msg = EDVObjectOPGetError(core);
 		if(!STRISEMPTY(error_msg))
 		{
+		    /* Report the error */
 		    EDVPlaySoundError(core);
-		    EDVMessageObjectOPError(
+		    EDVMessageError(
 			error_title,
 			error_msg,
-			path,
+			NULL,
 			toplevel
 		    );
 		}
 
 		/* Get the source object's statistics for reporting */
-		if(lstat(path, &lstat_buf))
+		if(lstat((const char *)path, &lstat_buf))
 		{
 #ifdef ENOENT
 		    /* Report the object being removed */
@@ -421,16 +423,12 @@ static void EDVImbrDragDataReceivedNexus(
 		/* Report the new object being added? */
 		if(new_path != NULL)
 		{
-		    if(!lstat(new_path, &lstat_buf))
+		    if(!lstat((const char *)new_path, &lstat_buf))
 		    {
 			objects_processed++;
 
 			imbr->processing = FALSE;
-			EDVObjectAddedEmit(
-			    core,
-			    new_path,
-			    &lstat_buf
-			);
+			EDVObjectAddedEmit(core, new_path, &lstat_buf);
 			imbr->processing = TRUE;
 		    }
 
@@ -454,7 +452,7 @@ static void EDVImbrDragDataReceivedNexus(
 	    ProgressDialogBreakQuery(TRUE);
 	    ProgressDialogSetTransientFor(NULL);
 
-	    /* Play completed sound on success */
+	    /* Play the "completed" sound on success */
 	    if(status == 0)
 		EDVPlaySoundCompleted(core);
 
@@ -478,7 +476,7 @@ static void EDVImbrDragDataReceivedNexus(
 	    imbr->processing = TRUE;
 
 	    /* Iterate through URL list */
-	    for(glist = url_list;
+	    for(glist = urls_list;
 		glist != NULL;
 		glist = g_list_next(glist)
 	    )
@@ -516,18 +514,17 @@ static void EDVImbrDragDataReceivedNexus(
 		    break;
 		}
 
-		/* Get error message (if any) describing the error that
-		 * might have occured in the above operation
-		 */
+		/* Check for errors */
 		if(error_msg == NULL)
-		    error_msg = EDVRecBinRecoverGetError();
+		    error_msg = EDVRecBinRecoverGetError(core);
 		if(!STRISEMPTY(error_msg))
 		{
+		    /* Report the error */
 		    EDVPlaySoundError(core);
-		    EDVMessageObjectOPError(
+		    EDVMessageError(
 			"Recover Recycled Object Error",
 			error_msg,
-			url->path_arg,
+			NULL,
 			toplevel
 		    );
 		}
@@ -535,17 +532,13 @@ static void EDVImbrDragDataReceivedNexus(
 		/* Object recovered? */
 		if(new_path != NULL)
 		{
-		    if(!lstat(new_path, &lstat_buf))
+		    if(!lstat((const char *)new_path, &lstat_buf))
 		    {
 			objects_recovered++;
 
 			imbr->processing = FALSE;
 			EDVRecycledObjectRemovedEmit(core, index);
-			EDVObjectAddedEmit(
-			    core,
-			    new_path,
-			    &lstat_buf
-			);
+			EDVObjectAddedEmit(core, new_path, &lstat_buf);
 			imbr->processing = TRUE;
 		    }
 
@@ -569,7 +562,7 @@ static void EDVImbrDragDataReceivedNexus(
 	    ProgressDialogBreakQuery(TRUE);
 	    ProgressDialogSetTransientFor(NULL);
 
-	    /* Play completed sound on success */
+	    /* Play the "completed" sound on success */
 	    if(status == 0)
 		EDVPlaySoundCompleted(core);
 
@@ -585,8 +578,9 @@ static void EDVImbrDragDataReceivedNexus(
 	    gboolean	preserve_directories = TRUE,
 			preserve_timestamps = TRUE;
 	    gint status, objects_extracted = 0;
-	    const gchar *arch_obj = NULL, *error_msg;
-	    GList *obj_list = NULL, *new_paths_list;
+	    const gchar *arch_path = NULL, *error_msg;
+	    gchar *password = NULL;
+	    GList *obj_list, *new_paths_list;
 
 	    EDVImbrSetBusy(imbr, TRUE);
 	    imbr->processing = TRUE;
@@ -596,13 +590,15 @@ static void EDVImbrDragDataReceivedNexus(
 	     */
 	    if(nurls >= 1)
 	    {
-		url = URL(url_list->data);
-		arch_obj = (url != NULL) ? url->path : NULL;
+		url = URL(urls_list->data);
+		arch_path = (url != NULL) ? url->path : NULL;
 	    }
 
 	    /* Query user for extract from archive options */
 	    if(!EDVArchExtractOptsGetResponse(
-		core, toplevel, arch_obj,
+		core, toplevel,
+		arch_path,
+		&password,
 		&preserve_directories,
 		&preserve_timestamps
 	    ))
@@ -610,62 +606,72 @@ static void EDVImbrDragDataReceivedNexus(
 		/* User canceled */
 		imbr->processing = FALSE;
 		EDVImbrSetBusy(imbr, FALSE);
-		DO_FREE_LOCALS
-		return;
+		g_free(password);  
+		CLEANUP_RETURN;
 	    }
 
 	    /* Get the stats for all the objects found in the archive */
+	    obj_list = NULL;
 	    if(nurls >= 2)
 	    {
 		GList *glist, *paths_list = NULL;
 
 		/* Add all the subsequent URL paths to the paths_list */
-		for(glist = g_list_next(url_list);	/* Skip the first URL */
+		for(glist = g_list_next(urls_list);	/* Skip the first URL */
 		    glist != NULL;
 		    glist = g_list_next(glist)
 		)
 		{
 		    url = URL(glist->data);
-		    if(url != NULL)
-			paths_list = g_list_append(
-			    paths_list, url->path
-			);
+		    if(url == NULL)
+			continue;
+
+		    if(url->path == NULL)
+			continue;
+
+		    paths_list = g_list_append(
+			paths_list,
+			STRDUP(url->path)
+		    );
+		}
+		if(paths_list != NULL)   
+		{
+		    obj_list = EDVArchStatList(
+			core,
+			arch_path,
+			paths_list,
+			NULL,			/* No filter */
+			password,		/* No password */
+			NULL, NULL
+		    );
+		    g_list_foreach(paths_list, (GFunc)g_free, NULL);
+		    g_list_free(paths_list);
 		}
-
-		obj_list = EDVArchStatList(
-		    core,
-		    arch_obj,
-		    paths_list,
-		    NULL,			/* No filter */
-		    NULL,			/* No password */
-		    NULL, NULL
-		);
-
-		g_list_free(paths_list);
 	    }
 
 	    /* Extract the object(s) from the archive */
 	    new_paths_list = NULL;
 	    status = EDVArchExtract(
-		core, arch_obj,
+		core, arch_path,
 		obj_list,
+		FALSE,				/* Not extract all */
 		parent_path, &new_paths_list,
-		NULL,			/* No password */
-/* TODO: Prompt for password? */
+		password,
 		toplevel, TRUE, TRUE, &yes_to_all,
 		preserve_directories,
 		preserve_timestamps
 	    );
 
-	    /* Check for and report any errors */
-	    error_msg = EDVArchExtractGetError();
+	    /* Check for errors */
+	    error_msg = EDVArchExtractGetError(core);
 	    if(!STRISEMPTY(error_msg))
 	    {
+		/* Report the error */
 		EDVPlaySoundError(core);
-		EDVMessageObjectOPError(
+		EDVMessageError(
 		    "Extract Object Error",
 		    error_msg,
-		    arch_obj,
+		    NULL,
 		    toplevel
 		);
 	    }
@@ -685,17 +691,19 @@ static void EDVImbrDragDataReceivedNexus(
 		)
 		{
 		    path = (const gchar *)glist->data;
-		    if(!STRISEMPTY(path) ? lstat(path, &lstat_buf) : TRUE)
+		    if(STRISEMPTY(path))
 			continue;
 
-		    EDVObjectAddedEmit(
-			core, path, &lstat_buf
-		    );
+		    if(lstat((const char *)path, &lstat_buf))
+			continue;
+
+		    EDVObjectAddedEmit(core, path, &lstat_buf);
 		    objects_extracted++;
 		}
 
 		imbr->processing = TRUE;
 
+		/* Delete the list of the extracted object paths */
 		g_list_foreach(new_paths_list, (GFunc)g_free, NULL);
 		g_list_free(new_paths_list);
 	    }
@@ -706,26 +714,29 @@ static void EDVImbrDragDataReceivedNexus(
 		g_list_length(obj_list), objects_extracted, status
 	    );
 
-	    /* Unmap progress dialog, it may have been mapped if any
-	     * operations occured in the above loop
-	     */
+	    /* Unmap the progress dialog */
 	    ProgressDialogBreakQuery(TRUE);
 	    ProgressDialogSetTransientFor(NULL);
 
-	    /* Play completed sound on success */
+	    g_free(password);
+
+	    /* Delete the list of archive object stats */
+	    if(obj_list != NULL)
+	    {
+		g_list_foreach(obj_list, (GFunc)EDVArchObjectDelete, NULL);
+		g_list_free(obj_list);
+	    }
+
+	    /* Play the "completed" sound on success */
 	    if(status == 0)
 		EDVPlaySoundCompleted(core);
 
 	    imbr->processing = FALSE;
 	    EDVImbrSetBusy(imbr, FALSE);
-
-	    /* Delete the list of archive object stats */
-	    g_list_foreach(obj_list, (GFunc)EDVArchObjectDelete, NULL);
-	    g_list_free(obj_list);
 	}
 
-	DO_FREE_LOCALS
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN;
+#undef CLEANUP_RETURN
 }
 
 
@@ -844,7 +855,7 @@ void EDVImbrTListDragDataGetCB(
 	gboolean data_sent = FALSE;
 	gint thumb_num;
 	edv_core_struct *core;
-	GList *glist, *url_list = NULL;
+	GList *glist, *urls_list = NULL;
 	url_struct *url;
 	tlist_struct *tlist;
 	edv_object_struct *obj;
@@ -857,8 +868,6 @@ void EDVImbrTListDragDataGetCB(
 
 	tlist = imbr->tlist;
 	core = imbr->core;
-	if((tlist == NULL) || (core == NULL))
-	    return;
 
 	EDVImbrSyncData(imbr);
 
@@ -875,14 +884,14 @@ void EDVImbrTListDragDataGetCB(
 
 	    url = URLNew();
 	    url->path = STRDUP(obj->full_path);
-	    url_list = g_list_append(url_list, url);
+	    urls_list = g_list_append(urls_list, url);
 	}
 
 	/* Encode DDE buffer from the URL list */
-	if(url_list != NULL)
+	if(urls_list != NULL)
 	{
 	    gint buf_len;
-	    guint8 *buf = URLEncode(url_list, &buf_len);
+	    guint8 *buf = URLEncode(urls_list, &buf_len);
 	    if(buf != NULL)
 	    {
 		/* Send out DND data buffer */ 
@@ -898,9 +907,12 @@ void EDVImbrTListDragDataGetCB(
 	    }
 	}
 
-	/* Delete URL list */
-	g_list_foreach(url_list, (GFunc)URLDelete, NULL);
-	g_list_free(url_list);
+	/* Delete the URLs list */
+	if(urls_list != NULL)
+	{
+	    g_list_foreach(urls_list, (GFunc)URLDelete, NULL);
+	    g_list_free(urls_list);
+	}
 
 	/* If failed to send out data then respond with error */
 	if(!data_sent)
