@@ -1328,6 +1328,7 @@ void EDVImbrOPMove(edv_imbr_struct *imbr)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_MOVE,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVImbrCurrentLocation(imbr),
 	    toplevel
@@ -1387,6 +1388,7 @@ void EDVImbrOPCopy(edv_imbr_struct *imbr)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_COPY,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVImbrCurrentLocation(imbr),
 	    toplevel
@@ -1454,6 +1456,7 @@ void EDVImbrOPLink(edv_imbr_struct *imbr)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_LINK,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVImbrCurrentLocation(imbr),
 	    toplevel
@@ -1500,8 +1503,8 @@ void EDVImbrOPChMod(edv_imbr_struct *imbr)
 {
 	GList *sel_objs_list;
 	GtkWidget *toplevel;
-	edv_core_struct *core;
 	edv_obj_op_dlg_struct *d;
+	edv_core_struct *core;
 
 	if(imbr == NULL)
 	    return;
@@ -1541,6 +1544,7 @@ void EDVImbrOPChMod(edv_imbr_struct *imbr)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_CHMOD,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVImbrCurrentLocation(imbr),
 	    toplevel
@@ -1559,8 +1563,8 @@ void EDVImbrOPChOwn(edv_imbr_struct *imbr)
 {
 	GList *sel_objs_list;
 	GtkWidget *toplevel;
-	edv_core_struct *core;
 	edv_obj_op_dlg_struct *d;
+	edv_core_struct *core;
 
 	if(imbr == NULL)
 	    return;
@@ -1600,6 +1604,7 @@ void EDVImbrOPChOwn(edv_imbr_struct *imbr)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_CHOWN,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVImbrCurrentLocation(imbr),
 	    toplevel
@@ -1612,14 +1617,14 @@ void EDVImbrOPChOwn(edv_imbr_struct *imbr)
 }
 
 /*
- *	Set Time Stamps.
+ *	Change Time Stamps.
  */
 void EDVImbrOPChTime(edv_imbr_struct *imbr)
 {
 	GList *sel_objs_list;
 	GtkWidget *toplevel;
-	edv_core_struct *core;
 	edv_obj_op_dlg_struct *d;
+	edv_core_struct *core;
 
 	if(imbr == NULL)
 	    return;
@@ -1659,6 +1664,7 @@ void EDVImbrOPChTime(edv_imbr_struct *imbr)
 	EDVObjOpDlgMapValues(
 	    d,
 	    EDV_OBJ_OP_DLG_OP_CHTIME,
+	    EDV_LOCATION_TYPE_VFS,
 	    sel_objs_list,
 	    EDVImbrCurrentLocation(imbr),
 	    toplevel
@@ -1866,12 +1872,24 @@ void EDVImbrOPProperties(edv_imbr_struct *imbr)
 
 	EDVImbrSyncData(imbr);
 
-	/* Get object from last selected thumb */
+	/* Get the selected object */
 	obj = EDV_OBJECT(TListGetThumbData(
 	    imbr->tlist, imbr->tlist_selected_thumb
 	));
-	if(obj != NULL)
-	    EDVNewPropertiesDialog(core, obj, toplevel);
+
+	/* No selected object? */
+	if(obj == NULL)
+	{
+	    EDVImbrSetBusy(imbr, FALSE);
+	    return;
+	}
+
+	/* Create a new properties dialog displaying the object */
+	EDVNewPropertiesDialogVFS(
+	    core,
+	    obj,
+	    toplevel
+	);
 
 	EDVImbrSetBusy(imbr, FALSE);
 }
