@@ -76,14 +76,15 @@ GList *EDVImbrTListLoadImageRGBA(
 );
 
 static void EDVImbrTListSetThumbName(
-	edv_core_struct *core, edv_imbr_struct *imbr,
-	tlist_struct *tlist, edv_object_struct *obj,
+	edv_core_struct *core,
+	edv_imbr_struct *imbr,
+	tlist_struct *tlist,
+	edv_object_struct *obj,
 	const gint thumb_num
 );
 
 static gint EDVImbrTListAppendObject(
-	edv_core_struct *core, edv_imbr_struct *imbr,
-	tlist_struct *tlist,
+	edv_imbr_struct *imbr,
 	edv_object_struct *obj
 );
 
@@ -104,7 +105,8 @@ void EDVImbrTListRealizeListing(edv_imbr_struct *imbr);
 
 /* Get Listing */
 void EDVImbrTListGetListing(
-	edv_imbr_struct *imbr, const gchar *path,
+	edv_imbr_struct *imbr,
+	const gchar *path,
 	const gboolean update_status_bar
 );
 void EDVImbrTlistClear(edv_imbr_struct *imbr);
@@ -131,18 +133,19 @@ static void EDVImbrTListFPromptRenameApplyCB(
 );
 static void EDVImbrTListFPromptRenameCancelCB(gpointer data);
 void EDVImbrTListPromptRename(
-	edv_imbr_struct *imbr, const gint thumb_num
+	edv_imbr_struct *imbr,
+	const gint thumb_num
 );
 
 /* Object Callbacks */
 void EDVImbrTListObjectAddedNotify(
 	edv_imbr_struct *imbr, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVImbrTListObjectModifiedNotify(
 	edv_imbr_struct *imbr, const gchar *path,
 	const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 );
 void EDVImbrTListObjectRemovedNotify(
 	edv_imbr_struct *imbr, const gchar *path
@@ -151,13 +154,12 @@ void EDVImbrTListObjectRemovedNotify(
 /* Mount Callbacks */
 void EDVImbrTListMountNotify(
 	edv_imbr_struct *imbr, edv_device_struct *dev,
-	gboolean is_mounted
+	const gboolean is_mounted
 );
 
 
 struct _EDVImbrTListFPromptData {
 	edv_imbr_struct	*imbr;
-	tlist_struct	*tlist;
 	gint		thumb_num;
 };
 
@@ -595,8 +597,10 @@ GList *EDVImbrTListLoadImageRGBA(
  *	Sets the text for the specified Thumb.
  */
 static void EDVImbrTListSetThumbName(
-	edv_core_struct *core, edv_imbr_struct *imbr,
-	tlist_struct *tlist, edv_object_struct *obj,
+	edv_core_struct *core,
+	edv_imbr_struct *imbr,
+	tlist_struct *tlist,
+	edv_object_struct *obj,
 	const gint thumb_num
 )
 {
@@ -821,12 +825,13 @@ static void EDVImbrTListSetThumbName(
  *	All inputs assumed valid.
  */
 static gint EDVImbrTListAppendObject(
-	edv_core_struct *core, edv_imbr_struct *imbr,
-	tlist_struct *tlist,
+	edv_imbr_struct *imbr,
 	edv_object_struct *obj
 )
 {
 	gint thumb_num;
+	tlist_struct *tlist = imbr->tlist;
+	edv_core_struct *core = imbr->core;
 
 	TListFreeze(tlist);
 
@@ -1032,7 +1037,8 @@ void EDVImbrTListRealizeListing(edv_imbr_struct *imbr)
  *	specified by path.
  */
 void EDVImbrTListGetListing(
-	edv_imbr_struct *imbr, const gchar *path,
+	edv_imbr_struct *imbr,
+	const gchar *path,
 	gboolean update_status_bar
 )
 {
@@ -1124,7 +1130,8 @@ void EDVImbrTListGetListing(
 		edv_object_struct *obj;
 #define UPDATE_PROGRESS	{				\
  if(update_status_bar && (nobjs > 0)) {			\
-  const gint progress_percent = nobjs_loaded * 100 / nobjs; \
+  const gint progress_percent = nobjs_loaded *		\
+   100 / nobjs;						\
   if(progress_percent > last_progress_percent) {	\
    EDVStatusBarProgress(				\
     sb,							\
@@ -1135,6 +1142,33 @@ void EDVImbrTListGetListing(
   }							\
  }							\
 }
+		/* Add the parent directory */
+		if(TRUE)
+		{
+		    /* Create a new object */
+		    obj = EDVObjectNew();
+		    if(obj != NULL)
+		    {
+			full_path = STRDUP(PrefixPaths(path, ".."));
+			if(full_path != NULL)
+			{
+			    EDVObjectSetPath(obj, full_path);
+			    if(!lstat((const char *)full_path, &stat_buf))
+				EDVObjectSetStat(obj, &stat_buf);
+			    EDVObjectUpdateLinkFlags(obj);
+
+			    g_free(full_path);
+			    full_path = NULL;
+			}
+
+			/* Append/transfer this object to the listing */
+			EDVImbrTListAppendObject(imbr, obj);
+
+			/* Do not count this object */
+/*			nobjs_loaded++; */
+		    }
+		}
+
 		/* Iterate through the directory contents and pick
 		 * out just the directories for this first iteration
 		 */
@@ -1156,7 +1190,9 @@ void EDVImbrTListGetListing(
 			FREE_AND_CONTINUE
 
 		    /* Skip special directory notations */
-		    if(!strcmp(name, "."))
+		    if(!strcmp((const char *)name, ".") ||
+		       !strcmp((const char *)name, "..")
+		    )
 		    {
 			nobjs_loaded++;
 /*			UPDATE_PROGRESS */
@@ -1199,10 +1235,7 @@ void EDVImbrTListGetListing(
 			const gint error_code = (gint)errno;
 			obj = EDVImbrNewErrorObject(full_path, g_strerror(error_code));
 			if(obj != NULL)
-			    EDVImbrTListAppendObject(
-				core, imbr, tlist,
-				obj
-			    );
+			    EDVImbrTListAppendObject(imbr, obj);
 			nobjs_loaded++;
 /*			UPDATE_PROGRESS */
 			g_free(names_list[i]);
@@ -1230,10 +1263,7 @@ void EDVImbrTListGetListing(
 			else
 			{
 			    /* Append/transfer this object to the listing */
-			    EDVImbrTListAppendObject(
-				core, imbr, tlist,
-				obj
-			    );
+			    EDVImbrTListAppendObject(imbr, obj);
 			}
 		    }
 
@@ -1270,7 +1300,9 @@ void EDVImbrTListGetListing(
 			FREE_AND_CONTINUE
 
 		    /* Skip special directory notations */
-		    if(!strcmp(name, "."))
+		    if(!strcmp((const char *)name, ".") ||
+                       !strcmp((const char *)name, "..")
+		    )
 			FREE_AND_CONTINUE
 
 		    /* Filter check */
@@ -1315,10 +1347,7 @@ void EDVImbrTListGetListing(
 			const gint error_code = (gint)errno;
 			obj = EDVImbrNewErrorObject(full_path, g_strerror(error_code));
 			if(obj != NULL)
-			    EDVImbrTListAppendObject(
-				core, imbr, tlist,
-				obj
-			    );
+			    EDVImbrTListAppendObject(imbr, obj);
 			nobjs_loaded++;
 /*			UPDATE_PROGRESS */
 			FREE_AND_CONTINUE
@@ -1348,10 +1377,7 @@ void EDVImbrTListGetListing(
 			else
 			{
 			    /* Append/transfer this object to the listing */
-			    EDVImbrTListAppendObject(
-				core, imbr, tlist,
-				obj
-			    );
+			    EDVImbrTListAppendObject(imbr, obj);
 			}
 		    }
 
@@ -1820,25 +1846,23 @@ static void EDVImbrTListFPromptRenameApplyCB(
 )
 {
 	gint thumb_num;
-	tlist_struct *tlist;
-	edv_status_bar_struct *sb;
 	edv_imbr_struct *imbr;
         EDVImbrTListFPromptData *d = EDV_IMBR_TLIST_FPROMPT_DATA(data);
 	if(d == NULL)
             return;
 
 	imbr = d->imbr;
-	tlist = d->tlist;
 	thumb_num = d->thumb_num;
-	sb = imbr->status_bar;
 
 	/* Inputs valid? */
-	if((imbr != NULL) && (tlist != NULL) && (thumb_num >= 0) &&
-	   (value != NULL)
-	)
+	if((imbr != NULL) && (thumb_num > -1) && (value != NULL))
 	{
 	    GtkWidget *toplevel = imbr->toplevel;
+	    tlist_struct *tlist = imbr->tlist;
+	    edv_status_bar_struct *sb = imbr->status_bar;
 	    edv_core_struct *core = imbr->core;
+
+	    /* Get the object from the selected thumb */
 	    edv_object_struct *obj = EDV_OBJECT(
 		TListGetThumbData(tlist, thumb_num)
 	    );
@@ -1960,10 +1984,12 @@ static void EDVImbrTListFPromptRenameCancelCB(gpointer data)
  *	The thumb_num specifies the thumb index.
  */
 void EDVImbrTListPromptRename(
-	edv_imbr_struct *imbr, const gint thumb_num
+	edv_imbr_struct *imbr,
+	const gint thumb_num
 )
 {
 	gint cx, cy, px, py, pwidth, pheight;
+	GtkWidget *toplevel;
 	tlist_struct *tlist;
 	edv_object_struct *obj;
 	edv_core_struct *core;
@@ -1971,11 +1997,12 @@ void EDVImbrTListPromptRename(
 	if((imbr == NULL) || (thumb_num < 0) || FPromptIsQuery())
 	    return;
 
+	toplevel = imbr->toplevel;
 	tlist = imbr->tlist;
 	core = imbr->core;
 
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core, TRUE, imbr->toplevel))
+	if(EDVCheckWriteProtect(core, TRUE, toplevel))
 	    return;
 
 	EDVImbrSyncData(imbr);
@@ -2022,17 +2049,16 @@ void EDVImbrTListPromptRename(
 	{
 	    gchar *value = STRDUP(obj->name);
 	    EDVImbrTListFPromptData *d = EDV_IMBR_TLIST_FPROMPT_DATA(
-		g_malloc0(sizeof(EDVImbrTListFPromptData))
+		g_malloc(sizeof(EDVImbrTListFPromptData))
 	    );
 	    if(d != NULL)
 	    {
 		d->imbr = imbr;
-		d->tlist = tlist;
 		d->thumb_num = thumb_num;
 	    }
 
 	    /* Map floating prompt to change values */
-	    FPromptSetTransientFor(imbr->toplevel);
+	    FPromptSetTransientFor(toplevel);
 	    FPromptSetPosition(px, py);
 	    FPromptMapQuery(
 		NULL,			/* No label */
@@ -2057,7 +2083,7 @@ void EDVImbrTListPromptRename(
  */
 void EDVImbrTListObjectAddedNotify(
 	edv_imbr_struct *imbr, const gchar *path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	gint thumb_num;
@@ -2125,10 +2151,7 @@ void EDVImbrTListObjectAddedNotify(
 		    EDVObjectSetStat(obj, lstat_buf);
 		    EDVObjectUpdateLinkFlags(obj);
 
-		    new_thumb_num = EDVImbrTListAppendObject(
-			core, imbr, tlist,
-			obj
-		    );
+		    new_thumb_num = EDVImbrTListAppendObject(imbr, obj);
 		    if(new_thumb_num > -1)
 		    {
 			/* Need to (re)queue loading process so that
@@ -2150,7 +2173,7 @@ void EDVImbrTListObjectAddedNotify(
 void EDVImbrTListObjectModifiedNotify(
 	edv_imbr_struct *imbr, const gchar *path,
 	const gchar *new_path,
-	const struct stat *lstat_buf
+	struct stat *lstat_buf
 )
 {
 	gint thumb_num;
@@ -2257,7 +2280,7 @@ void EDVImbrTListObjectRemovedNotify(
  */
 void EDVImbrTListMountNotify(
 	edv_imbr_struct *imbr, edv_device_struct *dev,
-	gboolean is_mounted
+	const gboolean is_mounted
 )
 {
 	gchar *cur_path, *mount_path;
