@@ -284,12 +284,11 @@ imgview_cropdlg_struct *ImgViewCropDlgNew(
 	{
 	    gdk_window_set_decorations(
 		window,
-		GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
-		GDK_DECOR_MINIMIZE
+		GDK_DECOR_BORDER | GDK_DECOR_TITLE
 	    );
 	    gdk_window_set_functions(
 		window,
-		GDK_FUNC_MOVE | GDK_FUNC_MINIMIZE | GDK_FUNC_CLOSE
+		GDK_FUNC_MOVE | GDK_FUNC_CLOSE
 	    );
 	    GUISetWMIcon(window, (guint8 **)icon_cut_32x32_xpm);
 	}
