@@ -69,7 +69,7 @@ static void KeymapListSetDefaultKeysCB(GtkWidget *widget, gpointer data);
 
 static gint KeymapListScanIdleCB(gpointer data);
 
-static void QueryWindowGrab(query_window_struct *qw);
+static void QueryWindowGrab(query_window_struct *qw, const gulong t);
 
 
 /* Operations */
@@ -120,27 +120,27 @@ void KeymapListSetKeyDefaultRequestCB(
 	gpointer data
 );
 gint KeymapListInsert( 
-	keymap_list_struct *kmlist, gint row,
+	keymap_list_struct *kmlist, const gint row,
 	guint8 **icon_data, const gchar *name,
-	keymap_key_struct *km			/* Shared */
+	keymap_key_struct *km			/* Transfered */
 );
 gint KeymapListAppend(
 	keymap_list_struct *kmlist,
 	guint8 **icon_data, const gchar *name,
-	keymap_key_struct *km			/* Shared */
+	keymap_key_struct *km			/* Transfered */
 );
 void KeymapListSet(
-	keymap_list_struct *kmlist, gint row,
+	keymap_list_struct *kmlist, const gint row,
 	guint8 **icon_data, const gchar *name,
-	keymap_key_struct *km			/* Shared */
+	keymap_key_struct *km			/* Transfered */
 );
 void KeymapListSetKey(
-	keymap_list_struct *kmlist, gint row,
-	keymap_key_struct *km			/* Shared */
+	keymap_list_struct *kmlist, const gint row,
+	keymap_key_struct *km			/* Transfered */
 );
 void KeymapListClear(keymap_list_struct *kmlist);
 keymap_key_struct *KeymapListGet(
-	keymap_list_struct *kmlist, gint row
+	keymap_list_struct *kmlist, const gint row
 );
 void KeymapListUpdateWidgets(keymap_list_struct *kmlist);
 void KeymapListMap(keymap_list_struct *kmlist);
@@ -626,7 +626,6 @@ static gint QueryWindowEventCB(
 			keyval, key->state, km->data
 		    );
 		    KeymapListSetKey(kmlist, row, km_new);
-		    KeymapKeyDelete(km_new);
 
 		    /* Mark that we got a response and a Keymap Key has
 		     * been set
@@ -645,15 +644,20 @@ static gint QueryWindowEventCB(
 
 	  case GDK_BUTTON_PRESS:
 	    button = (GdkEventButton *)event;
-	    /* Any button press cancels the scan */
-	    gtk_main_quit();
+	    switch(button->button)
+	    {
+	      case GDK_BUTTON1:
+		/* Cancel scan */
+		gtk_main_quit();
+		break;
+	    }
 	    status = FALSE;
 	    break;
 
 	  case GDK_BUTTON_RELEASE:
 	    button = (GdkEventButton *)event;
 	    /* Grab the Query Window */
-	    QueryWindowGrab(qw);
+	    QueryWindowGrab(qw, button->time);
 	    status = FALSE;
 	    break;
 	}
@@ -703,7 +707,7 @@ static gint KeymapListScanIdleCB(gpointer data)
 /*
  *	Grabs the Query Window.
  */
-static void QueryWindowGrab(query_window_struct *qw)
+static void QueryWindowGrab(query_window_struct *qw, const gulong t)
 {
 	GtkWidget *w = (qw != NULL) ? qw->toplevel : NULL;
 	if(w == NULL)
@@ -718,12 +722,12 @@ static void QueryWindowGrab(query_window_struct *qw)
 	    GDK_BUTTON_RELEASE_MASK,
 	    NULL,		/* Do not confine pointer */
 	    NULL,		/* Use default cursor */
-	    GDK_CURRENT_TIME
+	    (guint32)t
 	);
 	gdk_keyboard_grab(
 	    w->window,
 	    TRUE,		/* Report event relative to event's window */
-	    GDK_CURRENT_TIME
+	    (guint32)t
 	);
 }
 
@@ -759,12 +763,12 @@ static void KeymapListDoScanKey(keymap_list_struct *kmlist)
 
 	/* Create toplevel */
 	qw->toplevel = w = gtk_window_new(GTK_WINDOW_POPUP);
+	gtk_window_set_policy(GTK_WINDOW(w), FALSE, FALSE, TRUE);
 	gtk_widget_ref(w);
 	gdk_window_get_root_position(
 	    kmlist->clist->window, &x, &y
 	);
 	gtk_widget_set_uposition(w, x, y);
-	gtk_window_set_policy(GTK_WINDOW(w), FALSE, FALSE, TRUE);
 	gtk_widget_add_events(
 	    w,
 	    GDK_EXPOSURE_MASK | GDK_STRUCTURE_MASK |
@@ -858,6 +862,7 @@ static void KeymapListDoScanKey(keymap_list_struct *kmlist)
 
 	/* Create shadow */
 	qw->shadow = w = gtk_window_new(GTK_WINDOW_POPUP);
+	gtk_window_set_policy(GTK_WINDOW(w), FALSE, FALSE, TRUE);
 	gtk_widget_ref(w);
 	gdk_window_get_root_position(
 	    kmlist->clist->window, &x, &y  
@@ -873,7 +878,6 @@ static void KeymapListDoScanKey(keymap_list_struct *kmlist)
 	    GTK_OBJECT(w), "draw",
 	    GTK_SIGNAL_FUNC(QueryWindowShadowPaintCB), (GtkObject *)qw
 	);
-	gtk_window_set_policy(GTK_WINDOW(w), FALSE, FALSE, TRUE);
 	gtk_widget_realize(w);
 
 
@@ -886,7 +890,7 @@ static void KeymapListDoScanKey(keymap_list_struct *kmlist)
 
 
 	/* Grab the Query Window */
-	QueryWindowGrab(qw);
+	QueryWindowGrab(qw, GDK_CURRENT_TIME);
 
 
 	/* Push main loop level and block */
@@ -901,7 +905,7 @@ static void KeymapListDoScanKey(keymap_list_struct *kmlist)
 	/* Get response flag */
 	got_key = qw->got_key;
 
-	/* Destroy the Query Window */
+	/* Delete the Query Window */
 	GTK_WIDGET_DESTROY(qw->toplevel);
 	gtk_widget_unref(qw->toplevel);
 	GTK_WIDGET_DESTROY(qw->shadow);
@@ -1008,7 +1012,6 @@ void KeymapListClearKey(keymap_list_struct *kmlist, const gint row)
 	/* Copy/clear the Keymap Key's key sequence */
 	km_new = KeymapKeyNew(0, 0, km->data);
 	KeymapListSetKey(kmlist, _row, km_new);
-	KeymapKeyDelete(km_new);
 
 	/* Reget the Keymap Key */
 	km = KeymapListGet(kmlist, _row);
@@ -1109,7 +1112,6 @@ predefinite?",
 	    km_new = KeymapKeyCopy(km);
 	    func_cb(kmlist, km_new, func_data);
 	    KeymapListSetKey(kmlist, row, km_new);
-	    KeymapKeyDelete(km_new);
 
 	    /* Reget the Keymap Key */
 	    km = KeymapListGet(kmlist, row);
@@ -1439,7 +1441,8 @@ keymap_list_struct *KeymapListNew(
 	heading[1] = "Key Sequence";
 #endif
 	kmlist->clist = w = gtk_clist_new_with_titles(
-	    sizeof(heading) / sizeof(gchar *), heading
+	    sizeof(heading) / sizeof(gchar *),
+	    heading
 	);
 	clist = GTK_CLIST(w);
 	gtk_widget_add_events(
@@ -1483,11 +1486,19 @@ keymap_list_struct *KeymapListNew(
 	);
 	gtk_container_add(GTK_CONTAINER(parent2), w);
 	gtk_widget_realize(w);
-	gtk_clist_set_row_height(clist, KEYMAP_LIST_ROW_SPACING);
-	gtk_clist_set_column_auto_resize(clist, 0, TRUE);
-	gtk_clist_set_column_auto_resize(clist, 1, TRUE);
-	gtk_clist_set_selection_mode(clist, GTK_SELECTION_BROWSE);
 	gtk_clist_column_titles_passive(clist);
+	gtk_clist_set_column_auto_resize(clist, 0, TRUE);
+	gtk_clist_set_column_resizeable(clist, 0, TRUE);
+	gtk_clist_set_column_justification(
+	    clist, 0, GTK_JUSTIFY_LEFT
+	);
+	gtk_clist_set_column_auto_resize(clist, 1, TRUE);
+	gtk_clist_set_column_resizeable(clist, 1, TRUE);
+	gtk_clist_set_column_justification(
+	    clist, 1, GTK_JUSTIFY_LEFT
+	);
+	gtk_clist_set_selection_mode(clist, GTK_SELECTION_BROWSE);
+	gtk_clist_set_row_height(clist, KEYMAP_LIST_ROW_SPACING);
 	gtk_widget_show(w);
 
 
@@ -1802,64 +1813,97 @@ void KeymapListSetKeyDefaultRequestCB(
 
 /*
  *	Inserts an item to the Keymap List.
+ *
+ *	The kmlist specifies the Keymap List.
+ *
+ *	The row specifies the row index to insert the new item at.
+ *
+ *	The icon_data specifies the icon for the new item. If
+ *	icon_data is NULL then no icon will be set.
+ *
+ *	The name specifies the name for the new item.
+ *
+ *	The km specifies the Keymap Key which will be transfered
+ *	to the Keymap List and should not be referenced again after
+ *	this call.
+ *
+ *	Returns the new item's row index or negative on error.
  */
 gint KeymapListInsert(
-	keymap_list_struct *kmlist, gint row,
+	keymap_list_struct *kmlist, const gint row,
 	guint8 **icon_data, const gchar *name,
-	keymap_key_struct *km		/* Shared */
+	keymap_key_struct *km		/* Transfered */
 )
 {
-	gint i, columns;
+	gint i, ncolumns, new_row;
 	gchar **strv;
-	GtkCList *clist = (kmlist != NULL) ?
-	    (GtkCList *)kmlist->clist : NULL;
-	if(clist == NULL)
-	    return(-1);
+	GtkCList *clist;
 
-	columns = clist->columns;
+	if(kmlist == NULL)
+	{
+	    KeymapKeyDelete(km);
+	    return(-1);
+	}
+
+	clist = GTK_CLIST(kmlist->clist);
+	ncolumns = MAX(clist->columns, 1);
 
 	gtk_clist_freeze(clist);
 
-	/* Allocate row cell values */
-	strv = (gchar **)g_malloc0(columns * sizeof(gchar *));
-	for(i = 0; i < columns; i++)
+	/* Allocate the row cell values */
+	strv = (gchar **)g_malloc(ncolumns * sizeof(gchar *));
+	for(i = 0; i < ncolumns; i++)
 	    strv[i] = "";
 
 	/* Insert or append row */
 	if(row > -1)
-	    row = gtk_clist_insert(clist, row, strv);
+	    new_row = gtk_clist_insert(clist, row, strv);
 	else
-	    row = gtk_clist_append(clist, strv);
+	    new_row = gtk_clist_append(clist, strv);
 
-	/* Delete row cell values */
+	/* Delete the row cell values */
 	g_free(strv);
 
-	/* Failed to create new row? */
-	if(row < 0)
+	/* Failed to create the new row? */
+	if(new_row < 0)
 	{
 	    gtk_clist_thaw(clist);
+	    KeymapKeyDelete(km);
 	    return(-1);
 	}
 
 	/* Set the row cells and copy/set the Keymap Key as the row
 	 * data, this will delete the old Keymap Key (if any)
 	 */
-	KeymapListSet(kmlist, row, icon_data, name, km);
+	KeymapListSet(kmlist, new_row, icon_data, name, km);
 
 	gtk_clist_thaw(clist);
 
 	KeymapListUpdateWidgets(kmlist);
 
-	return(row);
+	return(new_row);
 }
 
 /*
  *	Appends an item to the Keymap List.
+ *
+ *	The kmlist specifies the Keymap List.
+ *
+ *	The icon_data specifies the icon for the new item. If
+ *	icon_data is NULL then no icon will be set.
+ *
+ *	The name specifies the name for the new item.
+ *
+ *	The km specifies the Keymap Key which will be transfered
+ *	to the Keymap List and should not be referenced again after
+ *	this call.
+ *
+ *	Returns the new item's row index or negative on error.
  */
 gint KeymapListAppend(
 	keymap_list_struct *kmlist,
 	guint8 **icon_data, const gchar *name,
-	keymap_key_struct *km			/* Shared */
+	keymap_key_struct *km			/* Transfered */
 )
 {
 	return(KeymapListInsert(
@@ -1872,21 +1916,42 @@ gint KeymapListAppend(
 /*
  *	Sets the Keymap Key for the specified Keymap List item and
  *	updates the Function and Key Sequence cells.
+ *
+ *	The kmlist specifies the Keymap List.
+ *
+ *	The row specifies the keymap list item.
+ *
+ *	The icon_data specifies the icon. If icon_data is NULL then no
+ *	icon will be set.
+ *
+ *	The name specifies the name for the item.
+ *
+ *	The km specifies the Keymap Key which will be transfered
+ *	to the Keymap List and should not be referenced again after
+ *	this call.
  */
 void KeymapListSet(
-	keymap_list_struct *kmlist, gint row,
+	keymap_list_struct *kmlist, const gint row,
 	guint8 **icon_data, const gchar *name,
-	keymap_key_struct *km			/* Shared */
+	keymap_key_struct *km			/* Transfered */
 )
 {
-	gint column;
-	GtkCList *clist = (kmlist != NULL) ?
-	    (GtkCList *)kmlist->clist : NULL;
-	if(clist == NULL)
-	    return;
+	gint column, ncolumns;
+	GtkCList *clist;
 
-	if((row < 0) || (row >= clist->rows))
+	if(kmlist == NULL)
+	{
+	    KeymapKeyDelete(km);
 	    return;
+	}
+
+	clist = GTK_CLIST(kmlist->clist);
+	ncolumns = MAX(clist->columns, 1);
+	if((row < 0) || (row >= clist->rows))
+	{
+	    KeymapKeyDelete(km);
+	    return;
+	}
 
 	gtk_clist_freeze(clist);
 
@@ -1937,20 +2002,37 @@ void KeymapListSet(
 /*
  *	Sets the Keymap Key for the specified Keymap List item and
  *	updates the Key Sequence cell.
+ *
+ *	The kmlist specifies the Keymap List.
+ *
+ *	The row specifies the keymap list item.
+ *
+ *	The km specifies the Keymap Key which will be transfered
+ *	to the Keymap List and should not be referenced again after
+ *	this call.
  */
 void KeymapListSetKey(
-	keymap_list_struct *kmlist, gint row,
-	keymap_key_struct *km			/* Shared */
+	keymap_list_struct *kmlist, const gint row,
+	keymap_key_struct *km			/* Transfered */
 )
 {
-	gint column;
-	GtkCList *clist = (kmlist != NULL) ?
-	    (GtkCList *)kmlist->clist : NULL;
-	if(clist == NULL)
-	    return;
+	gint column, ncolumns, nrows;
+	GtkCList *clist;
 
-	if((row < 0) || (row >= clist->rows))
+	if(kmlist == NULL)
+	{
+	    KeymapKeyDelete(km);
 	    return;
+	}
+
+	clist = GTK_CLIST(kmlist->clist);
+	ncolumns = MAX(clist->columns, 1);
+	nrows = clist->rows;
+	if((row < 0) || (row >= nrows))
+	{
+	    KeymapKeyDelete(km);
+	    return;
+	}
 
 	gtk_clist_freeze(clist);
 
@@ -2023,15 +2105,13 @@ void KeymapListSetKey(
 	    );
 	}
 
-	/* Copy/set the Keymap Key as the row data, this will delete
-	 * the old Keymap Key (if any)
-	 */
-	if(km != NULL)
-	    gtk_clist_set_row_data_full(
-		clist, row,
-		KeymapKeyCopy(km),
-		KeymapListCListDestroyCB
-	    );
+	/* Set this row's data as the Keymap Key */
+	gtk_clist_set_row_data_full(
+	    clist, row,
+	    km, KeymapListCListDestroyCB
+	);
+
+	gtk_clist_columns_autosize(clist);
 
 	gtk_clist_thaw(clist);
 }
@@ -2041,13 +2121,15 @@ void KeymapListSetKey(
  */
 void KeymapListClear(keymap_list_struct *kmlist)
 {
-	GtkCList *clist = (kmlist != NULL) ?
-	    (GtkCList *)kmlist->clist : NULL;
-	if(clist == NULL)
+	GtkCList *clist;
+
+	if(kmlist == NULL)
 	    return;
 
+	clist = GTK_CLIST(kmlist->clist);
 	gtk_clist_freeze(clist);
 	gtk_clist_clear(clist);
+	gtk_clist_columns_autosize(clist);
 	gtk_clist_thaw(clist);
 
 	KeymapListUpdateWidgets(kmlist);
@@ -2057,14 +2139,15 @@ void KeymapListClear(keymap_list_struct *kmlist)
  *	Returns the Keymap Key for the specified Keymap Key List item.
  */
 keymap_key_struct *KeymapListGet(
-	keymap_list_struct *kmlist, gint row
+	keymap_list_struct *kmlist, const gint row
 )
 {
-	GtkCList *clist = (kmlist != NULL) ?  
-	    (GtkCList *)kmlist->clist : NULL;
-	return((clist != NULL) ?
-	    KEYMAP_KEY(gtk_clist_get_row_data(clist, row)) : NULL
-	);
+	if(kmlist == NULL)
+	    return(NULL);
+
+	return(KEYMAP_KEY(gtk_clist_get_row_data(
+	    GTK_CLIST(kmlist->clist), row
+	)));
 }
 
 /*
