@@ -282,7 +282,7 @@ static guint recycle_object_iterate(
 	/* Record history */
 	EDVHistoryAppend(
 	    ctx,
-	    EDV_HISTORY_DISK_OBJECT_DELETE,
+	    EDV_HISTORY_VFS_OBJECT_DELETE,
 	    time_start, (gulong)time(NULL),
 	    recycle_status,
 	    path,
