@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 #include <sys/stat.h>
 #include <glib.h>
 
@@ -43,16 +44,16 @@ void EDVContextWait(edv_context_struct *ctx);
 void EDVContextDelete(edv_context_struct *ctx);
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -741,6 +742,7 @@ void EDVContextFlush(edv_context_struct *ctx)
  */
 void EDVContextWait(edv_context_struct *ctx)
 {
+	gint p;
 	cfg_item_struct *cfg_list;
 
 	if(ctx == NULL)
@@ -748,10 +750,30 @@ void EDVContextWait(edv_context_struct *ctx)
 
 	cfg_list = ctx->cfg_list;
 
-	while(
-	    (EDVInterPSGetLock(cfg_list) > 0) ?
-		EDVInterPSHaveCommand(cfg_list) : FALSE
-	);
+	/* Is the process running? */
+	p = EDVInterPSGetLock(cfg_list);
+	if(p > 0)
+	{
+	    const gulong time_start = time(NULL);
+	    gulong time_cur, time_delta;
+
+	    /* Wait until the commands file has been removed */
+	    while(EDVInterPSHaveCommand(cfg_list))
+	    {
+		time_cur = (gulong)time(NULL);
+		time_delta = time_cur - time_start;
+		if(time_delta > 0l)
+		{
+		    /* Resend the signal every 3 seconds */
+		    if((time_delta % 3l) == 0l)
+			EDVInterPSSendCommandNotify(cfg_list, p);
+
+		    /* Give up after 60 seconds */
+		    if(time_delta > 60l)
+			break;
+		}
+	    }
+	}
 }
 
 /*
