@@ -30,9 +30,13 @@ struct _edv_context_struct {
 	/* Configuration list */
 	cfg_item_struct	*cfg_list;
 
-        /* Devices list */
-        edv_device_struct	**device;
-        gint			total_devices;
+	/* UID & GID list */
+	GList		*uids_list,
+			*gids_list;
+
+	/* Devices list */
+	edv_device_struct	**device;
+	gint			total_devices;
 
 	/* MIME Types list */
 	edv_mime_type_struct	**mimetype;
