@@ -1,5 +1,5 @@
 /*
-                              Endeavour Device
+			      Endeavour Device
  */
 
 #ifndef EDV_DEVICE_H
@@ -19,11 +19,20 @@ typedef struct _edv_device_struct	edv_device_struct;
  *      Device Flags:
  */
 typedef enum {
-	EDV_DEVICE_MOUNTED		= (1 << 0),
-	EDV_DEVICE_READ_ONLY		= (1 << 1),
-	EDV_DEVICE_NO_UNMOUNT		= (1 << 2),
-	EDV_DEVICE_UNLISTED		= (1 << 3)	/* Do not show on
+	EDV_DEVICE_MOUNTED		= (1 << 0),	/* Device is mounted */
+	EDV_DEVICE_READ_ONLY		= (1 << 1),	/* Mount as read-only,
+							 * making all objects
+							 * on the device
+							 * read-only */
+	EDV_DEVICE_NO_UNMOUNT		= (1 << 2),	/* May not be unmounted */
+	EDV_DEVICE_UNLISTED		= (1 << 3),	/* Do not show on
 							 * "brief" listings */
+	EDV_DEVICE_NO_SCAN		= (1 << 4),	/* Do not scan this
+							 * device's contents
+							 * unless absolutely
+							 * nessisary (useful
+							 * for NFS mounted
+							 * devices) */
 } edv_device_flags;
 
 /*
@@ -207,14 +216,21 @@ struct _edv_device_struct {
 			last_check_time;	/* Last time command_check aws runned */
 
 };
+
 #define EDV_DEVICE_IS_MOUNTED(p)	(((p) != NULL) ? \
- ((p)->flags & EDV_DEVICE_MOUNTED) : FALSE)
+ (((p)->flags & EDV_DEVICE_MOUNTED) ? TRUE : FALSE) : FALSE)
+
 #define EDV_DEVICE_IS_READ_ONLY(p)	(((p) != NULL) ? \
- ((p)->flags & EDV_DEVICE_READ_ONLY) : FALSE)
+ (((p)->flags & EDV_DEVICE_READ_ONLY) ? TRUE : FALSE) : FALSE)
+
 #define EDV_DEVICE_IS_NO_UNMOUNT(p)	(((p) != NULL) ? \
- ((p)->flags & EDV_DEVICE_NO_UNMOUNT) : FALSE)
+ (((p)->flags & EDV_DEVICE_NO_UNMOUNT) ? TRUE : FALSE) : FALSE)
+
 #define EDV_DEVICE_IS_UNLISTED(p)	(((p) != NULL) ? \
- ((p)->flags & EDV_DEVICE_UNLISTED) : FALSE)
+ (((p)->flags & EDV_DEVICE_UNLISTED) ? TRUE : FALSE) : FALSE)
+
+#define EDV_DEVICE_IS_NO_SCAN(p)	(((p) != NULL) ? \
+ (((p)->flags & EDV_DEVICE_NO_SCAN) ? TRUE : FALSE) : FALSE)
 
 
 /*
