@@ -11,6 +11,7 @@ gchar **EDVGetConfigurationParameters(
 	gint *total
 );
 
+edv_get_type EDVGetType(edv_context_struct *ctx, const gchar *parm);
 gboolean EDVGetB(edv_context_struct *ctx, const gchar *parm);
 gint EDVGetI(edv_context_struct *ctx, const gchar *parm);
 glong EDVGetL(edv_context_struct *ctx, const gchar *parm);
@@ -88,6 +89,86 @@ gchar **EDVGetConfigurationParameters(
 	return(params);
 }
 
+/*
+ *	Gets the type of the configuration parameter.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
+ *
+ *	The parm specifies the configuration parameter.
+ *
+ *	Can return EDV_GET_TYPE_NONE on error.
+ */
+edv_get_type EDVGetType(edv_context_struct *ctx, const gchar *parm)
+{
+	gint i;
+	cfg_item_struct *item;
+
+	if((ctx == NULL) || STRISEMPTY(parm))
+	    return(EDV_GET_TYPE_NONE);
+
+	i = CFGItemListMatchParameter(ctx->cfg_list, parm);
+	if(i < 0)
+	    return(EDV_GET_TYPE_NONE);
+
+	item = &ctx->cfg_list[i];
+	switch(item->type)
+	{
+	  case CFG_ITEM_TYPE_NONE:
+	    return(EDV_GET_TYPE_NONE);
+	    break;
+	  case CFG_ITEM_TYPE_INT8:
+	    return(EDV_GET_TYPE_INT8);
+	    break;
+          case CFG_ITEM_TYPE_UINT8:
+	    return(EDV_GET_TYPE_UINT8);
+	    break;
+          case CFG_ITEM_TYPE_INT16:
+	    return(EDV_GET_TYPE_INT16);
+	    break;
+          case CFG_ITEM_TYPE_UINT16:
+	    return(EDV_GET_TYPE_UINT16);
+	    break;
+          case CFG_ITEM_TYPE_INT32:
+	    return(EDV_GET_TYPE_INT32);
+	    break;
+          case CFG_ITEM_TYPE_UINT32:
+	    return(EDV_GET_TYPE_UINT32);
+	    break;
+          case CFG_ITEM_TYPE_INT64:
+	    return(EDV_GET_TYPE_INT64);
+	    break;
+          case CFG_ITEM_TYPE_UINT64:
+	    return(EDV_GET_TYPE_UINT64);
+	    break;
+          case CFG_ITEM_TYPE_FLOAT:
+	    return(EDV_GET_TYPE_FLOAT);
+	    break;
+          case CFG_ITEM_TYPE_DOUBLE:
+	    return(EDV_GET_TYPE_DOUBLE);
+	    break;
+          case CFG_ITEM_TYPE_STRING:
+	    return(EDV_GET_TYPE_STRING);
+	    break;
+          case CFG_ITEM_TYPE_INTLIST:
+	    return(EDV_GET_TYPE_INTLIST);
+	    break;
+          case CFG_ITEM_TYPE_COLOR:
+	    return(EDV_GET_TYPE_COLOR);
+	    break;
+          case CFG_ITEM_TYPE_ACCELKEY_LIST:
+	    return(EDV_GET_TYPE_ACCELKEY_LIST);
+	    break;
+          case CFG_ITEM_TYPE_STYLE:
+	    return(EDV_GET_TYPE_STYLE);
+	    break;
+          case CFG_ITEM_TYPE_MENU:
+	    return(EDV_GET_TYPE_MENU);
+	    break;
+	}
+
+	return(EDV_GET_TYPE_NONE);
+}
+
 /*
  *	Gets the boolean value of the configuration parameter.
  *
@@ -97,12 +178,12 @@ gchar **EDVGetConfigurationParameters(
  */
 gboolean EDVGetB(edv_context_struct *ctx, const gchar *parm)
 {
-        if((ctx == NULL) || STRISEMPTY(parm))
-            return(FALSE);
+	if((ctx == NULL) || STRISEMPTY(parm))
+	    return(FALSE);
 
-        return((gboolean)CFGItemListGetValueI(
-            ctx->cfg_list, parm
-        ));
+	return((gboolean)CFGItemListGetValueI(
+	    ctx->cfg_list, parm
+	));
 }
 
 /*
