@@ -1,5 +1,5 @@
 /*
-                            Configuration Fetching
+			    Configuration Fetching
  */
 
 #ifndef EDV_GET_H
@@ -9,6 +9,41 @@
 #include "edv_context.h"
 
 
+/*
+ *	Value Types:
+ */
+typedef enum {
+	EDV_GET_TYPE_NONE,
+	EDV_GET_TYPE_INT8,
+        EDV_GET_TYPE_UINT8,
+        EDV_GET_TYPE_INT16,
+        EDV_GET_TYPE_UINT16,
+        EDV_GET_TYPE_INT32,
+        EDV_GET_TYPE_UINT32,
+        EDV_GET_TYPE_INT64,
+        EDV_GET_TYPE_UINT64,
+        EDV_GET_TYPE_FLOAT,
+        EDV_GET_TYPE_DOUBLE,
+        EDV_GET_TYPE_STRING,
+        EDV_GET_TYPE_INTLIST,
+        EDV_GET_TYPE_COLOR,
+        EDV_GET_TYPE_ACCELKEY_LIST,
+        EDV_GET_TYPE_STYLE,
+        EDV_GET_TYPE_MENU
+} edv_get_type;
+
+
+/*
+ *	Gets the type of the configuration parameter.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
+ *
+ *	The parm specifies the configuration parameter.
+ *
+ *	Can return EDV_GET_TYPE_NONE on error.
+ */
+extern edv_get_type EDVGetType(edv_context_struct *ctx, const gchar *parm);
+
 /*
  *	Gets the complete list of Endeavour 2 configuration parameters.
  *
