@@ -26,16 +26,16 @@ edv_mime_type_struct *EDVMimeTypeMatchType(
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -83,28 +83,25 @@ edv_mime_type_struct *EDVMimeTypeMatch(
 	const struct stat *lstat_buf
 )
 {
-	mode_t st_mode;
+	const mode_t st_mode = (lstat_buf != NULL) ? lstat_buf->st_mode : 0;
+#ifdef S_ISREG
+	const gboolean is_file = S_ISREG(st_mode) ? TRUE : FALSE;
+#else
+	const gboolean is_file = FALSE;
+#endif
 	gint i, total;
-	gboolean is_dir;
+	const gchar *name = (path != NULL) ? g_basename(path) : NULL;
 	edv_mime_type_struct *m, **list;
 
 	if((ctx == NULL) || STRISEMPTY(path))
 	    return(NULL);
 
-	/* Get MIME Types list */
+	/* Get the MIME Types list */
 	list = ctx->mimetype;
 	total = ctx->total_mimetypes;
 	if(list == NULL)
 	    return(NULL);
 
-	/* Get object stats */
-	st_mode = (lstat_buf != NULL) ? lstat_buf->st_mode : 0;
-#ifdef S_ISDIR
-	is_dir = S_ISDIR(st_mode) ? TRUE : FALSE;
-#else
-	is_dir = FALSE;
-#endif
-
 #ifdef S_ISLNK
 	/* Is link? */
 	if(S_ISLNK(st_mode))
@@ -122,7 +119,7 @@ edv_mime_type_struct *EDVMimeTypeMatch(
 		   !STRISEMPTY(m->type)
 		)
 		{
-		    if(!strcmp(m->type, link_type_str))
+		    if(!strcmp((const char *)m->type, (const char *)link_type_str))
 			return(m);
 		}
 	    }
@@ -149,18 +146,18 @@ edv_mime_type_struct *EDVMimeTypeMatch(
 		{
 		  case EDV_MIME_TYPE_CLASS_SYSTEM:
 		    break;
-		  case EDV_MIME_TYPE_CLASS_UNIQUE:
-		  case EDV_MIME_TYPE_CLASS_PROGRAM:
-		    if((path != NULL) ? ISPATHABSOLUTE(path) : FALSE)
+		  case EDV_MIME_TYPE_CLASS_FORMAT:
+		    if(is_file && (name != NULL))
 		    {
-			if(!strcmp(value, path))
+			if(EDVIsExtension(name, value))
 			    return(m);
 		    }
 		    break;
-		  case EDV_MIME_TYPE_CLASS_FORMAT:
-		    if(!is_dir)
+		  case EDV_MIME_TYPE_CLASS_PROGRAM:
+		  case EDV_MIME_TYPE_CLASS_UNIQUE:
+		    if((path != NULL) ? g_path_is_absolute(path) : FALSE)
 		    {
-			if(EDVIsExtension(path, value))
+			if(!strcmp((const char *)value, (const char *)path))
 			    return(m);
 		    }
 		    break;
@@ -241,7 +238,7 @@ edv_mime_type_struct *EDVMimeTypeMatch(
 		mime_type_str = EDV_MIME_TYPE_TYPE_INODE_UNKNOWN;
 	    }
 
-	    /* Iterate through system class MIME Types */
+	    /* Iterate through the system class MIME Types */
 	    for(i = 0; i < total; i++)
 	    {
 		m = list[i];
@@ -253,7 +250,7 @@ edv_mime_type_struct *EDVMimeTypeMatch(
 		   !STRISEMPTY(m->type)
 		)
 		{
-		    if(!strcmp(m->type, mime_type_str))
+		    if(!strcmp((const char *)m->type, (const char *)mime_type_str))
 			return(m);
 		}
 	    }
@@ -299,7 +296,7 @@ edv_mime_type_struct *EDVMimeTypeMatchType(
 	    if(STRISEMPTY(m->type))
 		continue;
 
-	    if(!strcmp(m->type, type))
+	    if(!strcmp((const char *)m->type, (const char *)type))
 		return(m);
 	}
 
