@@ -1,5 +1,5 @@
 /*
-                  Endeavour Mark II API Master Header File
+		  Endeavour Mark II API Master Header File
  */
 
 #ifndef LIBENDEAVOUR2_H
@@ -17,6 +17,9 @@
 #include "edv_get.h"			/* Cfg Fetching */
 #include "edv_help.h"			/* Help Browser & Help Displaying */
 #include "edv_history.h"		/* History Event Logging */
+#include "edv_id.h"			/* User and Group ID */
+#include "edv_id_get.h"			/* User and Group ID Fetching & Matching */
+/* edv_id_list.h is private */
 #include "edv_message.h"		/* Message Output & Play Sound */
 #include "edv_mime_type.h"		/* MIME Types */
 #include "edv_mime_type_get.h"		/* MIME Types Fetching & Matching */
