@@ -387,19 +387,46 @@ gboolean EDVMimeTypesMailcapImportOptsGetResponse(
 	client_vbox = DLG(d)->client_vbox;
 	style = gtk_widget_get_style(toplevel);
 
-	/* Create options widgets */
+	/* Create the options widgets */
 	if(client_vbox != NULL)
 	{
+	    gint font_size;
+	    const gchar *font_encoding;
+	    gchar *font_name_h1_bold;
+	    GdkFont *font;
 	    GtkStateType state;
 	    GtkRcStyle *rcstyle;
+	    GtkStyle *style = gtk_widget_get_style(toplevel);
 	    GtkWidget *w, *parent = client_vbox, *parent2, *parent3;
 
+	    /* Get the base font size */
+	    font = style->font;
+	    font_size = GDK_FONT_GET_FONT_NAME_SIZE(font);
+	    if(font_size < 3)
+		font_size = 3;
+
+	    /* Format the font names */
+#if defined(PROG_LANGUAGE_POLISH)
+	    font_encoding = "iso8859-2";
+#else
+	    font_encoding = "iso8859-1";
+#endif
+
+            font_name_h1_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+                font_size + 2,
+                font_encoding
+            );
+
+	    /* OK button accel keys */
 	    w = DLG(d)->ok_btn;
 	    gtk_accel_group_add(
 		accelgrp, GDK_i, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE,
 		GTK_OBJECT(w), "clicked"
 	    );
 	    GUIButtonLabelUnderline(w, GDK_i);
+
+	    /* Cancel button accel keys */
 	    w = DLG(d)->cancel_btn;
 	    gtk_accel_group_add(
 		accelgrp, GDK_Escape, 0, GTK_ACCEL_VISIBLE,
@@ -460,15 +487,13 @@ gboolean EDVMimeTypesMailcapImportOptsGetResponse(
 		gtk_widget_show(w);
 
 		rcstyle = gtk_rc_style_new();
-		rcstyle->font_name = STRDUP(
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
-		);
+		rcstyle->font_name = STRDUP(font_name_h1_bold);
 		w = gtk_label_new(g_basename(path));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_modify_style(w, rcstyle);
+		GTK_RC_STYLE_UNREF(rcstyle);
 		gtk_widget_show(w);
-		GTK_RC_STYLE_UNREF(rcstyle)
 
 		w = gtk_hbox_new(FALSE, border_major);
 		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
@@ -508,7 +533,7 @@ from this file then check \"Update\"."
 		gtk_widget_show(w);
 	    }
 
-	    /* Vbox for option widgets */
+	    /* GtkVBox for option widgets */
 	    w = gtk_vbox_new(FALSE, border_minor);
 	    gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
@@ -519,7 +544,7 @@ from this file then check \"Update\"."
 	    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
 	    parent3 = w;
-	    /* Check button */
+	    /* GtkCheckButton */
 	    d->update_check = w = gtk_check_button_new_with_label(
 		"Update"
 	    );
@@ -560,9 +585,11 @@ from this file then check \"Update\"."
 		gtk_toggle_button_set_active(
 		    GTK_TOGGLE_BUTTON(d->only_newer_check), *only_newer
 		);
+
+	    g_free(font_name_h1_bold);
 	}
 
-	/* Map toplevel */
+	/* Map the dialog */
 	gtk_widget_show(toplevel);
 
 	/* Wait for user response */
@@ -665,16 +692,43 @@ gboolean EDVMimeTypesMediaTypesImportOptsGetResponse(
 	/* Create options widgets */
 	if(client_vbox != NULL)
 	{
+	    gint font_size;
+	    const gchar *font_encoding;
+	    gchar *font_name_h1_bold;
+	    GdkFont *font;
 	    GtkStateType state;
 	    GtkRcStyle *rcstyle;
+	    GtkStyle *style = gtk_widget_get_style(toplevel);
 	    GtkWidget *w, *parent = client_vbox, *parent2, *parent3;
 
+	    /* Get the base font size */
+	    font = style->font;
+	    font_size = GDK_FONT_GET_FONT_NAME_SIZE(font);
+	    if(font_size < 3)
+		font_size = 3;
+
+	    /* Format the font names */
+#if defined(PROG_LANGUAGE_POLISH)
+	    font_encoding = "iso8859-2";
+#else
+	    font_encoding = "iso8859-1";
+#endif
+
+            font_name_h1_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+                font_size + 2,
+                font_encoding
+            );
+
+	    /* OK button accel keys */
 	    w = DLG(d)->ok_btn;
 	    gtk_accel_group_add(
 		accelgrp, GDK_i, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE,
 		GTK_OBJECT(w), "clicked"
 	    );
 	    GUIButtonLabelUnderline(w, GDK_i);
+
+	    /* Cancel button accel keys */
 	    w = DLG(d)->cancel_btn;
 	    gtk_accel_group_add(
 		accelgrp, GDK_Escape, 0, GTK_ACCEL_VISIBLE,
@@ -735,15 +789,13 @@ gboolean EDVMimeTypesMediaTypesImportOptsGetResponse(
 		gtk_widget_show(w);
 
 		rcstyle = gtk_rc_style_new();
-		rcstyle->font_name = STRDUP(
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
-		);
+		rcstyle->font_name = STRDUP(font_name_h1_bold);
 		w = gtk_label_new(g_basename(path));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_modify_style(w, rcstyle);
+		GTK_RC_STYLE_UNREF(rcstyle);
 		gtk_widget_show(w);
-		GTK_RC_STYLE_UNREF(rcstyle)
 
 		w = gtk_hbox_new(FALSE, border_major);
 		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
@@ -835,9 +887,11 @@ from this file then check \"Update\"."
 		gtk_toggle_button_set_active(
 		    GTK_TOGGLE_BUTTON(d->only_newer_check), *only_newer
 		);
+
+	    g_free(font_name_h1_bold);
 	}
 
-	/* Map toplevel */
+	/* Map the dialog */
 	gtk_widget_show(toplevel);
 
 	/* Wait for user response */
@@ -939,16 +993,43 @@ gboolean EDVMIMETypesEndeavourImportOptsGetResponse(
 	/* Create the option widgets */
 	if(client_vbox != NULL)
 	{
+	    gint font_size;
+	    const gchar *font_encoding;
+	    gchar *font_name_h1_bold;
+	    GdkFont *font;
 	    GtkStateType state;
 	    GtkRcStyle *rcstyle;
+	    GtkStyle *style = gtk_widget_get_style(toplevel);
 	    GtkWidget *w, *parent = client_vbox, *parent2, *parent3;
 
+	    /* Get the base font size */
+	    font = style->font;
+	    font_size = GDK_FONT_GET_FONT_NAME_SIZE(font);
+	    if(font_size < 3)
+		font_size = 3;
+
+	    /* Format the font names */
+#if defined(PROG_LANGUAGE_POLISH)
+	    font_encoding = "iso8859-2";
+#else
+	    font_encoding = "iso8859-1";
+#endif
+
+            font_name_h1_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+                font_size + 2,
+                font_encoding
+            );
+
+	    /* OK button accel keys */
 	    w = DLG(d)->ok_btn;
 	    gtk_accel_group_add(
 		accelgrp, GDK_i, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE,
 		GTK_OBJECT(w), "clicked"
 	    );
 	    GUIButtonLabelUnderline(w, GDK_i);
+
+	    /* Cancel button accel keys */
 	    w = DLG(d)->cancel_btn;
 	    gtk_accel_group_add(
 		accelgrp, GDK_Escape, 0, GTK_ACCEL_VISIBLE,
@@ -1009,15 +1090,13 @@ gboolean EDVMIMETypesEndeavourImportOptsGetResponse(
 		gtk_widget_show(w);
 
 		rcstyle = gtk_rc_style_new();
-		rcstyle->font_name = STRDUP(
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
-		);
+		rcstyle->font_name = STRDUP(font_name_h1_bold);
 		w = gtk_label_new(g_basename(path));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_modify_style(w, rcstyle);
+		GTK_RC_STYLE_UNREF(rcstyle);
 		gtk_widget_show(w);
-		GTK_RC_STYLE_UNREF(rcstyle)
 
 		w = gtk_hbox_new(FALSE, border_major);
 		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
@@ -1046,7 +1125,7 @@ file than the ones you have, check \"Update\" and\n\
 		gtk_widget_show(w);
 	    }
 
-	    /* Vbox for option widgets */
+	    /* GtkVBox for the option widgets */
 	    w = gtk_vbox_new(FALSE, border_minor);
 	    gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
@@ -1057,7 +1136,7 @@ file than the ones you have, check \"Update\" and\n\
 	    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
 	    parent3 = w;
-	    /* Check button */
+	    /* GtkCheckButton */
 	    d->update_check = w = gtk_check_button_new_with_label(
 		"Update"
 	    );
@@ -1074,7 +1153,7 @@ file than the ones you have, check \"Update\" and\n\
 	    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
 	    parent3 = w;
-	    /* Check button */
+	    /* GtkCheckButton */
 	    d->only_newer_check = w = gtk_check_button_new_with_label(
 		"Only Newer"
 	    );
@@ -1098,9 +1177,11 @@ file than the ones you have, check \"Update\" and\n\
 		gtk_toggle_button_set_active(
 		    GTK_TOGGLE_BUTTON(d->only_newer_check), *only_newer
 		);
+
+	    g_free(font_name_h1_bold);
 	}
 
-	/* Map toplevel */
+	/* Map the dialog */
 	gtk_widget_show(toplevel);
 
 	/* Wait for user response */
