@@ -120,15 +120,15 @@ void EDVMimeTypesListWinReconfiguredNotifyCB(
 );
 void EDVMimeTypesListWinMimeTypeAddedCB(
 	edv_mime_types_list_win_struct *lw,
-	gint mt_num, edv_mime_type_struct *mt_ptr
+	const gint mt_num, edv_mime_type_struct *m
 );
 void EDVMimeTypesListWinMimeTypeModifiedCB(
 	edv_mime_types_list_win_struct *lw,
-	gint mt_num, edv_mime_type_struct *mt_ptr
+	const gint mt_num, edv_mime_type_struct *m
 );
 void EDVMimeTypesListWinMimeTypeRemovedCB(
 	edv_mime_types_list_win_struct *lw,
-	gint mt_num
+	const gint mt_num
 );
 
 /* Utilities */
@@ -1013,7 +1013,7 @@ void EDVMimeTypesListWinReconfiguredNotifyCB(
  */
 void EDVMimeTypesListWinMimeTypeAddedCB(
 	edv_mime_types_list_win_struct *lw,
-	gint mt_num, edv_mime_type_struct *m
+	const gint mt_num, edv_mime_type_struct *m
 )
 {
 	gint i, row, new_row;
@@ -1058,7 +1058,7 @@ void EDVMimeTypesListWinMimeTypeAddedCB(
  */
 void EDVMimeTypesListWinMimeTypeModifiedCB(
 	edv_mime_types_list_win_struct *lw,
-	gint mt_num, edv_mime_type_struct *m
+	const gint mt_num, edv_mime_type_struct *m
 )
 {
 	GtkCList *clist;
@@ -1094,7 +1094,8 @@ void EDVMimeTypesListWinMimeTypeModifiedCB(
  *	MIME Type removed callback.
  */
 void EDVMimeTypesListWinMimeTypeRemovedCB(
-	edv_mime_types_list_win_struct *lw, gint mt_num
+	edv_mime_types_list_win_struct *lw,
+	const gint mt_num
 )
 {
 	gint row, sel_row;
@@ -1208,11 +1209,18 @@ static void EDVMimeTypesListWinUpdateDisplay(
 {
 	const gint	border_major = 5,
 			border_minor = 2;
-	edv_date_relativity date_relativity;
-	const gchar *date_format;
+	gint font_size;
+	const gchar *date_format, *font_encoding;
+	gchar	*font_name_h1_bold,
+		*font_name_h1,
+		*font_name_h2_bold,
+		*font_name_h2;
+	GdkFont *font;
 	GtkRcStyle *rcstyle, *standard_rcstyle;
+	GtkStyle *style;
 	GtkWidget *w, *parent, *parent2, *parent3, *parent4;
 	const cfg_item_struct *cfg_list;
+	edv_date_relativity date_relativity;
 	edv_core_struct *core;
 
 	if(lw == NULL)
@@ -1238,9 +1246,56 @@ static void EDVMimeTypesListWinUpdateDisplay(
 	if(parent == NULL)
 	    return;
 
+	style = gtk_widget_get_style(parent);
+	if(style == NULL)
+	    return;
+
+	font = style->font;
+	font_size = GDK_FONT_GET_FONT_NAME_SIZE(font);
+	if(font_size < 3)
+	    font_size = 3;
+
+#if defined(PROG_LANGUAGE_POLISH)
+	font_encoding = "iso8859-2";
+#else
+	font_encoding = "iso8859-1";
+#endif
+
+	font_name_h1_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+	    font_size + 2,
+	    font_encoding
+	);
+	font_name_h1 = g_strdup_printf(
+"-adobe-helvetica-medium-r-normal-*-%i-*-*-*-*-*-%s",
+	    font_size + 2,
+	    font_encoding
+	);
+	font_name_h2_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+	    font_size,
+	    font_encoding
+	);
+	font_name_h2 = g_strdup_printf(
+"-adobe-helvetica-medium-r-normal-*-%i-*-*-*-*-*-%s",
+	    font_size,
+	    font_encoding
+	);
+
+#define CLEANUP_RETURN	{		\
+ g_free(font_name_h1_bold);		\
+ g_free(font_name_h1);			\
+ g_free(font_name_h2_bold);		\
+ g_free(font_name_h2);			\
+					\
+ return;				\
+}
+
 	/* Do not continue updating if the specified MIME Type is NULL */
 	if(m == NULL)
-	    return;
+	{
+	    CLEANUP_RETURN;
+	}
 
 	/* Get the configuration */
 	date_relativity = (edv_date_relativity)EDV_GET_I(
@@ -1350,9 +1405,7 @@ static void EDVMimeTypesListWinUpdateDisplay(
 	    }
 	    /* Class heading label */
 	    rcstyle = gtk_rc_style_new();
-	    rcstyle->font_name = STRDUP(
-"-adobe-helvetica-medium-r-normal-*-14-*-*-*-*-*-iso8859-1"
-	    );
+	    rcstyle->font_name = STRDUP(font_name_h1);
 	    w = gtk_label_new(
 		(class_str != NULL) ? class_str :
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1479,9 +1532,7 @@ static void EDVMimeTypesListWinUpdateDisplay(
 	    if(s != NULL)
 	    {
 		rcstyle = gtk_rc_style_new();
-		rcstyle->font_name = STRDUP(
-"-adobe-helvetica-bold-r-normal-*-12-*-*-*-*-*-iso8859-1"
-		);
+		rcstyle->font_name = STRDUP(font_name_h2_bold);
 		w = gtk_label_new(s2);
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_RIGHT);
 		gtk_box_pack_end(GTK_BOX(parent3), w, FALSE, FALSE, 0);
@@ -1490,9 +1541,7 @@ static void EDVMimeTypesListWinUpdateDisplay(
 		GTK_RC_STYLE_UNREF(rcstyle)
 
 		rcstyle = gtk_rc_style_new();
-		rcstyle->font_name = STRDUP(
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-		);
+		rcstyle->font_name = STRDUP(font_name_h2);
 		w = gtk_label_new(s);
 		gtk_box_pack_end(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_modify_style(w, rcstyle);
@@ -1546,9 +1595,7 @@ static void EDVMimeTypesListWinUpdateDisplay(
 	}
 	/* Type label */
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
-	);
+	rcstyle->font_name = STRDUP(font_name_h1_bold);
 	w = gtk_label_new(
 	    (m->type != NULL) ? m->type : "(null)"
 	);
@@ -1625,9 +1672,7 @@ static void EDVMimeTypesListWinUpdateDisplay(
 		break;
 	    }
 	    rcstyle = gtk_rc_style_new();
-	    rcstyle->font_name = STRDUP(
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-	    );
+	    rcstyle->font_name = STRDUP(font_name_h2);
 	    w = gtk_label_new(value_label);
 	    gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	    gtk_widget_modify_style(w, rcstyle);
@@ -1636,9 +1681,7 @@ static void EDVMimeTypesListWinUpdateDisplay(
 
 	    /* Value */
 	    rcstyle = gtk_rc_style_new();
-	    rcstyle->font_name = STRDUP(
-"-adobe-courier-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-	    );
+	    rcstyle->font_name = STRDUP(font_name_h2);
 	    w = gtk_label_new(value);
 	    gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	    gtk_widget_modify_style(w, rcstyle);
@@ -1657,9 +1700,7 @@ static void EDVMimeTypesListWinUpdateDisplay(
 
 	    /* Description label */
 	    rcstyle = gtk_rc_style_new();
-	    rcstyle->font_name = STRDUP(
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-	    );
+	    rcstyle->font_name = STRDUP(font_name_h2);
 	    w = gtk_label_new(m->description);
 	    gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	    gtk_widget_modify_style(w, rcstyle);
@@ -1676,9 +1717,7 @@ static void EDVMimeTypesListWinUpdateDisplay(
 	    parent3 = w;
 
 	    rcstyle = gtk_rc_style_new();
-	    rcstyle->font_name = STRDUP(
-"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
-	    );
+	    rcstyle->font_name = STRDUP(font_name_h2);
 	    /* Prefix */
 	    w = gtk_label_new(
 "Last Modified:"
@@ -1700,10 +1739,11 @@ static void EDVMimeTypesListWinUpdateDisplay(
 	        gtk_widget_show(w);
 	    }
 
-	    GTK_RC_STYLE_UNREF(rcstyle)
+	    GTK_RC_STYLE_UNREF(rcstyle);
 	}
 
-
+	CLEANUP_RETURN;
+#undef CLEANUP_RETURN
 }
 
 
@@ -2068,19 +2108,26 @@ void EDVMimeTypesListWinAdd(
 
 	EDVMimeTypesListWinSetBusy(lw, TRUE);
 
+	/* Create a new MIME Type */
+	m = EDVMimeTypeNew();
+	if(m == NULL)
+	{
+	    EDVMimeTypesListWinSetBusy(lw, FALSE);
+	    return;
+	}
+
+	m->mt_class = EDV_MIME_TYPE_CLASS_FORMAT;
+	m->type = STRDUP("misc/untitled");
+	m->description = STRDUP("New MIME Type");
+
 	/* Get the last selected MIME Type */
 	row = EDVCListGetSelectedLast(clist, NULL);
 
-	/* Insert a new MIME Type */
+	/* Insert the new MIME Type */
 	mt_num = EDVMimeTypesListInsert(
 	    &core->mimetype, &core->total_mimetypes,
 	    row,
-	    EDVMimeTypeNew(
-		EDV_MIME_TYPE_CLASS_FORMAT,
-		NULL,
-		"misc/untitled",
-		"New MIME Type"
-	    )
+	    m
 	);
 	if(mt_num < 0)
 	{
@@ -3281,17 +3328,17 @@ edv_mime_types_list_win_struct *EDVMimeTypesListWinNew(
 	gtk_widget_realize(w);
 	gtk_clist_set_selection_mode(clist, GTK_SELECTION_EXTENDED);
 	gtk_clist_set_column_width(clist, 0, 160);
-        gtk_clist_set_column_justification(   
-            clist, 0, GTK_JUSTIFY_LEFT
-        );
+	gtk_clist_set_column_justification(   
+	    clist, 0, GTK_JUSTIFY_LEFT
+	);
 	gtk_clist_set_column_width(clist, 1, 150);
-        gtk_clist_set_column_justification(   
-            clist, 1, GTK_JUSTIFY_LEFT
-        );
+	gtk_clist_set_column_justification(   
+	    clist, 1, GTK_JUSTIFY_LEFT
+	);
 	gtk_clist_set_column_width(clist, 2, 20);
-        gtk_clist_set_column_justification(   
-            clist, 2, GTK_JUSTIFY_CENTER
-        );
+	gtk_clist_set_column_justification(   
+	    clist, 2, GTK_JUSTIFY_CENTER
+	);
 	gtk_clist_column_titles_passive(clist);
 	gtk_clist_set_row_height(clist, EDV_LIST_ROW_SPACING);
 	gtk_clist_set_shadow_type(clist, GTK_SHADOW_IN);
