@@ -10,7 +10,7 @@
 #include "edv_generic_options_win.h"
 
 
-extern void EDVOptionsWindowSelectTab(
+extern gboolean EDVOptionsWindowSelectTab(
 	edv_gen_opt_win_struct *optwin, const gchar *tab_name
 );
 extern edv_gen_opt_win_struct *EDVCreateOptionsWindow(
