@@ -8,19 +8,19 @@
 
 static void PieChartDrawArc(
 	GdkPixmap *pixmap, GdkGC *gc,
-	gint x, gint y, gint width, gint height,
-	gfloat start_angle,     /* 0.0 to 1.0 */
-	gfloat end_angle,       /* 0.0 to 1.0 */
-	gboolean outline_circumferance,
-	gboolean outline_radius, gboolean outline_height
+	const gint x, const gint y, const gint width, const gint height,
+	const gfloat start_angle,     /* 0.0 to 1.0 */
+	const gfloat end_angle,       /* 0.0 to 1.0 */
+	const gboolean outline_circumferance,
+	const gboolean outline_radius, const gboolean outline_height
 );
 static void PieChartDrawPieIterate(
 	pie_chart_struct *pc, GtkStyle *style, GdkPixmap *pixmap,
-	gint state, gint x, gint y,
-	gint width, gint height,
-	gboolean outline_circumference, gboolean outline_radius,
-	gboolean outline_height,
-	gboolean shaded, gboolean shadow
+	const GtkStateType state,
+	const gint x, const gint y, const gint width, const gint height,
+	const gboolean outline_circumference, const gboolean outline_radius,
+	const gboolean outline_height,
+	const gboolean shaded, const gboolean shadow
 );
 static void PieChartCreateValueLabel(
 	pie_chart_struct *pc,
@@ -28,7 +28,7 @@ static void PieChartCreateValueLabel(
 	GtkWidget **type_label_hbox_rtn, GtkWidget **value_label_hbox_rtn,
 	GtkWidget **drawing_area_rtn
 );
-static void PieChartDoRealize(pie_chart_struct *pc);
+static void PieChartRealize(pie_chart_struct *pc);
 static void PieChartRedrawPixmap(pie_chart_struct *pc);
 
 static gint PieChartValueLabelExposeCB(
@@ -38,23 +38,30 @@ static gint PieChartExposeCB(
 	GtkWidget *widget, GdkEventExpose *expose, gpointer data
 );
 
+
+/* Pie Chart Value */
+pie_chart_value_struct *PieChartValueNew(void);
+void PieChartValueDelete(pie_chart_value_struct *v);
 gint PieChartValueAdd(
 	pie_chart_struct *pc,
 	GtkAdjustment *adj, GdkColor *c,
 	const gchar *type_label, const gchar *value_label
 );
 void PieChartValueSet(
-	pie_chart_struct *pc, gint value_num,
+	pie_chart_struct *pc, const gint value_num,
 	GtkAdjustment *adj, GdkColor *c,
 	const gchar *type_label, const gchar *value_label
 );
 void PieChartValueRemove(
-	pie_chart_struct *pc, gint value_num
+	pie_chart_struct *pc, const gint value_num
 );
-void PieChartValueRemoveAll(pie_chart_struct *pc);
+void PieChartClear(pie_chart_struct *pc);
 
+/* Pie Chart */
 pie_chart_struct *PieChartNew(
-	GtkAdjustment *adj, GdkColor *c, gint width, gint height,
+	const gint width, const gint height,
+	GtkAdjustment *adj,
+	GdkColor *c,
 	const gchar *title, const gchar *footer,
 	const gchar *base_type_label, const gchar *base_value_label
 );
@@ -89,29 +96,30 @@ void PieChartDelete(pie_chart_struct *pc);
  */
 static void PieChartDrawArc(
 	GdkPixmap *pixmap, GdkGC *gc,
-	gint x, gint y, gint width, gint height,
-	gfloat start_angle,	/* 0.0 to 1.0 */
-	gfloat end_angle,	/* 0.0 to 1.0 */
-	gboolean outline_circumferance,
-	gboolean outline_radius, gboolean outline_height
+	const gint x, const gint y, const gint width, const gint height,
+	const gfloat start_angle,	/* 0.0 to 1.0 */
+	const gfloat end_angle,		/* 0.0 to 1.0 */
+	const gboolean outline_circumferance,
+	const gboolean outline_radius, const gboolean outline_height
 )
 {
-	gfloat delta_angle;
+	gfloat	_start_angle = start_angle,
+		delta_angle;
 
 	if((pixmap == NULL) || (gc == NULL))
 	    return;
 
 	/* Calculate delta angle */
-	delta_angle = start_angle - end_angle;
+	delta_angle = _start_angle - end_angle;
 	if(delta_angle == 0.0f)
 	    return;
 
 	/* Outline radius? */
 	if(outline_radius &&
-	   ((start_angle != 0.0f) || (end_angle != 1.0f))
+	   ((_start_angle != 0.0f) || (end_angle != 1.0f))
 	)
 	{
-	    gfloat	ostart_angle = start_angle,
+	    gfloat	ostart_angle = _start_angle,
 			oend_angle = end_angle;
 	    gint	rx = (width / 2),
 			ry = (height / 2),
@@ -146,7 +154,7 @@ static void PieChartDrawArc(
 	/* Outline height? */
 	if(outline_height)
 	{
-	    gfloat      ostart_angle = start_angle,
+	    gfloat      ostart_angle = _start_angle,
 			oend_angle = end_angle;
 	    gint        rx = (width / 2),
 			ry = (height / 2),
@@ -200,18 +208,18 @@ static void PieChartDrawArc(
 	/* Convert angles to degrees and make it relative to the 3
 	 * o'clock position
 	 */
-	start_angle = 90.0f - (start_angle * 360.0f);
-	while(start_angle < 0.0f)
-	    start_angle += 360.0f;
-	while(start_angle >= 360.0f)
-	    start_angle -= 360.0f;
+	_start_angle = 90.0f - (_start_angle * 360.0f);
+	while(_start_angle < 0.0f)
+	    _start_angle += 360.0f;
+	while(_start_angle >= 360.0f)
+	    _start_angle -= 360.0f;
 
 	delta_angle *= 360.0f;
 
 	gdk_draw_arc(
 	    pixmap, gc, !outline_circumferance,
 	    x, y, width, height,
-	    (gint)(start_angle * 64.0f),
+	    (gint)(_start_angle * 64.0f),
 	    (gint)(delta_angle * 64.0f)
 	);
 }
@@ -326,19 +334,27 @@ static void PieChartCreateValueLabel(
  *	realized then all colors and pixmap will be created and the pie
  *	chart will be marked as realized.
  */
-static void PieChartDoRealize(pie_chart_struct *pc)
+static void PieChartRealize(pie_chart_struct *pc)
 {
-	gint i, width, height;
+	gint width, height;
 	GdkColor *c;
 	GdkColormap *colormap;
 	GdkWindow *window;
 	GdkPixmap *pixmap;
-	GtkWidget *w = (pc != NULL) ? pc->drawing_area : NULL;
-	pie_chart_value_struct *value_ptr;
+	GList *glist;
+	GtkWidget *w;
+	pie_chart_value_struct *v;
+
+	if(pc == NULL)
+	    return;
+
+	w = pc->drawing_area;
 	if(w == NULL)
 	    return;
 
-	/* Pie chart already realized or drawing area not realized? */
+	/* Pie chart already realized or drawing area GtkWidget
+	 * not realized?
+	 */
 	if(pc->realized || !GTK_WIDGET_REALIZED(w))
 	    return;
 
@@ -348,8 +364,7 @@ static void PieChartDoRealize(pie_chart_struct *pc)
 
 	gdk_window_get_size(window, &width, &height);
 
-
-	/* Get colormap */
+	/* Get the colormap */
 	colormap = pc->colormap;
 	if(colormap == NULL)
 	{
@@ -366,18 +381,18 @@ static void PieChartDoRealize(pie_chart_struct *pc)
 	if(colormap == NULL)
 	    return;
 
-
-	/* Create graphics context */
+	/* Create the graphics context */
 	if(pc->gc == NULL)
 	    pc->gc = GDK_GC_NEW();
 
-
-	/* Create off screen buffer pixmap for drawing area */
+	/* Create the offscreen GdkPixmap buffer */
 	pixmap = pc->pixmap;
 	if(pixmap == NULL)
-	    pc->pixmap = pixmap = GDK_PIXMAP_NEW(width, height);
+	    pc->pixmap = pixmap = gdk_pixmap_new(
+		window, width, height, -1
+	    );
 
-	/* Set pie base colors */
+	/* Set the pie base colors */
 	c = &pc->c;
 	GDK_COLORMAP_ALLOC_COLOR(colormap, c)
 	c = &pc->c_shade;
@@ -390,57 +405,58 @@ static void PieChartDoRealize(pie_chart_struct *pc)
 	    NULL, NULL, NULL
 	);
 
-	/* Realize all values */
-	for(i = 0; i < pc->total_values; i++)
+	/* Realize all the values */
+	for(glist = pc->values_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    value_ptr = pc->value[i];
-	    if(value_ptr == NULL)
+	    v = PIE_CHART_VALUE(glist->data);
+	    if(v == NULL)
 		continue;
 
 	    /* Allocate color of this value */
-	    c = &value_ptr->c;
-	    GDK_COLORMAP_ALLOC_COLOR(colormap, c)
-	    c = &value_ptr->c_shade;
-	    GDK_COLORMAP_ALLOC_COLOR(colormap, c)
+	    c = &v->c;
+	    GDK_COLORMAP_ALLOC_COLOR(colormap, c);
+	    c = &v->c_shade;
+	    GDK_COLORMAP_ALLOC_COLOR(colormap, c);
 
 	    /* Create label widget for this value */
 	    PieChartCreateValueLabel(
-		pc, &value_ptr->c, value_ptr->type_label, value_ptr->value_label,
-		&value_ptr->type_label_hbox, &value_ptr->value_label_hbox,
-		&value_ptr->drawing_area
+		pc, &v->c, v->type_label, v->value_label,
+		&v->type_label_hbox, &v->value_label_hbox,
+		&v->drawing_area
 	    );
 	}
 
-
 	/* Mark as realized */
 	pc->realized = TRUE;
 }
 
 
 /*
- *	Draws one itteration of a complete pie disk at the given
+ *	Draws one iteration of a complete pie disk at the given
  *	coordinates.
  */
 static void PieChartDrawPieIterate(
 	pie_chart_struct *pc, GtkStyle *style, GdkPixmap *pixmap,
-	gint state, gint x, gint y,
-	gint width, gint height,
-	gboolean outline_circumference, gboolean outline_radius,
-	gboolean outline_height,
-	gboolean shaded, gboolean shadow
+	const GtkStateType state,
+	const gint x, const gint y, const gint width, const gint height,
+	const gboolean outline_circumference, const gboolean outline_radius,
+	const gboolean outline_height,
+	const gboolean shaded, const gboolean shadow
 )
 {
-	gint i;
-	gboolean outline = (outline_circumference || outline_radius || outline_height) ?
+	const gboolean outline = (outline_circumference || outline_radius || outline_height) ?
 	    TRUE : FALSE;
 	gfloat values_range, total_range, values_range_coeff;
+	GList *glist;
 	GdkGC *gc;
 	GtkAdjustment *adj;
-	pie_chart_value_struct *value_ptr;
-
+	pie_chart_value_struct *v;
 
 	if((pc == NULL) || (style == NULL) || (pixmap == NULL) ||
-	   (width < 1) || (height < 1)
+	   (width <= 0) || (height <= 0)
 	)
 	    return;
 
@@ -464,20 +480,23 @@ static void PieChartDrawPieIterate(
 	}
 
 	/* Calculate total range of all values */
-	values_range = 0.0;
-	for(i = 0; i < pc->total_values; i++)
+	values_range = 0.0f;
+	for(glist = pc->values_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    value_ptr = pc->value[i];
-	    if(value_ptr == NULL)
+	    v = PIE_CHART_VALUE(glist->data);
+	    if(v == NULL)
 		continue;
 
-	    adj = value_ptr->adj;
-	    values_range += (adj != NULL) ? (adj->upper - adj->lower) : 0.0;
+	    adj = v->adj;
+	    values_range += (adj != NULL) ? (adj->upper - adj->lower) : 0.0f;
 	}
 
 	/* Calculate absolute total range */
 	adj = pc->adj;
-	total_range = (adj != NULL) ? (adj->upper - adj->lower) : 0.0;
+	total_range = (adj != NULL) ? (adj->upper - adj->lower) : 0.0f;
 
 	/* Check if more of the values range is visible on the `lower'
 	 * side
@@ -485,9 +504,9 @@ static void PieChartDrawPieIterate(
 	 * Note that angles are in units from 0.0 to 1.0 starting at
 	 * the 12 o'clock position being 0.0 going clockwise
 	 */
-	values_range_coeff = (total_range > 0.0) ?
-	    (values_range / total_range) : 0.0;
-	if(values_range_coeff < 0.5)
+	values_range_coeff = (total_range > 0.0f) ?
+	    (values_range / total_range) : 0.0f;
+	if(values_range_coeff < 0.5f)
 	{
 	    gfloat value_pos_coeff = 0.5 + (values_range_coeff / 2.0);
 	    gfloat value_pos_delta;
@@ -500,101 +519,104 @@ static void PieChartDrawPieIterate(
 		outline_circumference, outline_radius,
 		outline_height
 	    );
-	    /* Do not draw beyond this point if this disk is to be a
-	     * shadow.
-	     */
-	    if(shadow)
-		return;
-
-	    /* Draw each value */
-	    for(i = 0; i < pc->total_values; i++)
+	    /* Draw each value only if this disk is not a shadow */
+	    if(!shadow)
 	    {
-		value_ptr = pc->value[i];
-		if(value_ptr == NULL)
-		    continue;
-
-		adj = value_ptr->adj;
-		if((adj != NULL) && (total_range > 0.0))
-		    value_pos_delta = (adj->upper - adj->lower) /
-			total_range;
-		else
-		    value_pos_delta = 0.0;
-
-		if(!outline)
+		/* Draw each value */
+		for(glist = pc->values_list;
+		    glist != NULL;
+		    glist = g_list_next(glist)
+		)
 		{
-		    if(shaded)
-			gdk_gc_set_foreground(gc, &value_ptr->c_shade);
+		    v = PIE_CHART_VALUE(glist->data);
+		    if(v == NULL)
+			continue;
+
+		    adj = v->adj;
+		    if((adj != NULL) && (total_range > 0.0f))
+			value_pos_delta = (adj->upper - adj->lower) /
+			    total_range;
 		    else
-			gdk_gc_set_foreground(gc, &value_ptr->c);
-		    gdk_gc_set_fill(gc, GDK_SOLID);
+			value_pos_delta = 0.0f;
+
+		    if(!outline)
+		    {
+			if(shaded)
+			    gdk_gc_set_foreground(gc, &v->c_shade);
+			else
+			    gdk_gc_set_foreground(gc, &v->c);
+			gdk_gc_set_fill(gc, GDK_SOLID);
+		    }
+
+		    PieChartDrawArc(
+			pixmap, gc, x, y, width, height,
+			value_pos_coeff, value_pos_coeff - value_pos_delta,
+			outline_circumference, outline_radius,
+			outline_height
+		    );
+
+		    value_pos_coeff -= value_pos_delta;
 		}
-
-		PieChartDrawArc(
-		    pixmap, gc, x, y, width, height,
-		    value_pos_coeff, value_pos_coeff - value_pos_delta,
-		    outline_circumference, outline_radius,
-		    outline_height
-		);
-
-		value_pos_coeff -= value_pos_delta;
 	    }
 	}
 	else
 	{
-	    gfloat value_pos_coeff = 1.0 - (values_range_coeff / 2.0);
-	    gfloat value_pos_delta;
-
+	    gfloat	value_pos_coeff = 1.0f - (values_range_coeff / 2.0f),
+			value_pos_delta;
 
 	    /* Draw base disk */
 	    PieChartDrawArc(
 		pixmap, gc, x, y, width, height,
-		0.0, 1.0,
+		0.0f, 1.0f,
 		outline_circumference, outline_radius,
 		outline_height
 	    );
-	    /* Do not draw beyond this point if this disk is to be a
-	     * shadow.
-	     */
-	    if(shadow)
-		return;
 
-	    /* Draw each value */
-	    for(i = 0; i < pc->total_values; i++)
+	    /* Draw each value only if this disk is not a shadow */
+	    if(!shadow)
 	    {
-		value_ptr = pc->value[i];
-		if(value_ptr == NULL)
-		    continue;
-
-		adj = value_ptr->adj;
-		if((adj != NULL) && (total_range > 0.0))
-		    value_pos_delta = (adj->upper - adj->lower) /
-			total_range;
-		else
-		    value_pos_delta = 0.0;
-
-		if(!outline)
+		/* Draw each value */
+		for(glist = pc->values_list;
+		    glist != NULL;
+		    glist = g_list_next(glist)
+		)
 		{
-		    if(shaded)
-			gdk_gc_set_foreground(gc, &value_ptr->c_shade);
+		    v = PIE_CHART_VALUE(glist->data);
+		    if(v == NULL)
+			continue;
+
+		    adj = v->adj;
+		    if((adj != NULL) && (total_range > 0.0f))
+			value_pos_delta = (adj->upper - adj->lower) /
+			    total_range;
 		    else
-			gdk_gc_set_foreground(gc, &value_ptr->c);
-		    gdk_gc_set_fill(gc, GDK_SOLID);
+			value_pos_delta = 0.0f;
+
+		    if(!outline)
+		    {
+			if(shaded)
+			    gdk_gc_set_foreground(gc, &v->c_shade);
+			else
+			    gdk_gc_set_foreground(gc, &v->c);
+			gdk_gc_set_fill(gc, GDK_SOLID);
+		    }
+
+		    PieChartDrawArc(
+			pixmap, gc, x, y, width, height,
+			value_pos_coeff, value_pos_coeff + value_pos_delta,
+			outline_circumference, outline_radius,
+			outline_height
+		    );
+
+		    value_pos_coeff += value_pos_delta;
 		}
 
-		PieChartDrawArc(
-		    pixmap, gc, x, y, width, height,
-		    value_pos_coeff, value_pos_coeff + value_pos_delta,
-		    outline_circumference, outline_radius,
-		    outline_height
-		);
-
-		value_pos_coeff += value_pos_delta;
 	    }
 	}
 }
 
 /*
- *	Redraws the off screen buffer pixmap on the given pie chart.
+ *	Redraws the off screen buffer pixmap.
  *
  *	The pie chart will be realized as needed.
  */
@@ -608,7 +630,6 @@ static void PieChartRedrawPixmap(pie_chart_struct *pc)
 	GtkStyle *style;
 	GtkWidget *w;
 
-
 	if(pc == NULL)
 	    return;
 
@@ -624,11 +645,12 @@ static void PieChartRedrawPixmap(pie_chart_struct *pc)
 	if((window == NULL) || (style == NULL))
 	    return;
 
+	/* Realize the pie chart as needed */
 	if(!pc->realized)
-	    PieChartDoRealize(pc);
+	    PieChartRealize(pc);
 
-	/* Get offscreen buffer pixmap that we will be drawing to,
-	 * this pixmap should be created in PieChartDoRealize()
+	/* Get the offscreen buffer pixmap that we will be drawing to,
+	 * this pixmap should be created in PieChartRealize()
 	 */
 	pixmap = pc->pixmap;
 	if(pixmap == NULL)
@@ -637,14 +659,12 @@ static void PieChartRedrawPixmap(pie_chart_struct *pc)
 	state = GTK_WIDGET_STATE(w);
 	gdk_window_get_size(pixmap, &width, &height);
 
-
-	/* Get graphics context */
+	/* Get the graphics context */
 	gc = pc->gc;
 	if(gc == NULL)
 	    return;
 
-
-	/* Begin drawing */
+	/* Begin drawing the pie chart */
 
 	/* Draw background */
 	gtk_style_apply_default_background(
@@ -738,47 +758,49 @@ static gint PieChartValueLabelExposeCB(
 	GtkWidget *widget, GdkEventExpose *expose, gpointer data
 )
 {
-	gint i, state, width, height;
+	gint width, height;
+	GList *glist;
 	GdkColor *c_bg;
 	GdkGC *gc;
 	GdkWindow *window;
+	GtkStateType state;
 	GtkStyle *style;
-	pie_chart_value_struct *value_ptr;
+	pie_chart_value_struct *v;
 	pie_chart_struct *pc = PIE_CHART(data);
 	if((widget == NULL) || (pc == NULL))
 	    return(FALSE);
 
-
-	/* Find value structure that contains this drawing area */
-	value_ptr = NULL;
-	for(i = 0; i < pc->total_values; i++)
+	/* Find the value that contains this GtkDrawingArea */
+	v = NULL;
+	for(glist = pc->values_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    value_ptr = pc->value[i];
-	    if(value_ptr == NULL)
+	    v = PIE_CHART_VALUE(glist->data);
+	    if(v == NULL)
 		continue;
 
-	    if(value_ptr->drawing_area == widget)
+	    if(v->drawing_area == widget)
 		break;
 	}
-	if(i >= pc->total_values)
-	    value_ptr = NULL;
-	if(value_ptr != NULL)
+	if(glist == NULL)
+	    v = NULL;
+	if(v != NULL)
 	{
-	    c_bg = &value_ptr->c;
+	    c_bg = &v->c;
 	}
 	else
 	{
 	    c_bg = &pc->c;
 	}
 
-
 	state = GTK_WIDGET_STATE(widget);
 	window = widget->window;
 	style = gtk_widget_get_style(widget);
 	if((window == NULL) || (style == NULL))
 	    return(FALSE);
 
-
 	gdk_window_get_size(window, &width, &height);
 	
 	gc = pc->gc;
@@ -859,8 +881,67 @@ static gint PieChartExposeCB(
 
 
 /*
- *	Adds a new value to the pie chart, returns an index id to that
- *	value or -1 on failure.
+ *	Creates a new pie chart value.
+ */
+pie_chart_value_struct *PieChartValueNew(void)
+{
+	return(PIE_CHART_VALUE(g_malloc0(sizeof(pie_chart_value_struct))));
+}
+
+/*
+ *	Deletes the pie chart value.
+ */
+void PieChartValueDelete(pie_chart_value_struct *v)
+{
+	GdkColormap *colormap;
+	pie_chart_struct *pc;
+
+	if(v == NULL)
+	    return;
+
+	/* Get the pie chart that this value is on */
+	pc = v->pc;
+
+	/* Unref the GtkAdjustment */
+	if(v->adj != NULL)
+	{
+	    gtk_object_unref(GTK_OBJECT(v->adj));
+	    v->adj = NULL;
+	}
+
+	/* Delete the GdkColors */
+	colormap = (pc != NULL) ? pc->colormap : NULL;
+	if(colormap != NULL)
+	{
+	    GDK_COLORMAP_FREE_COLOR(colormap, &v->c);
+/*	    memset(&v->c, 0x00, sizeof(GdkColor)); */
+
+	    GDK_COLORMAP_FREE_COLOR(colormap, &v->c_shade);
+/*	    memset(&v->c_shade, 0x00, sizeof(GdkColor)); */
+	}
+
+	/* Label GtkHBox */
+	if(v->type_label_hbox != NULL)
+	{
+	    gtk_widget_destroy(v->type_label_hbox);
+	    v->type_label_hbox = NULL;
+	}
+	if(v->value_label_hbox != NULL)
+	{
+	    gtk_widget_destroy(v->value_label_hbox);
+	    v->value_label_hbox = NULL;
+	}
+/*	v->drawing_area = NULL; */
+
+	g_free(v->type_label);
+	g_free(v->value_label);
+
+	g_free(v);
+}
+
+
+/*
+ *	Adds a new value to the pie chart.
  */
 gint PieChartValueAdd(
 	pie_chart_struct *pc,
@@ -868,105 +949,79 @@ gint PieChartValueAdd(
 	const gchar *type_label, const gchar *value_label
 )
 {
-	int i;
+	gint i;
+	GdkColor *tc;
 	GdkColormap *colormap;
-	pie_chart_value_struct *value_ptr;
-
+	pie_chart_value_struct *v;
 
 	if((pc == NULL) || (adj == NULL) || (c == NULL))
-	    return(-1);
+	    return(-2);
 
-	/* Sanitize total */
-	if(pc->total_values < 0)
-	    pc->total_values = 0;
+	/* Create a new pie chart value */
+	v = PieChartValueNew();
+	if(v == NULL)
+	    return(-3);
 
-	/* Allocate more pointers */
-	i = pc->total_values;
-	pc->total_values = i + 1;
-	pc->value = (pie_chart_value_struct **)g_realloc(
-	    pc->value,
-	    pc->total_values * sizeof(pie_chart_value_struct *)
-	);
-	if(pc->value == NULL)
+	i = g_list_length(pc->values_list);
+
+	/* Add the new pie chart value to the values list */
+	pc->values_list = g_list_append(pc->values_list, v);
+
+	/* Set the pie chart that this value is on */
+	v->pc = pc;
+
+	/* Set the GtkAdjustment */
+	gtk_object_ref(GTK_OBJECT(adj));
+	v->adj = adj;
+
+	/* Set the GdkColor */
+	tc = &v->c;
+	memcpy(tc, c, sizeof(GdkColor));
+
+	tc = &v->c_shade;
+	tc->red = c->red / 2;
+	tc->green = c->green / 2;
+	tc->blue = c->blue / 2;
+
+	colormap = pc->colormap;
+	if(colormap != NULL)
 	{
-	    pc->total_values = 0;
-	    return(-1);
+	    GDK_COLORMAP_ALLOC_COLOR(colormap, &v->c);
+	    GDK_COLORMAP_ALLOC_COLOR(colormap, &v->c_shade);
 	}
 
-	/* Allocate a new value structure */
-	pc->value[i] = value_ptr = (pie_chart_value_struct *)g_malloc0(
-	    sizeof(pie_chart_value_struct)
-	);
-	if(value_ptr != NULL)
-	{
-	    GdkColor *tc;
+	v->type_label = STRDUP(type_label);
+	v->value_label = STRDUP(value_label);
 
-	    /* Add a refcount to the given adjustment and assign it */
-	    gtk_object_ref(GTK_OBJECT(adj));
-	    value_ptr->adj = adj;
-
-	    /* Set given color, allocate it if the colormap is set */
-	    tc = &value_ptr->c;
-	    memcpy(tc, c, sizeof(GdkColor));
-
-	    tc = &value_ptr->c_shade;
-	    tc->red = c->red / 2;
-	    tc->green = c->green / 2;
-	    tc->blue = c->blue / 2;
-
-	    colormap = pc->colormap;
-	    if(colormap != NULL)
-	    {
-		GDK_COLORMAP_ALLOC_COLOR(
-		    colormap, &value_ptr->c
-		)
-		GDK_COLORMAP_ALLOC_COLOR(
-		    colormap, &value_ptr->c_shade
-		)
-	    }
-
-	    value_ptr->type_label = STRDUP(type_label);
-	    value_ptr->value_label = STRDUP(value_label);
-
-	    return(i);
-	}
-	else
-	{
-	    return(-1);
-	}
+	return(i);
 }
 
 /*
- *	Sets the value specified by index value_num on the given pie 
- *	chart.
+ *	Sets the value on the pie chart.
  */
 void PieChartValueSet(
-	pie_chart_struct *pc, gint value_num,
+	pie_chart_struct *pc, const gint value_num,
 	GtkAdjustment *adj, GdkColor *c,
 	const gchar *type_label, const gchar *value_label
 )
 {
 	GdkColormap *colormap;
-	pie_chart_value_struct *value_ptr;
-
+	pie_chart_value_struct *v;
 
 	if((pc == NULL) || (adj == NULL) || (c == NULL))
 	    return;
 
-	if((value_num < 0) || (value_num >= pc->total_values))
-	    return;
-
-	value_ptr = pc->value[value_num];
-	if(value_ptr == NULL)
+	v = PIE_CHART_VALUE(g_list_nth_data(pc->values_list, value_num));
+	if(v == NULL)
 	    return;
 
 	/* Add refcount to given adjustment, remove refcount from existing
 	 * adjustment and assign given adjustment.
 	 */
 	gtk_object_ref(GTK_OBJECT(adj));
-	if(value_ptr->adj != NULL)
-	    gtk_object_unref(GTK_OBJECT(value_ptr->adj));
-	value_ptr->adj = adj;
+	if(v->adj != NULL)
+	    gtk_object_unref(GTK_OBJECT(v->adj));
+	v->adj = adj;
 
 	/* Delete old color if colormap is available, set new color
 	 * and allocate it if colormap is available
@@ -976,152 +1031,105 @@ void PieChartValueSet(
 	{
 	    GdkColor *tc;
 
-	    tc = &value_ptr->c;
-	    GDK_COLORMAP_FREE_COLOR(colormap, tc)
+	    tc = &v->c;
+	    GDK_COLORMAP_FREE_COLOR(colormap, tc);
 	    memcpy(tc, c, sizeof(GdkColor));
-	    GDK_COLORMAP_ALLOC_COLOR(colormap, tc)
+	    GDK_COLORMAP_ALLOC_COLOR(colormap, tc);
 
-	    tc = &value_ptr->c_shade;
-	    GDK_COLORMAP_FREE_COLOR(colormap, tc)
+	    tc = &v->c_shade;
+	    GDK_COLORMAP_FREE_COLOR(colormap, tc);
 	    tc->red = c->red / 2;
 	    tc->green = c->green / 2;
 	    tc->blue = c->blue / 2;
-	    GDK_COLORMAP_ALLOC_COLOR(colormap, tc)
+	    GDK_COLORMAP_ALLOC_COLOR(colormap, tc);
 	}
 	else
 	{
 	    GdkColor *tc;
 
-	    tc = &value_ptr->c;
+	    tc = &v->c;
 	    memcpy(tc, c, sizeof(GdkColor));
 
-	    tc = &value_ptr->c_shade;
+	    tc = &v->c_shade;
 	    tc->red = c->red / 2;
 	    tc->green = c->green / 2;
 	    tc->blue = c->blue / 2;
 	}
 
+	/* Set the new label text */
+	g_free(v->type_label);
+	v->type_label = STRDUP(type_label);
 
-	/* Set new label text */
-	g_free(value_ptr->type_label);
-	value_ptr->type_label = STRDUP(type_label);
-
-	g_free(value_ptr->value_label);
-	value_ptr->value_label = STRDUP(value_label);
+	g_free(v->value_label);
+	v->value_label = STRDUP(value_label);
 
 /* Need to recreate pixmap */
 }
 
 /*
- *	Removes the value specified by index value_num on the given pie
- *	chart.
+ *	Removes the value from the pie chart.
  */
 void PieChartValueRemove(
-	pie_chart_struct *pc, gint value_num
+	pie_chart_struct *pc, const gint value_num
 )
 {
-	pie_chart_value_struct *value_ptr;
-	GdkColormap *colormap;
-
+	pie_chart_value_struct *v;
 
 	if(pc == NULL)
 	    return;
 
-	if((value_num < 0) || (value_num >= pc->total_values))
+	v = PIE_CHART_VALUE(g_list_nth_data(pc->values_list, value_num));
+	if(v == NULL)
 	    return;
 
-	value_ptr = pc->value[value_num];
-	if(value_ptr == NULL)
-	    return;
-
-
-	/* Unref adjustment */
-	if(value_ptr->adj != NULL)
-	{
-	    gtk_object_unref(GTK_OBJECT(value_ptr->adj));
-	    value_ptr->adj = NULL;
-	}
-
-	/* Free color */
-	colormap = pc->colormap;
-	if(colormap != NULL)
-	{
-	    GDK_COLORMAP_FREE_COLOR(colormap, &value_ptr->c)
-	    memset(&value_ptr->c, 0x00, sizeof(GdkColor));
-
-	    GDK_COLORMAP_FREE_COLOR(colormap, &value_ptr->c_shade)
-	    memset(&value_ptr->c_shade, 0x00, sizeof(GdkColor));
-	}
-
-	/* Label hbox */
-	if(value_ptr->type_label_hbox != NULL)
-	{
-	    gtk_widget_destroy(value_ptr->type_label_hbox);
-	    value_ptr->type_label_hbox = NULL;
-	}
-	if(value_ptr->value_label_hbox != NULL)
-	{
-	    gtk_widget_destroy(value_ptr->value_label_hbox);
-	    value_ptr->value_label_hbox = NULL;
-	}
-	value_ptr->drawing_area = NULL;
-
-	/* Labels */
-	g_free(value_ptr->type_label);
-	value_ptr->type_label = NULL;
-	g_free(value_ptr->value_label);
-	value_ptr->value_label = NULL;
-
-
-	/* Deallocate structure itself and mark it as having been 
-	 * deallocated.
-	 */
-	g_free(value_ptr);
-	pc->value[value_num] = value_ptr = NULL;
+	PieChartValueDelete(v);
+	g_list_remove(pc->values_list, v);
 }
 
 /*
  *	Removes all values on the given pie chart.
  */
-void PieChartValueRemoveAll(pie_chart_struct *pc)
+void PieChartClear(pie_chart_struct *pc)
 {
-	gint i;
-
-
 	if(pc == NULL)
 	    return;
 
-	for(i = 0; i < pc->total_values; i++)
-	    PieChartValueRemove(pc, i);
-
-	g_free(pc->value);
-	pc->value = NULL;
-	pc->total_values = 0;
+	if(pc->values_list != NULL)
+	{
+	    g_list_foreach(pc->values_list, (GFunc)PieChartValueDelete, NULL);
+	    g_list_free(pc->values_list);
+	    pc->values_list = NULL;
+	}
 }
 
 
-
 /*
  *	Creates a new pie chart widget.
  */
 pie_chart_struct *PieChartNew(
-	GtkAdjustment *adj, GdkColor *c, gint width, gint height,
+	const gint width, const gint height,
+	GtkAdjustment *adj,
+	GdkColor *c,
 	const gchar *title, const gchar *footer,
 	const gchar *base_type_label, const gchar *base_value_label
 )
 {
 	const gint	border_major = 5,
 			border_minor = 2;
-	GtkWidget *w, *parent, *parent2;
+	GtkWidget *w, *parent, *parent2, *toplevel;
 	pie_chart_struct *pc = PIE_CHART(g_malloc0(
 	    sizeof(pie_chart_struct)
 	));
 	if(pc == NULL)
 	    return(pc);
 
-	/* Reset values */
-	pc->initialized = TRUE;
+	pc->toplevel = toplevel = gtk_vbox_new(FALSE, border_minor);
+	pc->realized = FALSE;
 	pc->map_state = FALSE;
+	pc->show_labels = TRUE;
+	pc->shadows = TRUE;
+	pc->outline = TRUE;
+	pc->freeze_count = 0;
 	pc->width = width;
 	pc->height = height;
 	pc->pixmap = NULL;
@@ -1143,26 +1151,17 @@ pie_chart_struct *PieChartNew(
 	pc->base_value_label = STRDUP(base_value_label);
 	pc->gc = NULL;
 	pc->colormap = NULL;
-	pc->realized = FALSE;
-	pc->value = NULL;
-	pc->total_values = 0;
+	pc->values_list = NULL;
 
-	pc->show_labels = TRUE;
-	pc->shadows = TRUE;
-	pc->outline = TRUE;
-
-
-	/* Transfer given adjustment over and add a refcount for 
-	 * ourselves
-	 */
+	/* Claim the specified GtkAdjustment */
 	pc->adj = adj;
 	if(adj != NULL)
 	    gtk_object_ref(GTK_OBJECT(adj));
 
+	pc->freeze_count++;
 
-	/* Create toplevel vbox */
-	pc->toplevel = w = gtk_vbox_new(FALSE, border_minor);
-	gtk_widget_show(w);
+	/* Toplevel GtkVBox */
+	w = toplevel;
 	parent = w;
 
 	/* Create title label if title string is given */
@@ -1174,35 +1173,35 @@ pie_chart_struct *PieChartNew(
 	}
 
 
-	/* Create hbox for columnizing type and value labels */
+	/* Type and value labels GtkHBox */
 	w = gtk_hbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Create vbox for type labels */
+	/* Type labels GtkVBox */
 	pc->type_labels_vbox = w = gtk_vbox_new(FALSE, border_minor);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 
-	/* Hbox to center right column vbox */
+	/* Center right column GtkHBox */
 	w = gtk_hbox_new(TRUE, border_minor);
 	gtk_box_pack_start(GTK_BOX(parent2), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
-	/* Create vbox for value labels */
+	/* Value labels GtkVBox */
 	pc->value_labels_vbox = w = gtk_vbox_new(FALSE, border_minor);
 	gtk_box_pack_start(GTK_BOX(parent2), w, TRUE, FALSE, 0);
 	gtk_widget_show(w);
 
 
-	/* Create hbox to center pie chart drawing area */
+	/* Pie chart GtkHBox */
 	w = gtk_hbox_new(TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Drawing area */
+	/* Pie chart GtkDrawingArea */
 	pc->drawing_area = w = gtk_drawing_area_new();
 	gtk_widget_set_usize(w, width, height);
 	gtk_widget_add_events(w, GDK_EXPOSURE_MASK);
@@ -1213,7 +1212,7 @@ pie_chart_struct *PieChartNew(
 	gtk_box_pack_start(GTK_BOX(parent2), w, TRUE, FALSE, 0);
 	gtk_widget_show(w);
 
-	/* Create footer label if title string is given */
+	/* Create footer label if the title is specified */
 	if(footer != NULL)
 	{
 	    pc->footer_label = w = gtk_label_new(footer);
@@ -1221,7 +1220,7 @@ pie_chart_struct *PieChartNew(
 	    gtk_widget_show(w);
 	}
 
-
+	pc->freeze_count--;
 
 	return(pc);
 }
@@ -1231,21 +1230,11 @@ pie_chart_struct *PieChartNew(
  */
 void PieChartMap(pie_chart_struct *pc)
 {
-	GtkWidget *w;
-
-
 	if(pc == NULL)
 	    return;
 
-	w = pc->toplevel;
-	if(w == NULL)
-	    return;
-
-	if(!pc->map_state)
-	{
-	    gtk_widget_show(w);
-	    pc->map_state = TRUE;
-	}
+	gtk_widget_show(pc->toplevel);
+	pc->map_state = TRUE;
 }
 
 /*
@@ -1253,25 +1242,15 @@ void PieChartMap(pie_chart_struct *pc)
  */
 void PieChartUnmap(pie_chart_struct *pc)
 {
-	GtkWidget *w;
-
-
 	if(pc == NULL)
 	    return;
 
-	w = pc->toplevel;
-	if(w == NULL)
-	    return;
-
-	if(pc->map_state)
-	{
-	    gtk_widget_hide(w);
-	    pc->map_state = FALSE;
-	}
+	gtk_widget_hide(pc->toplevel);
+	pc->map_state = FALSE;
 }
 
 /*
- *	Deallocates the given pie chart and all its resources.
+ *	Deletes the pie chart.
  */
 void PieChartDelete(pie_chart_struct *pc)
 {
@@ -1280,36 +1259,30 @@ void PieChartDelete(pie_chart_struct *pc)
 	if(pc == NULL)
 	    return;
 
+	pc->freeze_count++;
+
+	/* Delete all the values */
+	PieChartClear(pc);
+
+	/* Delete all the colors */
 	colormap = pc->colormap;
+	GDK_COLORMAP_FREE_COLOR(colormap, &pc->c);
+	GDK_COLORMAP_FREE_COLOR(colormap, &pc->c_shade);
+	GDK_COLORMAP_FREE_COLOR(colormap, &pc->c_shadow);
 
-	/* Remove all value structures from the pie chart */
-	PieChartValueRemoveAll(pc);
+	GTK_OBJECT_UNREF(pc->adj);
 
-	/* Delete colors */
-	GDK_COLORMAP_FREE_COLOR(colormap, &pc->c)
-	GDK_COLORMAP_FREE_COLOR(colormap, &pc->c_shade)
-	GDK_COLORMAP_FREE_COLOR(colormap, &pc->c_shadow)
+	GDK_PIXMAP_UNREF(pc->pixmap);
 
-	GTK_OBJECT_UNREF(pc->adj)
+	gtk_widget_destroy(pc->toplevel);
 
-	GDK_PIXMAP_UNREF(pc->pixmap)
-
-	/* Begin destroying widgets */
-	GTK_WIDGET_DESTROY(pc->footer_label)
-	GTK_WIDGET_DESTROY(pc->title_label)
-	GTK_WIDGET_DESTROY(pc->type_labels_vbox)
-	GTK_WIDGET_DESTROY(pc->value_labels_vbox)
-	GTK_WIDGET_DESTROY(pc->drawing_area)
-	GTK_WIDGET_DESTROY(pc->toplevel)
-
-	GDK_GC_UNREF(pc->gc)
-
-	GDK_COLORMAP_UNREF(pc->colormap)
-
-	pc->realized = FALSE;
+	GDK_GC_UNREF(pc->gc);
+	GDK_COLORMAP_UNREF(pc->colormap);
 
 	g_free(pc->base_type_label);
 	g_free(pc->base_value_label);
 
+	pc->freeze_count--;
+
 	g_free(pc);
 }
