@@ -13,59 +13,10 @@
 #include "progressdialog.h"
 
 
-/*
- *	Animated Icon:
- */
-typedef struct {
-
-	GdkPixmap	*pixmap;
-	GdkBitmap	*mask;
-	gint		width, height;
-
-} icon_struct;
-#define ICON(p)		((icon_struct *)(p))
-
-/*
- *	Progress Dialog:
- */
-typedef struct {
-
-	gboolean	initialized,
-			map_state;
-	gint		stop_count;
-	GtkWidget	*transient_for;		/* Transient for widget */
-
-	GtkAccelGroup	*accelgrp;
-
-	GtkWidget	*toplevel,
-			*main_vbox,
-			*icon_vbox,	/* Holds icon fixed and pixmap widgets */
-			*icon_fixed,	/* For single icon mode */
-			*icon_pm,
-			*label,
-			*progress_bar,
-			*stop_btn,
-			*stop_btn_label;
-
-	/* Members for animated progress display */
-	GdkGC		*animation_gc;
-	GtkWidget	*animation_da;
-	GdkPixmap	*animation_buffer;
-	guint16		animation_position,
-			animation_increment;
-	gulong		animation_time_last,
-			animation_interval;	/* In ms */
-
-	icon_struct	**start_icon;
-	gint		total_start_icons;
-	icon_struct	**icon;
-	gint		total_icons;
-	icon_struct	**end_icon;
-	gint		total_end_icons;
-
-} progress_dialog_struct;
-#define PROGRESS_DIALOG(p)	((progress_dialog_struct *)(p))
-static progress_dialog_struct progress_dialog;
+typedef struct _ProgressDialogIcon	ProgressDialogIcon;
+#define PROGRESS_DIALOG_ICON(p)		((ProgressDialogIcon *)(p))
+typedef struct _ProgressDialog		ProgressDialog;
+#define PROGRESS_DIALOG(p)		((ProgressDialog *)(p))
 
 
 /* Callbacks */
@@ -80,13 +31,13 @@ static gint ProgressDialogAnimationDrawCB(
 /* Utilities */
 static gulong ProgressDialogCurrentTime(void);
 static void ProgressDialogChangeIcon(
-	progress_dialog_struct *pd, const guint8 **icon_data
+	ProgressDialog *pd, const guint8 **icon_data
 );
-static icon_struct *ProgressDialogIconNew(
-	progress_dialog_struct *pd, const guint8 **icon_data
+static ProgressDialogIcon *ProgressDialogIconNew(
+	ProgressDialog *pd, const guint8 **icon_data
 );
-static void ProgressDialogIconDelete(icon_struct *icon);
-static void ProgressDialogIconDeleteAll(progress_dialog_struct *pd);
+static void ProgressDialogIconDelete(ProgressDialogIcon *icon);
+static void ProgressDialogIconDeleteAll(ProgressDialog *pd);
 
 /* Front Ends */
 gint ProgressDialogInit(void);
@@ -117,25 +68,28 @@ void ProgressDialogUpdate(
 	const gchar *label,
 	const guint8 **icon_data,
 	const gchar *stop_btn_label,
-	gdouble position,		/* 0.0 to 1.0 */
-	guint nblocks,			/* 0 for continuous */
-	gboolean allow_gtk_iteration
+	const gfloat position,		/* 0.0 to 1.0 */
+	const guint nblocks,		/* 0 for continuous */
+	const gboolean allow_gtk_iteration
 );
 void ProgressDialogUpdateUnknown(
 	const gchar *title,
 	const gchar *label,
 	const guint8 **icon_data,
 	const gchar *stop_btn_label,
-	gboolean allow_gtk_iteration
+	const gboolean allow_gtk_iteration
 );
 void ProgressDialogUnmap(void);
 void ProgressDialogShutdown(void);
 
 
+static ProgressDialog progress_dialog;
+
+
 #define PROGRESS_DIALOG_WIDTH		380
 #define PROGRESS_DIALOG_HEIGHT		-1
 
-#define PROGRESS_DIALOG_ANIMATION_DA_WIDTH      270
+#define PROGRESS_DIALOG_ANIMATION_DA_WIDTH	270
 #define PROGRESS_DIALOG_ANIMATION_DA_HEIGHT	45
 
 
@@ -143,17 +97,75 @@ void ProgressDialogShutdown(void);
 #define PROGRESS_DIALOG_PROGRESS_HEIGHT		20
 
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+/*
+ *	Icon:
+ *
+ *	Used in animation.
+ */
+struct _ProgressDialogIcon {
+
+	GdkPixmap	*pixmap;
+	GdkBitmap	*mask;
+	gint		width, height;
+
+};
+
+/*
+ *	Progress Dialog:
+ */
+struct _ProgressDialog {
+
+	GtkWidget	*toplevel;
+	GtkAccelGroup	*accelgrp;
+	gboolean	initialized,
+			map_state;
+	gint		stop_count;
+
+	GtkWidget	*transient_for;		/* Transient for widget */
+
+	GtkWidget	*main_vbox,
+			*icon_vbox,	/* Holds icon fixed and pixmap widgets */
+			*icon_fixed,	/* For single icon mode */
+			*icon_pm,
+			*label,
+			*progress_bar,
+			*stop_btn,
+			*stop_btn_label;
+
+	/* Animated Progress */
+	GdkGC		*animation_gc;
+	GtkWidget	*animation_da;
+	GdkPixmap	*animation_buffer;
+	guint16		animation_position,
+			animation_increment;
+	gulong		animation_time_last,
+			animation_interval;	/* In ms */
+
+	GList		*start_icons_list,
+			*icons_list,
+			*end_icons_list;
+
+};
+
+
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
- *	Stop button callback.
+ *	Stop callback.
  */
 static void ProgressDialogStopCB(GtkWidget *w, gpointer data)
 {
-	progress_dialog_struct *pd = PROGRESS_DIALOG(data);
+	ProgressDialog *pd = PROGRESS_DIALOG(data);
 	if(pd == NULL)
 	    return;
 
@@ -161,10 +173,11 @@ static void ProgressDialogStopCB(GtkWidget *w, gpointer data)
 	    pd->stop_count = 0;
 
 	pd->stop_count++;
-
+#if 0
 	/* Give up on the fifth press? */
 	if(pd->stop_count >= 5)
 	    ProgressDialogUnmap();
+#endif
 }
 
 /*
@@ -175,7 +188,6 @@ static gint ProgressDialogCloseCB(
 )
 {
 	ProgressDialogStopCB(widget, data);
-
 	return(TRUE);
 }
 
@@ -187,12 +199,12 @@ static gint ProgressDialogAnimationDrawCB(
 )
 {
 	GtkStateType state;
-	gint	width,
-		height,
+	gint	width, height,
 		start_icon_width = 0,
 		end_icon_width = 0,
+		nicons,
 		frame,
-		total_frames,
+		nframes,
 		anim_per_frame;
 	GdkGC *gc;
 	GdkWindow *window;
@@ -200,7 +212,7 @@ static gint ProgressDialogAnimationDrawCB(
 	GdkDrawable *drawable;
 	GtkStyle *style;
 	GtkWidget *w;
-	progress_dialog_struct *pd = PROGRESS_DIALOG(data);
+	ProgressDialog *pd = PROGRESS_DIALOG(data);
 	if(pd == NULL)
 	    return(TRUE);
 
@@ -229,7 +241,7 @@ static gint ProgressDialogAnimationDrawCB(
 
 	/* Begin drawing */
 
-	/* Draw background */
+	/* Draw the background */
 	gtk_style_apply_default_background(
 	    style, drawable, FALSE, state,
 	    NULL,
@@ -237,51 +249,47 @@ static gint ProgressDialogAnimationDrawCB(
 	);
 
 
-	/* Begin drawing icons */
+	/* Begin drawing the icons */
 
 	/* Calculate total frames, this is the number of icons in the
 	 * inside animatino frame plus two end point icons (the start and
 	 * end icons)
 	 */
-	total_frames = MAX(pd->total_icons + 2, 2);
+	nicons = g_list_length(pd->icons_list);
+	nframes = MAX((nicons + 2), 2);
 
 	/* Calculate animation frame index */
 	frame = (gint)(
 	    (gfloat)pd->animation_position / (gfloat)((guint16)-1) *
-	    total_frames
+	    nframes
 	);
 
 	/* Calculate number of animation units in one frame */
-	if(total_frames > 0)
-	    anim_per_frame = (gint)((guint16)-1) / total_frames;
+	if(nframes > 0)
+	    anim_per_frame = (gint)((guint16)-1) / nframes;
 	else
 	    anim_per_frame = 0;
 
-
-	/* Draw start icons */
-	if(pd->total_start_icons > 0)
+	/* Draw the start icons */
+	if(pd->start_icons_list != NULL)
 	{
-	    icon_struct *icon;
+	    ProgressDialogIcon *icon;
 
-	    /* Check which icon structure to draw based on frame index */
-	    if((frame == 0) && (pd->total_start_icons > 0))
-	    {
-		icon = pd->start_icon[0];
-	    }
-	    else if((frame == (total_frames - 1)) && (pd->total_start_icons > 2))
-	    {
-		icon = pd->start_icon[2];
-	    }
-	    else if(pd->total_start_icons > 1)
-	    {
-		icon = pd->start_icon[1];
-	    }
+	    /* Get the icon based on the frame index */
+	    if(frame == 0)
+		icon = PROGRESS_DIALOG_ICON(g_list_nth_data(
+		    pd->start_icons_list, 0
+		));
+	    else if(frame == (nframes - 1))
+		icon = PROGRESS_DIALOG_ICON(g_list_nth_data(
+		    pd->start_icons_list, 2
+		));
 	    else
-	    {
-		icon = NULL;
-	    }
+		icon = PROGRESS_DIALOG_ICON(g_list_nth_data(
+		    pd->start_icons_list, 1
+		));
 
-	    /* Got icon? */
+	    /* Got the icon? */
 	    if(icon != NULL)
 	    {
 		gint    icon_width = icon->width,
@@ -318,30 +326,26 @@ static gint ProgressDialogAnimationDrawCB(
 	    }
 	}
 
-	/* Draw end icons */
-	if(pd->total_end_icons > 0)
+	/* Draw the end icons */
+	if(pd->end_icons_list != NULL)
 	{
-	    icon_struct *icon;
+	    ProgressDialogIcon *icon;
 
-	    /* Check which icon structure to draw based on frame index */
-	    if((frame == 0) && (pd->total_end_icons > 0))
-	    {
-		icon = pd->end_icon[0];
-	    }
-	    else if((frame == (total_frames - 1)) && (pd->total_end_icons > 2))
-	    {
-		icon = pd->end_icon[2];
-	    }
-	    else if(pd->total_end_icons > 1)
-	    {
-		icon = pd->end_icon[1];
-	    }
+	    /* Get the icon based on the frame index */
+	    if(frame == 0)
+		icon = PROGRESS_DIALOG_ICON(g_list_nth_data(
+		    pd->end_icons_list, 0
+		));
+	    else if(frame == (nframes - 1))
+		icon = PROGRESS_DIALOG_ICON(g_list_nth_data(
+		    pd->end_icons_list, 2
+		));
 	    else
-	    {
-		icon = NULL;
-	    }
+		icon = PROGRESS_DIALOG_ICON(g_list_nth_data(
+		    pd->end_icons_list, 1
+		));
 
-	    /* Found a valid icon structure to draw? */
+	    /* Got the icon? */
 	    if(icon != NULL)
 	    {
 		gint	icon_width = icon->width,
@@ -379,17 +383,16 @@ static gint ProgressDialogAnimationDrawCB(
 	}
 
 
-	/* Draw intermediate icons */
-	if((pd->total_icons > 0) &&
-	   (frame > 0) && (frame < (total_frames - 1))
+	/* Draw the intermediate icons */
+	if((pd->icons_list != NULL) &&
+	   (frame > 0) && (frame < (nframes - 1))
 	)
 	{
 	    gint i, iframe_max;
 	    gfloat iframe_coeff;
-	    icon_struct *icon = NULL;
+	    ProgressDialogIcon *icon = NULL;
 
-
-	    /* Calculate inside frame coeff */
+	    /* Calculate the inside frame coeff */
 	    iframe_max = (gint)((guint16)-1) - (2 * anim_per_frame);
 	    if(iframe_max > 0)
 		iframe_coeff = CLIP(
@@ -399,16 +402,13 @@ static gint ProgressDialogAnimationDrawCB(
 	    else
 		iframe_coeff = 0.0f;
 
-	    /* Calculate icon index based on inside frame coeff */
-	    i = (gint)(iframe_coeff * pd->total_icons);
+	    /* Calculate the icon index based on the inside frame coeff */
+	    i = (gint)(iframe_coeff * nicons);
 
-	    /* Check which icon structure to draw based on frame index */
-	    if((i >= 0) && (i < pd->total_icons))
-		icon = pd->icon[i];
-	    else
-		icon = NULL;
-
-	    /* Found a valid icon structure to draw? */
+	    /* Get the icon based on the frame index */
+	    icon = PROGRESS_DIALOG_ICON(g_list_nth_data(
+		pd->icons_list, i
+	    ));
 	    if(icon != NULL)
 	    {
 		gint	y_border = 0,
@@ -471,13 +471,13 @@ static gint ProgressDialogAnimationDrawCB(
 
 	/* Put buffer to window as needed */
 	if(drawable != window)
-	gdk_window_copy_area(
-	    window, gc,
-	    0, 0,
-	    drawable,
-	    0, 0,
-	    width, height
-	);
+	    gdk_window_copy_area(
+		window, gc,
+		0, 0,
+		drawable,
+		0, 0,
+		width, height
+	    );
 
 	return(TRUE);
 }
@@ -489,7 +489,7 @@ static gint ProgressDialogAnimationDrawCB(
 static gulong ProgressDialogCurrentTime(void)
 {
 #if defined(_WIN32)
-	SYSTEMTIME t;   /* Current time of day structure */
+	SYSTEMTIME t;		/* Current time of day structure */
 
 	GetSystemTime(&t);
 	return(
@@ -502,9 +502,12 @@ static gulong ProgressDialogCurrentTime(void)
 	struct timeval tv[1];
 
 	if(gettimeofday(tv, NULL) < 0)
-	    return(-1);
+	    return(0l);
 
-	return(((tv->tv_sec % 86400) * 1000) + (tv->tv_usec / 1000));
+	return(
+	    (gulong)((tv->tv_sec % 86400) * 1000) +
+	    (gulong)(tv->tv_usec / 1000)
+	);
 #endif
 }
 
@@ -516,7 +519,7 @@ static gulong ProgressDialogCurrentTime(void)
  *	Inputs assumed valid.
  */
 static void ProgressDialogChangeIcon(
-	progress_dialog_struct *pd, const guint8 **icon_data
+	ProgressDialog *pd, const guint8 **icon_data
 )
 {
 	gint width, height;
@@ -564,17 +567,16 @@ static void ProgressDialogChangeIcon(
 }
 
 /*
- *	Allocates and returns a new icon structure, loading the icon
- *	data from icon_data.
+ *	Creates a new Icon.
  */
-static icon_struct *ProgressDialogIconNew(
-	progress_dialog_struct *pd, const guint8 **icon_data
+static ProgressDialogIcon *ProgressDialogIconNew(
+	ProgressDialog *pd, const guint8 **icon_data
 )
 {
 	gint width, height;
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
-	icon_struct *icon;
+	ProgressDialogIcon *icon;
 
 	if((pd == NULL) || (icon_data == NULL))
 	    return(NULL);
@@ -586,18 +588,20 @@ static icon_struct *ProgressDialogIconNew(
 	    return(NULL);
 
 	/* Create a new animated icon */
-	icon = ICON(g_malloc0(sizeof(icon_struct)));
+	icon = PROGRESS_DIALOG_ICON(g_malloc0(
+	    sizeof(ProgressDialogIcon)
+	));
 	if(icon == NULL)
 	{
-	    GDK_PIXMAP_UNREF(pixmap)
-	    GDK_BITMAP_UNREF(mask)
+	    GDK_PIXMAP_UNREF(pixmap);
+	    GDK_BITMAP_UNREF(mask);
 	    return(NULL);
 	}
 
 	icon->pixmap = pixmap;
 	icon->mask = mask;
 
-	/* Get size */
+	/* Get the size */
 	gdk_window_get_size(pixmap, &width, &height);
 	icon->width = width;
 	icon->height = height;
@@ -606,51 +610,58 @@ static icon_struct *ProgressDialogIconNew(
 }
 
 /*
- *	Deletes the animation icon structure and all its resources.
+ *	Deletes the Icon.
  */
-static void ProgressDialogIconDelete(icon_struct *icon)
+static void ProgressDialogIconDelete(ProgressDialogIcon *icon)
 {
 	if(icon == NULL)
 	    return;
 
-	GDK_PIXMAP_UNREF(icon->pixmap)
-	GDK_BITMAP_UNREF(icon->mask)
+	GDK_PIXMAP_UNREF(icon->pixmap);
+	GDK_BITMAP_UNREF(icon->mask);
 	g_free(icon);
 }
 
 /*
- *	Deletes all animation icons on the given progress dialog.
+ *	Deletes all the icons on the dialog.
  */
-static void ProgressDialogIconDeleteAll(
-	progress_dialog_struct *pd
-)
+static void ProgressDialogIconDeleteAll(ProgressDialog *pd)
 {
-	gint i;
-
-
 	if(pd == NULL)
 	    return;
 
-	/* Delete all animation start icons */
-	for(i = 0; i < pd->total_start_icons; i++)
-	    ProgressDialogIconDelete(pd->start_icon[i]);
-	g_free(pd->start_icon);
-	pd->start_icon = NULL;
-	pd->total_start_icons = 0;
+	if(pd->start_icons_list != NULL)
+	{
+	    g_list_foreach(
+		pd->start_icons_list,
+		(GFunc)ProgressDialogIconDelete,
+		NULL
+	    );
+	    g_list_free(pd->start_icons_list);
+	    pd->start_icons_list = NULL;
+	}
 
-	/* Delete all animation intermediate icons */
-	for(i = 0; i < pd->total_icons; i++)
-	    ProgressDialogIconDelete(pd->icon[i]);
-	g_free(pd->icon);
-	pd->icon = NULL;
-	pd->total_icons = 0;
+	if(pd->end_icons_list != NULL)
+	{
+	    g_list_foreach(
+		pd->end_icons_list,
+		(GFunc)ProgressDialogIconDelete,
+		NULL
+	    );
+	    g_list_free(pd->end_icons_list);
+	    pd->end_icons_list = NULL;
+	}
 
-	/* Delete all animation end icons */
-	for(i = 0; i < pd->total_end_icons; i++)
-	    ProgressDialogIconDelete(pd->end_icon[i]);
-	g_free(pd->end_icon);
-	pd->end_icon = NULL;
-	pd->total_end_icons = 0;
+	if(pd->icons_list != NULL)
+	{
+	    g_list_foreach(
+		pd->icons_list,
+		(GFunc)ProgressDialogIconDelete,
+		NULL
+	    );
+	    g_list_free(pd->icons_list);
+	    pd->icons_list = NULL;
+	}
 }
 
 /*
@@ -667,14 +678,14 @@ gint ProgressDialogInit(void)
 	GtkWidget *w, *parent, *parent2, *parent3;
 	GtkAdjustment *adj;
 	GtkAccelGroup *accelgrp;
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 
 
 	/* Reset globals */
 /* None */
 
 	/* Reset values */
-	memset(pd, 0x00, sizeof(progress_dialog_struct));
+	memset(pd, 0x00, sizeof(ProgressDialog));
 
 	pd->initialized = TRUE;
 	pd->map_state = FALSE;
@@ -695,7 +706,7 @@ gint ProgressDialogInit(void)
 	    GTK_WINDOW(w), "dialog", PROG_NAME
 	);
 #endif
-	gtk_widget_realize(w);                          
+	gtk_widget_realize(w);
 	window = w->window;
 	if(window != NULL)
 	{
@@ -891,7 +902,7 @@ gint ProgressDialogInit(void)
 void ProgressDialogSetStyle(GtkRcStyle *rc_style)
 {
 	GtkWidget *w;
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 
 	if(!pd->initialized)
 	    return;
@@ -919,7 +930,7 @@ void ProgressDialogSetStyle(GtkRcStyle *rc_style)
  */
 void ProgressDialogSetTransientFor(GtkWidget *w)
 {
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 
 	if(!pd->initialized)
 	    return;
@@ -961,7 +972,7 @@ void ProgressDialogSetTransientFor(GtkWidget *w)
 void ProgressDialogSetWMIconData(const guint8 **icon_data)
 {
 	GtkWidget *w;
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 
 
 	if(!pd->initialized)
@@ -980,7 +991,7 @@ void ProgressDialogSetWMIconData(const guint8 **icon_data)
  */
 gboolean ProgressDialogIsQuery(void)
 {
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 
 	if(!pd->initialized)
 	    return(FALSE);
@@ -993,7 +1004,7 @@ gboolean ProgressDialogIsQuery(void)
  */
 void ProgressDialogBreakQuery(gboolean allow_gtk_iteration)
 {
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 
 
 	if(allow_gtk_iteration)
@@ -1016,7 +1027,7 @@ void ProgressDialogBreakQuery(gboolean allow_gtk_iteration)
  */
 gint ProgressDialogStopCount(void)
 {
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 		    
 	if(!pd->initialized)
 	    return(0);
@@ -1045,7 +1056,7 @@ void ProgressDialogMap(
 	const gchar *stop_btn_label
 )
 {
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 	GtkWidget *w;
 
 
@@ -1132,7 +1143,7 @@ void ProgressDialogMapAnimation(
 )
 {
 	gint i;
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 	GtkWidget *w;
 
 
@@ -1179,56 +1190,46 @@ void ProgressDialogMapAnimation(
 
 	/* Begin setting new animation icons */
 
-	/* Deallocate all existing animation icons (if any) */
+	/* Delete all the existing animation icons */
 	ProgressDialogIconDeleteAll(pd);
 
 	/* Start icons */
-	pd->total_start_icons = total_start_icon_datas;
-	if(pd->total_start_icons > 0)
+	if(total_start_icon_datas > 0)
 	{
-	    pd->start_icon = (icon_struct **)g_realloc(
-		pd->start_icon,
-		pd->total_start_icons * sizeof(icon_struct *)
-	    );
-	    if(pd->start_icon == NULL)
-		pd->total_start_icons = 0;
-	    for(i = 0; i < pd->total_start_icons; i++)
-		pd->start_icon[i] = ProgressDialogIconNew(
-		    pd, (const guint8 **)start_icon_data[i]
-		);
-	}
-	/* Icons */
-	pd->total_icons = total_icon_datas;
-	if(pd->total_icons > 0)
-	{
-	    pd->icon = (icon_struct **)g_realloc(
-		pd->icon,
-		pd->total_icons * sizeof(icon_struct *)
-	    );
-	    if(pd->icon == NULL)
-		pd->total_icons = 0;
-	    for(i = 0; i < pd->total_icons; i++)
-		pd->icon[i] = ProgressDialogIconNew(
-		    pd, (const guint8 **)icon_data[i]
-		);
-	}
-	/* End icons */
-	pd->total_end_icons = total_end_icon_datas;
-	if(pd->total_end_icons > 0)
-	{
-	    pd->end_icon = (icon_struct **)g_realloc(
-		pd->end_icon,
-		pd->total_end_icons * sizeof(icon_struct *)
-	    );
-	    if(pd->end_icon == NULL)
-		pd->total_end_icons = 0;
-	    for(i = 0; i < pd->total_end_icons; i++)
-		pd->end_icon[i] = ProgressDialogIconNew(
-		    pd, (const guint8 **)end_icon_data[i]
+	    for(i = 0; i < total_start_icon_datas; i++)
+		pd->start_icons_list = g_list_append(
+		    pd->start_icons_list,
+		    ProgressDialogIconNew(
+			pd, (const guint8 **)start_icon_data[i]
+		    )
 		);
 	}
 
-	/* Reset animation values */
+	/* Icons */
+	if(total_icon_datas > 0)
+	{
+	    for(i = 0; i < total_icon_datas; i++)
+		pd->icons_list = g_list_append(
+		    pd->icons_list,
+		    ProgressDialogIconNew(
+			pd, (const guint8 **)icon_data[i]
+		    )
+		);
+	}
+
+	/* End icons */
+	if(total_end_icon_datas > 0)
+	{
+	    for(i = 0; i < total_end_icon_datas; i++)
+		pd->end_icons_list = g_list_append(
+		    pd->end_icons_list,
+		    ProgressDialogIconNew(
+			pd, (const guint8 **)end_icon_data[i]
+		    )
+		);
+	}
+
+	/* Reset the animation values */
 	pd->animation_time_last = ProgressDialogCurrentTime();
 	pd->animation_interval = animation_interval;
 	pd->animation_position = 0;
@@ -1246,8 +1247,7 @@ void ProgressDialogMapAnimation(
 	/* Map progress dialog (as needed) */
 	if(!pd->map_state)
 	{
-	    w = pd->toplevel;
-	    gtk_widget_show_raise(w);
+	    gtk_widget_show_raise(pd->toplevel);
 	    pd->map_state = TRUE;
 	}
 }
@@ -1268,18 +1268,19 @@ void ProgressDialogUpdate(
 	const gchar *label,
 	const guint8 **icon_data,
 	const gchar *stop_btn_label,
-	gdouble position,               /* 0.0 to 1.0 */
-	guint nblocks,			/* 0 for continuous */
-	gboolean allow_gtk_iteration
+	const gfloat position,		/* 0.0 to 1.0 */
+	const guint nblocks,		/* 0 for continuous */
+	const gboolean allow_gtk_iteration
 )
 {
-	progress_dialog_struct *pd = &progress_dialog;
+	gfloat _position = position;
+	ProgressDialog *pd = &progress_dialog;
 	GtkWidget *w;
 
 	if(!pd->initialized || !pd->map_state)
 	    return;
 
-	/* Change title? */
+	/* Change the title? */
 	if(title != NULL)
 	{
 	    w = pd->toplevel;
@@ -1287,19 +1288,19 @@ void ProgressDialogUpdate(
 		gtk_window_set_title(GTK_WINDOW(w), title);
 	}
 
-	/* Change label? */
+	/* Change the label? */
 	if(label != NULL)
 	{
 	    w = pd->label;
-	    if(w != NULL)  
+	    if(w != NULL)
 		gtk_label_set_text(GTK_LABEL(w), label);
 	}
 
-	/* Change icon? */
+	/* Change the icon? */
 	if(icon_data != NULL)
 	    ProgressDialogChangeIcon(pd, icon_data);
 
-	/* Change stop button label? */
+	/* Change the stop button label? */
 	if(stop_btn_label != NULL)
 	{
 	    w = pd->stop_btn_label;
@@ -1307,17 +1308,17 @@ void ProgressDialogUpdate(
 		gtk_label_set_text(GTK_LABEL(w), stop_btn_label);
 	}
 
-	/* Begin updating progress bar position */
+	/* Begin updating the progress bar position */
 	w = pd->progress_bar;
 	if(w != NULL)
 	{
 	    GtkProgress *pr = GTK_PROGRESS(w);
 	    GtkProgressBar *pb = GTK_PROGRESS_BAR(w);
 
-	    if(position > 1.0)
-		position = 1.0;
-	    else if(position < 0.0)
-		position = 0.0;
+	    if(_position > 1.0f)
+		_position = 1.0f;
+	    else if(_position < 0.0f)
+		_position = 0.0f;
 
 	    gtk_progress_set_activity_mode(pr, FALSE);
 /*
@@ -1337,7 +1338,7 @@ void ProgressDialogUpdate(
 		    pb, GTK_PROGRESS_CONTINUOUS
 		);
 	    }
-	    gtk_progress_bar_update(pb, (gfloat)position);
+	    gtk_progress_bar_update(pb, _position);
 	}
 
 	/* Check if animation drawing area widget is mapped */
@@ -1348,14 +1349,13 @@ void ProgressDialogUpdate(
 /* For syncing animation position with progress */
 	    /* Set animation position to match progress position */
 	    pd->animation_position = (guint16)(
-		position * (guint16)-1
+		_position * (guint16)-1
 	    );
 
 	    /* Redraw animation */
 	    ProgressDialogAnimationDrawCB(w, NULL, pd);
 #endif
-
-	    gulong cur_time = ProgressDialogCurrentTime();
+	    const gulong cur_time = ProgressDialogCurrentTime();
 	    gulong dt;
 	    gfloat tc;
 
@@ -1411,10 +1411,10 @@ void ProgressDialogUpdateUnknown(
 	const gchar *label,
 	const guint8 **icon_data,
 	const gchar *stop_btn_label,
-	gboolean allow_gtk_iteration
+	const gboolean allow_gtk_iteration
 )
 {
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 	GtkWidget *w;
   
 
@@ -1525,17 +1525,16 @@ void ProgressDialogUpdateUnknown(
  */
 void ProgressDialogUnmap(void)
 {
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 	GtkWidget *w;
 
-
 	if(!pd->initialized)
 	    return;
 
-	/* Delete all animation icons (if any) */
+	/* Delete all animation icons */
 	ProgressDialogIconDeleteAll(pd);
 
-/* Do not check current map state */
+/* Do not check the current map state */
 
 	w = pd->toplevel;
 	if(w != NULL)
@@ -1551,37 +1550,30 @@ void ProgressDialogUnmap(void)
  */
 void ProgressDialogShutdown(void)
 {
-	progress_dialog_struct *pd = &progress_dialog;
+	ProgressDialog *pd = &progress_dialog;
 
 	if(pd->initialized)
 	{
+	    gtk_widget_hide(pd->toplevel);
+
 	    /* Unset transient for widget as needed */
 	    if(pd->transient_for != NULL)
 		ProgressDialogSetTransientFor(NULL);
 
-	    /* Delete all animation icons */
+	    /* Delete all the animation icons */
 	    ProgressDialogIconDeleteAll(pd);
 
-	    /* Delete animation resources */
-	    GTK_WIDGET_DESTROY(pd->animation_da)
-	    pd->animation_da = NULL;
+	    /* Delete all the animation resources */
+	    GTK_WIDGET_DESTROY(pd->animation_da);
 
-	    GDK_PIXMAP_UNREF(pd->animation_buffer)
-	    pd->animation_buffer = NULL;
+	    GDK_PIXMAP_UNREF(pd->animation_buffer);
+	    GDK_GC_UNREF(pd->animation_gc);
 
-	    GDK_GC_UNREF(pd->animation_gc)
-	    pd->animation_gc = NULL;
+	    GTK_WIDGET_DESTROY(pd->toplevel);
 
-	    /* Destroy widgets */
-	    GTK_WIDGET_DESTROY(pd->icon_pm)
-	    pd->icon_pm = NULL;
-	    GTK_WIDGET_DESTROY(pd->toplevel)
-	    pd->toplevel = NULL;
-
-	    GTK_ACCEL_GROUP_UNREF(pd->accelgrp)
-	    pd->accelgrp = NULL;
+	    GTK_ACCEL_GROUP_UNREF(pd->accelgrp);
 	}
 
 	/* Clear progress dialog structure */
-	memset(pd, 0x00, sizeof(progress_dialog_struct));
+	memset(pd, 0x00, sizeof(ProgressDialog));
 }
