@@ -32,15 +32,21 @@
 #include "images/icon_recover_20x20.xpm"
 #include "images/icon_purge_20x20.xpm"
 #include "images/icon_purge_all_20x20.xpm"
+#include "images/icon_rename_20x20.xpm"
+#include "images/icon_chmod_20x20.xpm"
+#include "images/icon_owned_20x20.xpm"
+#include "images/icon_time_stamp_20x20.xpm"
 #include "images/icon_select_all_20x20.xpm"
 #include "images/icon_unselect_all_20x20.xpm"
 #include "images/icon_invert_selection_20x20.xpm"
+#include "images/icon_properties2_20x20.xpm"
 #include "images/icon_reload_20x20.xpm"
 #include "images/icon_mimetypes_20x20.xpm"
 #include "images/icon_search_20x20.xpm"
 #include "images/icon_tool_bar_20x20.xpm"
 #include "images/icon_status_bar_20x20.xpm"
 #include "images/icon_wildcards_20x20.xpm"
+#include "images/icon_resize_column_20x20.xpm"
 #include "images/icon_options2_20x20.xpm"
 #include "images/icon_customize_20x20.xpm"
 #include "images/icon_insecure_20x20.xpm"
@@ -60,12 +66,19 @@
 
 /* Utilities */
 edv_recbin_opid_struct *EDVRecBinMatchOPID(
-	edv_recbin_struct *recbin, edv_recbin_op op
+	edv_recbin_struct *recbin,
+	const edv_recbin_op op
 );
 
 /* Title */
 void EDVRecBinSetTitle(edv_recbin_struct *recbin);
 
+/* Get selected object & paths */
+GList *EDVRecBinGetSelectedObjectsList(
+	edv_recbin_struct *recbin,
+	const gboolean copy
+);
+
 /* Regenerate Style, Menus, and Tool Bar */
 void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin);
 void EDVRecBinToolBarRegenerate(edv_recbin_struct *recbin);
@@ -83,15 +96,12 @@ cfg_accelkey_list_struct *EDVRecBinAccelkeysListNewDefault(void);
 
 /* Recycle Bin */
 static void EDVRecBinCreateMenuBar(
-	edv_recbin_struct *recbin, GtkWidget *parent
+	edv_recbin_struct *recbin,
+	GtkWidget *parent
 );
 edv_recbin_struct *EDVRecBinNew(edv_core_struct *core);
 void EDVRecBinSyncData(edv_recbin_struct *recbin);
 void EDVRecBinUpdateMenus(edv_recbin_struct *recbin);
-void EDVRecBinUpdateContentsHeadings(
-	edv_recbin_struct *recbin,
-	const gint *contents_heading, gint total_contents_headings
-);
 void EDVRecBinSetBusy(edv_recbin_struct *recbin, gboolean busy);
 gboolean EDVRecBinIsMapped(edv_recbin_struct *recbin);
 void EDVRecBinMap(edv_recbin_struct *recbin);
@@ -192,6 +202,52 @@ void EDVRecBinSetTitle(edv_recbin_struct *recbin)
 }
 
 
+/*
+ *	Gets a list of the selected recycled objects.
+ *
+ *	If copy is TRUE then each object in the returned list will
+ *	be a copy of the original object.
+ *
+ *	Returns a GList of edv_recycled_object_struct * objects. If
+ *	copy was TRUE then the calling function must delete each
+ *	object in the list and the list itself, otherwise the
+ *	calling function need only delete the returned list.
+ */
+GList *EDVRecBinGetSelectedObjectsList(
+	edv_recbin_struct *recbin, const gboolean copy
+)
+{
+	gint row;
+	GList *glist, *objs_list;
+	GtkCList *clist;
+	edv_recycled_object_struct *obj;
+
+	if(recbin == NULL)
+	    return(NULL);
+
+	clist = GTK_CLIST(recbin->contents_clist);
+
+	objs_list = NULL;
+	for(glist = clist->selection;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
+	{
+	    row = (gint)glist->data;
+	    obj = EDV_RECYCLED_OBJECT(gtk_clist_get_row_data(clist, row));
+	    if(obj == NULL)
+		continue;
+
+	    objs_list = g_list_append(
+		objs_list,
+		(copy) ? EDVRecycledObjectCopy(obj) : obj
+	    );
+	}
+
+	return(objs_list);
+}
+
+
 /*
  *	Resets the Recycle Bin's accelkeys displayed on the widgets.
  */
@@ -283,6 +339,22 @@ void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin)
 	    recbin->edit_purge_all_mi,
 	    EDV_RECBIN_OP_PURGE_ALL
 	);
+	UPDATE_ACCELKEY(
+	    recbin->rename_mi,
+	    EDV_RECBIN_OP_RENAME
+	);
+	UPDATE_ACCELKEY(
+	    recbin->chmod_mi,
+	    EDV_RECBIN_OP_CHMOD
+	);
+	UPDATE_ACCELKEY(
+	    recbin->chown_mi,
+	    EDV_RECBIN_OP_CHOWN
+	);
+	UPDATE_ACCELKEY(
+	    recbin->chtime_mi,
+	    EDV_RECBIN_OP_CHTIME
+	);
 	UPDATE_ACCELKEY(
 	    recbin->select_all_mi,
 	    EDV_RECBIN_OP_SELECT_ALL
@@ -299,6 +371,10 @@ void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin)
 	    recbin->find_mi,
 	    EDV_RECBIN_OP_FIND
 	);
+	UPDATE_ACCELKEY(
+	    recbin->properties_mi,
+	    EDV_RECBIN_OP_PROPERTIES
+	);
 
 	UPDATE_ACCELKEY(
 	    recbin->refresh_mi,
@@ -324,6 +400,10 @@ void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin)
 	    recbin->contents_list_filter_mi,
 	    EDV_RECBIN_OP_CONTENTS_LIST_FILTER
 	);
+	UPDATE_ACCELKEY(
+	    recbin->contents_list_auto_resize_columns_micheck,
+	    EDV_RECBIN_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS
+	);
 	UPDATE_ACCELKEY(
 	    recbin->mime_types_mi,
 	    EDV_RECBIN_OP_MIME_TYPES
@@ -397,6 +477,26 @@ void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin)
 	    recbin->contents_clist_purge_all_mi,
 	    EDV_RECBIN_OP_PURGE_ALL
 	);
+	UPDATE_ACCELKEY(
+	    recbin->contents_clist_rename_mi,
+	    EDV_RECBIN_OP_RENAME
+	);
+	UPDATE_ACCELKEY(
+	    recbin->contents_clist_chmod_mi,
+	    EDV_RECBIN_OP_CHMOD
+	);
+	UPDATE_ACCELKEY(
+	    recbin->contents_clist_chown_mi,
+	    EDV_RECBIN_OP_CHOWN
+	);
+	UPDATE_ACCELKEY(
+	    recbin->contents_clist_chtime_mi,
+	    EDV_RECBIN_OP_CHTIME
+	);
+	UPDATE_ACCELKEY(
+	    recbin->contents_clist_properties_mi,
+	    EDV_RECBIN_OP_PROPERTIES
+	);
 
 #undef UPDATE_ACCELKEY
 }
@@ -505,7 +605,7 @@ void EDVRecBinContentsMenuRegenerate(edv_recbin_struct *recbin)
 	if(recbin == NULL)
 	    return;
 
-	/* Recreate menu */
+	/* Recreate the menu */
 	GTK_WIDGET_DESTROY(recbin->contents_clist_menu);
 	recbin->contents_clist_menu = menu = GUIMenuCreate();
 
@@ -552,6 +652,30 @@ void EDVRecBinContentsMenuRegenerate(edv_recbin_struct *recbin)
 	DO_ADD_MENU_ITEM_LABEL
 	recbin->contents_clist_purge_all_mi = w;
 
+	DO_ADD_MENU_SEP
+
+	op = EDV_RECBIN_OP_RENAME;
+	DO_ADD_MENU_ITEM_LABEL
+	recbin->contents_clist_rename_mi = w;
+
+	op = EDV_RECBIN_OP_CHMOD;
+	DO_ADD_MENU_ITEM_LABEL
+	recbin->contents_clist_chmod_mi = w;
+
+	op = EDV_RECBIN_OP_CHOWN;
+	DO_ADD_MENU_ITEM_LABEL
+	recbin->contents_clist_chown_mi = w;
+
+	op = EDV_RECBIN_OP_CHTIME;
+	DO_ADD_MENU_ITEM_LABEL
+	recbin->contents_clist_chtime_mi = w;
+
+	DO_ADD_MENU_SEP
+
+	op = EDV_RECBIN_OP_PROPERTIES;
+	DO_ADD_MENU_ITEM_LABEL
+	recbin->contents_clist_properties_mi = w;
+
 #undef DO_ADD_MENU_ITEM_LABEL
 #undef DO_ADD_MENU_SEP
 }
@@ -1014,6 +1138,123 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	DO_APPEND_OPID
 
 
+	op = EDV_RECBIN_OP_RENAME;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_rename_20x20_xpm;
+	menu_icon_data = button_icon_data;
+#if defined(PROG_LANGUAGE_SPANISH)
+	button_name = "Renombrar";
+	menu_name = "Renombrar";
+	tooltip = "Renombrar archivo escogido";
+#elif defined(PROG_LANGUAGE_FRENCH)
+	button_name = "Renommer";
+	menu_name = "Renommer";
+	tooltip = "Renomme l'objet choisi";
+#elif defined(PROG_LANGUAGE_POLISH)
+	button_name = "Zmie nazw";
+	menu_name = "Zmie nazw";
+	tooltip = "Zmie nazw zaznaczonego (zaznaczonych) obiektu (obiektw)";
+#else
+	button_name = "Rename";
+	menu_name = "Rename";
+	tooltip = "Rename the selected object";
+#endif
+	accel_key = GDK_F2;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
+	op = EDV_RECBIN_OP_CHMOD;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_chmod_20x20_xpm;
+	menu_icon_data = button_icon_data;
+#if defined(PROG_LANGUAGE_SPANISH)
+	button_name = "ChMod";
+	menu_name = "Cambie permisos...";
+	tooltip = "El Cambio escogi los permisos de objetos";
+#elif defined(PROG_LANGUAGE_FRENCH)
+	button_name = "ChMod";
+	menu_name = "Changer Le Mode...";
+	tooltip = "Le Changement a choisi des permissions des objets";
+#elif defined(PROG_LANGUAGE_POLISH)
+	button_name = "ChMod";
+	menu_name = "Zmiana uprawnie...";
+	tooltip = "Zmie uprawnienia dostpu do zaznaczonego (zaznaczonych) obiektu (obiektw)";
+#else
+	button_name = "ChMod";
+	menu_name = "Change Permissions...";
+	tooltip = "Change the permissions of the selected object(s)";
+#endif
+	accel_key = GDK_F9;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
+	op = EDV_RECBIN_OP_CHOWN;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_owned_20x20_xpm;
+	menu_icon_data = button_icon_data;
+#if defined(PROG_LANGUAGE_SPANISH)
+	button_name = "ChOwn";
+	menu_name = "Change Ownership...";
+	tooltip = "Chown escogido(s)";
+#elif defined(PROG_LANGUAGE_FRENCH)
+	button_name = "ChOwn";
+	menu_name = "Change Ownership...";
+	tooltip = "Chown a choisi l'objet(s)";
+#elif defined(PROG_LANGUAGE_POLISH)
+	button_name = "ChOwn";
+	menu_name = "Zmiana waciciela...";
+	tooltip = "Zmie wacicela zaznaczonego (zaznaczonych) obiektu (obiektw)";
+#else
+	button_name = "ChOwn";
+	menu_name = "Change Ownership...";
+	tooltip = "Change the ownership of the selected object(s)";
+#endif
+	accel_key = GDK_F10;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
+	op = EDV_RECBIN_OP_CHTIME;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_time_stamp_20x20_xpm;
+	menu_icon_data = button_icon_data;
+	button_name = "ChTime";
+	menu_name = "Change Time Stamps...";
+	tooltip = "Change the time stamps of the selected object(s)";
+	accel_key = GDK_F11;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
+	op = EDV_RECBIN_OP_PROPERTIES;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_properties2_20x20_xpm;
+	menu_icon_data = button_icon_data;
+#if defined(PROG_LANGUAGE_SPANISH)
+	button_name = "Props";
+	menu_name = "Las Propiedades";
+	tooltip = "Modifican escogi las propiedades de objeto";
+#elif defined(PROG_LANGUAGE_FRENCH)
+	button_name = "Props";
+	menu_name = "Les Proprits";
+	tooltip = "Modifier a choisi les proprits de l'objet";
+#elif defined(PROG_LANGUAGE_POLISH)
+	button_name = "Waciwoci";
+	menu_name = "Waciwoci...";
+	tooltip = "Modyfikuj waciwoci zaznaczonego obiektu";
+#else
+	button_name = "Properties";
+	menu_name = "Properties...";
+	tooltip = "View the selected object's properties";
+#endif
+	accel_key = GDK_Return;
+	accel_mods = GDK_CONTROL_MASK;
+	DO_APPEND_OPID
+
+
 	op = EDV_RECBIN_OP_SELECT_ALL;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
 	flags = 0;
@@ -1234,6 +1475,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	accel_mods = 0;
 	DO_APPEND_OPID
 
+
 	op = EDV_RECBIN_OP_CONTENTS_LIST_FILTER;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
 	flags = 0;
@@ -1246,6 +1488,18 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	accel_mods = 0;
 	DO_APPEND_OPID
 
+	op = EDV_RECBIN_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS;
+	tb_item_type = TOOLBAR_ITEM_TOGGLE_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_resize_column_20x20_xpm;
+	menu_icon_data = NULL;
+	button_name = "ReSzCol";
+	menu_name = "Auto Resize Columns";
+	tooltip = "Automatically resize the columns each time the list is updated";
+	accel_key = 0;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
 
 	op = EDV_RECBIN_OP_MIME_TYPES;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
@@ -1618,7 +1872,8 @@ cfg_accelkey_list_struct *EDVRecBinAccelkeysListNewDefault(void)
  *	This function should be called by EDVRecBinNew().
  */
 static void EDVRecBinCreateMenuBar(
-	edv_recbin_struct *recbin, GtkWidget *parent
+	edv_recbin_struct *recbin,
+	GtkWidget *parent
 )
 {
 	guint8 **icon_data = NULL;
@@ -1772,6 +2027,24 @@ static void EDVRecBinCreateMenuBar(
 
 	    DO_ADD_MENU_SEP
 
+	    op = EDV_RECBIN_OP_RENAME;
+	    DO_ADD_MENU_ITEM_LABEL
+	    recbin->rename_mi = w;
+
+	    op = EDV_RECBIN_OP_CHMOD;
+	    DO_ADD_MENU_ITEM_LABEL
+	    recbin->chmod_mi = w;
+
+	    op = EDV_RECBIN_OP_CHOWN;
+	    DO_ADD_MENU_ITEM_LABEL
+	    recbin->chown_mi = w;
+
+	    op = EDV_RECBIN_OP_CHTIME;
+	    DO_ADD_MENU_ITEM_LABEL
+	    recbin->chtime_mi = w;
+
+	    DO_ADD_MENU_SEP
+
 	    op = EDV_RECBIN_OP_SELECT_ALL;
 	    DO_ADD_MENU_ITEM_LABEL
 	    recbin->select_all_mi = w;
@@ -1789,6 +2062,12 @@ static void EDVRecBinCreateMenuBar(
 	    op = EDV_RECBIN_OP_FIND;
 	    DO_ADD_MENU_ITEM_LABEL
 	    recbin->find_mi = w;
+
+	    DO_ADD_MENU_SEP
+
+	    op = EDV_RECBIN_OP_PROPERTIES;
+	    DO_ADD_MENU_ITEM_LABEL
+	    recbin->properties_mi = w;
 	}
 	GUIMenuAddToMenuBar(
 	    menu_bar, menu,
@@ -1841,6 +2120,10 @@ static void EDVRecBinCreateMenuBar(
 
 	    DO_ADD_MENU_SEP
 
+	    op = EDV_RECBIN_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS;
+	    DO_ADD_MENU_ITEM_CHECK
+	    recbin->contents_list_auto_resize_columns_micheck = w;
+
 	    op = EDV_RECBIN_OP_CONTENTS_LIST_FILTER;
 	    DO_ADD_MENU_ITEM_LABEL
 	    recbin->contents_list_filter_mi = w;
@@ -2157,22 +2440,20 @@ edv_recbin_struct *EDVRecBinNew(edv_core_struct *core)
 	style = gtk_widget_get_style(w);
 	parent = w;
 
-
-	/* Main vbox */
+	/* Main GtkVBox */
 	recbin->main_vbox = w = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(parent), w);
 	gtk_widget_show(w);
 	parent = w;
 
-
-	/* Vbox for tool bars */
+	/* Bars GtkVBox */
 	recbin->bars_vbox = w = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent2 = w;
 
 
-	/* Handle for menu bar */
+	/* GtkHandleBox for the menu bar */
 	recbin->menu_bar_handle = w = gtk_handle_box_new();
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	gtk_signal_connect_after(
@@ -2184,7 +2465,7 @@ edv_recbin_struct *EDVRecBinNew(edv_core_struct *core)
 	    GTK_SIGNAL_FUNC(EDVRecBinHandleChildDetachedCB), recbin
 	);
 	gtk_widget_show(w);
-	/* Create menu bar */
+	/* Create the menu bar */
 	EDVRecBinCreateMenuBar(recbin, w);
 
 
@@ -2201,7 +2482,7 @@ edv_recbin_struct *EDVRecBinNew(edv_core_struct *core)
 	);
 	if(recbin->tool_bar_map_state)
 	    gtk_widget_show(w);
-	/* Build tool bar later */
+	/* Build the tool bar later */
 	recbin->tool_bar = NULL;
 
 
@@ -2223,7 +2504,7 @@ edv_recbin_struct *EDVRecBinNew(edv_core_struct *core)
 	/* Create the Find Bar */
 	recbin->find_bar = EDVFindBarNew(
 	    core, parent2,
-	    EDV_FINDBAR_ROLE_RECYCLED_OBJECT,
+	    EDV_LOCATION_TYPE_RECBIN,
 	    NULL,
 	    EDVRecBinFindBarStartCB,
 	    EDVRecBinFindBarEndCB,
@@ -2235,7 +2516,7 @@ edv_recbin_struct *EDVRecBinNew(edv_core_struct *core)
 	EDVFindBarMap(recbin->find_bar);
 
 
-	/* Scrolled window for contents clist */
+	/* GtkScrolledWindow for the contents list */
 	w = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(
 	    GTK_SCROLLED_WINDOW(w),
@@ -2246,7 +2527,7 @@ edv_recbin_struct *EDVRecBinNew(edv_core_struct *core)
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Contents clist */
+	/* Contents GtkCList */
 	recbin->contents_clist = w = gtk_clist_new(
 	    EDV_RECBIN_CONTENTS_CLIST_COLUMNS_MAX
 	);
@@ -2314,7 +2595,7 @@ edv_recbin_struct *EDVRecBinNew(edv_core_struct *core)
 	    GTK_OBJECT(w), "unselect_row",
 	    GTK_SIGNAL_FUNC(EDVRecBinUnselectRowCB), recbin
 	);
-	/* Set up DND for the contents list */
+	/* Set up the contents list for DND */
 	GUIDNDSetSrc(
 	    w,
 	    dnd_src_types,
@@ -2432,12 +2713,18 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	core = recbin->core;
 	cfg_list = core->cfg_list;
 
-#define DO_SHOW			\
-{ if(w != NULL) gtk_widget_show(w); }
-#define DO_HIDE			\
-{ if(w != NULL) gtk_widget_hide(w); }
-#define DO_SET_CHECK_STATE	\
-{ GUIMenuItemSetCheck(w, state, FALSE); }
+#define MAP_WIDGET(_w_)		{		\
+ if((_w_) != NULL)				\
+  gtk_widget_show(_w_);				\
+}
+#define UNMAP_WIDGET(_w_)	{		\
+ if((_w_) != NULL)				\
+  gtk_widget_hide(_w_);				\
+}
+#define SET_CHECK_STATE(_w_, _state_)	{	\
+ if((_w_) != NULL)				\
+  GUIMenuItemSetCheck((_w_), (_state_), FALSE);	\
+}
 
 	/* Get global write protect state */
 	write_protect = EDV_GET_B(EDV_CFG_PARM_WRITE_PROTECT);
@@ -2502,8 +2789,8 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	recbin->last_recbin_items = core->last_recbin_items;
 
 
-        /* Update the find bar */
-        EDVFindBarUpdateMenus(recbin->find_bar);
+	/* Update the find bar */
+	EDVFindBarUpdateMenus(recbin->find_bar);
 
 
 	/* Begin updating menu items and tool bar items */
@@ -2511,18 +2798,17 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	/* File */
 	sensitive = (selected_obj_row > -1) ? TRUE : FALSE;
 	/* Recover */
-	GTK_WIDGET_SET_SENSITIVE(recbin->recover_mi, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(recbin->edit_recover_mi, sensitive)
+	GTK_WIDGET_SET_SENSITIVE(recbin->recover_mi, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(recbin->edit_recover_mi, sensitive);
 	ToolBarItemSetSensitiveID(
 	    tb, EDV_RECBIN_OP_RECOVER, sensitive
 	);
 	/* Purge */
-	GTK_WIDGET_SET_SENSITIVE(recbin->purge_mi, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(recbin->edit_purge_mi, sensitive)
+	GTK_WIDGET_SET_SENSITIVE(recbin->purge_mi, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(recbin->edit_purge_mi, sensitive);
 	ToolBarItemSetSensitiveID(
 	    tb, EDV_RECBIN_OP_PURGE, sensitive
 	);
-
 	/* Sync Recycle bin */
 	if(recbin_icon_data != NULL)
 	{
@@ -2535,30 +2821,65 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	    );
 	}
 
+	/* Edit */
+	sensitive = (selected_obj_row > -1) ? TRUE : FALSE;
+	/* Rename */
+	GTK_WIDGET_SET_SENSITIVE(recbin->rename_mi, sensitive);
+	ToolBarItemSetSensitiveID(
+	    tb, EDV_RECBIN_OP_RENAME, sensitive
+	);
+	/* Change Mode */
+	GTK_WIDGET_SET_SENSITIVE(recbin->chmod_mi, sensitive);
+	ToolBarItemSetSensitiveID(
+	    tb, EDV_RECBIN_OP_CHMOD, sensitive
+	);
+	/* Change Ownership */
+	GTK_WIDGET_SET_SENSITIVE(recbin->chown_mi, sensitive);
+	ToolBarItemSetSensitiveID(
+	    tb, EDV_RECBIN_OP_CHOWN, sensitive
+	);
+	/* Change Timestamps */
+	GTK_WIDGET_SET_SENSITIVE(recbin->chtime_mi, sensitive);
+	ToolBarItemSetSensitiveID(
+	    tb, EDV_RECBIN_OP_CHTIME, sensitive
+	);
+	/* Properties */
+	GTK_WIDGET_SET_SENSITIVE(recbin->properties_mi, sensitive);
+	ToolBarItemSetSensitiveID(
+	    tb, EDV_RECBIN_OP_PROPERTIES, sensitive
+	);
 
 	/* View */
 	/* Show Tool Bar */
 	w = recbin->show_tool_bar_micheck;
 	state = EDV_GET_B(EDV_CFG_PARM_RECBIN_SHOW_TOOL_BAR);
-	DO_SET_CHECK_STATE
+	SET_CHECK_STATE(w, state);
 	ToolBarItemSetToggleID(
 	    tb, EDV_RECBIN_OP_SHOW_TOOL_BAR, state
 	);
 	/* Show Find Bar */
 	w = recbin->show_find_bar_micheck;
 	state = EDV_GET_B(EDV_CFG_PARM_RECBIN_SHOW_FIND_BAR);
-	DO_SET_CHECK_STATE
+	SET_CHECK_STATE(w, state);
 	ToolBarItemSetToggleID(
 	    tb, EDV_RECBIN_OP_SHOW_FIND_BAR, state
 	);
 	/* Show Status Bar */
 	w = recbin->show_status_bar_micheck;
 	state = EDV_GET_B(EDV_CFG_PARM_RECBIN_SHOW_STATUS_BAR);
-	DO_SET_CHECK_STATE
+	SET_CHECK_STATE(w, state);
 	ToolBarItemSetToggleID(
 	    tb, EDV_RECBIN_OP_SHOW_STATUS_BAR, state
 	);
 
+	/* Auto Resize Columns */
+	w = recbin->contents_list_auto_resize_columns_micheck;
+	state = EDV_GET_B(EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS);
+	SET_CHECK_STATE(w, state);
+	ToolBarItemSetToggleID(
+	    tb, EDV_RECBIN_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS, state
+	);
+
 
 	/* Settings */
 	if(write_protect_changed)
@@ -2584,7 +2905,7 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	GUIMenuItemSetPixmap(w, recbin_icon_data);
 	state = (delete_method == EDV_DELETE_METHOD_RECYCLE) ?
 	    TRUE : FALSE;
-	DO_SET_CHECK_STATE
+	SET_CHECK_STATE(w, state);
 	ToolBarItemUpdateByID(
 	    tb, EDV_RECBIN_OP_DELETE_METHOD_RECYCLE,
 	    NULL, recbin_icon_data, NULL                              
@@ -2597,7 +2918,7 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	w = recbin->delete_method_purge_micheck;
 	state = (delete_method == EDV_DELETE_METHOD_PURGE) ?
 	    TRUE : FALSE;
-	DO_SET_CHECK_STATE
+	SET_CHECK_STATE(w, state);
 	ToolBarItemSetToggleID(
 	    tb, EDV_RECBIN_OP_DELETE_METHOD_PURGE, state
 	);
@@ -2606,23 +2927,37 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	/* Windows */
 
 
-	/* Update contents clist menu */
+	/* Contents list right-click menu */
 	sensitive = (selected_obj_row > -1) ? TRUE : FALSE;
-	GTK_WIDGET_SET_SENSITIVE(
-	    recbin->contents_clist_purge_mi, sensitive
-	)
 	GTK_WIDGET_SET_SENSITIVE(
 	    recbin->contents_clist_recover_mi, sensitive
-	)
+	);
+	GTK_WIDGET_SET_SENSITIVE(
+	    recbin->contents_clist_purge_mi, sensitive
+	);
+	GTK_WIDGET_SET_SENSITIVE(
+	    recbin->contents_clist_rename_mi, sensitive
+	);
+	GTK_WIDGET_SET_SENSITIVE(
+	    recbin->contents_clist_chmod_mi, sensitive
+	);
+	GTK_WIDGET_SET_SENSITIVE(
+	    recbin->contents_clist_chown_mi, sensitive
+	);
+	GTK_WIDGET_SET_SENSITIVE(
+	    recbin->contents_clist_chtime_mi, sensitive
+	);
+	GTK_WIDGET_SET_SENSITIVE(
+	    recbin->contents_clist_properties_mi, sensitive
+	);
 
 
-
-	/* Update status bar */
+	/* Status Bar */
 	EDVStatusBarUpdate(recbin->status_bar);
 
 
 
-	/* Update toplevel GdkWindow's WM icon */
+	/* Toplevel GdkWindow's WM icon */
 	w = recbin->toplevel;
 	if(((w != NULL) ? (w->window != NULL) : FALSE) &&
 	   (recbin_icon_large_data != NULL)
@@ -2630,9 +2965,9 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	    GUISetWMIcon(w->window, (guint8 **)recbin_icon_large_data);
 
 
-#undef DO_SHOW
-#undef DO_HIDE
-#undef DO_SET_CHECK_STATE
+#undef MAP_WIDGET
+#undef UNMAP_WIDGET
+#undef SET_CHECK_STATE
 
 	recbin->freeze_count--;
 }
@@ -2681,8 +3016,8 @@ void EDVRecBinSetBusy(edv_recbin_struct *recbin, gboolean busy)
  */
 gboolean EDVRecBinIsMapped(edv_recbin_struct *recbin)
 {
-        if(recbin == NULL)
-            return(FALSE);
+	if(recbin == NULL)
+	    return(FALSE);
 
 	return(GTK_WIDGET_MAPPED(recbin->toplevel));
 }
