@@ -15,6 +15,7 @@
 
 typedef struct _edv_recbin_struct	edv_recbin_struct;
 #define EDV_RECBIN(p)			((edv_recbin_struct *)(p))
+
 typedef struct _edv_recbin_opid_struct	edv_recbin_opid_struct;
 #define EDV_RECBIN_OPID(p)		((edv_recbin_opid_struct *)(p))
 
@@ -23,22 +24,20 @@ typedef struct _edv_recbin_opid_struct	edv_recbin_opid_struct;
  *	Recycle Bin Contents List Column Types:
  */
 typedef enum {
-
-	EDV_RECBIN_COLUMN_TYPE_NAME			= 0,
-	EDV_RECBIN_COLUMN_TYPE_SIZE			= 1,
-	EDV_RECBIN_COLUMN_TYPE_TYPE			= 2,
-	EDV_RECBIN_COLUMN_TYPE_PERMISSIONS		= 3,
-	EDV_RECBIN_COLUMN_TYPE_OWNER			= 4,
-	EDV_RECBIN_COLUMN_TYPE_GROUP			= 5,
-	EDV_RECBIN_COLUMN_TYPE_DATE_ACCESS		= 6,
-	EDV_RECBIN_COLUMN_TYPE_DATE_MODIFIED		= 7,
-	EDV_RECBIN_COLUMN_TYPE_DATE_CHANGED		= 8,
-	EDV_RECBIN_COLUMN_TYPE_DATE_DELETED		= 9,
-	EDV_RECBIN_COLUMN_TYPE_LINKED_TO		= 10,
-	EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION	= 11,
-	EDV_RECBIN_COLUMN_TYPE_INDEX			= 12,
+	EDV_RECBIN_COLUMN_TYPE_INDEX			= 0,
+	EDV_RECBIN_COLUMN_TYPE_NAME			= 1,
+	EDV_RECBIN_COLUMN_TYPE_SIZE			= 2,
+	EDV_RECBIN_COLUMN_TYPE_TYPE			= 3,
+	EDV_RECBIN_COLUMN_TYPE_PERMISSIONS		= 4,
+	EDV_RECBIN_COLUMN_TYPE_OWNER			= 5,
+	EDV_RECBIN_COLUMN_TYPE_GROUP			= 6,
+	EDV_RECBIN_COLUMN_TYPE_DATE_ACCESS		= 7,
+	EDV_RECBIN_COLUMN_TYPE_DATE_MODIFIED		= 8,
+	EDV_RECBIN_COLUMN_TYPE_DATE_CHANGED		= 9,
+	EDV_RECBIN_COLUMN_TYPE_DATE_DELETED		= 10,
+	EDV_RECBIN_COLUMN_TYPE_LINKED_TO		= 11,
+	EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION	= 12,
 	EDV_RECBIN_COLUMN_TYPE_CAPACITY_USED		= 13
-
 } edv_recbin_column_type;
 /* Total number of column types */
 #define EDV_RECBIN_CONTENTS_CLIST_COLUMNS_MAX		14
@@ -50,55 +49,62 @@ typedef enum {
 typedef enum {
 
 	EDV_RECBIN_OP_NONE			= 0,
-	EDV_RECBIN_OP_SEPARATOR			= 10,
+	EDV_RECBIN_OP_SEPARATOR			= 100,
 
-	EDV_RECBIN_OP_CLOSE			= 20,
-	EDV_RECBIN_OP_EXIT			= 21,
+	EDV_RECBIN_OP_CLOSE			= 200,
+	EDV_RECBIN_OP_EXIT			= 201,
 
-	EDV_RECBIN_OP_SYNC_DISKS		= 30,
-	EDV_RECBIN_OP_RUN			= 31,
-	EDV_RECBIN_OP_RUN_TERMINAL		= 32,
-	EDV_RECBIN_OP_WRITE_PROTECT		= 35,
-	EDV_RECBIN_OP_DELETE_METHOD_RECYCLE	= 38,
-	EDV_RECBIN_OP_DELETE_METHOD_PURGE	= 39,
+	EDV_RECBIN_OP_SYNC_DISKS		= 301,
+	EDV_RECBIN_OP_HISTORY			= 302,
+	EDV_RECBIN_OP_RUN			= 303,
+	EDV_RECBIN_OP_RUN_TERMINAL		= 304,
+	EDV_RECBIN_OP_WRITE_PROTECT		= 305,
+	EDV_RECBIN_OP_DELETE_METHOD_RECYCLE	= 308,
+	EDV_RECBIN_OP_DELETE_METHOD_PURGE	= 309,
 
-	EDV_RECBIN_OP_SYNC_RECYCLE_BIN		= 40,
+	EDV_RECBIN_OP_SYNC_RECYCLE_BIN		= 350,
 
-	EDV_RECBIN_OP_RECOVER			= 60,
-	EDV_RECBIN_OP_PURGE			= 61,
-	EDV_RECBIN_OP_PURGE_ALL			= 62,
-	EDV_RECBIN_OP_SELECT_ALL		= 70,
-	EDV_RECBIN_OP_UNSELECT_ALL		= 71,
-	EDV_RECBIN_OP_INVERT_SELECTION		= 72,
-	EDV_RECBIN_OP_FIND			= 73,
+	EDV_RECBIN_OP_RECOVER			= 700,
+	EDV_RECBIN_OP_PURGE			= 701,
+	EDV_RECBIN_OP_PURGE_ALL			= 702,
+	EDV_RECBIN_OP_RENAME			= 703,
+	EDV_RECBIN_OP_CHMOD			= 704,
+	EDV_RECBIN_OP_CHOWN			= 705,
+	EDV_RECBIN_OP_CHTIME			= 706,
+	EDV_RECBIN_OP_PROPERTIES		= 707,
 
-	EDV_RECBIN_OP_HISTORY			= 77,
+	EDV_RECBIN_OP_SELECT_ALL		= 800,
+	EDV_RECBIN_OP_UNSELECT_ALL		= 801,
+	EDV_RECBIN_OP_INVERT_SELECTION		= 802,
+	EDV_RECBIN_OP_FIND			= 850,
 
-	EDV_RECBIN_OP_REFRESH			= 80,
-	EDV_RECBIN_OP_REFRESH_ALL		= 81,
-	EDV_RECBIN_OP_SHOW_TOOL_BAR		= 90,
-	EDV_RECBIN_OP_SHOW_FIND_BAR		= 91,
-	EDV_RECBIN_OP_SHOW_STATUS_BAR		= 92,
+	EDV_RECBIN_OP_REFRESH			= 1000,
+	EDV_RECBIN_OP_REFRESH_ALL		= 1001,
 
-	EDV_RECBIN_OP_CONTENTS_LIST_FILTER	= 97,
+	EDV_RECBIN_OP_SHOW_TOOL_BAR		= 1300,
+	EDV_RECBIN_OP_SHOW_FIND_BAR		= 1303,
+	EDV_RECBIN_OP_SHOW_STATUS_BAR		= 1304,
 
-	EDV_RECBIN_OP_MIME_TYPES		= 100,
+	EDV_RECBIN_OP_CONTENTS_LIST_FILTER	= 1400,
+	EDV_RECBIN_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS = 1410,
 
-	EDV_RECBIN_OP_NEW_BROWSER		= 110,
-	EDV_RECBIN_OP_NEW_IMBR			= 111,
-	EDV_RECBIN_OP_NEW_ARCHIVER		= 112,
+	EDV_RECBIN_OP_MIME_TYPES		= 1700,
 
-	EDV_RECBIN_OP_OPTIONS			= 150,
-	EDV_RECBIN_OP_CUSTOMIZE			= 151,
+	EDV_RECBIN_OP_NEW_BROWSER		= 1800,
+	EDV_RECBIN_OP_NEW_IMBR			= 1801,
+	EDV_RECBIN_OP_NEW_ARCHIVER		= 1802,
 
-	EDV_RECBIN_OP_HELP_ABOUT		= 1000,
-	EDV_RECBIN_OP_HELP_CONTENTS		= 1001,
-	EDV_RECBIN_OP_HELP_FILE_BROWSER		= 1002,
-	EDV_RECBIN_OP_HELP_IMAGE_BROWSER	= 1003,
-	EDV_RECBIN_OP_HELP_ARCHIVER		= 1004,
-	EDV_RECBIN_OP_HELP_RECYCLE_BIN		= 1005,
-	EDV_RECBIN_OP_HELP_KEYS_LIST		= 1006,
-	EDV_RECBIN_OP_HELP_COMMON_OPERATIONS	= 1007
+	EDV_RECBIN_OP_OPTIONS			= 2000,
+	EDV_RECBIN_OP_CUSTOMIZE			= 2001,
+
+	EDV_RECBIN_OP_HELP_CONTENTS		= 3000,
+	EDV_RECBIN_OP_HELP_FILE_BROWSER		= 3010,
+	EDV_RECBIN_OP_HELP_IMAGE_BROWSER	= 3011,
+	EDV_RECBIN_OP_HELP_ARCHIVER		= 3012,
+	EDV_RECBIN_OP_HELP_RECYCLE_BIN		= 3030,
+	EDV_RECBIN_OP_HELP_KEYS_LIST		= 3050,
+	EDV_RECBIN_OP_HELP_COMMON_OPERATIONS	= 3053,
+	EDV_RECBIN_OP_HELP_ABOUT		= 3100
 
 } edv_recbin_op;
 
@@ -175,7 +181,7 @@ struct _edv_recbin_struct {
 	toolbar_struct		*tool_bar;
 
 	/* Find Bar */
-	edv_findbar_struct	*find_bar;
+	edv_find_bar_struct	*find_bar;
 
 	/* Menus and Menu Items */
 	GtkWidget	*recover_mi,
@@ -190,10 +196,15 @@ struct _edv_recbin_struct {
 			*edit_recover_mi,
 			*edit_purge_mi,
 			*edit_purge_all_mi,
+			*rename_mi,
+			*chmod_mi,
+			*chown_mi,
+			*chtime_mi,
 			*select_all_mi,
 			*unselect_all_mi,
 			*invert_selection_mi,
 			*find_mi,
+			*properties_mi,
 
 			*refresh_mi,
 			*refresh_all_mi,
@@ -201,6 +212,7 @@ struct _edv_recbin_struct {
 			*show_find_bar_micheck,
 			*show_status_bar_micheck,
 			*contents_list_filter_mi,
+			*contents_list_auto_resize_columns_micheck,
 			*mime_types_mi,
 
 			*write_protect_mi,
@@ -223,7 +235,12 @@ struct _edv_recbin_struct {
 	GtkWidget       *contents_clist_menu,
 			*contents_clist_recover_mi,
 			*contents_clist_purge_mi,
-			*contents_clist_purge_all_mi;
+			*contents_clist_purge_all_mi,
+			*contents_clist_rename_mi,
+			*contents_clist_chmod_mi,
+			*contents_clist_chown_mi,
+			*contents_clist_chtime_mi,
+			*contents_clist_properties_mi;
 
 	gchar		*contents_list_filter;
 
@@ -254,32 +271,40 @@ struct _edv_recbin_struct {
 };
 
 
+/* Utilities */
 extern edv_recbin_opid_struct *EDVRecBinMatchOPID(
-	edv_recbin_struct *recbin, edv_recbin_op op
+	edv_recbin_struct *recbin,
+	const edv_recbin_op op
 );
 
+/* Title */
 extern void EDVRecBinSetTitle(edv_recbin_struct *recbin);
 
+/* Get selected object & paths */
+extern GList *EDVRecBinGetSelectedObjectsList(
+	edv_recbin_struct *recbin, 
+	const gboolean copy
+);
+
+/* Regenerate Style, Menus, and Tool Bar */
 extern void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin);
 extern void EDVRecBinToolBarRegenerate(edv_recbin_struct *recbin);
 extern void EDVRecBinContentsMenuRegenerate(edv_recbin_struct *recbin);
 
+/* Sync Configuration */
 extern void EDVRecBinSyncConfiguration(edv_recbin_struct *recbin);
 
-extern GList *EDVRecBinOPIDListNew(
-	edv_recbin_struct *recbin	/* Can be NULL */
-);
+/* Operation IDs */
+extern GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin);
 extern void EDVRecBinOPIDListDelete(GList *glist);
 
+/* Accel Keys */
 extern cfg_accelkey_list_struct *EDVRecBinAccelkeysListNewDefault(void);
 
+/* Recycle Bin */
 extern edv_recbin_struct *EDVRecBinNew(edv_core_struct *core);
 extern void EDVRecBinSyncData(edv_recbin_struct *recbin);
 extern void EDVRecBinUpdateMenus(edv_recbin_struct *recbin);
-extern void EDVRecBinUpdateContentsHeadings(
-	edv_recbin_struct *recbin,
-	const gint *contents_heading, gint total_contents_headings
-);
 extern void EDVRecBinSetBusy(edv_recbin_struct *recbin, gboolean is_busy);
 extern gboolean EDVRecBinIsMapped(edv_recbin_struct *recbin);
 extern void EDVRecBinMap(edv_recbin_struct *recbin);
