@@ -1,18 +1,13 @@
 #include <stdlib.h>
-#include <ctype.h>
 #include <string.h>
+#include <ctype.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "../include/string.h"
-#include "../include/disk.h"
-
 #include "guiutils.h"
-#include "cdialog.h"
 
-#include "edv_types.h"
 #include "cfg.h"
-#include "edv_obj.h"
+#include "edv_types.h"
 #include "edv_recycled_obj.h"
 #include "edv_status_bar.h"
 #include "recbin.h"
@@ -21,8 +16,8 @@
 #include "recbin_dnd.h"
 #include "recbin_contents_list.h"
 #include "endeavour2.h"
-#include "edv_op.h"
 #include "edv_cb.h"
+#include "edv_op.h"
 #include "edv_utils.h"
 #include "edv_utils_gtk.h"
 #include "edv_list_seek.h"
@@ -33,9 +28,15 @@
 /* GTK+ Signal Callbacks */
 void EDVRecBinContentsItemDestroyCB(gpointer data);
 
+static gint EDVRecBinCListColumnSortIndexCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
+static gint EDVRecBinCListColumnSortSizeCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+);
 static gint EDVRecBinCListColumnSortDateNexus(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2,
-	gint sort_code
+	const gint sort_code
 );
 static gint EDVRecBinCListColumnSortDateAccessCB(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
@@ -95,34 +96,41 @@ gint EDVRecBinMenuItemLeaveCB(
 );
 
 /* Find Bar Callbacks */
-void EDVRecBinFindBarStartCB(edv_findbar_struct *fb, gpointer data);
+void EDVRecBinFindBarStartCB(
+	edv_find_bar_struct *fb,
+	gpointer data
+);
 void EDVRecBinFindBarEndCB(
-	edv_findbar_struct *fb, gint total_matches, gpointer data
+	edv_find_bar_struct *fb,
+	const gint nmatches,
+	gpointer data
 );
 void EDVRecBinFindBarMatchCB(
-	const gchar *path, const struct stat *lstat_buf,
-	const gchar *excerpt, gint line_index,
+	const gchar *path,
+	struct stat *lstat_buf,
+	const gchar *excerpt,
+	const gint line_index,
 	gpointer data
 );
 
 /* Status Bar Callbacks */
 void EDVRecBinStatusMessageCB(const gchar *message, gpointer data);
-void EDVRecBinStatusProgressCB(gfloat progress, gpointer data);
+void EDVRecBinStatusProgressCB(const gfloat progress, gpointer data);
 
 /* Write Protect Changed Callback */
 void EDVRecBinWriteProtectChangedCB(
-	edv_recbin_struct *recbin, gboolean state
+	edv_recbin_struct *recbin, const gboolean state
 );
 
 /* Recycled Object Callbacks */
 void EDVRecBinRecycledObjectAddedNotifyCB(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 );
 void EDVRecBinRecycledObjectModifiedNotifyCB(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 );
 void EDVRecBinRecycledObjectRemovedNotifyCB(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 );
 
 /* Reconfigured Callback */
@@ -131,31 +139,32 @@ void EDVRecBinReconfiguredNotifyCB(edv_recbin_struct *recbin);
 /* MIME Type Callbacks */
 void EDVRecBinMimeTypeAddedCB(
 	edv_recbin_struct *recbin,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 );
 void EDVRecBinMimeTypeModifiedCB(
 	edv_recbin_struct *recbin,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 );
 void EDVRecBinMimeTypeRemovedCB(
-	edv_recbin_struct *recbin, gint mt_num
+	edv_recbin_struct *recbin,
+	const gint mt_num
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
- *	Recycle Bin contents GtkCList item "destroy" signal callback.
+ *	Contents GtkCList item "destroy" signal callback.
  */
 void EDVRecBinContentsItemDestroyCB(gpointer data)
 {
@@ -164,61 +173,100 @@ void EDVRecBinContentsItemDestroyCB(gpointer data)
 
 
 /*
- *	Returns the sort code for the rows sorted by date.
- *
- *	The recycled object structures are obtained from each row and the
- *	dates are compared.
+ *	Contents GtkCList column sort indicies callback.
  */
-static gint EDVRecBinCListColumnSortDateNexus(
-	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2,
-	gint sort_code
+static gint EDVRecBinCListColumnSortIndexCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
 )
 {
-	gint sort_column;
-	const GtkCListRow *row1 = (const GtkCListRow *)ptr1;
-	const GtkCListRow *row2 = (const GtkCListRow *)ptr2;
-	edv_recycled_object_struct *obj1, *obj2;
-
-	if((clist == NULL) || (row1 == NULL) || (row2 == NULL))
-	    return(0);
-
-	sort_column = clist->sort_column;
-	if((sort_column < 0) || (sort_column >= clist->columns))
-	    return(0);
-
-	obj1 = EDV_RECYCLED_OBJECT(row1->data);
-	obj2 = EDV_RECYCLED_OBJECT(row2->data);
+	edv_recycled_object_struct	*obj1 = EDV_RECYCLED_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+					*obj2 = EDV_RECYCLED_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
 	if((obj1 == NULL) || (obj2 == NULL))
 	    return(0);
 
+	if(obj1->index <= obj2->index)
+	    return(obj1->index < obj2->index);
+	else
+	    return(-1);
+}
+
+/*
+ *	Contents GtkCList column sort size callback.
+ */
+static gint EDVRecBinCListColumnSortSizeCB(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
+)
+{
+	edv_recycled_object_struct	*obj1 = EDV_RECYCLED_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+					*obj2 = EDV_RECYCLED_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	if(obj1->size <= obj2->size)
+	    return(obj1->size < obj2->size);
+	else
+	    return(-1);
+}
+
+/*
+ *	Contents GtkCList column sort date nexus.
+ *
+ *	The ptr1 and ptr2 specifies the two GtkCListRow * rows
+ *	that contain the object date data to compare.
+ *
+ *	The sort_code specifies which date value to compare.
+ */
+static gint EDVRecBinCListColumnSortDateNexus(
+	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2,
+	const gint sort_code
+)
+{
+	edv_recycled_object_struct	*obj1 = EDV_RECYCLED_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+					*obj2 = EDV_RECYCLED_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((clist == NULL) || (obj1 == NULL) || (obj2 == NULL))
+	    return(0);
+
+	/* Handle by the sort code */
 	switch(sort_code)
 	{
 	  case 0:       /* Access time */
 	    if(obj1->access_time <= obj2->access_time)
-		    return((gint)(obj1->access_time < obj2->access_time));
-		else
-		    return(-1);
+		return(obj1->access_time < obj2->access_time);
+	    else
+		return(-1);
 	    break;
 
 	  case 1:       /* Modify time */
 	    if(obj1->modify_time <= obj2->modify_time)
-		    return((gint)(obj1->modify_time < obj2->modify_time));
-		else
-		    return(-1);
+		return(obj1->modify_time < obj2->modify_time);
+	    else
+		return(-1);
 	    break;
 
 	  case 2:       /* Change time */
 	    if(obj1->change_time <= obj2->change_time)
-		    return((gint)(obj1->change_time < obj2->change_time));
-		else
-		    return(-1);
+		return(obj1->change_time < obj2->change_time);
+	    else
+		return(-1);
 	    break;
 
 	  case 3:	/* Delete time */
 	    if(obj1->deleted_time <= obj2->deleted_time)
-		    return((gint)(obj1->deleted_time < obj2->deleted_time));
-		else
-		    return(-1);
+		return(obj1->deleted_time < obj2->deleted_time);
+	    else
+		return(-1);
 	    break;
 	}
 
@@ -261,28 +309,31 @@ static gint EDVRecBinCListColumnSortDateDeleteCB(
 	));
 }
 
+/*
+ *	Contents GtkCList column sort capacity used callback.
+ */
 static gint EDVRecBinCListColumnSortCapacityUsedCB(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
 )
 {
-	const GtkCListRow       *row1 = (const GtkCListRow *)ptr1,
-				*row2 = (const GtkCListRow *)ptr2;
-	edv_recycled_object_struct	*o1 = EDV_RECYCLED_OBJECT(row1->data),
-					*o2 = EDV_RECYCLED_OBJECT(row2->data);
-	if((o1 != NULL) && (o2 != NULL))
-	{
-	    if(o1->size <= o2->size)
-		return((gint)(o1->size < o2->size));
-	    else
-		return(-1);
-	}
-	else
+	edv_recycled_object_struct	*obj1 = EDV_RECYCLED_OBJECT(
+		((const GtkCListRow *)ptr1)->data
+	),
+					*obj2 = EDV_RECYCLED_OBJECT(
+		((const GtkCListRow *)ptr2)->data
+	);
+	if((obj1 == NULL) || (obj2 == NULL))
 	    return(0);
+
+	if(obj1->size <= obj2->size)
+	    return(obj1->size < obj2->size);
+	else
+	    return(-1);
 }
 
 
 /*
- *	Recycle Bin toplevel GtkWidget "delete_event" signal callback.
+ *	Toplevel GtkWidget "delete_event" signal callback.
  */
 gint EDVRecBinDeleteEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
@@ -301,7 +352,7 @@ gint EDVRecBinDeleteEventCB(
 }
 
 /*
- *	Recycle Bin "key_press_event" or "key_release_event" signal
+ *	Any GtkWidget "key_press_event" or "key_release_event" signal
  *	callback.
  */
 gint EDVRecBinKeyEventCB(
@@ -319,7 +370,7 @@ gint EDVRecBinKeyEventCB(
 	if((widget == NULL) || (key == NULL) || (recbin == NULL))
 	    return(status);
 
-	if(recbin->processing)
+	if(recbin->processing || (recbin->freeze_count > 0))
 	    return(status);
 
 	w = recbin->toplevel;
@@ -368,9 +419,10 @@ gint EDVRecBinKeyEventCB(
 	    }
 	}
 
-	/* Check which widget this signal is for */
-
-	/* Contents List */
+	/* Check which widget this signal is for
+	 *
+	 * Contents GtkCList
+	 */
 	if(widget == recbin->contents_clist)
 	{
 	    GtkCList *clist = GTK_CLIST(widget);
@@ -416,9 +468,9 @@ gint EDVRecBinKeyEventCB(
 		 */
 		if(isalnum((int)keyval) && is_press)
 		{
-                    const gboolean backwards = (state & GDK_MOD1_MASK) ? TRUE : FALSE;
-                    const gint start_row = (backwards) ?
-                        (clist->rows - 1) : 0;
+		    const gboolean backwards = (state & GDK_MOD1_MASK) ? TRUE : FALSE;
+		    const gint start_row = (backwards) ?
+			(clist->rows - 1) : 0;
 
 		    /* Find the column that is set to display the name */
 		    cfg_intlist_struct *intlist = EDV_GET_INTLIST(
@@ -451,12 +503,13 @@ gint EDVRecBinKeyEventCB(
 	    }
 	}
 
-	return(status);
 #undef STOP_SIGNAL_EMISSION
+
+	return(status);
 }
 
 /*
- *	Recycle Bin GtkWidget "button_press_event" signal callback.
+ *	Any GtkWidget "button_press_event" signal callback.
  */
 gint EDVRecBinButtonPressEventCB(
 	GtkWidget *widget, GdkEventButton *button, gpointer data
@@ -469,17 +522,16 @@ gint EDVRecBinButtonPressEventCB(
 	if((widget == NULL) || (recbin == NULL))
 	    return(status);
 
-	if(recbin->processing)
+	if(recbin->processing || (recbin->freeze_count > 0))
 	    return(status);
 
 	core = recbin->core;
-	if(core == NULL)
-	    return(status);
-
-	/* Get event type */
 	etype = button->type;
 
-	/* Check which widget this signal is for */
+	/* Check which widget this signal is for
+	 *
+	 * Contents GtkCList
+	 */
 	if(widget == recbin->contents_clist)
 	{
 	    gint row, column;
@@ -487,8 +539,7 @@ gint EDVRecBinButtonPressEventCB(
 	    GList *glist;
 	    GtkCList *clist = GTK_CLIST(widget);
 
-
-	    /* Find row and column based on given coordinates */
+	    /* Find the row and column */
 	    if(!gtk_clist_get_selection_info(
 		clist, button->x, button->y, &row, &column
 	    ))
@@ -509,7 +560,7 @@ gint EDVRecBinButtonPressEventCB(
 	    /* Handle by button number */
 	    switch(button->button)
 	    {
-	      case 3:
+	      case GDK_BUTTON3:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 		    GtkMenu *menu;
@@ -546,7 +597,7 @@ gint EDVRecBinButtonPressEventCB(
 		status = TRUE;
 		break;
 
-	      case 2:
+	      case GDK_BUTTON2:
 		if(etype == GDK_BUTTON_PRESS)
 		{
 		    if((row >= 0) && (row < clist->rows))
@@ -556,7 +607,7 @@ gint EDVRecBinButtonPressEventCB(
 		}
 		break;
 
-	      case 1:
+	      case GDK_BUTTON1:
 		/* Double click? */
 		if(etype == GDK_2BUTTON_PRESS)
 		{
@@ -569,9 +620,6 @@ gint EDVRecBinButtonPressEventCB(
 		}
 		break;
 	    }
-
-	    if(etype == GDK_BUTTON_PRESS)
-		gtk_widget_grab_focus(widget);
 	}
 
 	return(status);
@@ -612,7 +660,7 @@ void EDVRecBinHandleChildDetachedCB(
 
 
 /*
- *	Recycle Bin GtkCList "resize_column" signal callback.
+ *	Contents GtkCList "resize_column" signal callback.
  */
 void EDVRecBinResizeColumnCB(
 	GtkCList *clist, gint column, gint width, gpointer data
@@ -623,12 +671,10 @@ void EDVRecBinResizeColumnCB(
 	if((clist == NULL) || (recbin == NULL))
 	    return;
 
-	if(recbin->processing)
+	if((recbin->processing) || (recbin->freeze_count > 0))
 	    return;
 
 	core = recbin->core;
-	if(core == NULL)
-	    return;
 
 	/* Check which clist this signal is for */
 	if(GTK_WIDGET(clist) == recbin->contents_clist)
@@ -698,41 +744,45 @@ void EDVRecBinResizeColumnCB(
 }
 
 /*
- *	Recycle Bin GtkCList "click_column" signal callback.
+ *	Contents GtkCList "click_column" signal callback.
  */
 void EDVRecBinClickColumnCB(
 	GtkCList *clist, gint column, gpointer data
 )
 {
+	GtkWidget *widget, *toplevel;
 	edv_core_struct *core;
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
 	if((clist == NULL) || (recbin == NULL))
 	    return;
 
-	if(recbin->processing)
+	if((recbin->processing) || (recbin->freeze_count > 0))
 	    return;
 
+	widget = GTK_WIDGET(clist);
+	toplevel = recbin->toplevel;
 	core = recbin->core;
-	if(core == NULL)
-	    return;
 
-	/* Check which clist this signal is for */
+	/* Check which widget this signal is for
+	 *
+	 * Contents GtkCList
+	 */
 	if(GTK_WIDGET(clist) == recbin->contents_clist)
 	{
 	    cfg_intlist_struct *column_types_intlist;
 	    GtkCListCompareFunc cmp_func = NULL;
 	    GtkCListCompareFunc cmp_func_str =
 		 (GtkCListCompareFunc)EDVCListColumnSortStringCB;
+#if 0
 	    GtkCListCompareFunc cmp_func_num =
 		(GtkCListCompareFunc)EDVCListColumnSortNumberCB;
-
+#endif
 
 	    EDVRecBinSetBusy(recbin, TRUE);
-	    GUIBlockInput(recbin->toplevel, TRUE);
+	    GUIBlockInput(toplevel, TRUE);
 	    recbin->processing = TRUE;
 
-
-	    /* Get column types mapping */
+	    /* Get the column types mapping list */
 	    column_types_intlist = CFGItemListGetValueIntList(
 		core->cfg_list, EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN
 	    );
@@ -744,11 +794,14 @@ void EDVRecBinClickColumnCB(
 		);
 		switch(column_type)
 		{
+		  case EDV_RECBIN_COLUMN_TYPE_INDEX:
+		    cmp_func = EDVRecBinCListColumnSortIndexCB;
+		    break;
 		  case EDV_RECBIN_COLUMN_TYPE_NAME:
 		    cmp_func = cmp_func_str;
 		    break;
 		  case EDV_RECBIN_COLUMN_TYPE_SIZE:
-		    cmp_func = cmp_func_num;
+		    cmp_func = EDVRecBinCListColumnSortSizeCB;
 		    break;
 		  case EDV_RECBIN_COLUMN_TYPE_TYPE:
 		    cmp_func = cmp_func_str;
@@ -780,9 +833,6 @@ void EDVRecBinClickColumnCB(
 		  case EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION:
 		    cmp_func = cmp_func_str;
 		    break;
-		  case EDV_RECBIN_COLUMN_TYPE_INDEX:
-		    cmp_func = cmp_func_num;
-		    break;
 		  case EDV_RECBIN_COLUMN_TYPE_CAPACITY_USED:
 		    cmp_func = EDVRecBinCListColumnSortCapacityUsedCB;
 		    break;
@@ -792,7 +842,10 @@ void EDVRecBinClickColumnCB(
 
 	    gtk_clist_freeze(clist);
 
-	    /* Set sort column settings on the clist */
+	    /* Set or invert the sort column on the GtkCList based
+	     * on if the clicked on column is already the current
+	     * sort column
+	     */
 	    if(column != clist->sort_column)
 		gtk_clist_set_sort_column(clist, column);
 	    else
@@ -804,13 +857,15 @@ void EDVRecBinClickColumnCB(
 	    if(cmp_func != NULL)
 		gtk_clist_set_compare_func(clist, cmp_func);
 
-	    /* Sort rows */
+	    /* Sort the rows, this will call the GtkCList column
+	     * sort callbacks
+	     */
 	    gtk_clist_sort(clist);
 
 	    gtk_clist_thaw(clist);
 
 	    recbin->processing = FALSE;
-	    GUIBlockInput(recbin->toplevel, FALSE);
+	    GUIBlockInput(toplevel, FALSE);
 	    EDVRecBinSetBusy(recbin, FALSE);
 
 	    EDVRecBinUpdateMenus(recbin);
@@ -903,13 +958,34 @@ void EDVRecBinSelectRowCB(
 			break;
 		    }
 
-		    /* Set status bar message */
+		    /* Set the status bar message */
 		    if(nselected > 1)
-			s = g_strdup_printf(
-			    "%s objects selected",
-			    EDVSizeStrDelim(nselected)
+		    {
+			gulong total_size = 0l;
+			edv_recycled_object_struct *obj;
+			GList *glist = clist->selection;
+			while(glist != NULL)
+			{
+			    obj = EDV_RECYCLED_OBJECT(gtk_clist_get_row_data(
+				clist, (gint)glist->data
+			    ));
+			    if(obj != NULL)
+				total_size += obj->size;
+			    glist = g_list_next(glist);
+			}
+			g_free(size_str);
+			size_str = g_strdup_printf(
+			    "%s %s",
+			    EDVSizeStrDelim(total_size),
+			    (total_size == 1l) ? "byte" : "bytes"
 			);
-		    else if(!strcmp(obj->name, ".."))
+			s = g_strdup_printf(
+			    "%s objects selected (totaling %s)",
+			    EDVSizeStrDelim(nselected),
+			    size_str
+			);
+		    }
+		    else if(!strcmp((const char *)obj->name, ".."))
 			s = g_strdup_printf(
 			    "Parent directory selected"
 			);
@@ -929,7 +1005,7 @@ void EDVRecBinSelectRowCB(
 		{
 		    EDVStatusBarMessage(
 			recbin->status_bar,
-			"Object with NULL name selected",
+			"Object with no name selected",
 			FALSE
 		    );
 		}
@@ -975,13 +1051,35 @@ void EDVRecBinUnselectRowCB(
 	    /* Get total number of objects selected */
 	    const gint nselected = g_list_length(clist->selection);
 
-	    /* Update status bar message */
+	    /* Update the status bar message */
 	    if(nselected > 0)
-		s = g_strdup_printf(
-		    "%s %s selected",
-		    EDVSizeStrDelim(nselected),
-		    (nselected == 1) ? "object" : "objects"  
+	    {
+		gchar *size_str;
+		gulong total_size = 0l;
+		edv_recycled_object_struct *obj;
+		GList *glist = clist->selection;
+		while(glist != NULL)
+		{
+		    obj = EDV_RECYCLED_OBJECT(gtk_clist_get_row_data(
+			clist, (gint)glist->data
+		    ));
+		    if(obj != NULL)
+			total_size += obj->size;
+		    glist = g_list_next(glist);
+		}
+		size_str = g_strdup_printf(
+		    "%s %s",
+		    EDVSizeStrDelim(total_size),
+		    (total_size == 1l) ? "byte" : "bytes"
 		);
+		s = g_strdup_printf(
+		    "%s %s selected (totaling %s)",
+		    EDVSizeStrDelim(nselected),
+		    (nselected == 1) ? "object" : "objects",
+		    size_str
+		);
+		g_free(size_str);
+	    }
 	    else
 		s = STRDUP("No objects selected");
 	    EDVStatusBarMessage(
@@ -1034,16 +1132,17 @@ gint EDVRecBinMenuItemLeaveCB(
 /*
  *	Find bar start find callback.
  */
-void EDVRecBinFindBarStartCB(edv_findbar_struct *fb, gpointer data)
+void EDVRecBinFindBarStartCB(
+	edv_find_bar_struct *fb,
+	gpointer data
+)
 {
 	GtkCList *clist;
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
 	if(recbin == NULL)
 	    return;
 
-	clist = (GtkCList *)recbin->contents_clist;
-	if(clist == NULL)
-	    return;
+	clist = GTK_CLIST(recbin->contents_clist);
 
 	EDVRecBinSetBusy(recbin, TRUE);
 /*	GUIBlockInput(recbin->toplevel, TRUE); */
@@ -1059,7 +1158,9 @@ void EDVRecBinFindBarStartCB(edv_findbar_struct *fb, gpointer data)
  *	Find bar end find callback.
  */
 void EDVRecBinFindBarEndCB(
-	edv_findbar_struct *fb, gint total_matches, gpointer data
+	edv_find_bar_struct *fb,
+	const gint nmatches,
+	gpointer data
 )
 {
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
@@ -1075,22 +1176,30 @@ void EDVRecBinFindBarEndCB(
  *	Find bar match callback.
  */
 void EDVRecBinFindBarMatchCB(
-	const gchar *path, const struct stat *lstat_buf,
-	const gchar *excerpt, gint line_index,
+	const gchar *path,
+	struct stat *lstat_buf,
+	const gchar *excerpt,
+	const gint line_index,
 	gpointer data
 )
 {
 	gint row;
+	guint index;
+	const gchar *index_str;
 	GtkCList *clist;
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
 	if((path == NULL) || (lstat_buf == NULL) || (recbin == NULL))
 	    return;
 
-	clist = (GtkCList *)recbin->contents_clist;
-	if(clist == NULL)
-	    return;
+	/* Get the path as the index string, format is "#<index>" */
+	index_str = path;
+	if(*index_str == '#')
+	    index_str++;
+	index = (guint)ATOI(index_str);
 
-	row = EDVRecBinContentsFindRowByIndex(recbin, (guint)atoi(path));
+	clist = GTK_CLIST(recbin->contents_clist);
+
+	row = EDVRecBinContentsFindRowByIndex(recbin, index);
 	if((row >= 0) && (row < clist->rows))
 	    gtk_clist_select_row(clist, row, 0);
 }
@@ -1111,7 +1220,7 @@ void EDVRecBinStatusMessageCB(const gchar *message, gpointer data)
 /*
  *	Status progress callback.
  */
-void EDVRecBinStatusProgressCB(gfloat progress, gpointer data)
+void EDVRecBinStatusProgressCB(const gfloat progress, gpointer data)
 {
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
 	if(recbin == NULL)
@@ -1121,14 +1230,11 @@ void EDVRecBinStatusProgressCB(gfloat progress, gpointer data)
 }
 
 
-
-
-
 /*
  *	Write protect changed callback.
  */
 void EDVRecBinWriteProtectChangedCB(
-	edv_recbin_struct *recbin, gboolean state
+	edv_recbin_struct *recbin, const gboolean state
 )
 {
 	if(recbin == NULL)
@@ -1144,7 +1250,7 @@ void EDVRecBinWriteProtectChangedCB(
  *	Recycled object added callback.
  */
 void EDVRecBinRecycledObjectAddedNotifyCB(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 )
 {
 	edv_core_struct *core;
@@ -1156,8 +1262,6 @@ void EDVRecBinRecycledObjectAddedNotifyCB(
 	    return;
 
 	core = recbin->core;
-	if(core == NULL)
-	    return;
 
 	/* Contents List */
 	EDVRecBinContentsObjectAddedNotify(recbin, index);
@@ -1174,7 +1278,7 @@ void EDVRecBinRecycledObjectAddedNotifyCB(
  *	Recycled object modified callback.
  */
 void EDVRecBinRecycledObjectModifiedNotifyCB(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 )
 {
 	edv_core_struct *core;
@@ -1202,7 +1306,7 @@ void EDVRecBinRecycledObjectModifiedNotifyCB(
  *	Recycled object removed callback.
  */
 void EDVRecBinRecycledObjectRemovedNotifyCB(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 )
 {
 	edv_core_struct *core;
@@ -1318,13 +1422,12 @@ void EDVRecBinReconfiguredNotifyCB(edv_recbin_struct *recbin)
 	/* Realize listings */
 	EDVRecBinContentsRealizeListing(recbin);
 
-	/* Update menus */
 	EDVRecBinUpdateMenus(recbin);
 
-	/* Notify toplevel to resize */
-	w = recbin->toplevel;
-	if(w != NULL)
-	    gtk_widget_queue_resize(w);
+        /* Notify GTK about possible size changes (such as the tool
+         * bar resizing)
+         */
+	gtk_widget_queue_resize(recbin->toplevel);
 }
 
 
@@ -1333,7 +1436,7 @@ void EDVRecBinReconfiguredNotifyCB(edv_recbin_struct *recbin)
  */
 void EDVRecBinMimeTypeAddedCB(
 	edv_recbin_struct *recbin,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 )
 {
 	/* Treat a MIME Type added the same as it would be for a MIME
@@ -1348,7 +1451,7 @@ void EDVRecBinMimeTypeAddedCB(
  */
 void EDVRecBinMimeTypeModifiedCB(
 	edv_recbin_struct *recbin,
-	gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt
 )
 {
 	if(recbin == NULL)
@@ -1367,7 +1470,8 @@ void EDVRecBinMimeTypeModifiedCB(
  *	MIME Type removed callback.
  */
 void EDVRecBinMimeTypeRemovedCB(
-	edv_recbin_struct *recbin, gint mt_num
+	edv_recbin_struct *recbin,
+	const gint mt_num
 )
 {
 	if(recbin == NULL)
