@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 #include <sys/stat.h>
 #if defined(HAVE_REGEX)
 # include <regex.h>
@@ -12,6 +13,7 @@
 #include "../include/disk.h"
 
 #include "guiutils.h"
+#include "fprompt.h"
 #include "cdialog.h"
 #include "progressdialog.h"
 
@@ -31,6 +33,7 @@
 #include "recbin_contents_list.h"
 #include "endeavour2.h"
 #include "edv_cb.h"
+#include "edv_recycled_obj_op.h"
 #include "edv_utils.h"
 #include "edv_utils_gtk.h"
 
@@ -38,16 +41,32 @@
 #include "config.h"
 
 
+typedef struct _EDVRecBinContentsListFPromptData	EDVRecBinContentsListFPromptData;
+#define EDV_RECBIN_CONTENTS_LIST_FPROMPT_DATA(p)	((EDVRecBinContentsListFPromptData *)(p))
+
+
 static edv_recycled_object_struct *EDVRecBinNewErrorObject(
 	const guint index,
 	const gchar *name
 );
 
+/* Columns */
 static void EDVRecBinContentsResetColumns(
 	edv_core_struct *core, edv_recbin_struct *recbin,
 	GtkCList *clist
 );
+void EDVRecBinContentsResizeColumnOptimul(
+	edv_recbin_struct *recbin,
+	const gint column_num
+);
+void EDVRecBinContentsResizeColumnsOptimul(edv_recbin_struct *recbin);
 
+/* Cell Setting */
+static void EDVRecBinContentsSetCellIndex(
+	edv_core_struct *core, edv_recbin_struct *recbin,
+	GtkCList *clist, edv_recycled_object_struct *obj,
+	const gint row, const gint column
+);
 static void EDVRecBinContentsSetCellName(
 	edv_core_struct *core, edv_recbin_struct *recbin,
 	GtkCList *clist, edv_recycled_object_struct *obj,
@@ -58,8 +77,8 @@ static void EDVRecBinContentsSetCellSize(
 	GtkCList *clist, edv_recycled_object_struct *obj,
 	const gint row, const gint column,
 	const gboolean hide_dir_size, const gboolean hide_link_size,
-        const edv_size_format size_format,
-        const gulong block_size
+	const edv_size_format size_format,
+	const gulong block_size
 );
 static void EDVRecBinContentsSetCellType(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -116,11 +135,6 @@ static void EDVRecBinContentsSetCellOriginalLocation(
 	GtkCList *clist, edv_recycled_object_struct *obj,
 	const gint row, const gint column
 );
-static void EDVRecBinContentsSetCellIndex(
-	edv_core_struct *core, edv_recbin_struct *recbin,
-	GtkCList *clist, edv_recycled_object_struct *obj,
-	const gint row, const gint column
-);
 static void EDVRecBinContentsSetCellCapacityUsed(
 	edv_core_struct *core, edv_recbin_struct *recbin,
 	GtkCList *clist, edv_recycled_object_struct *obj,
@@ -134,18 +148,17 @@ static void EDVRecBinContentsSetRow(
 );
 
 static gint EDVRecBinContentsAppendObject(
-	edv_core_struct *core, edv_recbin_struct *recbin,
-	GtkCList *clist,
+	edv_recbin_struct *recbin,
 	edv_recycled_object_struct *obj
 );
 static void EDVRecBinContentsAppendListing(
-	edv_core_struct *core, edv_recbin_struct *recbin,
-	GtkCList *clist,
+	edv_recbin_struct *recbin,
 	const gboolean update_status_bar
 );
 
 gint EDVRecBinContentsFindRowByIndex(
-	edv_recbin_struct *recbin, const guint index
+	edv_recbin_struct *recbin,
+	const guint index
 );
 
 /* Realize Listing */
@@ -158,18 +171,36 @@ void EDVRecBinContentsGetListing(
 );
 void EDVRecBinContentsClear(edv_recbin_struct *recbin);
 
+/* Renaming */
+static void EDVRecBinContentsFPromptRenameApplyCB(
+	gpointer data, const gchar *value
+);
+static void EDVRecBinContentsFPromptRenameCancelCB(gpointer data);
+void EDVRecBinContentsPromptRename(
+	edv_recbin_struct *recbin,
+	const gint row,
+	const gint column
+);
+
 /* Callbacks */
 void EDVRecBinContentsObjectAddedNotify(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 );
 void EDVRecBinContentsObjectModifiedNotify(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 );
 void EDVRecBinContentsObjectRemovedNotify(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 );
 
 
+struct _EDVRecBinContentsListFPromptData {
+	edv_recbin_struct	*recbin;
+	gint		row,
+			column;
+};
+
+
 #define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
 #define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
 #define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
@@ -276,6 +307,10 @@ static void EDVRecBinContentsResetColumns(
 	     */
 	    switch(column_type)
 	    {
+	      case EDV_RECBIN_COLUMN_TYPE_INDEX:
+		title = "Index";
+		justify = GTK_JUSTIFY_RIGHT;
+		break;
 	      case EDV_RECBIN_COLUMN_TYPE_NAME:
 		title = "Name";
 		justify = GTK_JUSTIFY_LEFT;
@@ -324,10 +359,6 @@ static void EDVRecBinContentsResetColumns(
 		title = "Original Location";
 		justify = GTK_JUSTIFY_LEFT;
 		break;
-	      case EDV_RECBIN_COLUMN_TYPE_INDEX:
-		title = "Index";
-		justify = GTK_JUSTIFY_RIGHT;
-		break;
 	      case EDV_RECBIN_COLUMN_TYPE_CAPACITY_USED:
 		title = "Capacity Used";
 		justify = GTK_JUSTIFY_LEFT;
@@ -355,10 +386,93 @@ static void EDVRecBinContentsResetColumns(
 	gtk_clist_thaw(clist);
 }
 
+/*
+ *      Resizes the column to optimul size.
+ */
+void EDVRecBinContentsResizeColumnOptimul(
+	edv_recbin_struct *recbin,
+	const gint column_num
+)
+{
+	gint ncolumns, width;
+	GtkCList *clist;
+
+	if(recbin == NULL)
+	    return;
+
+	clist = GTK_CLIST(recbin->contents_clist);
+	ncolumns = clist->columns;
+	if((column_num < 0) || (column_num >= ncolumns))
+	    return;
+
+	gtk_clist_freeze(clist);
+
+	width = gtk_clist_optimal_column_width(clist, column_num);
+	gtk_clist_set_column_width(clist, column_num, width);
+
+	gtk_clist_thaw(clist);
+}
 
 /*
- *	Sets the recycled object name for the specified cell on the
- *	given clist.
+ *      Resizes all the columns to optimul sizes.
+ */
+void EDVRecBinContentsResizeColumnsOptimul(edv_recbin_struct *recbin)
+{
+	gint i, ncolumns;
+	GtkCList *clist;
+
+	if(recbin == NULL)
+	    return;
+
+	clist = GTK_CLIST(recbin->contents_clist);
+	ncolumns = clist->columns;
+
+	gtk_clist_freeze(clist);
+
+	for(i = 0; i < ncolumns; i++)
+	    EDVRecBinContentsResizeColumnOptimul(recbin, i);
+
+	gtk_clist_thaw(clist);
+}
+
+
+/*
+ *	Sets the cell's index value and attributes.
+ */
+static void EDVRecBinContentsSetCellIndex(
+	edv_core_struct *core, edv_recbin_struct *recbin,
+	GtkCList *clist, edv_recycled_object_struct *obj,
+	const gint row, const gint column
+)
+{
+	const gint border_minor = 2;
+	const guint index = obj->index;
+ 	gchar num_str[40];
+
+	/* Format the index string */
+	if(index != 0)
+	    g_snprintf(
+		num_str, sizeof(num_str),
+		"#%u",
+		obj->index
+	    );
+	else
+	    *num_str = '\0';
+
+	/* Set the cell */
+	gtk_clist_freeze(clist);
+	gtk_clist_set_text(
+	    clist, row, column,
+	    num_str
+	);
+	gtk_clist_set_shift(
+	    clist, row, column, 0, -border_minor
+	);
+	gtk_clist_thaw(clist);
+}
+
+/*
+ *	Sets the cell's name value and attributes.
  */
 static void EDVRecBinContentsSetCellName(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -370,7 +484,7 @@ static void EDVRecBinContentsSetCellName(
 	GdkPixmap *pixmap, *pixmap_hid;
 	GdkBitmap *mask, *mask_hid;
 
-	/* Get icon */
+	/* Get the icon */
 	EDVMatchObjectIcon(
 	    NULL, 0,
 	    core->mimetype, core->total_mimetypes,
@@ -382,17 +496,21 @@ static void EDVRecBinContentsSetCellName(
 	    NULL, NULL,
 	    &pixmap_hid, &mask_hid
 	);
-	/* Checking an alternate state icon should be used */
-	/* Hidden */
-	if(!STRISEMPTY(name) ?
-	    ((*name == '.') && (pixmap_hid != NULL)) : FALSE
-	)
+
+	/* Check if an alternate state icon should be used
+	 *
+	 * Hidden
+	 */
+	if(EDVIsObjectNameHidden(name))
 	{
-	    pixmap = pixmap_hid;
-	    mask = mask_hid;
+	    if(pixmap_hid != NULL)
+	    {
+		pixmap = pixmap_hid;
+		mask = mask_hid;
+	    }
 	}
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	if(pixmap != NULL)
 	    gtk_clist_set_pixtext(
@@ -414,16 +532,15 @@ static void EDVRecBinContentsSetCellName(
 }
 
 /*
- *	Sets the recycled object size for the specified cell on the
- *	given clist.
+ *	Sets the cell's size value and attributes.
  */
 static void EDVRecBinContentsSetCellSize(
 	edv_core_struct *core, edv_recbin_struct *recbin,
 	GtkCList *clist, edv_recycled_object_struct *obj,
 	const gint row, const gint column,
 	const gboolean hide_dir_size, const gboolean hide_link_size,
-        const edv_size_format size_format,
-        const gulong block_size
+	const edv_size_format size_format,
+	const gulong block_size
 )
 {
 	const gint border_minor = 2;
@@ -444,7 +561,7 @@ static void EDVRecBinContentsSetCellSize(
 		obj->size, size_format, block_size, ',', TRUE
 	    );
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, (s != NULL) ? s : ""
@@ -457,8 +574,7 @@ static void EDVRecBinContentsSetCellSize(
 }
 
 /*
- *	Sets the recycled object type for the specified cell on the
- *	given clist.
+ *	Sets the cell's MIME Type value.
  */
 static void EDVRecBinContentsSetCellType(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -476,7 +592,7 @@ static void EDVRecBinContentsSetCellType(
 	    &type_str
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, (type_str != NULL) ? type_str : ""
@@ -489,8 +605,7 @@ static void EDVRecBinContentsSetCellType(
 }
 
 /*
- *	Sets the recycled object permissions for the specified cell on
- *	the given clist.
+ *	Sets the cell's permissions value and attributes.
  */
 static void EDVRecBinContentsSetCellPermissions(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -499,47 +614,31 @@ static void EDVRecBinContentsSetCellPermissions(
 )
 {
 	const edv_permission_flags permissions = obj->permissions;
-	gchar s[80];
+	gchar *s;
 
 	/* Get permissions string */
 	if(hide_link_permissions && (obj->type == EDV_OBJECT_TYPE_LINK))
-	    *s = '\0';
+	    s = NULL;
 	else
-	    g_snprintf(
-		s, sizeof(s),
-		"%c%c%c%c%c%c%c%c%c",
-	    (permissions & EDV_PERMISSION_UREAD) ? 'r' : '-',
-	    (permissions & EDV_PERMISSION_UWRITE) ? 'w' : '-',
-	    (permissions & EDV_PERMISSION_SETUID) ?
-		'S' :
-		((permissions & EDV_PERMISSION_UEXECUTE) ? 'x' : '-'),
-	    (permissions & EDV_PERMISSION_GREAD) ? 'r' : '-',
-	    (permissions & EDV_PERMISSION_GWRITE) ? 'w' : '-',
-	    (permissions & EDV_PERMISSION_SETGID) ?
-		'G' :
-		((permissions & EDV_PERMISSION_GEXECUTE) ? 'x' : '-'),
-	    (permissions & EDV_PERMISSION_AREAD) ? 'r' : '-',
-	    (permissions & EDV_PERMISSION_AWRITE) ? 'w' : '-',
-	    (permissions & EDV_PERMISSION_STICKY) ?
-		'T' :
-		((permissions & EDV_PERMISSION_AEXECUTE) ? 'x' : '-')
-	    );
+	    s = EDVGetPermissionsString(permissions);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, s
+	    clist, row, column,
+	    (s != NULL) ? s : ""
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
 	gtk_clist_thaw(clist);
+
+	g_free(s);
 }
 
 /*
- *	Sets the recycled object owner for the specified cell on the
- *	given clist.
+ *	Sets the cell's owner value and attributes.
  */
 static void EDVRecBinContentsSetCellOwner(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -553,7 +652,7 @@ static void EDVRecBinContentsSetCellOwner(
 	    obj->owner_id, NULL
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column,
@@ -569,8 +668,7 @@ static void EDVRecBinContentsSetCellOwner(
 }
 
 /*
- *	Sets the recycled object owner for the specified cell on the
- *	given clist.
+ *	Sets the cell's group value and attributes.
  */
 static void EDVRecBinContentsSetCellGroup(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -584,7 +682,7 @@ static void EDVRecBinContentsSetCellGroup(
 	    obj->group_id, NULL
 	);
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column,
@@ -600,8 +698,7 @@ static void EDVRecBinContentsSetCellGroup(
 }
 
 /*
- *	Sets the recycled object last access date for the specified
- *	cell on the given clist.
+ *	Sets the cell's access date value and attributes.
  */
 static void EDVRecBinContentsSetCellDateAccess(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -610,21 +707,16 @@ static void EDVRecBinContentsSetCellDateAccess(
 	edv_date_relativity date_relativity, const gchar *date_format
 )
 {
-	const gchar *date_str;
+	/* Get/format the date string */
+	const gulong t = obj->access_time;
+	const gchar *date_str = (t > 0l) ?
+	    EDVDateFormatString(t, date_format, date_relativity) : "";
 
-	/* Get string for date accessed */
-	gulong t = obj->access_time;
-	if(t > 0)
-	    date_str = EDVDateFormatString(
-		t, date_format, date_relativity
-	    );
-	else
-	    date_str = "";
-
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, date_str
+	    clist, row, column,
+	    date_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -634,8 +726,7 @@ static void EDVRecBinContentsSetCellDateAccess(
 }
 
 /*
- *	Sets the recycled object last modified date for the specified
- *	cell on the given clist.
+ *	Sets the cell's modified date value and attributes.
  */
 static void EDVRecBinContentsSetCellDateModified(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -644,21 +735,16 @@ static void EDVRecBinContentsSetCellDateModified(
 	edv_date_relativity date_relativity, const gchar *date_format
 )
 {
-	const gchar *date_str;
+	/* Get/format the date string */
+	const gulong t = obj->modify_time;
+	const gchar *date_str = (t > 0l) ?
+	    EDVDateFormatString(t, date_format, date_relativity) : "";
 
-	/* Get string for date modified */
-	gulong t = obj->modify_time;
-	if(t > 0)
-	    date_str = EDVDateFormatString(
-		t, date_format, date_relativity
-	    );
-	else
-	    date_str = "";
-
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, date_str
+	    clist, row, column,
+	    date_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -668,8 +754,7 @@ static void EDVRecBinContentsSetCellDateModified(
 }
 
 /*
- *	Sets the recycled object last changed date for the specified
- *	cell on the given clist.
+ *	Sets the cell's changed date value and attributes.
  */
 static void EDVRecBinContentsSetCellDateChanged(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -678,21 +763,16 @@ static void EDVRecBinContentsSetCellDateChanged(
 	edv_date_relativity date_relativity, const gchar *date_format
 )
 {
-	const gchar *date_str;
+	/* Get/format the date string */
+	const gulong t = obj->change_time;
+	const gchar *date_str = (t > 0l) ?
+	    EDVDateFormatString(t, date_format, date_relativity) : "";
 
-	/* Get string for date changed */
-	gulong t = obj->change_time;
-	if(t > 0)
-	    date_str = EDVDateFormatString(
-		t, date_format, date_relativity
-	    );
-	else
-	    date_str = "";
-
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, date_str
+	    clist, row, column,
+	    date_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -702,8 +782,7 @@ static void EDVRecBinContentsSetCellDateChanged(
 }
 
 /*
- *	Sets the recycled object delete date for the specified cell
- *	on the given clist.
+ *	Sets the cell's deleted date value and attributes.
  */
 static void EDVRecBinContentsSetCellDateDeleted(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -713,8 +792,6 @@ static void EDVRecBinContentsSetCellDateDeleted(
 )
 {
 	const gchar *date_str;
-
-	/* Get date string */
 	const gulong t = obj->deleted_time;
 	if(t > 0l)
 	    date_str = EDVDateFormatString(
@@ -723,10 +800,11 @@ static void EDVRecBinContentsSetCellDateDeleted(
 	else
 	    date_str = "";
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
-	    clist, row, column, date_str
+	    clist, row, column,
+	    date_str
 	);
 	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_set_shift(
@@ -737,8 +815,7 @@ static void EDVRecBinContentsSetCellDateDeleted(
 
 
 /*
- *	Sets the recycled object linked to path for the specified cell
- *	on the given clist.
+ *	Sets the cell's linked to value and attributes.
  */
 static void EDVRecBinContentsSetCellLinkedTo(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -751,7 +828,7 @@ static void EDVRecBinContentsSetCellLinkedTo(
 	    (obj->type == EDV_OBJECT_TYPE_LINK)) ?
 	    obj->link_target : "";
 
-	/* Set cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	gtk_clist_set_text(
 	    clist, row, column, target
@@ -764,8 +841,7 @@ static void EDVRecBinContentsSetCellLinkedTo(
 }
 
 /*
- *	Sets the recycled object original location for the specified
- *	cell on the given clist.
+ *	Sets the cell's original location value and attributes.
  */
 static void EDVRecBinContentsSetCellOriginalLocation(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -773,48 +849,65 @@ static void EDVRecBinContentsSetCellOriginalLocation(
 	const gint row, const gint column
 )
 {
-	GdkBitmap *mask;
-	GdkPixmap *pixmap;
-	struct stat lstat_buf;
-	const gchar	*location = (obj->original_path != NULL) ?
-			    obj->original_path : "";
+	GdkBitmap	*mask = NULL,
+			*mask_hid = NULL,
+			*mask_ext = NULL;
+	GdkPixmap	*pixmap = NULL,
+			*pixmap_hid = NULL,
+			*pixmap_ext = NULL;
+	const gchar *location = (obj->original_path != NULL) ?
+	    obj->original_path : "";
 	edv_object_struct *loc_obj = EDVObjectNew();
-	EDVObjectSetPath(loc_obj, location);
-	if(!lstat(location, &lstat_buf))
+	if(loc_obj != NULL)
 	{
-	    EDVObjectSetStat(loc_obj, &lstat_buf);
-	    EDVObjectUpdateLinkFlags(loc_obj);
-	    EDVMatchObjectIcon(
-		core->device, core->total_devices,
-		core->mimetype, core->total_mimetypes,
-		loc_obj->type,
-		loc_obj->full_path,
-		EDV_OBJECT_IS_LINK_VALID(loc_obj),
-		loc_obj->permissions,
-		0,			/* Small icons */
-		&pixmap, &mask,
-		NULL, NULL,
-		NULL, NULL,
-		NULL, NULL
-	    );
-	}
-	else
-	{
-	    edv_mime_type_struct *m = EDVMimeTypesListMatchType(
-		core->mimetype, core->total_mimetypes,
-		NULL,
-		EDV_MIME_TYPE_TYPE_INODE_DIRECTORY,
-		FALSE
-	    );
-	    if(m != NULL)
-	    {
-		pixmap = m->small_pixmap[EDV_MIME_TYPE_ICON_STATE_STANDARD];
-		mask = m->small_mask[EDV_MIME_TYPE_ICON_STATE_STANDARD];
-	    }
-	}
-	EDVObjectDelete(loc_obj);
+	    struct stat lstat_buf;
 
-	/* Set cell */
+	    EDVObjectSetPath(loc_obj, location);
+	    if(!lstat((const char *)location, &lstat_buf))
+	    {
+		EDVObjectSetStat(loc_obj, &lstat_buf);
+		EDVObjectUpdateLinkFlags(loc_obj);
+		EDVMatchObjectIcon(
+		    core->device, core->total_devices,
+		    core->mimetype, core->total_mimetypes,
+		    loc_obj->type,
+		    loc_obj->full_path,
+		    EDV_OBJECT_IS_LINK_VALID(loc_obj),
+		    loc_obj->permissions,
+		    0,			/* Small icons */
+		    &pixmap, &mask,
+		    NULL, NULL,
+		    &pixmap_ext, &mask_ext,
+		    &pixmap_hid, &mask_hid
+		);
+		/* Hidden */
+		if(EDVIsObjectHidden(loc_obj))
+		{
+		    if(pixmap_hid != NULL)
+		    {
+			pixmap = pixmap_hid;
+			mask = mask_hid;
+		    }
+		}
+	    }
+	    else
+	    {
+		edv_mime_type_struct *m = EDVMimeTypesListMatchType(
+		    core->mimetype, core->total_mimetypes,
+		    NULL,
+		    EDV_MIME_TYPE_TYPE_INODE_DIRECTORY,
+		    FALSE
+		);
+		if(m != NULL)
+		{
+		    pixmap = m->small_pixmap[EDV_MIME_TYPE_ICON_STATE_STANDARD];
+		    mask = m->small_mask[EDV_MIME_TYPE_ICON_STATE_STANDARD];
+		}
+	    }
+	    EDVObjectDelete(loc_obj);
+	}
+
+	/* Set the cell */
 	gtk_clist_freeze(clist);
 	if(pixmap != NULL)
 	    gtk_clist_set_pixtext(
@@ -834,39 +927,7 @@ static void EDVRecBinContentsSetCellOriginalLocation(
 }
 
 /*
- *	Sets the recycled object index to path for the specified cell
- *	on the given clist.
- */
-static void EDVRecBinContentsSetCellIndex(
-	edv_core_struct *core, edv_recbin_struct *recbin,
-	GtkCList *clist, edv_recycled_object_struct *obj,
-	const gint row, const gint column
-)
-{
-	const gint border_minor = 2;
- 	gchar num_str[40];
-
-	/* Format the index string */
-	g_snprintf(
-	    num_str, sizeof(num_str),
-	    "#%i",
-	    obj->index
-	);
-
-	/* Set cell */
-	gtk_clist_freeze(clist);
-	gtk_clist_set_text(
-	    clist, row, column, num_str
-	);
-	gtk_clist_set_shift(
-	    clist, row, column, 0, -border_minor
-	);
-	gtk_clist_thaw(clist);
-}
-
-/*
- *	Sets the recycled object capacity used for the specified cell
- *	on the given clist.
+ *	Sets the cell's capacity used value and attributes.
  */
 static void EDVRecBinContentsSetCellCapacityUsed(
 	edv_core_struct *core, edv_recbin_struct *recbin,
@@ -876,11 +937,11 @@ static void EDVRecBinContentsSetCellCapacityUsed(
 )
 {
 	gfloat usage_coeff;
-        GdkBitmap *mask = NULL;
-        GdkPixmap *pixmap;
-        GtkCListColumn *column_ptr = ((column >= 0) && (column < clist->columns)) ?
-            &clist->column[column] : NULL;
-        const gint	width = (column_ptr != NULL) ?
+	GdkBitmap *mask = NULL;
+	GdkPixmap *pixmap;
+	GtkCListColumn *column_ptr = ((column >= 0) && (column < clist->columns)) ?
+	    &clist->column[column] : NULL;
+	const gint	width = (column_ptr != NULL) ?
 	    column_ptr->width : 60,
 			height = GTK_CLIST_ROW_HEIGHT_SET(clist) ?
 	    (clist->row_height - 4) : -1;
@@ -911,17 +972,17 @@ static void EDVRecBinContentsSetCellCapacityUsed(
 	    &mask
 	);
 
-        /* Set the cell */
+	/* Set the cell */
 	gtk_clist_freeze(clist);
-        if(pixmap != NULL)
-            gtk_clist_set_pixmap(clist, row, column, pixmap, mask);
-        else 
-            gtk_clist_set_text(clist, row, column, "");
-        gtk_clist_set_cell_style(clist, row, column, NULL);
+	if(pixmap != NULL)
+	    gtk_clist_set_pixmap(clist, row, column, pixmap, mask);
+	else 
+	    gtk_clist_set_text(clist, row, column, "");
+	gtk_clist_set_cell_style(clist, row, column, NULL);
 	gtk_clist_thaw(clist);
 
-        GDK_PIXMAP_UNREF(pixmap);
-        GDK_BITMAP_UNREF(mask);
+	GDK_PIXMAP_UNREF(pixmap);
+	GDK_BITMAP_UNREF(mask);
 }
 
 /*
@@ -988,6 +1049,12 @@ static void EDVRecBinContentsSetRow(
 	    column_type = (edv_recbin_column_type)glist->data;
 	    switch(column_type)
 	    {
+	      case EDV_RECBIN_COLUMN_TYPE_INDEX:
+		EDVRecBinContentsSetCellIndex(
+		    core, recbin, clist, obj,
+		    row, i
+		);
+		break;
 	      case EDV_RECBIN_COLUMN_TYPE_NAME:
 		EDVRecBinContentsSetCellName(
 		    core, recbin, clist, obj,
@@ -1062,12 +1129,6 @@ static void EDVRecBinContentsSetRow(
 		    row, i
 		);
 		break;
-	      case EDV_RECBIN_COLUMN_TYPE_INDEX:
-		EDVRecBinContentsSetCellIndex(
-		    core, recbin, clist, obj,
-		    row, i
-		);
-		break;
 	      case EDV_RECBIN_COLUMN_TYPE_CAPACITY_USED:
 		EDVRecBinContentsSetCellCapacityUsed(
 		    core, recbin, clist, obj,
@@ -1096,14 +1157,15 @@ static void EDVRecBinContentsSetRow(
  *	All inputs assumed valid.
  */
 static gint EDVRecBinContentsAppendObject(
-	edv_core_struct *core, edv_recbin_struct *recbin,
-	GtkCList *clist,
+	edv_recbin_struct *recbin,
 	edv_recycled_object_struct *obj
 )
 {
+	GtkCList *clist = GTK_CLIST(recbin->contents_clist);
 	const gint ncolumns = MAX(clist->columns, 1);
 	gint i, new_row;
 	gchar **strv;
+	edv_core_struct *core = recbin->core;
 
 	gtk_clist_freeze(clist);
 
@@ -1156,8 +1218,7 @@ static gint EDVRecBinContentsAppendObject(
  *	All inputs assumed valid.
  */
 static void EDVRecBinContentsAppendListing(
-	edv_core_struct *core, edv_recbin_struct *recbin,
-	GtkCList *clist,
+	edv_recbin_struct *recbin,
 	const gboolean update_status_bar
 )
 {
@@ -1167,6 +1228,8 @@ static void EDVRecBinContentsAppendListing(
 	gint nobjs, nobjs_loaded, last_progress_percent;
 	const gchar	*recbin_index_file,
 			*filter = recbin->contents_list_filter;
+	GtkCList *clist = GTK_CLIST(recbin->contents_clist);
+	edv_core_struct *core = recbin->core;
 	const cfg_item_struct *cfg_list = core->cfg_list;
 	edv_recycled_object_struct *obj;
 	edv_recbin_index_struct *rbi_ptr;
@@ -1276,10 +1339,7 @@ static void EDVRecBinContentsAppendListing(
 		if(tar_obj != NULL)
 		{
 		    /* Append/transfer the object to the listing */
-		    EDVRecBinContentsAppendObject(
-			core, recbin, clist,
-			tar_obj
-		    );
+		    EDVRecBinContentsAppendObject(recbin, tar_obj);
 		    nobjs_loaded++;
 		    UPDATE_PROGRESS
 		}
@@ -1293,10 +1353,7 @@ static void EDVRecBinContentsAppendListing(
 		if(tar_obj != NULL)
 		{
 		    /* Append/transfer the object to the listing */
-		    EDVRecBinContentsAppendObject(
-			core, recbin, clist,
-			tar_obj
-		    );
+		    EDVRecBinContentsAppendObject(recbin, tar_obj);
 		    nobjs_loaded++;
 		    UPDATE_PROGRESS
 		}
@@ -1327,7 +1384,8 @@ static void EDVRecBinContentsAppendListing(
  *	Returns the matched row or negative on error.
  */
 gint EDVRecBinContentsFindRowByIndex(
-	edv_recbin_struct *recbin, const guint index
+	edv_recbin_struct *recbin,
+	const guint index
 )
 {
 	gint i, n;
@@ -1368,6 +1426,7 @@ void EDVRecBinContentsRealizeListing(edv_recbin_struct *recbin)
 {
 	gint i, n;
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 	edv_recycled_object_struct *obj;
 
@@ -1376,6 +1435,7 @@ void EDVRecBinContentsRealizeListing(edv_recbin_struct *recbin)
 
 	clist = GTK_CLIST(recbin->contents_clist);
 	core = recbin->core;
+	cfg_list = core->cfg_list;
 
 	gtk_clist_freeze(clist);
 
@@ -1397,6 +1457,10 @@ void EDVRecBinContentsRealizeListing(edv_recbin_struct *recbin)
 	    );
 	}
 
+	/* Resize the columns */
+	if(EDV_GET_B(EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+	    EDVRecBinContentsResizeColumnsOptimul(recbin);
+
 	gtk_clist_thaw(clist);
 }
 
@@ -1416,6 +1480,7 @@ void EDVRecBinContentsGetListing(
 )
 {
 	GtkCList *clist;
+	cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 
 	if(recbin == NULL)
@@ -1423,6 +1488,7 @@ void EDVRecBinContentsGetListing(
 
 	clist = GTK_CLIST(recbin->contents_clist);
 	core = recbin->core;
+	cfg_list = core->cfg_list;
 
 	/* Report the initial progress? */
 	if(update_status_bar)
@@ -1446,10 +1512,11 @@ void EDVRecBinContentsGetListing(
 	EDVRecBinContentsResetColumns(core, recbin, clist);
 
 	/* Append the list of recycled objects to the listing */
-	EDVRecBinContentsAppendListing(
-	    core, recbin, clist,
-	    update_status_bar
-	);
+	EDVRecBinContentsAppendListing(recbin, update_status_bar);
+
+	/* Resize the columns */
+	if(EDV_GET_B(EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+	    EDVRecBinContentsResizeColumnsOptimul(recbin);
 
 	gtk_clist_thaw(clist);
 
@@ -1485,11 +1552,277 @@ void EDVRecBinContentsClear(edv_recbin_struct *recbin)
 }
 
 
+/*
+ *	FPrompt rename apply callback.
+ */
+static void EDVRecBinContentsFPromptRenameApplyCB(
+	gpointer data, const gchar *value
+)
+{
+	gint row;
+	edv_recbin_struct *recbin;
+	EDVRecBinContentsListFPromptData *d = EDV_RECBIN_CONTENTS_LIST_FPROMPT_DATA(data);
+	if(d == NULL)
+	    return;
+
+	recbin = d->recbin;
+	row = d->row;
+
+	/* Inputs valid? */
+	if((recbin != NULL) && (row > -1) && (value != NULL))
+	{
+	    GtkWidget *toplevel = recbin->toplevel;
+	    GtkCList *clist = GTK_CLIST(recbin->contents_clist);
+	    edv_status_bar_struct *sb = recbin->status_bar;
+	    edv_core_struct *core = recbin->core;
+
+	    /* Get the selected object */
+	    edv_recycled_object_struct *obj = EDV_RECYCLED_OBJECT(
+		gtk_clist_get_row_data(clist, row)
+	    );
+	    if(obj != NULL)
+	    {
+		gboolean yes_to_all = FALSE;
+		const guint index = obj->index;
+		gchar *old_name = STRDUP(obj->name);
+		const gchar *new_name = value;
+		const gchar *error_msg;
+		GList *modified_indicies_list;
+
+		/* Rename */
+		(void)EDVRecycledObjectOPRename(
+		    core,
+		    index,
+		    new_name,
+		    &modified_indicies_list,
+		    toplevel,
+		    FALSE,			/* Do not show progress */
+		    TRUE,			/* Interactive */
+		    &yes_to_all
+		);
+
+                /* Unmap the progress dialog */
+                ProgressDialogBreakQuery(FALSE);
+                ProgressDialogSetTransientFor(NULL);
+
+                /* Check for errors */
+                error_msg = EDVRecycledObjectOPGetError(core);
+                if(!STRISEMPTY(error_msg))
+                {
+                    /* Report the error */
+                    EDVPlaySoundError(core);
+                    EDVMessageError(
+                        "Rename Error",
+                        error_msg,
+                        NULL,
+                        toplevel
+                    );
+                }
+
+                if(modified_indicies_list != NULL)
+                {
+		    guint index;
+		    gchar *msg;
+		    GList *glist;
+
+		    /* Notify about the modified recycled objects */
+                    for(glist = modified_indicies_list;
+                        glist != NULL;
+                        glist = g_list_next(glist)
+                    )
+                    {
+                        index = (guint)glist->data;
+                        if(index == 0)
+                            continue;
+
+                        EDVRecycledObjectModifiedEmit(core, index);
+                    }
+
+		    /* Update the status bar message */
+		    msg = g_strdup_printf(
+                        "Object \"%s\" renamed to \"%s\"",
+			old_name,
+			new_name
+		    );
+                    EDVStatusBarMessage(sb, msg, FALSE);
+                    g_free(msg);
+
+		    /* Delete the modified indicies list */
+		    g_list_free(modified_indicies_list);
+                }
+                else
+                {
+                    /* Did not get the modified indicies list so this
+                     * implies failure
+                     */
+                    EDVStatusBarMessage(
+                        sb,
+                        "Rename object failed",
+                        FALSE
+                    );
+ 		}
+
+		g_free(old_name);
+	    }
+	}
+
+	g_free(d);
+}
+
+/*
+ *	FPrompt rename cancel callback.
+ */
+static void EDVRecBinContentsFPromptRenameCancelCB(gpointer data)
+{
+	EDVRecBinContentsListFPromptData *d = EDV_RECBIN_CONTENTS_LIST_FPROMPT_DATA(data);
+	if(d == NULL)
+	    return;
+
+	g_free(d);
+}
+
+/*
+ *	Prompts to rename the object.
+ *
+ *	The row and column specifies the object on the list to map
+ *	the rename prompt at. If column is -1 then the column that
+ *	is set to EDV_RECBIN_COLUMN_TYPE_NAME will be used.
+ */
+void EDVRecBinContentsPromptRename(
+	edv_recbin_struct *recbin,
+	const gint row,
+	const gint column
+)
+{
+	gint cx, cy, px, py, pwidth, pheight, name_column;
+	GtkWidget *toplevel;
+	GtkCList *clist;
+	const cfg_item_struct *cfg_list;
+	cfg_intlist_struct *column_type_intlist;
+	edv_recycled_object_struct *obj;
+	edv_core_struct *core;
+
+	if((recbin == NULL) || FPromptIsQuery())
+	    return;
+
+	toplevel = recbin->toplevel;
+	clist = GTK_CLIST(recbin->contents_clist);
+	core = recbin->core;
+	cfg_list = core->cfg_list;
+
+	/* Check and warn if write protect is enabled */
+	if(EDVCheckWriteProtect(core, TRUE, toplevel))
+	    return;
+
+	EDVRecBinSyncData(recbin);
+
+	/* Row does not exist? */
+	if((row < 0) || (row >= clist->rows))
+	    return;
+
+	/* Find which column is displaying the name */
+	name_column = -1;
+	column_type_intlist = EDV_GET_INTLIST(
+	    EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN
+	);
+	if(column_type_intlist != NULL)
+	{
+	    gint i = 0;
+	    GList *glist;
+
+	    for(glist = column_type_intlist->list;
+		glist != NULL;
+		glist = g_list_next(glist)
+	    )
+	    {
+		if((edv_recbin_column_type)glist->data ==
+		    EDV_RECBIN_COLUMN_TYPE_NAME
+		)
+		{
+		    name_column = i;
+		    break;
+		}
+		i++;
+	    }
+	}
+	/* No column displaying the name? */
+	if(name_column < 0)
+	    return;
+
+	/* Get the cell's geometry */
+	if(!gtk_clist_get_cell_geometry(
+	    clist, name_column, row,
+	    &cx, &cy, &pwidth, &pheight
+	))
+	    return;
+
+	/* Get the root window relative coordinates */
+	px = 0;
+	py = 0;
+	gdk_window_get_deskrelative_origin(
+	    clist->clist_window, &px, &py
+	);
+	px += cx + 0;
+	py += cy - 2;           /* Move up a little */
+
+	/* Get the recycled object */
+	obj = EDV_RECYCLED_OBJECT(gtk_clist_get_row_data(clist, row));
+	if(obj == NULL)
+	    return;
+
+	/* Check if the object's name is a special notation that
+	 * may not be renamed
+	 */
+	if(!STRISEMPTY(obj->name))
+	{
+	    const gchar *name = obj->name;
+	    if(!strcmp((const char *)name, ".") ||
+	       !strcmp((const char *)name, "..") ||
+	       !strcmp((const char *)name, "/")
+	    )
+		return;
+	}
+
+	/* Is the specified column the name column or -1? */
+	if((column == name_column) || (column < 0))
+	{
+	    gchar *value = STRDUP(obj->name);
+	    EDVRecBinContentsListFPromptData *d = EDV_RECBIN_CONTENTS_LIST_FPROMPT_DATA(
+		g_malloc(sizeof(EDVRecBinContentsListFPromptData))
+	    );
+	    if(d != NULL)
+	    {
+		d->recbin = recbin;
+		d->row = row;
+		d->column = column;
+	    }
+
+	    /* Map floating prompt to change values */
+	    FPromptSetTransientFor(toplevel);
+	    FPromptSetPosition(px, py);
+	    FPromptMapQuery(
+		NULL,			/* No label */
+		value,
+		NULL,			/* No tooltip message */
+		FPROMPT_MAP_NO_MOVE,	/* Map code */
+		pwidth, -1,		/* Width and height */
+		0,			/* No buttons */
+		d,			/* Callback data */
+		NULL,			/* No browse callback */
+		EDVRecBinContentsFPromptRenameApplyCB,
+		EDVRecBinContentsFPromptRenameCancelCB
+	    );
+
+	    g_free(value);
+	}
+}
+
+
 /*
  *	Recycled object added callback.
  */
 void EDVRecBinContentsObjectAddedNotify(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 )
 {
 	gint row;
@@ -1527,10 +1860,11 @@ void EDVRecBinContentsObjectAddedNotify(
 	    if(obj != NULL)
 	    {
 		/* Add the recycled object to the list */
-		EDVRecBinContentsAppendObject(
-		    core, recbin, clist,
-		    obj
-		);
+		EDVRecBinContentsAppendObject(recbin, obj);
+
+		/* Resize the columns */
+		if(EDV_GET_B(EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		    EDVRecBinContentsResizeColumnsOptimul(recbin);
 	    }
 	}
 }
@@ -1539,7 +1873,7 @@ void EDVRecBinContentsObjectAddedNotify(
  *	Recycled object modified callback.
  */
 void EDVRecBinContentsObjectModifiedNotify(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 )
 {
 	gint row;
@@ -1560,7 +1894,7 @@ void EDVRecBinContentsObjectModifiedNotify(
 	if(STRISEMPTY(recbin_index_file))
 	    return;
 
-	/* Update modified recycled object in the list */
+	/* Update the modified recycled object in the list */
 	row = EDVRecBinContentsFindRowByIndex(recbin, index);
 	if(row > -1)
 	{
@@ -1583,6 +1917,11 @@ void EDVRecBinContentsObjectModifiedNotify(
 		    obj,
 		    row
 		);
+
+		/* Resize the columns */
+		if(EDV_GET_B(EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		    EDVRecBinContentsResizeColumnsOptimul(recbin);
+
 		gtk_clist_thaw(clist);
 	    }
 	}
@@ -1596,10 +1935,11 @@ void EDVRecBinContentsObjectModifiedNotify(
 	    );
 	    if(obj != NULL)
 	    {
-		EDVRecBinContentsAppendObject(
-		    core, recbin, clist,
-		    obj
-		);
+		EDVRecBinContentsAppendObject(recbin, obj);
+
+		/* Resize the columns */
+		if(EDV_GET_B(EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		    EDVRecBinContentsResizeColumnsOptimul(recbin);
 	    }
 	}
 }
@@ -1608,16 +1948,20 @@ void EDVRecBinContentsObjectModifiedNotify(
  *	Recycled object removed callback.
  */
 void EDVRecBinContentsObjectRemovedNotify(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 )
 {
 	gint row;
 	GtkCList *clist;
+	const cfg_item_struct *cfg_list;
+	edv_core_struct *core;
 
 	if(recbin == NULL)
 	    return;
 
 	clist = GTK_CLIST(recbin->contents_clist);
+	core = recbin->core;
+	cfg_list = core->cfg_list;
 
 	/* Remove all the rows who's object's index matches the
 	 * removed index
@@ -1631,5 +1975,9 @@ void EDVRecBinContentsObjectRemovedNotify(
 		row = EDVRecBinContentsFindRowByIndex(recbin, index);
 	    } while(row > -1);
 	    gtk_clist_thaw(clist);
+
+	    /* Resize the columns */
+	    if(EDV_GET_B(EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS))
+		EDVRecBinContentsResizeColumnsOptimul(recbin);
 	}
 }
