@@ -9,9 +9,17 @@
 #include "recbin.h"
 
 
+/* Columns */
+extern void EDVRecBinContentsResizeColumnOptimul(
+	edv_recbin_struct *recbin,
+	const gint column_num
+);
+extern void EDVRecBinContentsResizeColumnsOptimul(edv_recbin_struct *recbin);
+
 /* Finding */
 extern gint EDVRecBinContentsFindRowByIndex(
-	edv_recbin_struct *recbin, const guint index
+	edv_recbin_struct *recbin,
+	const guint index
 );
 
 /* Realize Listing */
@@ -24,15 +32,22 @@ extern void EDVRecBinContentsGetListing(
 );
 extern void EDVRecBinContentsClear(edv_recbin_struct *recbin);
 
+/* Rename */
+extern void EDVRecBinContentsPromptRename(
+        edv_recbin_struct *recbin,
+	const gint row,
+	const gint column
+);
+
 /* Callbacks */
 extern void EDVRecBinContentsObjectAddedNotify(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 );
 extern void EDVRecBinContentsObjectModifiedNotify(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 );
 extern void EDVRecBinContentsObjectRemovedNotify(
-	edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, const guint index
 );
 
 
