@@ -33,27 +33,32 @@
 
 static gint EDVRecBinDNDConfirm(
 	edv_core_struct *core,
-	const gint gdk_action, const guint info,
+	const GdkDragAction action,
+	const guint info,
 	GtkWidget *toplevel,
 	GList *url_list
 );
 static void EDVRecBinDNDUpdateStatusBar(
 	edv_recbin_struct *recbin,
-	const gint gdk_action, const guint info,
-	const gint total_src_objects,
-	const gint total_objects_processed, const gint status
+	const GdkDragAction action,
+	const guint info,
+	const gint nsrc_objs,
+	const gint nobjs_processed,
+	const gint status
 );
 
 static void EDVRecBinDragDataReceivedNexus(
-	edv_recbin_struct *recbin,		/* Can be NULL */
 	edv_core_struct *core,
-	GdkDragContext *dc, const guint info,
+	edv_recbin_struct *recbin,
+	GdkDragContext *dc,
+	const guint info,
 	GtkSelectionData *selection_data
 );
 
 
 void EDVRecBinContentsDNDSetIcon(
-	edv_recbin_struct *recbin, gint row, gint column
+	edv_recbin_struct *recbin,
+	const gint row, const gint column
 );
 gboolean EDVRecBinContentsDragMotionCB(
 	GtkWidget *widget, GdkDragContext *dc,
@@ -87,32 +92,33 @@ void EDVRecBinContentsDragDataDeleteCB(
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
- *      All purpose initial operation confirmation procedure, prompts
- *      the user for response for confirmation of pending DND operation
- *      specified by the given inputs.
+ *	Confirmation nexus.
  *
- *      If the configuration will be checked first to se if confirmation
- *      is needed. If it is not needed then CDIALOG_RESPONSE_YES will
- *      be returned.
+ *	Queries the user for confirmation of the operation as needed.
  *
- *      Returns a CDIALOG_RESPONSE_* code.
+ *	The action specifies the GdkDragAction.
+ *
+ *	The info specifies the target type.
+ *
+ *	Returns one of CDIALOG_RESPONSE_*.
  */
 static gint EDVRecBinDNDConfirm(
 	edv_core_struct *core,
-	const gint gdk_action, const guint info,
+	const GdkDragAction action,
+	const guint info,
 	GtkWidget *toplevel,
 	GList *url_list
 )
@@ -133,13 +139,13 @@ static gint EDVRecBinDNDConfirm(
 		src_path = url->path;
 	}
 
-	/* Do confirmation, handle by dnd target type */
+	/* Confirm by the target type */
 	if((info == EDV_DND_INFO_TEXT_PLAIN) ||
 	   (info == EDV_DND_INFO_TEXT_URI_LIST) ||
 	   (info == EDV_DND_INFO_STRING)
 	)
 	{
-	    switch(gdk_action)
+	    switch((gint)action)
 	    {
 	      case GDK_ACTION_COPY:
 	      case GDK_ACTION_MOVE:
@@ -168,20 +174,19 @@ static gint EDVRecBinDNDConfirm(
 }
 
 /*
- *	Updates the Recycle Bin Status Bar to indicate the operation
+ *	Updates the Recycle Bin Status Bar to indicate the operation.
  */
 static void EDVRecBinDNDUpdateStatusBar(
 	edv_recbin_struct *recbin,
-	const gint gdk_action, const guint info,
-	const gint total_src_objects,
-	const gint total_objects_processed, const gint status
+	const GdkDragAction action,
+	const guint info,
+	const gint nsrc_objs,
+	const gint nobjs_processed,
+	const gint status
 )
 {
-	gchar *buf = NULL;
-	edv_status_bar_struct *sb = (recbin != NULL) ? 
-	    recbin->status_bar : NULL;
-	if(sb == NULL)
-	    return;
+	gchar *msg = NULL;
+	edv_status_bar_struct *sb = recbin->status_bar;
 
 	/* Begin formatting status message, handle by dnd target type */
 	if((info == EDV_DND_INFO_TEXT_PLAIN) ||
@@ -189,25 +194,25 @@ static void EDVRecBinDNDUpdateStatusBar(
 	   (info == EDV_DND_INFO_STRING)
 	)
 	{
-	    switch(gdk_action)
+	    switch((gint)action)
 	    {
 	      case GDK_ACTION_COPY:
 	      case GDK_ACTION_MOVE:
 	      case GDK_ACTION_LINK:
 		if(status == -4)
-		    buf = STRDUP(
+		    msg = STRDUP(
 			"Delete operation canceled"
 		    );
-		else if(total_objects_processed > 0)
-		    buf = g_strdup_printf(
+		else if(nobjs_processed > 0)
+		    msg = g_strdup_printf(
 			"Deleted %i %s",
-			total_objects_processed,
-			(total_objects_processed == 1) ? "object" : "objects"
+			nobjs_processed,
+			(nobjs_processed == 1) ? "object" : "objects"
 		    );
 		else
-		    buf = g_strdup_printf(
+		    msg = g_strdup_printf(
 			"Unable to delete %s",
-			(total_src_objects == 1) ? "object" : "objects"
+			(nsrc_objs == 1) ? "object" : "objects"
 		    );
 		break;
 	    }
@@ -228,14 +233,14 @@ static void EDVRecBinDNDUpdateStatusBar(
 	}
 
 	/* Set the status bar message */
-	EDVStatusBarMessage(sb, buf, FALSE);
+	EDVStatusBarMessage(sb, msg, FALSE);
 
-	g_free(buf);
+	g_free(msg);
 }
 
 
 /*
- *	Recycle Bin drag data received nexus.
+ *	Drag data received nexus.
  *
  *	The recbin specifies the Recycle Bin that the drag data is
  *	received relative to, it may be NULL if not applicable.
@@ -243,9 +248,10 @@ static void EDVRecBinDNDUpdateStatusBar(
  *	All inputs assumed valid.
  */
 static void EDVRecBinDragDataReceivedNexus(
-	edv_recbin_struct *recbin,		/* Can be NULL */
 	edv_core_struct *core,
-	GdkDragContext *dc, const guint info,
+	edv_recbin_struct *recbin,
+	GdkDragContext *dc,
+	const guint info,
 	GtkSelectionData *selection_data
 )
 {
@@ -428,21 +434,25 @@ static void EDVRecBinDragDataReceivedNexus(
 
 
 /*
- *	Sets the DND icon based on the Recycle Bin Contents List's
- *      selected cell specified by row and column
+ *	Sets the DND icon.
+ *
+ *	The row and column specifies the cell on the Contents List
+ *	from which to set the DND icon with.
  */
 void EDVRecBinContentsDNDSetIcon(
-	edv_recbin_struct *recbin, gint row, gint column
+	edv_recbin_struct *recbin,
+	const gint row, const gint column
 )
 {
+	GtkCList *clist;
 	edv_recycled_object_struct *obj;
-	GtkCList *clist = (GtkCList *)((recbin != NULL) ?
-	    recbin->contents_clist : NULL
-	);
-	if(clist == NULL)
+
+	if(recbin == NULL)
 	    return;
 
-	/* Get selected object */
+	clist = GTK_CLIST(recbin->contents_clist);
+
+	/* Get the selected object */
 	obj = EDV_RECYCLED_OBJECT(
 	    gtk_clist_get_row_data(clist, row)
 	);
@@ -454,8 +464,8 @@ void EDVRecBinContentsDNDSetIcon(
 	    GdkPixmap *pixmap = NULL;
 	    GdkBitmap *mask = NULL;
 
-	    /* Iterate through each cell of this row, looking for a
-	     * useable pixmap
+	    /* Look through each cell on this row for a useable
+	     * pixmap
 	     */
 	    for(i = 0; i < clist->columns; i++)
 	    {
@@ -483,7 +493,8 @@ void EDVRecBinContentsDNDSetIcon(
 	    }
 	    if(pixmap != NULL)
 	    {
-		gint width = 15, height = 15;
+		gint	width = 15,
+			height = 15;
 		gdk_window_get_size(pixmap, &width, &height);
 		GUIDNDSetDragIcon(
 		    pixmap, mask,
@@ -494,10 +505,10 @@ void EDVRecBinContentsDNDSetIcon(
 }
 
 /*
- *	Recycle Bin Contents List "drag_motion" signal callback.
+ *	DND "drag_motion" signal callback.
  *
- *	This is used to constrain all drags (regardless of its type
- *	or source data type) to be a drag action of move.
+ *	Used to constrain all drags (regardless of its action or
+ *	target type) to GDK_ACTION_MOVE.
  */
 gboolean EDVRecBinContentsDragMotionCB(
 	GtkWidget *widget, GdkDragContext *dc,
@@ -518,10 +529,10 @@ gboolean EDVRecBinContentsDragMotionCB(
 }
 
 /*
- *	Recycle Bin Desktop Icon "drag_motion" signal callback.
+ *	Desktop Icon DND "drag_motion" signal callback.
  *
- *      This is used to constrain all drags (regardless of its type
- *      or source data type) to be a drag action of move.
+ *	Used to constrain all drags (regardless of its action or
+ *	target type) to GDK_ACTION_MOVE.
  */
 gboolean EDVRecBinDeskIconDragMotionCB(
 	GtkWidget *widget, GdkDragContext *dc,
@@ -542,7 +553,7 @@ gboolean EDVRecBinDeskIconDragMotionCB(
 }
 
 /*
- *	Recycle Bin Contents List "drag_data_get" signal callback.
+ *	DND "drag_data_get" signal callback.
  */
 void EDVRecBinContentsDragDataGetCB(
 	GtkWidget *widget, GdkDragContext *dc,
@@ -563,11 +574,8 @@ void EDVRecBinContentsDragDataGetCB(
 	    return;
 
 	w = recbin->contents_clist;
-	core = recbin->core;
-	if((w == NULL) || (core == NULL))
-	    return;
-
 	clist = GTK_CLIST(w);
+	core = recbin->core;
 
 	EDVRecBinSyncData(recbin);
 
@@ -590,7 +598,7 @@ void EDVRecBinContentsDragDataGetCB(
 	     * recycled object's index value as a string
 	     */
 	    url->path = g_strdup_printf(
-		"%i", obj->index
+		"%u", obj->index
 	    );
 
 	    /* For recycled objects, the path argument must be set
@@ -601,7 +609,7 @@ void EDVRecBinContentsDragDataGetCB(
 	    url_list = g_list_append(url_list, url);
 	}
 
-	/* Encode DDE buffer from the URL list */
+	/* Encode the DND data from the URL list */
 	if(url_list != NULL) 
 	{
 	    gint buf_len;
@@ -619,11 +627,11 @@ void EDVRecBinContentsDragDataGetCB(
 		data_sent = TRUE;
 		g_free(buf);
 	    }
-	}
 
-	/* Delete the URL list */
-	g_list_foreach(url_list, (GFunc)URLDelete, NULL);
-	g_list_free(url_list);
+	    /* Delete the URL list */
+	    g_list_foreach(url_list, (GFunc)URLDelete, NULL);
+	    g_list_free(url_list);
+	}
 
 	/* If failed to send out data then respond with error */
 	if(!data_sent)
@@ -650,28 +658,30 @@ void EDVRecBinContentsDragDataReceivedCB(
 	gpointer data
 )
 {
+	GtkWidget *toplevel;
 	edv_core_struct *core;
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
 	if((dc == NULL) || (recbin == NULL))
 	    return;
 
+	toplevel = recbin->toplevel;
 	core = recbin->core;
-	if(core == NULL)
-	    return;
 
-	/* Check if received data is not empty */
+	/* No data? */
 	if((selection_data != NULL) ? (selection_data->length <= 0) : TRUE)
 	    return;
 
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core, TRUE, recbin->toplevel))
+	if(EDVCheckWriteProtect(core, TRUE, toplevel))
 	    return;
 
 	EDVRecBinSyncData(recbin);
 
 	/* Handle received drag data */
 	EDVRecBinDragDataReceivedNexus(
-	    recbin, core, dc, info, selection_data
+	    core, recbin,
+	    dc, info,
+	    selection_data
 	);
 }
 
@@ -704,13 +714,15 @@ void EDVRecBinDeskIconDragDataReceivedCB(
 
 	/* Handle received drag data */
 	EDVRecBinDragDataReceivedNexus(
-	    NULL, core, dc, info, selection_data
+	    core, NULL,
+	    dc, info,
+	    selection_data
 	);
 }
 
 
 /*
- *	Recycle Bin Contents List "drag_data_delete" signal callback.
+ *	DND "drag_data_delete" signal callback.
  */
 void EDVRecBinContentsDragDataDeleteCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
