@@ -14,7 +14,8 @@ extern void EDVRecBinDragDataDeleteCB(
 );
 
 extern void EDVRecBinContentsDNDSetIcon(
-	edv_recbin_struct *recbin, gint row, gint column
+	edv_recbin_struct *recbin,
+	const gint row, const gint column
 );
 extern gboolean EDVRecBinContentsDragMotionCB(
 	GtkWidget *widget, GdkDragContext *dc,
