@@ -53,6 +53,9 @@ void EDVRecBinOPLeaveCB(
 	toolbar_item_struct *item, gint id, gpointer data
 );
 
+void EDVRecBinOPClose(edv_recbin_struct *recbin);
+void EDVRecBinOPExit(edv_recbin_struct *recbin);
+
 void EDVRecBinOPSyncRecycleBin(edv_recbin_struct *recbin);
 
 void EDVRecBinOPSyncDisks(edv_recbin_struct *recbin);
@@ -60,12 +63,15 @@ void EDVRecBinOPWriteProtect(edv_recbin_struct *recbin);
 void EDVRecBinOPDeleteMethodRecycle(edv_recbin_struct *recbin);
 void EDVRecBinOPDeleteMethodPurge(edv_recbin_struct *recbin);
 
-void EDVRecBinOPClose(edv_recbin_struct *recbin);
-void EDVRecBinOPExit(edv_recbin_struct *recbin);
-
 void EDVRecBinOPRecover(edv_recbin_struct *recbin);
 void EDVRecBinOPPurge(edv_recbin_struct *recbin);
 void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin);
+void EDVRecBinOPRename(edv_recbin_struct *recbin);
+void EDVRecBinOPChMod(edv_recbin_struct *recbin);
+void EDVRecBinOPChOwn(edv_recbin_struct *recbin);
+void EDVRecBinOPChTime(edv_recbin_struct *recbin);
+void EDVRecBinOPProperties(edv_recbin_struct *recbin);
+
 void EDVRecBinOPSelectAll(edv_recbin_struct *recbin);
 void EDVRecBinOPUnselectAll(edv_recbin_struct *recbin);
 void EDVRecBinOPInvertSelection(edv_recbin_struct *recbin);
@@ -202,6 +208,7 @@ void EDVRecBinOPCB(
 )
 {
 	GtkWidget *toplevel;
+	cfg_item_struct *cfg_list;
 	edv_recbin_struct *recbin;
 	edv_core_struct *core;
 	edv_recbin_opid_struct *opid = EDV_RECBIN_OPID(data);
@@ -217,8 +224,7 @@ void EDVRecBinOPCB(
 
 	toplevel = recbin->toplevel;
 	core = recbin->core;
-	if(core == NULL)
-	    return;
+	cfg_list = core->cfg_list;
 
 	recbin->freeze_count++;
 
@@ -238,56 +244,12 @@ void EDVRecBinOPCB(
 	    break;
 
 
-	  case EDV_RECBIN_OP_RECOVER:
-	    EDVRecBinOPRecover(recbin);
-	    break;
-
-	  case EDV_RECBIN_OP_PURGE:
-	    EDVRecBinOPPurge(recbin);
-	    break;
-
-	  case EDV_RECBIN_OP_PURGE_ALL:
-	    EDVRecBinOPPurgeAll(recbin);
-	    break;
-
-	  case EDV_RECBIN_OP_SELECT_ALL:
-	    EDVRecBinOPSelectAll(recbin);
-	    break;
-
-	  case EDV_RECBIN_OP_UNSELECT_ALL:
-	    EDVRecBinOPUnselectAll(recbin);
-	    break;
-
-	  case EDV_RECBIN_OP_INVERT_SELECTION:
-	    EDVRecBinOPInvertSelection(recbin);
-	    break;
-
-	  case EDV_RECBIN_OP_FIND:
-	    EDVMapRecBinFindWin(core, recbin);
-	    break;
-
-	  case EDV_RECBIN_OP_HISTORY:
-	    EDVMapHistoryListWin(core, toplevel);
-	    break;
-
-	  case EDV_RECBIN_OP_SYNC_RECYCLE_BIN:
-	    EDVRecBinOPSyncRecycleBin(recbin);
-	    break;
-
 	  case EDV_RECBIN_OP_SYNC_DISKS:
 	    EDVRecBinOPSyncDisks(recbin);
 	    break;
 
-	  case EDV_RECBIN_OP_WRITE_PROTECT:
-	    EDVRecBinOPWriteProtect(recbin);
-	    break;
-
-	  case EDV_RECBIN_OP_DELETE_METHOD_RECYCLE:
-	    EDVRecBinOPDeleteMethodRecycle(recbin);
-	    break;
-
-	  case EDV_RECBIN_OP_DELETE_METHOD_PURGE:
-	    EDVRecBinOPDeleteMethodPurge(recbin);
+	  case EDV_RECBIN_OP_HISTORY:
+	    EDVMapHistoryListWin(core, toplevel);
 	    break;
 
 	  case EDV_RECBIN_OP_RUN:
@@ -303,6 +265,74 @@ void EDVRecBinOPCB(
 	    EDVRunTerminal(core, NULL, NULL, toplevel);
 	    break;
 
+	  case EDV_RECBIN_OP_WRITE_PROTECT:
+	    EDVRecBinOPWriteProtect(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_DELETE_METHOD_RECYCLE:
+	    EDVRecBinOPDeleteMethodRecycle(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_DELETE_METHOD_PURGE:
+	    EDVRecBinOPDeleteMethodPurge(recbin);
+	    break;
+
+
+	  case EDV_RECBIN_OP_SYNC_RECYCLE_BIN:
+	    EDVRecBinOPSyncRecycleBin(recbin);
+	    break;
+
+
+	  case EDV_RECBIN_OP_RECOVER:
+	    EDVRecBinOPRecover(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_PURGE:
+	    EDVRecBinOPPurge(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_PURGE_ALL:
+	    EDVRecBinOPPurgeAll(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_RENAME:
+	    EDVRecBinOPRename(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_CHMOD:
+	    EDVRecBinOPChMod(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_CHOWN:
+	    EDVRecBinOPChOwn(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_CHTIME:
+	    EDVRecBinOPChTime(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_PROPERTIES:
+	    EDVRecBinOPProperties(recbin);
+	    break;
+
+
+	  case EDV_RECBIN_OP_SELECT_ALL:
+	    EDVRecBinOPSelectAll(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_UNSELECT_ALL:
+	    EDVRecBinOPUnselectAll(recbin);
+	    break;
+
+	  case EDV_RECBIN_OP_INVERT_SELECTION:
+	    EDVRecBinOPInvertSelection(recbin);
+	    break;
+
+
+	  case EDV_RECBIN_OP_FIND:
+	    EDVMapRecBinFindWin(core, recbin);
+	    break;
+
 
 	  case EDV_RECBIN_OP_REFRESH:
 	    EDVRecBinOPRefresh(recbin);
@@ -315,12 +345,12 @@ void EDVRecBinOPCB(
 	  case EDV_RECBIN_OP_SHOW_TOOL_BAR:
 	    if(core != NULL)
 	    {
-		gboolean state = !CFGItemListGetValueI(
-		    core->cfg_list, EDV_CFG_PARM_RECBIN_SHOW_TOOL_BAR
+		const gboolean state = !EDV_GET_B(
+		    EDV_CFG_PARM_RECBIN_SHOW_TOOL_BAR
 		);
-		CFGItemListSetValueI(
-		    core->cfg_list, EDV_CFG_PARM_RECBIN_SHOW_TOOL_BAR,
-		    state, FALSE
+		EDV_SET_B(
+		    EDV_CFG_PARM_RECBIN_SHOW_TOOL_BAR,
+		    state
 		);
 		EDVReconfiguredEmit(core);
 	    }
@@ -329,12 +359,12 @@ void EDVRecBinOPCB(
 	  case EDV_RECBIN_OP_SHOW_FIND_BAR:
 	    if(core != NULL)
 	    {
-		gboolean state = !CFGItemListGetValueI(
-		    core->cfg_list, EDV_CFG_PARM_RECBIN_SHOW_FIND_BAR
+		const gboolean state = !EDV_GET_B(
+		    EDV_CFG_PARM_RECBIN_SHOW_FIND_BAR
 		);
-		CFGItemListSetValueI(
-		    core->cfg_list, EDV_CFG_PARM_RECBIN_SHOW_FIND_BAR,
-		    state, FALSE
+		EDV_SET_B(
+		    EDV_CFG_PARM_RECBIN_SHOW_FIND_BAR,
+		    state
 		);
 		EDVReconfiguredEmit(core);
 	    }
@@ -343,12 +373,12 @@ void EDVRecBinOPCB(
 	  case EDV_RECBIN_OP_SHOW_STATUS_BAR:
 	    if(core != NULL)
 	    {
-		gboolean state = !CFGItemListGetValueI(
-		    core->cfg_list, EDV_CFG_PARM_RECBIN_SHOW_STATUS_BAR
+		const gboolean state = !EDV_GET_B(
+		    EDV_CFG_PARM_RECBIN_SHOW_STATUS_BAR
 		);
-		CFGItemListSetValueI(
-		    core->cfg_list, EDV_CFG_PARM_RECBIN_SHOW_STATUS_BAR,
-		    state, FALSE
+		EDV_SET_B(
+		    EDV_CFG_PARM_RECBIN_SHOW_STATUS_BAR,
+		    state
 		);
 		EDVReconfiguredEmit(core);
 	    }
@@ -359,6 +389,20 @@ void EDVRecBinOPCB(
 	    EDVRecBinContentsFilter(recbin);
 	    break;
 
+	  case EDV_RECBIN_OP_CONTENTS_LIST_AUTO_RESIZE_COLUMNS:
+	    if(core != NULL)
+	    {
+		const gboolean state = !EDV_GET_B(
+		    EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS
+		);
+		EDV_SET_B(
+		    EDV_CFG_PARM_RECBIN_CONTENTS_LIST_AUTO_RESIZE_COLUMNS,
+		    state
+		);
+		EDVReconfiguredEmit(core);
+	    }
+	    break;
+
 
 	  case EDV_RECBIN_OP_MIME_TYPES:
 	    EDVRecBinMIMETypes(recbin);
@@ -387,9 +431,6 @@ void EDVRecBinOPCB(
 	    break;
 
 
-	  case EDV_RECBIN_OP_HELP_ABOUT:
-	    EDVAbout(core, toplevel);
-	    break;
 	  case EDV_RECBIN_OP_HELP_CONTENTS:
 	    EDVHelp(core, "Contents", toplevel);
 	    break;
@@ -411,6 +452,9 @@ void EDVRecBinOPCB(
 	  case EDV_RECBIN_OP_HELP_COMMON_OPERATIONS:
 	    EDVHelp(core, "Common Operations", toplevel);
 	    break;
+	  case EDV_RECBIN_OP_HELP_ABOUT:
+	    EDVAbout(core, toplevel);
+	    break;
 	}
 
 	recbin->freeze_count--;
@@ -453,63 +497,39 @@ void EDVRecBinOPLeaveCB(
 
 
 /*
- *	Sync Recycle Bin.
- *
- *	Compacts recycled objects and fix any errors.
+ *	Close.
  */
-void EDVRecBinOPSyncRecycleBin(edv_recbin_struct *recbin)
+void EDVRecBinOPClose(edv_recbin_struct *recbin)
+{
+	if(recbin == NULL)
+	    return;
+
+	EDVRecBinSyncConfiguration(recbin);
+	EDVRecBinUnmap(recbin);
+}
+
+/*
+ *	Close all windows.
+ */
+void EDVRecBinOPExit(edv_recbin_struct *recbin)
 {
-	gboolean yes_to_all = FALSE;
-	gint status;
-	GtkWidget *toplevel;
 	edv_core_struct *core;
 
 	if(recbin == NULL)
 	    return;
 
-	if(recbin->processing)
-	    return;
-
-	toplevel = recbin->toplevel;
 	core = recbin->core;
-	if(core == NULL)
-	    return;
 
-        /* Check and warn if write protect is enabled */
-        if(EDVCheckWriteProtect(core, TRUE, toplevel))
-            return;
+	/* Record the Recycle Bin's current configuration */
+	EDVRecBinSyncConfiguration(recbin);
 
-	EDVStatusBarMessage(
-	    recbin->status_bar,
-	    "Syncing recycle bin...",
-	    TRUE
-	);
+	/* Unmap the Recycle Bin */
+	EDVRecBinUnmap(recbin);
 
-	EDVRecBinSetBusy(recbin, TRUE);
-
-	/* Sync the recycle bin */
-	status = EDVRecBinSync(
-	    core,
-	    toplevel,
-	    TRUE,
-	    TRUE,
-	    &yes_to_all,
-	    EDVRecBinStatusMessageCB,
-	    EDVRecBinStatusProgressCB,
-	    recbin
-	);
-
-	/* Refresh listing of recycled objects */
-	EDVRecBinOPRefresh(recbin);
-
-	EDVRecBinSetBusy(recbin, FALSE);
-
-	EDVStatusBarMessage(
-	    recbin->status_bar,
-	    "Recycle bin sync done",
-	    FALSE
-	);
-	EDVStatusBarProgress(recbin->status_bar, 0.0f, FALSE);
+	/* Schedual a new pending operation on the core to close all
+	 * the windows
+	 */
+	core->pending_flags |= EDV_CORE_PENDING_CLOSE_ALL_WINDOWS;
 }
 
 
@@ -554,9 +574,6 @@ void EDVRecBinOPWriteProtect(edv_recbin_struct *recbin)
 	    return;
 
 	core = recbin->core;
-	if(core == NULL)
-	    return;
-
 	cfg_list = core->cfg_list;
 
 	/* Get current write protect state */
@@ -589,9 +606,6 @@ void EDVRecBinOPDeleteMethodRecycle(edv_recbin_struct *recbin)
 	    return;
 
 	core = recbin->core;
-	if(core == NULL)
-	    return;
-
 	cfg_list = core->cfg_list;
 
 	EDV_SET_I(
@@ -613,9 +627,6 @@ void EDVRecBinOPDeleteMethodPurge(edv_recbin_struct *recbin)
 	    return;
 
 	core = recbin->core;
-	if(core == NULL)
-	    return;
-
 	cfg_list = core->cfg_list;
 
 	EDV_SET_I(
@@ -627,44 +638,64 @@ void EDVRecBinOPDeleteMethodPurge(edv_recbin_struct *recbin)
 
 
 /*
- *	Close.
+ *	Sync Recycle Bin.
+ *
+ *	Compacts recycled objects and fix any errors.
  */
-void EDVRecBinOPClose(edv_recbin_struct *recbin)
-{
-	if(recbin == NULL)
-	    return;
-
-	EDVRecBinSyncConfiguration(recbin);
-	EDVRecBinUnmap(recbin);
-}
-
-/*
- *	Close all windows.
- */
-void EDVRecBinOPExit(edv_recbin_struct *recbin)
+void EDVRecBinOPSyncRecycleBin(edv_recbin_struct *recbin)
 {
+	gboolean yes_to_all = FALSE;
+	gint status;
+	GtkWidget *toplevel;
+	edv_status_bar_struct *sb;
 	edv_core_struct *core;
 
-
 	if(recbin == NULL)
 	    return;
 
-	core = recbin->core;
-	if(core == NULL)
+	if(recbin->processing)
 	    return;
 
-	/* Set current properties of the recycle bin to the configuration
-	 * list.
-	 */
-	EDVRecBinSyncConfiguration(recbin);
+	toplevel = recbin->toplevel;
+	core = recbin->core;
+	sb = recbin->status_bar;
 
-	/* Unmap this recycle bin */
-	EDVRecBinUnmap(recbin);
+	/* Check and warn if write protect is enabled */
+	if(EDVCheckWriteProtect(core, TRUE, toplevel))
+	    return;
 
-	/* Schedual a new pending operation on the core to close all
-	 * the windows
-	 */
-	core->pending_flags |= EDV_CORE_PENDING_CLOSE_ALL_WINDOWS;
+	EDVStatusBarMessage(
+	    sb,
+	    "Syncing recycle bin...",
+	    TRUE
+	);
+
+	EDVRecBinSetBusy(recbin, TRUE);
+
+	/* Sync the recycle bin */
+	status = EDVRecBinSync(
+	    core,
+	    toplevel,
+	    TRUE,
+	    TRUE,
+	    &yes_to_all,
+	    EDVRecBinStatusMessageCB,
+	    recbin,
+	    EDVRecBinStatusProgressCB,
+	    recbin
+	);
+
+	/* Refresh listing of recycled objects */
+	EDVRecBinOPRefresh(recbin);
+
+	EDVRecBinSetBusy(recbin, FALSE);
+
+	EDVStatusBarMessage(
+	    sb,
+	    "Recycle bin sync done",
+	    FALSE
+	);
+	EDVStatusBarProgress(sb, 0.0f, FALSE);
 }
 
 
@@ -709,8 +740,8 @@ void EDVRecBinOPRecover(edv_recbin_struct *recbin)
 
 	/* Get the list of selected recycled objects */
 	for(glist = clist->selection;
-            glist != NULL;
-            glist = g_list_next(glist)
+	    glist != NULL;
+	    glist = g_list_next(glist)
 	)
 	{
 	    row = (gint)glist->data;
@@ -758,8 +789,8 @@ void EDVRecBinOPRecover(edv_recbin_struct *recbin)
 	 */
 	status = 0;
 	for(glist = obj_list;
-            glist != NULL;
-            glist = g_list_next(glist)
+	    glist != NULL;
+	    glist = g_list_next(glist)
 	)
 	{
 	    obj = EDV_RECYCLED_OBJECT(glist->data);
@@ -1093,14 +1124,14 @@ void EDVRecBinOPPurge(edv_recbin_struct *recbin)
 }
 
 /*
- *	Purge all callback.
+ *	Purge all.
  */
 void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin)
 {
 	gboolean yes_to_all = FALSE;
 	gint status, nobjs, nobjs_purged = 0;
 	guint index;
-	const gchar *error_msg, *recycled_index_file;
+	const gchar *error_msg, *index_path;
 	GList *glist, *index_list = NULL;
 	GtkWidget *toplevel;
 	cfg_item_struct *cfg_list;
@@ -1118,11 +1149,9 @@ void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin)
 	if(EDVCheckWriteProtect(core, TRUE, toplevel))
 	    return;
 
-	/* Get the path to recycled objects index file */
-	recycled_index_file = EDV_GET_S(
-	    EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX
-	);
-	if(recycled_index_file == NULL)
+	/* Get the path to the recycled objects index file */
+	index_path = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX);
+	if(index_path == NULL)
 	    return;
 
 #define CLEANUP_RETURN	{	\
@@ -1131,8 +1160,8 @@ void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin)
  return;			\
 }
 
-	/* Get a list of all recycled object indices */
-	rbi_ptr = EDVRecBinIndexOpen(recycled_index_file);
+	/* Get the list of recycled objects */
+	rbi_ptr = EDVRecBinIndexOpen(index_path);
 	if(rbi_ptr != NULL)
 	{
 	    while(!EDVRecBinIndexNext(rbi_ptr))
@@ -1174,73 +1203,12 @@ void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin)
 	    break;
 	}
 
-#ifdef EDV_RECBIN_USE_PURGE_ALL
-/* Do not define this, this has issues about progress updating,
- * read subsequent comments in this block
- */
-	/* Purge all contents from the recycled objects directory
-	 * including the recycled objects index file
-	 */
-	status = EDVRecBinPurgeAll(
-	    core, toplevel,
-	    TRUE, TRUE, &yes_to_all
-	);
-
-	/* Check for errors */
-	error_msg = EDVRecBinPurgeGetError(core);
-	if(!STRISEMPTY(error_msg))
-	{
-	    /* Report the error */
-	    EDVPlaySoundError(core);
-	    EDVMessageError(
-		"Purge Recycled Object Error",
-		error_msg,
-		NULL,
-		toplevel
-	    );
-	}
-
-	/* All recycled objects purged successfully? */
-	if(status == 0)
-	{
-	    /* Send recycled object purged signal to all of Endeavour's
-	     * resources for each recycled object listed in our recorded
-	     * recycled objects index array
-	     */
-	    for(glist = index_list;
-		glist != NULL;
-		glist = g_list_next(glist)
-	    )
-	    {
-		index = (guint)glist->data;
-
-		/* Update the progress bar for notifying of resources
-		 * as well
-		 */
-/* This might appear a bit confusing since it is not very neat */
-		if(ProgressDialogIsQuery())
-		{
-		    ProgressDialogUpdate(
-			NULL, NULL, NULL, NULL,
-			(gfloat)nobjs_purged / (gfloat)nobjs,
-			EDV_DEF_PROGRESS_BAR_TICKS, TRUE
-		    );
-		    if(ProgressDialogStopCount() > 0)
-		    {
-			/* If user wants to stop, then end updating of
-			 * Endeavour's resources prematurly but do not
-			 * change the value of status.
-			 */
-			break;
-		    }
-		}
-		EDVRecycledObjectRemovedEmit(core, index);
-		nobjs_purged++;
-	    }
-	}
-#else
-	/* Iterate through list of recycled objects and purge each
-	 * one
+	/* Iterate through the list of recycled objects and purge
+	 * each one
+	 *
+	 * Note that EDVRecBinPurgeAll() is not used here because
+	 * it does not allow the reporting of each recycled object
+	 * purged during the purge
 	 */
 	status = 0;
 	for(glist = index_list;
@@ -1257,7 +1225,9 @@ void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin)
 		toplevel,
 		(nobjs > 0) ?
 		    ((gfloat)nobjs_purged / (gfloat)nobjs) : -1.0f,
-		TRUE, TRUE, &yes_to_all
+		TRUE,			/* Show progress */
+		TRUE,			/* Interactive */
+		&yes_to_all
 	    );
 
 	    /* Check for errors */
@@ -1277,8 +1247,9 @@ void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin)
 	    /* Was the recycled object purged successfully? */
 	    if(status == 0)
 	    {
-		nobjs_purged++;
+		/* Notify about this recycled object being purged */
 		EDVRecycledObjectRemovedEmit(core, index);
+		nobjs_purged++;
 	    }
 
 	    /* User aborted? */
@@ -1286,17 +1257,37 @@ void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin)
 		break;
 	}
 
-	/* If no errors or aborting occured then do one more through
-	 * purge all but do not show progress for it. This will also
-	 * remove any stray recycled object files and the recycled objects
-	 * index file
+	/* If no errors occured or no used abort then call
+	 * EDVRecBinPurgeAll() to remove any stray recycled object
+	 * files and the recycled objects index file
 	 */
 	if(status == 0)
-	    EDVRecBinPurgeAll(
-		core, toplevel,
-		FALSE, TRUE, &yes_to_all
+	{
+	    /* Remove any stray recycled object files and the recycled
+	     * objects index file
+	     */
+	    status = EDVRecBinPurgeAll(
+		core,
+		toplevel,
+		FALSE,			/* Do not show progress */
+		TRUE,			/* Interactive */
+		&yes_to_all
 	    );
-#endif
+
+	    /* Check for errors */
+	    error_msg = EDVRecBinPurgeGetError(core);
+	    if(!STRISEMPTY(error_msg))
+	    {
+		/* Report the error */
+		EDVPlaySoundError(core);
+		EDVMessageError(
+		    "Purge Recycled Object Error",
+		    error_msg,
+		    NULL,
+		    toplevel
+		);
+	    }
+	}
 
 	/* Unmap the progress dialog */
 	ProgressDialogBreakQuery(TRUE);
@@ -1335,6 +1326,269 @@ void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin)
 #undef CLEANUP_RETURN
 }
 
+/*
+ *	Rename.
+ */
+void EDVRecBinOPRename(edv_recbin_struct *recbin)
+{
+	gint row;
+	GtkWidget *toplevel;
+	GtkCList *clist;
+	edv_core_struct *core;
+
+	if(recbin == NULL)
+	    return;
+
+	toplevel = recbin->toplevel;
+	clist = GTK_CLIST(recbin->contents_clist);
+	core = recbin->core;
+
+	/* Check and warn if write protect is enabled */
+	if(EDVCheckWriteProtect(core, TRUE, recbin->toplevel))
+	    return;
+
+	/* Get the last selected row */
+	row = EDVCListGetSelectedLast(clist, NULL);
+	if(row > -1)
+	{
+	    /* Map the rename prompt */
+	    EDVRecBinContentsPromptRename(
+		recbin,
+		row, -1
+	    );
+	}
+}
+
+/*
+ *	Change Permissions.
+ */
+void EDVRecBinOPChMod(edv_recbin_struct *recbin)
+{
+	GList *sel_objs_list;
+	GtkWidget *toplevel;
+	edv_obj_op_dlg_struct *d;
+	edv_core_struct *core;
+
+	if(recbin == NULL)
+	    return;
+
+	EDVRecBinSetBusy(recbin, TRUE);
+
+	toplevel = recbin->toplevel;
+	core = recbin->core;
+
+	/* Check and warn if write protect is enabled */
+	if(EDVCheckWriteProtect(core, TRUE, toplevel))
+	{
+	    EDVRecBinSetBusy(recbin, FALSE);
+	    return;
+	}
+
+	/* Get the object operations dialog and create it as needed */
+	d = EDVGetObjOpDlg(core);
+	if(d == NULL)
+	{
+	    EDVRecBinSetBusy(recbin, FALSE);
+	    return;
+	}
+
+	/* Sync data to ensure that current values to operate on */
+	EDVRecBinSyncData(recbin);
+
+	/* Get the selected objects list */
+	sel_objs_list = EDVRecBinGetSelectedObjectsList(recbin, FALSE);
+	if(sel_objs_list == NULL)
+	{
+	    EDVRecBinSetBusy(recbin, FALSE);
+	    return;
+	}
+
+	/* Map the object operations dialog to change permissions */
+	EDVObjOpDlgMapValues(
+	    d,
+	    EDV_OBJ_OP_DLG_OP_CHMOD,
+	    EDV_LOCATION_TYPE_RECBIN,
+	    sel_objs_list,
+	    NULL,				/* No srouce directory */
+	    toplevel
+	);
+
+	/* Delete the selected objects list */
+	g_list_free(sel_objs_list);
+
+	EDVRecBinSetBusy(recbin, FALSE);
+}
+
+/*
+ *	Change Ownership.
+ */
+void EDVRecBinOPChOwn(edv_recbin_struct *recbin)
+{
+	GList *sel_objs_list;
+	GtkWidget *toplevel;
+	edv_obj_op_dlg_struct *d;
+	edv_core_struct *core;
+
+	if(recbin == NULL)
+	    return;
+
+	EDVRecBinSetBusy(recbin, TRUE);
+
+	toplevel = recbin->toplevel;
+	core = recbin->core;
+
+	/* Check and warn if write protect is enabled */
+	if(EDVCheckWriteProtect(core, TRUE, toplevel))
+	{
+	    EDVRecBinSetBusy(recbin, FALSE);
+	    return;
+	}
+
+	/* Get the object operations dialog and create it as needed */
+	d = EDVGetObjOpDlg(core);
+	if(d == NULL)
+	{
+	    EDVRecBinSetBusy(recbin, FALSE);
+	    return;
+	}
+
+	/* Sync data to ensure that current values to operate on */
+	EDVRecBinSyncData(recbin);
+
+	/* Get the selected objects list */
+	sel_objs_list = EDVRecBinGetSelectedObjectsList(recbin, FALSE);
+	if(sel_objs_list == NULL)
+	{
+	    EDVRecBinSetBusy(recbin, FALSE);
+	    return;
+	}
+
+	/* Map the object operations dialog to change ownership */
+	EDVObjOpDlgMapValues(
+	    d,
+	    EDV_OBJ_OP_DLG_OP_CHOWN,
+	    EDV_LOCATION_TYPE_RECBIN,
+	    sel_objs_list,
+	    NULL,				/* No srouce directory */
+	    toplevel
+	);
+
+	/* Delete the selected objects list */
+	g_list_free(sel_objs_list);
+
+	EDVRecBinSetBusy(recbin, FALSE);
+}
+
+/*
+ *	Change Time Stamps.
+ */
+void EDVRecBinOPChTime(edv_recbin_struct *recbin)
+{
+	GList *sel_objs_list;
+	GtkWidget *toplevel;
+	edv_obj_op_dlg_struct *d;
+	edv_core_struct *core;
+
+	if(recbin == NULL)
+	    return;
+
+	EDVRecBinSetBusy(recbin, TRUE);
+
+	toplevel = recbin->toplevel;
+	core = recbin->core;
+
+	/* Check and warn if write protect is enabled */
+	if(EDVCheckWriteProtect(core, TRUE, toplevel))
+	{
+	    EDVRecBinSetBusy(recbin, FALSE);
+	    return;
+	}
+
+	/* Get the object operations dialog and create it as needed */
+	d = EDVGetObjOpDlg(core);
+	if(d == NULL)
+	{
+	    EDVRecBinSetBusy(recbin, FALSE);
+	    return;
+	}
+
+	/* Sync data to ensure that current values to operate on */
+	EDVRecBinSyncData(recbin);
+
+	/* Get the selected objects list */
+	sel_objs_list = EDVRecBinGetSelectedObjectsList(recbin, FALSE);
+	if(sel_objs_list == NULL)
+	{
+	    EDVRecBinSetBusy(recbin, FALSE);
+	    return;
+	}
+
+	/* Map the object operations dialog to change time stamps */
+	EDVObjOpDlgMapValues(
+	    d,
+	    EDV_OBJ_OP_DLG_OP_CHTIME,
+	    EDV_LOCATION_TYPE_RECBIN,
+	    sel_objs_list,
+	    NULL,				/* No srouce directory */
+	    toplevel
+	);
+
+	/* Delete the selected objects list */
+	g_list_free(sel_objs_list);
+
+	EDVRecBinSetBusy(recbin, FALSE);
+}
+
+/*
+ *	Properties.
+ */
+void EDVRecBinOPProperties(edv_recbin_struct *recbin)
+{
+	GtkWidget *toplevel;
+	edv_recycled_object_struct *obj = NULL;
+	edv_core_struct *core;
+
+	if(recbin == NULL)
+	    return;
+
+	EDVRecBinSetBusy(recbin, TRUE);
+
+	toplevel = recbin->toplevel;
+	core = recbin->core;
+
+	EDVRecBinSyncData(recbin);
+
+	/* Get the selected object */
+	if(recbin->contents_clist_selected_row > -1)
+	{
+	    GtkCList *clist = GTK_CLIST(recbin->contents_clist);
+	    GList *glist = clist->selection_end;
+	    if(glist != NULL)
+		obj = EDV_RECYCLED_OBJECT(gtk_clist_get_row_data(
+		    clist,
+		    (gint)glist->data
+		));
+	}
+
+	/* No selected object? */
+	if(obj == NULL)
+	{
+	    EDVRecBinSetBusy(recbin, FALSE);
+	    return;
+	}
+
+	/* Create a new properties dialog displaying the object */
+	EDVNewPropertiesDialogRecycledPage(
+	    core,
+	    obj,
+	    NULL,				/* Default page */
+	    toplevel
+	);
+
+	EDVRecBinSetBusy(recbin, FALSE);
+}
+
+
 /*
  *	Select all.
  */
@@ -1450,6 +1704,7 @@ void EDVRecBinOPInvertSelection(edv_recbin_struct *recbin)
 	EDVRecBinSetBusy(recbin, FALSE);
 }
 
+
 /*
  *	Refresh.
  */
@@ -1506,7 +1761,7 @@ void EDVRecBinOPRefresh(edv_recbin_struct *recbin)
  */
 void EDVRecBinOPRefreshAll(edv_recbin_struct *recbin)
 {
-	const gchar *recycled_index_file;
+	const gchar *index_path;
 	const cfg_item_struct *cfg_list;
 	edv_core_struct *core;
 
@@ -1517,13 +1772,13 @@ void EDVRecBinOPRefreshAll(edv_recbin_struct *recbin)
 	cfg_list = core->cfg_list;
 
 	/* Get the path to the recycled objects index file */
-	recycled_index_file = CFGItemListGetValueS(
+	index_path = CFGItemListGetValueS(
 	    cfg_list, EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX
 	);
 
 	/* Update the number of recycled objects on the core */
 	core->last_recbin_items = EDVRecBinIndexGetTotal(
-	    recycled_index_file
+	    index_path
 	);
 
 	/* Refresh the Recycle Bin Desktop Icon */
