@@ -21,22 +21,36 @@ extern void EDVRecBinOPLeaveCB(
 	toolbar_item_struct *item, gint id, gpointer data
 );
 
+extern void EDVRecBinOPClose(edv_recbin_struct *recbin);
+extern void EDVRecBinOPExit(edv_recbin_struct *recbin);
+
+extern void EDVRecBinOPSyncRecycleBin(edv_recbin_struct *recbin);
+
 extern void EDVRecBinOPSyncDisks(edv_recbin_struct *recbin);
 extern void EDVRecBinOPWriteProtect(edv_recbin_struct *recbin);
 extern void EDVRecBinOPDeleteMethodRecycle(edv_recbin_struct *recbin);
 extern void EDVRecBinOPDeleteMethodPurge(edv_recbin_struct *recbin);
 
-extern void EDVRecBinOPClose(edv_recbin_struct *recbin);
-extern void EDVRecBinOPExit(edv_recbin_struct *recbin);
-
 extern void EDVRecBinOPRecover(edv_recbin_struct *recbin);
 extern void EDVRecBinOPPurge(edv_recbin_struct *recbin);
 extern void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin);
+extern void EDVRecBinOPRename(edv_recbin_struct *recbin);
+extern void EDVRecBinOPChMod(edv_recbin_struct *recbin);
+extern void EDVRecBinOPChOwn(edv_recbin_struct *recbin);
+extern void EDVRecBinOPChTime(edv_recbin_struct *recbin);
+
+extern void EDVRecBinOPProperties(edv_recbin_struct *recbin);
+
 extern void EDVRecBinOPSelectAll(edv_recbin_struct *recbin);
 extern void EDVRecBinOPUnselectAll(edv_recbin_struct *recbin);
+extern void EDVRecBinOPInvertSelection(edv_recbin_struct *recbin);
 
 extern void EDVRecBinOPRefresh(edv_recbin_struct *recbin);
 extern void EDVRecBinOPRefreshAll(edv_recbin_struct *recbin);
 
+extern void EDVRecBinContentsFilter(edv_recbin_struct *recbin);
+
+extern void EDVRecBinMIMETypes(edv_recbin_struct *recbin);
+
 
 #endif	/* RECBIN_OP_CB_H */
