@@ -49,10 +49,12 @@ static void EDVRunDlgCompleteCommand(edv_run_dlg_struct *d);
 
 /* Set & Get Values */
 void EDVRunDlgSetCommand(
-	edv_run_dlg_struct *d, const char *command
+	edv_run_dlg_struct *d,
+	const char *command
 );
 void EDVRunDlgSetWorkingDir(
-	edv_run_dlg_struct *d, const char *working_dir
+	edv_run_dlg_struct *d,
+	const char *working_dir
 );
 void EDVRunDlgFetchValues(edv_run_dlg_struct *d);
 
@@ -61,10 +63,14 @@ void EDVRunDlgRun(
 	edv_run_dlg_struct *d,
 	const gboolean record_cmd
 );
+void EDVRunDlgClose(
+	edv_run_dlg_struct *d,
+	const gboolean save_config
+);
 
 /* Run Dialog */
 edv_run_dlg_struct *EDVRunDlgNew(edv_core_struct *core);
-void EDVRunDlgSetBusy(edv_run_dlg_struct *d, gboolean is_busy);
+void EDVRunDlgSetBusy(edv_run_dlg_struct *d, const gboolean busy);
 gboolean EDVRunDlgIsMapped(edv_run_dlg_struct *d);
 void EDVRunDlgMap(edv_run_dlg_struct *d);
 void EDVRunDlgUnmap(edv_run_dlg_struct *d);
@@ -114,9 +120,12 @@ static gint EDVRunDlgDeleteEventCB(
 {
 	edv_run_dlg_struct *d = EDV_RUN_DLG(data);
 	if(d == NULL)
-	    return(TRUE);
+	    return(FALSE);
 
-	EDVRunDlgCloseCB(NULL, d);
+	if(d->freeze_count > 0)
+	    return(FALSE);
+
+	EDVRunDlgClose(d, TRUE);
 
 	return(TRUE);
 }
@@ -459,13 +468,8 @@ static void EDVRunDlgOptionsCB(GtkWidget *widget, gpointer data)
 /*
  *	Run dialog close button callback.
  */
-static void EDVRunDlgCloseCB(
-	GtkWidget *widget, gpointer data
-)
+static void EDVRunDlgCloseCB(GtkWidget *widget, gpointer data)
 {
-	GtkWidget *w;
-	edv_core_struct *core;
-	cfg_item_struct *cfg_list;
 	edv_run_dlg_struct *d = EDV_RUN_DLG(data);
 	if(d == NULL)
 	    return;
@@ -473,67 +477,7 @@ static void EDVRunDlgCloseCB(
 	if(d->freeze_count > 0)
 	    return;
 
-	core = d->core;
-	cfg_list = core->cfg_list;
-
-	/* Begin recording current widget values to global
-	 * configuration
-	 */
-
-	/* Run history */
-	w = d->run_combo;
-	if(w != NULL)
-	    EDVSaveFileGList(
-		EDV_GET_S(EDV_CFG_PARM_FILE_RUNDLG_HISTORY),
-		GUIComboGetList(w)
-	    );
-
-	/* Toplevel geometry */
-	w = d->toplevel;
-	if(w != NULL)
-	{
-	    gint x = 0, y = 0;
-	    GdkWindow *window = w->window;
-	    if(window != NULL)
-		gdk_window_get_root_origin(window, &x, &y);
-
-	    CFGItemListSetValueI(
-		cfg_list, EDV_CFG_PARM_RUNDLG_X,
-		x, FALSE
-	    );
-	    CFGItemListSetValueI(
-		cfg_list, EDV_CFG_PARM_RUNDLG_Y,
-		y, FALSE
-	    );
-	}
-
-	/* Last working directory */
-	w = d->working_dir_entry;
-	if(w != NULL)
-	    CFGItemListSetValueS(
-		cfg_list, EDV_CFG_PARM_RUNDLG_LAST_WORKING_DIR,
-		gtk_entry_get_text(GTK_ENTRY(w)), FALSE
-	    );
-
-	/* Run in terminal */
-	w = d->run_in_terminal_check;
-	if(w != NULL)
-	    CFGItemListSetValueI(
-		cfg_list, EDV_CFG_PARM_RUNDLG_RUN_IN_TERMINAL,
-		GTK_TOGGLE_BUTTON(w)->active, FALSE
-	    );
-
-	/* Keep dialog */
-	w = d->keep_dialog_check;
-	if(w != NULL)
-	    CFGItemListSetValueI(
-		cfg_list, EDV_CFG_PARM_RUNDLG_KEEP_DIALOG,
-		GTK_TOGGLE_BUTTON(w)->active, FALSE
-	    );
-
-
-	/* Close the dialog */
-	EDVRunDlgUnmap(d);
+	EDVRunDlgClose(d, TRUE);
 }
 
 
@@ -628,7 +572,8 @@ static void EDVRunDlgCompleteCommand(edv_run_dlg_struct *d)
  *	Sets the command value.
  */
 void EDVRunDlgSetCommand(
-	edv_run_dlg_struct *d, const char *command
+	edv_run_dlg_struct *d,
+	const char *command
 )
 {
 	GtkEntry *entry;
@@ -647,7 +592,8 @@ void EDVRunDlgSetCommand(
  *	Sets the working directory value.
  */
 void EDVRunDlgSetWorkingDir(
-	edv_run_dlg_struct *d, const char *working_dir
+	edv_run_dlg_struct *d,
+	const char *working_dir
 )
 {
 	GtkEntry *entry;
@@ -1029,7 +975,7 @@ is correct and that the program is set executable.",
 
 	/* Do not keep dialog after running? */
 	if(!GTK_TOGGLE_BUTTON_GET_ACTIVE(d->keep_dialog_check))
-	    EDVRunDlgCloseCB(d->close_btn, d);
+	    EDVRunDlgClose(d, TRUE);
 
 	g_free(wd);
 	g_free(cmd_src);
@@ -1037,6 +983,71 @@ is correct and that the program is set executable.",
 	EDVRunDlgSetBusy(d, FALSE);
 }
 
+/*
+ *	Closes the Run Dialog.
+ *
+ *	If save_config is TRUE then the Run Dialog's values will
+ *	be saved to the configuration.
+ */
+void EDVRunDlgClose(
+	edv_run_dlg_struct *d,
+	const gboolean save_config
+)
+{
+	GtkWidget *w;
+	edv_core_struct *core;
+	cfg_item_struct *cfg_list;
+
+	if(d == NULL)
+	    return;
+
+	core = d->core;
+	cfg_list = core->cfg_list;
+
+	if(save_config)
+	{
+	    /* Run history */
+	    EDVSaveFileGList(
+		EDV_GET_S(EDV_CFG_PARM_FILE_RUNDLG_HISTORY),
+		GUIComboGetList(d->run_combo)
+	    );
+
+	    /* Toplevel geometry */
+	    w = d->toplevel;
+	    if(w != NULL)
+	    {
+		gint x = 0, y = 0;
+		GdkWindow *window = w->window;
+		if(window != NULL)
+		    gdk_window_get_root_origin(window, &x, &y);
+
+		EDV_SET_I(EDV_CFG_PARM_RUNDLG_X, x);
+		EDV_SET_I(EDV_CFG_PARM_RUNDLG_Y, y);
+	    }
+
+	    /* Last working directory */
+	    EDV_SET_S(
+		EDV_CFG_PARM_RUNDLG_LAST_WORKING_DIR,
+		gtk_entry_get_text(GTK_ENTRY(d->working_dir_entry))
+	    );
+
+	    /* Run in terminal */
+	    EDV_SET_B(
+		EDV_CFG_PARM_RUNDLG_RUN_IN_TERMINAL,
+		GTK_TOGGLE_BUTTON_GET_ACTIVE(d->run_in_terminal_check)
+	    );
+
+	    /* Keep dialog */
+	    EDV_SET_B(
+		EDV_CFG_PARM_RUNDLG_KEEP_DIALOG,
+		GTK_TOGGLE_BUTTON_GET_ACTIVE(d->keep_dialog_check)
+	    );
+	}
+
+	/* Close the dialog */
+	EDVRunDlgUnmap(d);
+}
+
 
 /*
  *	Creates a new Run Dialog.
@@ -1055,19 +1066,19 @@ edv_run_dlg_struct *EDVRunDlgNew(edv_core_struct *core)
 			*toplevel;
 	GtkCombo *combo;
 	const cfg_item_struct *cfg_list;
-	edv_run_dlg_struct *d = EDV_RUN_DLG(
-	    g_malloc0(sizeof(edv_run_dlg_struct))
-	);
-	if((d == NULL) || (core == NULL))
-	{
-	    g_free(d);
+	edv_run_dlg_struct *d;
+
+	if(core == NULL)
 	    return(NULL);
-	}
 
 	cfg_list = core->cfg_list;
 	x = EDV_GET_I(EDV_CFG_PARM_RUNDLG_X);
 	y = EDV_GET_I(EDV_CFG_PARM_RUNDLG_Y);
 
+	d = EDV_RUN_DLG(g_malloc0(sizeof(edv_run_dlg_struct)));
+	if(d == NULL)
+	    return(NULL);
+
 	d->toplevel = toplevel = gtk_window_new(GTK_WINDOW_DIALOG);
 	d->accelgrp = accelgrp = gtk_accel_group_new();
 	d->processing = FALSE;
@@ -1100,6 +1111,11 @@ edv_run_dlg_struct *EDVRunDlgNew(edv_core_struct *core)
 	    );
 	    GUISetWMIcon(window, (guint8 **)icon_executable_48x48_xpm);
 	}
+	gtk_widget_add_events(
+	    w, 
+	    GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK |
+	    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
+	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "delete_event",
 	    GTK_SIGNAL_FUNC(EDVRunDlgDeleteEventCB), d
@@ -1117,7 +1133,7 @@ edv_run_dlg_struct *EDVRunDlgNew(edv_core_struct *core)
 	parent = w;
 
 
-	/* Hbox for run combo, browse button, and clear button */
+	/* GtkHBox for the run combo, browse button, and clear button */
 	w = gtk_hbox_new(FALSE, border_minor);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
@@ -1154,20 +1170,19 @@ edv_run_dlg_struct *EDVRunDlgNew(edv_core_struct *core)
 	gtk_box_pack_start(GTK_BOX(parent2), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
 
-	if(combo != NULL)
-	{
-	    w = combo->entry;
-	    gtk_signal_connect(
-		GTK_OBJECT(w), "focus_in_event",
-	        GTK_SIGNAL_FUNC(EDVRunDlgCommandFocusEventCB), d
-	    );
-	    gtk_signal_connect(
-		GTK_OBJECT(w), "focus_out_event",
-		GTK_SIGNAL_FUNC(EDVRunDlgCommandFocusEventCB), d
-	    );
-	    EDVEntrySetDND(core, w);
-	    EDVEntrySetCompletePath(core, w);
-	    GUISetWidgetTip(w,
+	w = combo->entry;
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "focus_in_event",
+	    GTK_SIGNAL_FUNC(EDVRunDlgCommandFocusEventCB), d
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "focus_out_event",
+	    GTK_SIGNAL_FUNC(EDVRunDlgCommandFocusEventCB), d
+	);
+	EDVEntrySetDND(core, w);
+	EDVEntrySetCompletePath(core, w);
+	GUISetWidgetTip(
+	    w,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Entre el nombre del programa ms cualquier argumento"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1185,20 +1200,19 @@ edv_run_dlg_struct *EDVRunDlgNew(edv_core_struct *core)
 #else
 "Enter the name of the program plus any arguments"
 #endif
-	    );
-	}
+	);
 
 	/* Browse button */
 	d->browse_btn = w = GUIButtonPixmap(
 	    (guint8 **)icon_browse_20x20_xpm
 	);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
-	combo = (GtkCombo *)d->run_combo;
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "clicked",
 	    GTK_SIGNAL_FUNC(EDVRunDlgBrowseCommandCB), d
 	);
-	GUISetWidgetTip(w,
+	GUISetWidgetTip(
+	    w,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Hojee"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1228,7 +1242,8 @@ edv_run_dlg_struct *EDVRunDlgNew(edv_core_struct *core)
 	    GTK_OBJECT(w), "clicked",
 	    GTK_SIGNAL_FUNC(EDVRunDlgClearCB), combo->entry
 	);
-	GUISetWidgetTip(w,
+	GUISetWidgetTip(
+	    w,
 #if defined(PROG_LANGUAGE_SPANISH)
 "Claro"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1667,7 +1682,7 @@ edv_run_dlg_struct *EDVRunDlgNew(edv_core_struct *core)
 /*
  *	Marks the Run Dialog as busy or ready.
  */
-void EDVRunDlgSetBusy(edv_run_dlg_struct *d, gboolean is_busy)
+void EDVRunDlgSetBusy(edv_run_dlg_struct *d, const gboolean busy)
 {
 	GdkCursor *cursor;
 	GtkWidget *w;
@@ -1676,12 +1691,12 @@ void EDVRunDlgSetBusy(edv_run_dlg_struct *d, gboolean is_busy)
 	if(d == NULL)
 	    return;
 
+	w = d->toplevel;
 	core = d->core;
 
-	w = d->toplevel;
 	if(w != NULL)
 	{
-	    if(is_busy)
+	    if(busy)
 	    {
 		/* Increase busy count */
 		d->busy_count++;
