@@ -48,7 +48,7 @@ extern void EDVRunDlgSetWorkingDir(
 extern void EDVRunDlgFetchValues(edv_run_dlg_struct *d);
 
 extern edv_run_dlg_struct *EDVRunDlgNew(edv_core_struct *core);
-extern void EDVRunDlgSetBusy(edv_run_dlg_struct *d, gboolean is_busy);
+extern void EDVRunDlgSetBusy(edv_run_dlg_struct *d, const gboolean busy);
 extern gboolean EDVRunDlgIsMapped(edv_run_dlg_struct *d);
 extern void EDVRunDlgMap(edv_run_dlg_struct *d);
 extern void EDVRunDlgUnmap(edv_run_dlg_struct *d);
