@@ -1,5 +1,5 @@
 /*
-                              Stack List
+			      Stack List
 
 	Pair of lists with reorderable items
  */
@@ -13,11 +13,20 @@
 typedef struct _stack_list_item_struct	stack_list_item_struct;
 #define STACK_LIST_ITEM(p)		((stack_list_item_struct *)(p))
 typedef struct _stack_list_struct	stack_list_struct;
-#define STACK_LIST(p)	((stack_list_struct *)(p))
+#define STACK_LIST(p)			((stack_list_struct *)(p))
 
 
 /*
- *	Stack List Flags:
+ *	Selection IDs:
+ */
+#define STACK_LIST_ITEM_SRC_TARGET_NAME	"StackList/Item/Source"
+#define STACK_LIST_ITEM_SRC_INFO	0
+#define STACK_LIST_ITEM_TAR_TARGET_NAME	"StackList/Item/Target"
+#define STACK_LIST_ITEM_TAR_INFO	1
+
+
+/*
+ *	Flags:
  */
 typedef enum {
 
@@ -29,7 +38,7 @@ typedef enum {
 
 
 /*
- *	Stack List Item:
+ *	Item:
  */
 struct _stack_list_item_struct {
 
@@ -38,7 +47,7 @@ struct _stack_list_item_struct {
 	GdkPixmap	*icon_pixmap;
 	GdkBitmap	*icon_mask;
 
-	gpointer	client_data;
+	gpointer	data;
 
 	gint		id;		/* Arbitary number used to
 					 * identify this item */ 
@@ -90,9 +99,14 @@ struct _stack_list_struct {
 			*tar_up_mi,
 			*tar_down_mi;
 
-	/* Cache of Stack List Items */
-	stack_list_item_struct	**item;
-	gint			total_items;
+	/* Complete list of Stack List Items, each data is a
+	 * stack_list_item_struct *
+	 *
+	 * This items list is used to maintain the order of items
+	 * on the src_list and to know exactly all the available
+	 * items
+	 */
+	GList		*items_list;
 
 	/* Last Stack List Item that was used for the description */
 	stack_list_item_struct	*last_description_item;
@@ -109,46 +123,53 @@ struct _stack_list_struct {
 	);
 	gpointer	changed_data;
 
-        /* Added & Removed Callbacks */
-        void	(*added_cb)(
+	/* Added & Removed Callbacks */
+	void	(*added_cb)(
 		stack_list_struct *,		/* Stack List */
 		stack_list_item_struct *,	/* Stack List Item */
-                gpointer			/* Data */
-        );
-        gpointer	added_data;
-        void	(*removed_cb)(
-                stack_list_struct *,		/* Stack List */
-                stack_list_item_struct *,	/* Stack List Item */
-                gpointer			/* Data */
-        );
-        gpointer	removed_data;
+		gpointer			/* Data */
+	);
+	gpointer	added_data;
+	void	(*removed_cb)(
+		stack_list_struct *,		/* Stack List */
+		stack_list_item_struct *,	/* Stack List Item */
+		gpointer			/* Data */
+	);
+	gpointer	removed_data;
 
 };
 
 
+/* Operations */
+extern void StackListAdd(stack_list_struct *slist);
+extern void StackListRemove(stack_list_struct *slist);
+extern void StackListShiftUp(stack_list_struct *slist);
+extern void StackListShiftDown(stack_list_struct *slist);
+
 /* Stack List Item */
-extern void StackListAppend(
+extern gint StackListAppend(
 	stack_list_struct *slist,
 	const gchar *name,
 	const gchar *description,
 	guint8 **icon_data,
-	gpointer client_data,
-	gint id,
-	gboolean allow_multiple, gboolean stay_on_target
+	gpointer data,
+	const gint id,
+	const gboolean allow_multiple,
+	const gboolean stay_on_target
 );
 extern void StackListClear(stack_list_struct *slist);
 
-extern void StackListItemAppendSrc(stack_list_struct *slist, gint id);
-extern void StackListItemAppendTar(stack_list_struct *slist, gint id);
+extern gint StackListItemAppendSrc(stack_list_struct *slist, const gint id);
+extern gint StackListItemAppendTar(stack_list_struct *slist, const gint id);
 extern void StackListItemSetAllFromCacheSrc(stack_list_struct *slist);
 
 extern void StackListItemRemoveByIDSrc(
-	stack_list_struct *slist, gint id,
-	gboolean exclude_allowed_multiples
+	stack_list_struct *slist, const gint id,
+	const gboolean exclude_allowed_multiples
 );
 extern void StackListItemRemoveByIDTar(
-	stack_list_struct *slist, gint id,
-	gboolean exclude_allowed_multiples
+	stack_list_struct *slist, const gint id,
+	const gboolean exclude_allowed_multiples
 );
 
 extern void StackListItemClearSrc(stack_list_struct *slist);
@@ -164,38 +185,38 @@ extern stack_list_struct *StackListNew(
 	const gchar *src_title, const gchar *tar_title
 );
 extern void StackListShowDescription(
-        stack_list_struct *slist, 
-        gboolean show_src_desc,
-        gboolean show_tar_desc
+	stack_list_struct *slist, 
+	gboolean show_src_desc,
+	gboolean show_tar_desc
 );
 extern void StackListSetMaintainSourceOrder(
 	stack_list_struct *slist, gboolean maintain_source_order
 );
 extern void StackListSetChangedCB(
-        stack_list_struct *slist, 
-        void (*cb)(
-                stack_list_struct *,		/* Stack List */
-                gpointer			/* Data */
-        ),
-        gpointer data   
+	stack_list_struct *slist, 
+	void (*cb)(
+		stack_list_struct *,		/* Stack List */
+		gpointer			/* Data */
+	),
+	gpointer data   
 );
 extern void StackListSetAddedCB(
-        stack_list_struct *slist,
-        void (*cb)(
-                stack_list_struct *,		/* Stack List */
-                stack_list_item_struct *,	/* Stack List Item */
-                gpointer			/* Data */
-        ),
-        gpointer data
+	stack_list_struct *slist,
+	void (*cb)(
+		stack_list_struct *,		/* Stack List */
+		stack_list_item_struct *,	/* Stack List Item */
+		gpointer			/* Data */
+	),
+	gpointer data
 );
 extern void StackListSetRemovedCB(
-        stack_list_struct *slist,
-        void (*cb)(
-                stack_list_struct *,		/* Stack List */
-                stack_list_item_struct *,	/* Stack List Item */
-                gpointer			/* Data */
-        ),                                                
-        gpointer data
+	stack_list_struct *slist,
+	void (*cb)(
+		stack_list_struct *,		/* Stack List */
+		stack_list_item_struct *,	/* Stack List Item */
+		gpointer			/* Data */
+	),                                                
+	gpointer data
 );
 extern void StackListUpdateMenus(stack_list_struct *slist);
 extern gboolean StackListMapped(stack_list_struct *slist);
