@@ -34,6 +34,9 @@ void StaticTipSet(
 );
 
 
+#define STATIC_TIP_BORDER_MINOR		4
+
+
 #define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
 #define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
 #define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
@@ -46,9 +49,6 @@ void StaticTipSet(
 #define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
-#define STATIC_TIP_BORDER_MINOR		4
-
-
 /*
  *	Static Tip Data destroy callback.
  */
@@ -77,24 +77,26 @@ static void StaticTipDraw(StaticTipData *t)
 	GdkWindow *window;
 	GtkStateType state;
 	GtkStyle *style;
-	GtkWidget *w = (t != NULL) ? t->toplevel : NULL;
-	if(w == NULL)
+	GtkWidget *w;
+
+	if(t == NULL)
 	    return;
 
+	w = t->toplevel;
 	window = w->window;
 	state = GTK_WIDGET_STATE(w);
 	style = gtk_widget_get_style(w);
 	if((window == NULL) || (style == NULL))
 	    return;
 
-	/* Draw background */
+	/* Draw the background */
 	gtk_paint_flat_box(
 	    style, window, state, GTK_SHADOW_OUT,
 	    NULL, w, "tooltip",
 	    0, 0, -1, -1
 	);
 
-	/* Draw text */
+	/* Draw the text */
 	font = style->font;
 	text = t->text;
 	if((font != NULL) && (text != NULL))
@@ -126,9 +128,9 @@ static StaticTipData *StaticTipDataNew(void)
 	    return(NULL);
 
 	t->toplevel = w = gtk_window_new(GTK_WINDOW_POPUP);
-	gtk_widget_set_app_paintable(w, TRUE);
 	gtk_window_set_policy(GTK_WINDOW(w), FALSE, FALSE, TRUE);
-	gtk_widget_set_name(w, "gtk-tooltips");
+	gtk_widget_set_app_paintable(w, TRUE);
+	gtk_widget_set_name(w, STATIC_TIP_WIDGET_NAME);
 	gtk_signal_connect_object(
 	    GTK_OBJECT(w), "expose_event",
 	    GTK_SIGNAL_FUNC(StaticTipPaintCB), (GtkObject *)t
@@ -150,7 +152,7 @@ static void StaticTipDataDelete(StaticTipData *t)
 	if(t == NULL)
 	    return;
 
-	GTK_WIDGET_DESTROY(t->toplevel)
+	GTK_WIDGET_DESTROY(t->toplevel);
 	g_free(t->text);
 
 	g_free(t);
