@@ -8,10 +8,11 @@
 #define STYLE_EDIT_H
 
 #include <gtk/gtk.h>
+#include "pulist.h"
 
 
 typedef struct _style_edit_struct	style_edit_struct;
-#define STYLE_EDIT(p)		((style_edit_struct *)(p))
+#define STYLE_EDIT(p)			((style_edit_struct *)(p))
 
 
 /*
@@ -27,11 +28,10 @@ typedef struct _style_edit_struct	style_edit_struct;
  */
 struct _style_edit_struct {
 
-	GtkWidget	*toplevel,
-			*state_previous_btn,
-			*state_entry,
-			*state_next_btn,
-			*font_name_prompt,
+	GtkWidget	*toplevel;
+	gint		freeze_count;
+
+	GtkWidget	*font_name_prompt,
 			*fg_color_btn,
 			*bg_color_btn,
 			*text_color_btn,
@@ -39,7 +39,7 @@ struct _style_edit_struct {
 			*bg_pixmap_name_entry,
 			*preview_da;
 
-	gint		freeze_count;
+	pulistbox_struct *state_pulistbox;
 
 	GtkStateType	prev_state;
 	GtkAdjustment	*state_adj;
@@ -60,12 +60,9 @@ GtkStateType StyleEditCurrentState(style_edit_struct *se);
 extern style_edit_struct *StyleEditNew(
 	GtkWidget *parent, const gchar *name
 );
-extern void StyleEditDelete(style_edit_struct *se);
-
 extern void StyleEditSetStyle(style_edit_struct *se, const GtkRcStyle *style);
 extern GtkRcStyle *StyleEditGetStyle(style_edit_struct *se);
 extern void StyleEditRestoreDefaultStyle(style_edit_struct *se);
-
 extern void StyleEditSetChangedCB(
 	style_edit_struct *se,
 	void (*changed_cb)(
@@ -74,6 +71,7 @@ extern void StyleEditSetChangedCB(
 	),
         gpointer changed_client_data
 );
+extern void StyleEditDelete(style_edit_struct *se);
 
 
 #endif	/* STYLE_EDIT_H */
