@@ -58,4 +58,10 @@ Usage: sysinfo [options] [GUI_options]\n\
 \n"
 
 
+/*
+ *	Widget Names:
+ */
+#define SYSINFO_TOPLEVEL_WIDGET_NAME	"sysinfo"
+
+
 #endif	/* CONFIG_SYSINFO_H */
