@@ -14,20 +14,20 @@ static void SysInfoSignalCB(int s);
 static gint SysInfoTimeOutCB(gpointer data);
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
- *      UNIX signal callback.
+ *	UNIX signal callback.
  */
 static void SysInfoSignalCB(int s)
 {
@@ -88,7 +88,9 @@ int main(int argc, char *argv[])
 	gulong poll_interval = 250l;
 	sysinfo_win_struct *si;
 
-#define DO_FREE_LOCALS	{		\
+#define CLEANUP_RETURN(_v_)	{	\
+					\
+ return(_v_);				\
 }
 
 	/* Set up signal callbacks */
@@ -128,8 +130,7 @@ int main(int argc, char *argv[])
 	    )
 	    {
 		g_print("%s", PROG_HELP_MESG);
-		DO_FREE_LOCALS
-		return(0);
+		CLEANUP_RETURN(0);
 	    }
 	    /* Version */
 	    else if(!g_strcasecmp(arg, "--version") ||
@@ -141,8 +142,7 @@ int main(int argc, char *argv[])
 		    PROG_NAME " Version " PROG_VERSION "\n"
 		    PROG_COPYRIGHT
 		);
-		DO_FREE_LOCALS
-		return(0);
+		CLEANUP_RETURN(0);
 	    }
 	    /* Display */
 	    else if(!g_strcasecmp(arg, "-d"))
@@ -232,7 +232,7 @@ int main(int argc, char *argv[])
 	    {
 		i++;
 		arg = (i < argc) ? argv[i] : NULL;
-		if(!STRISEMPTY(arg))    
+		if(!STRISEMPTY(arg))
 		{
 		    poll_interval = ATOL(arg);
 		}
@@ -248,7 +248,7 @@ int main(int argc, char *argv[])
 	    else if((*arg == '-') ? (arg[1] != '-') : FALSE)
 	    {
 		const gchar *v = arg + 1;
-/*              gchar c; */
+/*		gchar c; */
 
 		while(*v != '\0')
 		{
@@ -264,8 +264,7 @@ int main(int argc, char *argv[])
 "-%c: Unsupported argument.\n",
 			    c
 			);
-			DO_FREE_LOCALS
-			return(2);
+			CLEANUP_RETURN(2);
 		    }
 #endif
 		    v++;
@@ -277,8 +276,7 @@ int main(int argc, char *argv[])
 "%s: Unsupported argument.\n",
 		    arg
 		);
-		DO_FREE_LOCALS
-		return(2);
+		CLEANUP_RETURN(2);
 	    }
 	}
 
@@ -292,8 +290,7 @@ int main(int argc, char *argv[])
 	    if(!gtk_init_check(&argc, &argv))
 	    {
 		g_printerr("Unable to initialize GTK.\n");
-		DO_FREE_LOCALS
-		return(1);
+		CLEANUP_RETURN(1);
 	    }
 	    initialized_gtk = TRUE;
 	}
@@ -327,8 +324,6 @@ int main(int argc, char *argv[])
 	/* Reset the DND Icon */
 	GUIDNDSetDragIcon(NULL, NULL, 0, 0);
 
-	DO_FREE_LOCALS
-
-	return(0);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(0);
+#undef CLEANUP_RETURN
 }
