@@ -921,7 +921,7 @@ static void SysInfoUpdateDetails(sysinfo_win_struct *si)
 	/* Delete existing message */
 	gtk_editable_delete_text(editable, 0, -1);
 
-	/* Format details message */
+	/* Format the details message */
 	buf = g_strdup_printf(
 	    "\
 Vendor: %s\n\
@@ -989,10 +989,16 @@ sysinfo_win_struct *SysInfoNew(
 
 	si->pointer_in_widget = NULL;
 
-	/* Begin creating widgets */
+	si->freeze_count++;
 
-	/* Toplevel */
+	/* Toplevel GtkWindow */
 	si->toplevel = w = gtk_window_new(GTK_WINDOW_DIALOG);
+	gtk_widget_set_name(w, SYSINFO_TOPLEVEL_WIDGET_NAME);
+	gtk_window_set_policy(GTK_WINDOW(w), TRUE, TRUE, TRUE);
+	gtk_window_set_title(GTK_WINDOW(w), SysInfoGetCPUModel());
+	gtk_window_set_wmclass(
+	    GTK_WINDOW(w), "sysinfo", PROG_NAME
+	);
 	gtk_widget_add_events(
 	    w,
 	    GDK_STRUCTURE_MASK | GDK_EXPOSURE_MASK |
@@ -1032,11 +1038,6 @@ sysinfo_win_struct *SysInfoNew(
 	    GTK_OBJECT(w), "button_release_event",
 	    GTK_SIGNAL_FUNC(SysInfoEventCB), si
 	);
-	gtk_window_set_title(GTK_WINDOW(w), SysInfoGetCPUModel());
-	gtk_window_set_wmclass(
-	    GTK_WINDOW(w), "sysinfo", PROG_NAME
-	);
-	gtk_window_set_policy(GTK_WINDOW(w), TRUE, TRUE, TRUE);
 	gtk_widget_realize(w);
 	colormap = gtk_widget_get_colormap(w);
 	style = gtk_widget_get_style(w);
@@ -1060,12 +1061,11 @@ sysinfo_win_struct *SysInfoNew(
 
 	    gdk_window_set_decorations(
 		window,
-		GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
-		GDK_DECOR_MINIMIZE
+		GDK_DECOR_BORDER | GDK_DECOR_TITLE
 	    );
 	    gdk_window_set_functions(
 		window,
-		GDK_FUNC_MOVE | GDK_FUNC_MINIMIZE | GDK_FUNC_CLOSE
+		GDK_FUNC_MOVE | GDK_FUNC_CLOSE
 	    );
 	    GUISetWMIcon(
 		window,
@@ -1079,7 +1079,7 @@ sysinfo_win_struct *SysInfoNew(
 	gtk_window_add_accel_group(GTK_WINDOW(w), accelgrp);
 	parent = w;
 
-	/* Main box */
+	/* Main GtkVBox */
 	si->main_box = main_box = w = vertical ?
 	    gtk_hbox_new(FALSE, border_major) :
 	    gtk_vbox_new(FALSE, border_major);
@@ -1523,7 +1523,7 @@ sysinfo_win_struct *SysInfoNew(
 
 
 
-	/* Right-click menu */
+	/* Right-click popup menu */
 	si->menu = w = GUIMenuCreate();
 	if(w != NULL)
 	{
@@ -1639,10 +1639,10 @@ sysinfo_win_struct *SysInfoNew(
 	    GDK_COLORMAP_ALLOC_COLOR(colormap, c);
 	}
 
-
 	/* Update Details */
 	SysInfoUpdateDetails(si);
 
+	si->freeze_count--;
 
 	return(si);
 }
@@ -1762,7 +1762,8 @@ void SysInfoUpdate(sysinfo_win_struct *si)
 	if(si == NULL)
 	    return;
 
-	/* Begin updating */
+	si->freeze_count++;
+
 #define SET_CHECK_MENU_ITEM(_w_,_b_)		\
 { if((_w_) != NULL) {				\
  if(GTK_CHECK_MENU_ITEM(_w_)->active != (_b_))	\
@@ -1771,8 +1772,6 @@ void SysInfoUpdate(sysinfo_win_struct *si)
   );						\
 } }
 
-	si->freeze_count++;
-
 	SET_CHECK_MENU_ITEM(
 	    si->display_memory_micheck,
 	    (si->display & SYSINFO_DISPLAY_MEMORY) ? TRUE : FALSE
@@ -1786,9 +1785,6 @@ void SysInfoUpdate(sysinfo_win_struct *si)
 	    (si->display & SYSINFO_DISPLAY_CPU_DETAILS) ? TRUE : FALSE
 	);
 
-	si->freeze_count--;
-
-
 	/* CPU Load */
 	v = ExecCPUGetLoad(-1);
 	dv = v - si->cpu_load_last_value;
@@ -1821,8 +1817,9 @@ void SysInfoUpdate(sysinfo_win_struct *si)
 	SysInfoDrawAPMPower(si, v);
 	si->apm_power_last_value = v;
 
-
 #undef SET_CHECK_MENU_ITEM
+
+	si->freeze_count--;
 }
 
 /*
@@ -1830,8 +1827,10 @@ void SysInfoUpdate(sysinfo_win_struct *si)
  */
 gboolean SysInfoIsMapped(sysinfo_win_struct *si)
 {
-	GtkWidget *w = (si != NULL) ? si->toplevel : NULL;
-	return((w != NULL) ? GTK_WIDGET_MAPPED(w) : FALSE);
+	if(si == NULL)
+	    return(FALSE);
+
+	return(GTK_WIDGET_MAPPED(si->toplevel));
 }
 
 /*
@@ -1839,11 +1838,10 @@ gboolean SysInfoIsMapped(sysinfo_win_struct *si)
  */
 void SysInfoMap(sysinfo_win_struct *si)
 {
-	GtkWidget *w = (si != NULL) ? si->toplevel : NULL;
-	if(w == NULL)
+	if(si == NULL)
 	    return;
 
-	gtk_widget_show_raise(w);
+	gtk_widget_show_raise(si->toplevel);
 }
 
 /*
@@ -1851,11 +1849,10 @@ void SysInfoMap(sysinfo_win_struct *si)
  */
 void SysInfoUnmap(sysinfo_win_struct *si)
 {
-	GtkWidget *w = (si != NULL) ? si->toplevel : NULL;
-	if(w == NULL)
+	if(si == NULL)
 	    return;
 
-	gtk_widget_hide(w);
+	gtk_widget_hide(si->toplevel);
 }
 
 /*
@@ -1868,6 +1865,10 @@ void SysInfoDelete(sysinfo_win_struct *si)
 	if(si == NULL)
 	    return;
 
+	SysInfoUnmap(si);
+
+	si->freeze_count++;
+
 	colormap = gtk_widget_get_colormap(si->toplevel);
 	GDK_COLORMAP_FREE_COLOR(
 	    colormap, &si->bar_led_bg_color
@@ -1886,10 +1887,11 @@ void SysInfoDelete(sysinfo_win_struct *si)
 
 	GTK_WIDGET_DESTROY(si->menu);
 	GTK_WIDGET_DESTROY(si->toplevel);
+	GTK_ACCEL_GROUP_UNREF(si->accelgrp);
 
 	GDK_PIXMAP_UNREF(si->bar_pixmap);
 
-	GTK_ACCEL_GROUP_UNREF(si->accelgrp);
+	si->freeze_count--;
 
 	g_free(si);
 }
