@@ -3,36 +3,36 @@
 #include "../progressdialog.h"
 #include "../config.h"
 
-#include "../images/pdi_file01_20x20.xpm"
-#include "../images/pdi_file02_20x20.xpm"
-#include "../images/pdi_file03_20x20.xpm"
-#include "../images/pdi_file04_20x20.xpm"
-#include "../images/pdi_file05_20x20.xpm"
-#include "../images/pdi_file06_20x20.xpm"
+#include "../animations/file01_20x20.xpm"
+#include "../animations/file02_20x20.xpm"
+#include "../animations/file03_20x20.xpm"
+#include "../animations/file04_20x20.xpm"
+#include "../animations/file05_20x20.xpm"
+#include "../animations/file06_20x20.xpm"
 
-#include "../images/pdi_mail01_20x20.xpm"
-#include "../images/pdi_mail02_20x20.xpm"
-#include "../images/pdi_mail03_20x20.xpm"
-#include "../images/pdi_mail04_20x20.xpm"
-#include "../images/pdi_mail05_20x20.xpm"
-#include "../images/pdi_mail06_20x20.xpm"
+#include "../animations/mail01_20x20.xpm"
+#include "../animations/mail02_20x20.xpm"
+#include "../animations/mail03_20x20.xpm"
+#include "../animations/mail04_20x20.xpm"
+#include "../animations/mail05_20x20.xpm"
+#include "../animations/mail06_20x20.xpm"
 
-#include "../images/pdi_folder_32x32.xpm"
-#include "../images/pdi_folderfile_32x32.xpm"
-#include "../images/pdi_package_32x32.xpm"
-#include "../images/pdi_packagefile_32x32.xpm"
-#include "../images/pdi_mailbagfull_32x32.xpm"
-#include "../images/pdi_mailbox_32x32.xpm"
-#include "../images/pdi_mailboxfull_32x32.xpm"
+#include "../animations/folder_32x32.xpm"
+#include "../animations/folderfile_32x32.xpm"
+#include "../animations/package_32x32.xpm"
+#include "../animations/packagefile_32x32.xpm"
+#include "../animations/mailbagfull_32x32.xpm"
+#include "../animations/mailbox_32x32.xpm"
+#include "../animations/mailboxfull_32x32.xpm"
 #include "../images/icon_trash_32x32.xpm"
 #include "../images/icon_trash_empty_32x32.xpm"
 
-#include "../images/pdi_trash01_20x20.xpm"
-#include "../images/pdi_trash02_20x20.xpm"
-#include "../images/pdi_trash03_20x20.xpm"
-#include "../images/pdi_trash04_20x20.xpm"
-#include "../images/pdi_trash05_20x20.xpm"
-#include "../images/pdi_trash06_20x20.xpm"
+#include "../animations/trash01_20x20.xpm"
+#include "../animations/trash02_20x20.xpm"
+#include "../animations/trash03_20x20.xpm"
+#include "../animations/trash04_20x20.xpm"
+#include "../animations/trash05_20x20.xpm"
+#include "../animations/trash06_20x20.xpm"
 
 
 /*
@@ -130,21 +130,21 @@ int main(int argc, char *argv[])
 	{
 	  case ANIMATION_MOVE:
 	    animation_str = "move";
-	    start_icon_data[0] = (guint8 **)pdi_folderfile_32x32_xpm;
-	    start_icon_data[1] = (guint8 **)pdi_folder_32x32_xpm;
-	    start_icon_data[2] = (guint8 **)pdi_folder_32x32_xpm;
+	    start_icon_data[0] = (guint8 **)folderfile_32x32_xpm;
+	    start_icon_data[1] = (guint8 **)folder_32x32_xpm;
+	    start_icon_data[2] = (guint8 **)folder_32x32_xpm;
 	    break;
 	  case ANIMATION_COPY:
 	    animation_str = "copy";
-	    start_icon_data[0] = (guint8 **)pdi_folderfile_32x32_xpm;
-	    start_icon_data[1] = (guint8 **)pdi_folderfile_32x32_xpm;
-	    start_icon_data[2] = (guint8 **)pdi_folderfile_32x32_xpm;
+	    start_icon_data[0] = (guint8 **)folderfile_32x32_xpm;
+	    start_icon_data[1] = (guint8 **)folderfile_32x32_xpm;
+	    start_icon_data[2] = (guint8 **)folderfile_32x32_xpm;
 	    break;
 	  case ANIMATION_RECYCLE:
 	    animation_str = "recycle";
-	    start_icon_data[0] = (guint8 **)pdi_folderfile_32x32_xpm;
-	    start_icon_data[1] = (guint8 **)pdi_folder_32x32_xpm;
-	    start_icon_data[2] = (guint8 **)pdi_folder_32x32_xpm;
+	    start_icon_data[0] = (guint8 **)folderfile_32x32_xpm;
+	    start_icon_data[1] = (guint8 **)folder_32x32_xpm;
+	    start_icon_data[2] = (guint8 **)folder_32x32_xpm;
 	    break;
 	  case ANIMATION_PURGE:
 	    animation_str = "purge";
@@ -154,15 +154,15 @@ int main(int argc, char *argv[])
 	    break;
 	  case ANIMATION_ARCHIVE:
 	    animation_str = "archive";
-	    start_icon_data[0] = (guint8 **)pdi_packagefile_32x32_xpm;
-	    start_icon_data[1] = (guint8 **)pdi_package_32x32_xpm;
-	    start_icon_data[2] = (guint8 **)pdi_package_32x32_xpm;
+	    start_icon_data[0] = (guint8 **)packagefile_32x32_xpm;
+	    start_icon_data[1] = (guint8 **)package_32x32_xpm;
+	    start_icon_data[2] = (guint8 **)package_32x32_xpm;
 	    break;
 	  case ANIMATION_MAIL:
 	    animation_str = "mail";
-	    start_icon_data[0] = (guint8 **)pdi_mailbagfull_32x32_xpm;
-	    start_icon_data[1] = (guint8 **)pdi_mailbagfull_32x32_xpm;
-	    start_icon_data[2] = (guint8 **)pdi_mailbagfull_32x32_xpm;
+	    start_icon_data[0] = (guint8 **)mailbagfull_32x32_xpm;
+	    start_icon_data[1] = (guint8 **)mailbagfull_32x32_xpm;
+	    start_icon_data[2] = (guint8 **)mailbagfull_32x32_xpm;
 	    break;
 	}
 
@@ -173,28 +173,28 @@ int main(int argc, char *argv[])
 	  case ANIMATION_COPY:
 	  case ANIMATION_RECYCLE:
 	  case ANIMATION_ARCHIVE:
-	    icon_data[0] = (guint8 **)pdi_file01_20x20_xpm;
-	    icon_data[1] = (guint8 **)pdi_file02_20x20_xpm;
-	    icon_data[2] = (guint8 **)pdi_file03_20x20_xpm;
-	    icon_data[3] = (guint8 **)pdi_file04_20x20_xpm;
-	    icon_data[4] = (guint8 **)pdi_file05_20x20_xpm;
-	    icon_data[5] = (guint8 **)pdi_file06_20x20_xpm;
+	    icon_data[0] = (guint8 **)file01_20x20_xpm;
+	    icon_data[1] = (guint8 **)file02_20x20_xpm;
+	    icon_data[2] = (guint8 **)file03_20x20_xpm;
+	    icon_data[3] = (guint8 **)file04_20x20_xpm;
+	    icon_data[4] = (guint8 **)file05_20x20_xpm;
+	    icon_data[5] = (guint8 **)file06_20x20_xpm;
 	    break;
 	  case ANIMATION_PURGE:
-	    icon_data[0] = (guint8 **)pdi_trash01_20x20_xpm;
-	    icon_data[1] = (guint8 **)pdi_trash02_20x20_xpm;
-	    icon_data[2] = (guint8 **)pdi_trash03_20x20_xpm;
-	    icon_data[3] = (guint8 **)pdi_trash04_20x20_xpm;
-	    icon_data[4] = (guint8 **)pdi_trash05_20x20_xpm;
-	    icon_data[5] = (guint8 **)pdi_trash06_20x20_xpm;
+	    icon_data[0] = (guint8 **)trash01_20x20_xpm;
+	    icon_data[1] = (guint8 **)trash02_20x20_xpm;
+	    icon_data[2] = (guint8 **)trash03_20x20_xpm;
+	    icon_data[3] = (guint8 **)trash04_20x20_xpm;
+	    icon_data[4] = (guint8 **)trash05_20x20_xpm;
+	    icon_data[5] = (guint8 **)trash06_20x20_xpm;
 	    break;
 	  case ANIMATION_MAIL:
-	    icon_data[0] = (guint8 **)pdi_mail01_20x20_xpm;
-	    icon_data[1] = (guint8 **)pdi_mail02_20x20_xpm;
-	    icon_data[2] = (guint8 **)pdi_mail03_20x20_xpm;
-	    icon_data[3] = (guint8 **)pdi_mail04_20x20_xpm;
-	    icon_data[4] = (guint8 **)pdi_mail05_20x20_xpm;
-	    icon_data[5] = (guint8 **)pdi_mail06_20x20_xpm;
+	    icon_data[0] = (guint8 **)mail01_20x20_xpm;
+	    icon_data[1] = (guint8 **)mail02_20x20_xpm;
+	    icon_data[2] = (guint8 **)mail03_20x20_xpm;
+	    icon_data[3] = (guint8 **)mail04_20x20_xpm;
+	    icon_data[4] = (guint8 **)mail05_20x20_xpm;
+	    icon_data[5] = (guint8 **)mail06_20x20_xpm;
 	    break;
 	}
 
@@ -202,14 +202,14 @@ int main(int argc, char *argv[])
 	switch(animation)
 	{
 	  case ANIMATION_MOVE:
-	    end_icon_data[0] = (guint8 **)pdi_folder_32x32_xpm;
-	    end_icon_data[1] = (guint8 **)pdi_folder_32x32_xpm;
-	    end_icon_data[2] = (guint8 **)pdi_folderfile_32x32_xpm;
+	    end_icon_data[0] = (guint8 **)folder_32x32_xpm;
+	    end_icon_data[1] = (guint8 **)folder_32x32_xpm;
+	    end_icon_data[2] = (guint8 **)folderfile_32x32_xpm;
 	    break;
 	  case ANIMATION_COPY:
-	    end_icon_data[0] = (guint8 **)pdi_folder_32x32_xpm;
-	    end_icon_data[1] = (guint8 **)pdi_folder_32x32_xpm;
-	    end_icon_data[2] = (guint8 **)pdi_folderfile_32x32_xpm;
+	    end_icon_data[0] = (guint8 **)folder_32x32_xpm;
+	    end_icon_data[1] = (guint8 **)folder_32x32_xpm;
+	    end_icon_data[2] = (guint8 **)folderfile_32x32_xpm;
 	    break;
 	  case ANIMATION_RECYCLE:
 	    end_icon_data[0] = (guint8 **)icon_trash_empty_32x32_xpm;
@@ -222,14 +222,14 @@ int main(int argc, char *argv[])
 	    end_icon_data[2] = NULL;
 	    break;
 	  case ANIMATION_ARCHIVE:
-	    end_icon_data[0] = (guint8 **)pdi_folder_32x32_xpm;
-	    end_icon_data[1] = (guint8 **)pdi_folder_32x32_xpm;
-	    end_icon_data[2] = (guint8 **)pdi_folderfile_32x32_xpm;
+	    end_icon_data[0] = (guint8 **)folder_32x32_xpm;
+	    end_icon_data[1] = (guint8 **)folder_32x32_xpm;
+	    end_icon_data[2] = (guint8 **)folderfile_32x32_xpm;
 	    break;
 	  case ANIMATION_MAIL:
-	    end_icon_data[0] = (guint8 **)pdi_mailbox_32x32_xpm;
-	    end_icon_data[1] = (guint8 **)pdi_mailbox_32x32_xpm;
-	    end_icon_data[2] = (guint8 **)pdi_mailboxfull_32x32_xpm;
+	    end_icon_data[0] = (guint8 **)mailbox_32x32_xpm;
+	    end_icon_data[1] = (guint8 **)mailbox_32x32_xpm;
+	    end_icon_data[2] = (guint8 **)mailboxfull_32x32_xpm;
 	    break;
 	}
 
@@ -272,7 +272,7 @@ Dialog Style: \"%s\"\n",
 	    ProgressDialogMap(
 		"Progress Dialog",
 		"This is a sample Progress Dialog",
-		(const guint8 **)pdi_folderfile_32x32_xpm,
+		(const guint8 **)folderfile_32x32_xpm,
 		"Stop"
 	    );
 	    g_free(s);
