@@ -17,12 +17,9 @@
 
 
 static gint RecycleProgressCB(
-	gpointer client_data, gulong pos, gulong total
+	gpointer data, const gulong pos, const gulong total
 );
 
-void EDVGetDeviceNumbers(dev_t rdev, gint *major, gint *minor);
-dev_t EDVFormatDeviceNumbers(gint major, gint minor);
-
 static gint RecycleDoList(const gchar *recycled_index_file);
 static guint RecycleDoDelete(
 	const gchar *recycled_index_file, const gchar *path
@@ -35,6 +32,16 @@ static gint RecycleDoPurge(
 );
 
 
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -42,7 +49,7 @@ static gint RecycleDoPurge(
  *	a percent progress of the file operation.
  */
 static gint RecycleProgressCB(
-	gpointer client_data, gulong pos, gulong total
+	gpointer data, const gulong pos, const gulong total
 )
 {
 	if(total > 0)
@@ -53,33 +60,6 @@ static gint RecycleProgressCB(
 	return(0);
 }
 
-/*
- *	From edvutils.c
- *
- *      Parses and returns the major and minor numbers for the device
- *      given by rdev which should be obtained from a prior call to
- *      *stat() in structure struct stat stat_buf.st_rdev.
- */
-void EDVGetDeviceNumbers(dev_t rdev, gint *major, gint *minor)
-{
-	if(major != NULL)
-	    *major = ((rdev >> 8) & 0xff);
-	if(minor != NULL)
-	    *minor = ((rdev >> 0) & 0xff);
-}
-
-/*
- *      From edvutils.c
- *
- *      Returns a formatted rdev value formatted from the given device
- *      major and minor numbers.
- */
-dev_t EDVFormatDeviceNumbers(gint major, gint minor)
-{
-	return(((dev_t)major << 8) | ((dev_t)minor << 0));
-}
-
-
 /*
  *	Lists all contents in the recycle bin.
  */
@@ -134,7 +114,7 @@ static guint RecycleDoDelete(
 
 
 	/* Create a new tempory recycled object structure */
-	obj = EDVRecBinObjectNew();
+	obj = EDVRecycledObjectNew();
 
 	/* Begin setting values from actual object's lstat_buf structure
 	 * to the newly allocated recycled object structure.
@@ -214,8 +194,8 @@ static guint RecycleDoDelete(
 	);
 	if(index > 0)
 	{
-	    /* Remove actual disk object and place it into the recycled
-	     * objects directory.
+	    /* Remove the actual object and place it into the recycled
+	     * objects directory
 	     */
 	    printf(
 		"Recycling %s\n",
@@ -229,9 +209,8 @@ static guint RecycleDoDelete(
 		NULL, NULL
 	    );
 /*	    printf("\n"); */
-	    if(status)
-		fprintf(
-		    stderr,
+	    if(status != 0)
+		g_printerr(
 		    "%s\n",
 		    EDVRecBinIndexGetError()
 		);
@@ -240,7 +219,7 @@ static guint RecycleDoDelete(
 	/* Delete tempory recycled object structure, it is no longer
 	 * needed.
 	 */
-	EDVRecBinObjectDelete(obj);
+	EDVRecycledObjectDelete(obj);
 	obj = NULL;
 
 	return(index);
@@ -253,10 +232,8 @@ static gint RecycleDoRecover(
 	const gchar *recycled_index_file, guint index
 )
 {
-	gint status;
-
-
-	status = EDVRecBinDiskObjectRecover(
+	/* Recover the object */
+	const gint status = EDVRecBinDiskObjectRecover(
 	    recycled_index_file,
 	    index,
 	    NULL,
@@ -265,8 +242,7 @@ static gint RecycleDoRecover(
 	printf("\n");
 	if(status)
 	{
-	    fprintf(
-		stderr,
+	    g_printerr(
 		"%s\n",
 		EDVRecBinIndexGetError()
 	    );
@@ -303,8 +279,7 @@ static gint RecycleDoPurge(
 	printf("\n");
 	if(status)
 	{
-	    fprintf(
-		stderr,
+	    g_printerr(
 		"%s\n",
 		EDVRecBinIndexGetError()
 	    );
