@@ -18,52 +18,44 @@ static gint ToolbarLeaveNotifyCB(
 static void ToolbarClickedCB(GtkWidget *widget, gpointer data);
 
 
-/* Tool Bar Item List */
+/* Item */
 toolbar_item_struct *ToolBarItemNew(
-	toolbar_item_type type,		/* One of TOOLBAR_ITEM_* */
+	const toolbar_item_type type,
+	toolbar_struct *tb,
 	const gchar *text,
 	guint8 **icon_data,
 	const gchar *tooltip,
-	gint id,
+	const gint id,
 	void (*func_cb)(toolbar_item_struct *, gint, gpointer),
-	gpointer client_data,
+	gpointer func_data,
 	void (*enter_cb)(toolbar_item_struct *, gint, gpointer),
-	gpointer enter_client_data,
+	gpointer enter_data,
 	void (*leave_cb)(toolbar_item_struct *, gint, gpointer),
-	gpointer leave_client_data
+	gpointer leave_data
 );
 void ToolBarItemDelete(toolbar_item_struct *item);
 
-void ToolBarItemListAppend(
-	toolbar_item_struct ***item, gint *total_items,
-	toolbar_item_struct *item_ptr
-);
-void ToolBarItemListDeleteAll(
-	toolbar_item_struct ***item, gint *total_items 
-);
-
 toolbar_item_struct *ToolBarItemListMatchByID(
-	toolbar_item_struct **item, gint total_items,
-	gint id
+	GList *items_list, const gint id
 );
 
 
 /* Tool Bar */
 toolbar_struct *ToolBarNew(
-	toolbar_item_struct **item, gint total_items,
 	GtkWidget *parent,
-	toolbar_display display,
-	toolbar_relief relief,
-	gboolean vertical
+	GList *items_list,
+	const toolbar_display display,
+	const toolbar_relief relief,
+	const GtkOrientation orientation
 );
 void ToolBarSetDisplay(
-	toolbar_struct *tb, toolbar_display display
+	toolbar_struct *tb, const toolbar_display display
 );
 void ToolBarSetRelief(
-	toolbar_struct *tb, toolbar_relief relief
+	toolbar_struct *tb, const toolbar_relief relief
 );
 void ToolBarItemUpdateByID(
-	toolbar_struct *tb, gint id,
+	toolbar_struct *tb, const gint id,
 	const gchar *text,
 	guint8 **icon_data,
 	const gchar *tooltip
@@ -74,37 +66,36 @@ void ToolBarDelete(toolbar_struct *tb);
 
 
 /* Tool Bar Item */
-GtkWidget *ToolBarItemGetWidgetID(toolbar_struct *tb, gint id);
-
+GtkWidget *ToolBarItemGetWidgetID(
+	toolbar_struct *tb, const gint id
+);
 void ToolBarItemSetSensitiveID(
-	toolbar_struct *tb, gint id, gboolean sensitive
+	toolbar_struct *tb, const gint id,
+	const gboolean sensitive
 );
-
 void ToolBarItemSetToggleID(
-	toolbar_struct *tb, gint id, gboolean toggled
+	toolbar_struct *tb, const gint id,
+	const gboolean toggled
+);
+gboolean ToolBarItemGetToggleID(
+	toolbar_struct *tb, const gint id
 );
-gboolean ToolBarItemGetToggleID(toolbar_struct *tb, gint id);
-
 void ToolBarItemSetMenuID(
-	toolbar_struct *tb, gint id, GtkWidget *menu
+	toolbar_struct *tb, const gint id,
+	GtkWidget *menu
+);
+GtkWidget *ToolBarItemGetMenuID(
+	toolbar_struct *tb, const gint id
+);
+gboolean ToolBarItemIsMappedID(
+	toolbar_struct *tb, const gint id
+);
+void ToolBarItemMapID(
+	toolbar_struct *tb, const gint id
+);
+void ToolBarItemUnmapID(
+	toolbar_struct *tb, const gint id
 );
-GtkWidget *ToolBarItemGetMenuID(toolbar_struct *tb, gint id);
-
-gboolean ToolBarItemIsMappedID(toolbar_struct *tb, gint id);
-void ToolBarItemMapID(toolbar_struct *tb, gint id);
-void ToolBarItemUnmapID(toolbar_struct *tb, gint id);
-
-
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
-
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 #define TOOLBAR_BUTTON_PICTURE_AND_TEXT_WIDTH   GUI_BUTTON_VLABEL_WIDTH
@@ -146,6 +137,18 @@ void ToolBarItemUnmapID(toolbar_struct *tb, gint id);
 } } }
 
 
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
+
+
 /*
  *	Tool Bar Item "enter_notify_event" signal callback.
  */
@@ -157,11 +160,14 @@ static gint ToolbarEnterNotifyCB(
 	if(item == NULL)
 	    return(TRUE);
 
+	if(item->freeze_count > 0)
+	    return(TRUE);
+
 	if(item->enter_cb != NULL)
 	    item->enter_cb(
 		item,			/* Tool Bar Item */
 		item->id,		/* ID */
-		item->enter_client_data	/* Data */
+		item->enter_data	/* Data */
 	    );
 
 	return(TRUE);
@@ -178,11 +184,14 @@ static gint ToolbarLeaveNotifyCB(
 	if(item == NULL)
 	    return(TRUE);
 
+	if(item->freeze_count > 0)
+	    return(TRUE);
+
 	if(item->leave_cb != NULL)
 	    item->leave_cb(
 		item,			/* Tool Bar Item */
 		item->id,		/* ID */
-		item->leave_client_data	/* Data */
+		item->leave_data	/* Data */
 	    );
 
 	return(TRUE);
@@ -197,11 +206,14 @@ static void ToolbarClickedCB(GtkWidget *widget, gpointer data)
 	if(item == NULL)
 	    return;
 
+	if(item->freeze_count > 0)
+	    return;
+
 	if(item->func_cb != NULL)
 	    item->func_cb(
 		item,			/* Tool Bar Item */
 		item->id,		/* ID */
-		item->client_data	/* Data */
+		item->func_data		/* Data */
 	    );
 }
 
@@ -209,20 +221,21 @@ static void ToolbarClickedCB(GtkWidget *widget, gpointer data)
 /*
  *	Creates a new Tool Bar Item.
  *
- *	No widgets or other resources will be created.
+ *	The item's GtkWidget will not be created.
  */
 toolbar_item_struct *ToolBarItemNew(
-	toolbar_item_type type,		/* One of TOOLBAR_ITEM_* */
+	const toolbar_item_type type,
+	toolbar_struct *tb,
 	const gchar *text,
 	guint8 **icon_data,
 	const gchar *tooltip,
-	gint id,
+	const gint id,
 	void (*func_cb)(toolbar_item_struct *, gint, gpointer),
-	gpointer client_data,
+	gpointer func_data,
 	void (*enter_cb)(toolbar_item_struct *, gint, gpointer),
-	gpointer enter_client_data,
+	gpointer enter_data,
 	void (*leave_cb)(toolbar_item_struct *, gint, gpointer),
-	gpointer leave_client_data
+	gpointer leave_data
 )
 {
 	toolbar_item_struct *item = TOOLBAR_ITEM(g_malloc0(
@@ -232,20 +245,19 @@ toolbar_item_struct *ToolBarItemNew(
 	    return(item);
 
 	item->type = type;
-
-	item->w = NULL;
-
-	item->text = STRDUP(text);
+	item->freeze_count = 0;
+	item->tb = tb;
+	item->w = NULL;		/* Do not create this item's GtkWidget */
+ 	item->text = STRDUP(text);
 	item->icon_data = icon_data;
 	item->tooltip = STRDUP(tooltip);
-
 	item->id = id;
 	item->func_cb = func_cb;
-	item->client_data = client_data;
+	item->func_data = func_data;
 	item->enter_cb = enter_cb;
-	item->enter_client_data = enter_client_data;
+	item->enter_data = enter_data;
 	item->leave_cb = leave_cb;
-	item->leave_client_data = leave_client_data;
+	item->leave_data = leave_data;
 
 	return(item);
 }
@@ -258,91 +270,39 @@ void ToolBarItemDelete(toolbar_item_struct *item)
 	if(item == NULL)
 	    return;
 
-	/* Destroy widgets */
-	GTK_WIDGET_DESTROY(item->w)
+	item->freeze_count++;
 
+	GTK_WIDGET_DESTROY(item->w);
 	g_free(item->text);
-	/* item->icon_data = NULL; */	/* Shared */
 	g_free(item->tooltip);
+
+	item->freeze_count--;
+
 	g_free(item);
 }
 
 
 /*
- *	Appends the Tool Bar Item to the specified list.
- *
- *	The specified Tool Bar Item will be transfered to the list and
- *	should not be referenced again after this call.
- */
-void ToolBarItemListAppend(
-	toolbar_item_struct ***item, gint *total_items,
-	toolbar_item_struct *item_ptr
-)
-{
-	gint i;
-
-	if((item == NULL) || (total_items == NULL))
-	{
-	    ToolBarItemDelete(item_ptr);
-	    return;
-	}
-
-	i = MAX(*total_items, 0);
-	*total_items = i + 1;
-	*item = (toolbar_item_struct **)g_realloc(
-	    *item,
-	    (*total_items) * sizeof(toolbar_item_struct *)
-	);
-	if(*item == NULL)
-	{
-	    *total_items = 0;
-	    ToolBarItemDelete(item_ptr);
-	    return;
-	}
-
-	(*item)[i] = item_ptr;
-}
-
-/*
- *	Deletes all Tool Bar Items in the specified list.
- */
-void ToolBarItemListDeleteAll(
-	toolbar_item_struct ***item, gint *total_items
-)
-{
-	gint i, m;
-
-	if((item == NULL) || (total_items == NULL))
-	    return;
-
-	m = *total_items;
-
-	for(i = 0; i < m; i++)
-	    ToolBarItemDelete((*item)[i]);
-
-	g_free(*item);
-	*item = NULL;
-	*total_items = 0;
-}
-
-
-/*
- *	Returns a Tool Bar Item in the list that matches the specified
- *	id.
+ *	Matches the item by id.
  */
 toolbar_item_struct *ToolBarItemListMatchByID(
-	toolbar_item_struct **item, gint total_items,
-	gint id
+	GList *items_list, const gint id
 )
 {
-	gint i;
-	toolbar_item_struct *item_ptr;
+	GList *glist;
+	toolbar_item_struct *item;
 
-	for(i = 0; i < total_items; i++)
+	for(glist = items_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    item_ptr = item[i];
-	    if((item_ptr != NULL) ? (item_ptr->id == id) : FALSE)
-		return(item_ptr);
+	    item = TOOLBAR_ITEM(glist->data);
+	    if(item == NULL)
+		continue;
+
+	    if(item->id == id)
+		return(item);
 	}
 
 	return(NULL);
@@ -352,38 +312,40 @@ toolbar_item_struct *ToolBarItemListMatchByID(
 /*
  *	Creates a new Tool Bar.
  *
- *	The given list of Tool Bar Items will not be modified.
+ *	The items_list specifies a GList of toolbar_item_struct * items
+ *	to create. This list and each item is not modified or deleted by
+ *	this function.
+ *
+ *	Returns the new Tool Bar or NULL on error.
  */
 toolbar_struct *ToolBarNew(
-	toolbar_item_struct **item, gint total_items,
 	GtkWidget *parent,
-	toolbar_display display,
-	toolbar_relief relief,
-	gboolean vertical
+	GList *items_list,
+	const toolbar_display display,
+	const toolbar_relief relief,
+	const GtkOrientation orientation
 )
 {
 	const gint	border_major = 5,
 			border_minor = 2;
-	gint i;
-	GtkWidget *w, *parent2, *parent3;
-	const toolbar_item_struct *src_item_ptr;
-	toolbar_item_struct *item_ptr;
+	GList *glist;
+	GtkWidget	*w, *parent2, *parent3,
+			*label_rtn, *menu_rtn;
+	toolbar_item_struct *item;
 	toolbar_struct *tb = TOOLBAR(g_malloc0(
 	    sizeof(toolbar_struct)
 	));
 	if(tb == NULL)
 	    return(tb);
 
-	/* Reset values */
+	tb->freeze_count = 0;
 	tb->display = display;
 	tb->relief = relief;
-	tb->vertical = vertical;
+	tb->orientation = orientation;
+	tb->items_list = NULL;
 
-	tb->item = NULL;
-	tb->total_items = 0;
-
-	/* Create toplevel */
-	if(vertical)
+	/* Toplevel GtkBox */
+	if(orientation == GTK_ORIENTATION_VERTICAL)
 	    w = gtk_vbox_new(FALSE, 0);
 	else
 	    w = gtk_hbox_new(FALSE, 0);
@@ -398,198 +360,180 @@ toolbar_struct *ToolBarNew(
 	tb->toplevel = w;
 	parent2 = w;
 
-
-	/* Allocate pointer array for Tool Bar Items */
-	tb->total_items = total_items;
-	if(tb->total_items > 0)
+	/* Create the Tool Bar Items */
+	for(glist = items_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    tb->item = (toolbar_item_struct **)g_malloc0(
-		tb->total_items * sizeof(toolbar_item_struct *)
-	    );
-	    if(tb->item == NULL)
-	    {
-		tb->total_items = 0;
-	    }
-	}
-
-	/* Create Tool Bar Items */
-	for(i = 0; i < tb->total_items; i++)
-	{
-	    src_item_ptr = item[i];
-	    if(src_item_ptr == NULL)
+	    item = TOOLBAR_ITEM(glist->data);
+	    if(item == NULL)
 		continue;
 
-	    /* Create a copy of the item */
-	    tb->item[i] = item_ptr = ToolBarItemNew(
-		src_item_ptr->type,
-		src_item_ptr->text,
-		src_item_ptr->icon_data,
-		src_item_ptr->tooltip,
-		src_item_ptr->id,
-		src_item_ptr->func_cb,
-		src_item_ptr->client_data,
-		src_item_ptr->enter_cb,
-		src_item_ptr->enter_client_data,
-		src_item_ptr->leave_cb,
-		src_item_ptr->leave_client_data
+	    /* Copy this item and add it to the Toolbar's Items list */
+	    item = ToolBarItemNew(
+		item->type,
+		tb,			/* Use our Tool Bar */
+		item->text,
+		item->icon_data,
+		item->tooltip,
+		item->id,
+		item->func_cb,
+		item->func_data,
+		item->enter_cb,
+		item->enter_data,
+		item->leave_cb,
+		item->leave_data
+	    );
+	    if(item == NULL)
+		continue;
+
+	    tb->items_list = g_list_append(
+		tb->items_list,
+		item
 	    );
 
-	    /* Create widgets based on new item */
-	    if(item_ptr != NULL)
+	    /* Create this item's widgets based on its type */
+	    switch(item->type)
 	    {
-		GtkWidget *label_rtn, *menu_rtn;
+	      case TOOLBAR_ITEM_SEPARATOR:
+		item->w = w = gtk_vbox_new(TRUE, 0);
+		gtk_widget_set_usize(
+		    w,
+		    (orientation == GTK_ORIENTATION_VERTICAL) ? -1 : 5,
+		    (orientation == GTK_ORIENTATION_VERTICAL) ? 5 : -1
+		);
+		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
+		gtk_widget_show(w);
+		parent3 = w;
 
-		item_ptr->toolbar = tb;
+		if(orientation == GTK_ORIENTATION_VERTICAL)
+		    w = gtk_hseparator_new();
+		else
+		    w = gtk_vseparator_new();
+		gtk_box_pack_start(GTK_BOX(parent3), w, TRUE, TRUE, border_major);
+		gtk_widget_show(w);
+		break;
 
-		switch(item_ptr->type)
+	      case TOOLBAR_ITEM_BUTTON:
+		item->w = w = GUIButtonPixmapLabelV(
+		    (guint8 **)item->icon_data,
+		    item->text,
+		    &label_rtn
+		);
+		switch(relief)
 		{
-		  case TOOLBAR_ITEM_SEPARATOR:
-		    item_ptr->w = w = gtk_vbox_new(TRUE, 0);
-		    gtk_widget_set_usize(
-			w,
-			vertical ? -1 : 5,
-			vertical ? 5 : -1
-		    );
-		    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
-		    gtk_widget_show(w);
-		    parent3 = w;
-
-		    if(vertical)
-			w = gtk_hseparator_new();
-		    else
-			w = gtk_vseparator_new();
-		    gtk_box_pack_start(GTK_BOX(parent3), w, TRUE, TRUE, border_major);
-		    gtk_widget_show(w);
+		  case TOOLBAR_RELIEF_NONE:
+		    gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NONE);
 		    break;
-
-		  case TOOLBAR_ITEM_BUTTON:
-		    item_ptr->w = w = GUIButtonPixmapLabelV(
-			(guint8 **)item_ptr->icon_data,
-			item_ptr->text,
-			&label_rtn
-		    );
-		    switch(relief)
-		    {
-		      case TOOLBAR_RELIEF_NONE:
-			gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NONE);
-			break;
-		      case TOOLBAR_RELIEF_HALF:
-			gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_HALF);
-			break;
-		      case TOOLBAR_RELIEF_NORMAL:
-			gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NORMAL);
-			break;
-		    }
-		    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
-		    if(item_ptr->func_cb != NULL)
-			gtk_signal_connect(
-			    GTK_OBJECT(w), "clicked",
-			    GTK_SIGNAL_FUNC(ToolbarClickedCB),
-			    item_ptr
-			);
-		    if(item_ptr->enter_cb != NULL)
-			gtk_signal_connect(
-			    GTK_OBJECT(w), "enter_notify_event",
-			    GTK_SIGNAL_FUNC(ToolbarEnterNotifyCB),
-			    item_ptr
-			);
-		    if(item_ptr->leave_cb != NULL)
-			gtk_signal_connect(
-			    GTK_OBJECT(w), "leave_notify_event",
-			    GTK_SIGNAL_FUNC(ToolbarLeaveNotifyCB),
-			    item_ptr
-			);
-		    if(item_ptr->tooltip != NULL)
-			GUISetWidgetTip(w, item_ptr->tooltip);
-		    SET_BUTTON_LAYOUT(w, display)
-		    gtk_widget_show(w);
+		  case TOOLBAR_RELIEF_HALF:
+		    gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_HALF);
 		    break;
-
-		  case TOOLBAR_ITEM_TOGGLE_BUTTON:
-		    item_ptr->w = w = GUIToggleButtonPixmapLabelV(
-			(guint8 **)item_ptr->icon_data,
-			item_ptr->text,
-			&label_rtn
-		    );
-		    switch(relief)
-		    {
-		      case TOOLBAR_RELIEF_NONE:
-			gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NONE);
-			break;
-		      case TOOLBAR_RELIEF_HALF:
-			gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_HALF);
-			break;
-		      case TOOLBAR_RELIEF_NORMAL:
-			gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NORMAL);
-			break;
-		    }
-		    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
-		    if(item_ptr->func_cb != NULL)
-			gtk_signal_connect(
-			    GTK_OBJECT(w), "toggled",
-			    GTK_SIGNAL_FUNC(ToolbarClickedCB),
-			    item_ptr
-			);
-		    if(item_ptr->enter_cb != NULL)
-			gtk_signal_connect(
-			    GTK_OBJECT(w), "enter_notify_event",
-			    GTK_SIGNAL_FUNC(ToolbarEnterNotifyCB),
-			    item_ptr
-			);
-		    if(item_ptr->leave_cb != NULL)
-			gtk_signal_connect(
-			    GTK_OBJECT(w), "leave_notify_event",
-			    GTK_SIGNAL_FUNC(ToolbarLeaveNotifyCB),
-			    item_ptr
-			);
-		    if(item_ptr->tooltip != NULL)
-			GUISetWidgetTip(w, item_ptr->tooltip);
-		    SET_BUTTON_LAYOUT(w, display)
-		    gtk_widget_show(w);
+		  case TOOLBAR_RELIEF_NORMAL:
+		    gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NORMAL);
 		    break;
-
-		  case TOOLBAR_ITEM_MENU_BUTTON:
-		    item_ptr->w = MenuButtonNewV(
-			item_ptr->text,
-			(guint8 **)item_ptr->icon_data,
-			&menu_rtn
-		    );
-		    switch(relief)
-		    {
-		      case TOOLBAR_RELIEF_NONE:
-			gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NONE);
-			break;
-		      case TOOLBAR_RELIEF_HALF:
-			gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_HALF);
-			break;
-		      case TOOLBAR_RELIEF_NORMAL:
-			gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NORMAL);
-			break;
-		    }
-		    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
-		    if(item_ptr->func_cb != NULL)
-			gtk_signal_connect(
-			    GTK_OBJECT(w), "toggled",
-			    GTK_SIGNAL_FUNC(ToolbarClickedCB),
-			    item_ptr
-			);
-		    if(item_ptr->enter_cb != NULL)
-			gtk_signal_connect(
-			    GTK_OBJECT(w), "enter_notify_event",
-			    GTK_SIGNAL_FUNC(ToolbarEnterNotifyCB),
-			    item_ptr
-			);
-		    if(item_ptr->leave_cb != NULL)
-			gtk_signal_connect(
-			    GTK_OBJECT(w), "leave_notify_event",
-			    GTK_SIGNAL_FUNC(ToolbarLeaveNotifyCB),
-			    item_ptr
-			);
-		    if(item_ptr->tooltip != NULL)
-			GUISetWidgetTip(w, item_ptr->tooltip);
-		    SET_BUTTON_LAYOUT(w, display)
-		    gtk_widget_show(w);
 		}
+		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
+		if(item->func_cb != NULL)
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "clicked",
+			GTK_SIGNAL_FUNC(ToolbarClickedCB), item
+		    );
+		if(item->enter_cb != NULL)
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "enter_notify_event",
+			GTK_SIGNAL_FUNC(ToolbarEnterNotifyCB), item
+		    );
+		if(item->leave_cb != NULL)
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "leave_notify_event",
+			GTK_SIGNAL_FUNC(ToolbarLeaveNotifyCB), item
+		    );
+		if(item->tooltip != NULL)
+		    GUISetWidgetTip(w, item->tooltip);
+		SET_BUTTON_LAYOUT(w, display)
+		gtk_widget_show(w);
+		break;
+
+	      case TOOLBAR_ITEM_TOGGLE_BUTTON:
+		item->w = w = GUIToggleButtonPixmapLabelV(
+		    (guint8 **)item->icon_data,
+		    item->text,
+		    &label_rtn
+		);
+		switch(relief)
+		{
+		  case TOOLBAR_RELIEF_NONE:
+		    gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NONE);
+		    break;
+		  case TOOLBAR_RELIEF_HALF:
+		    gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_HALF);
+		    break;
+		  case TOOLBAR_RELIEF_NORMAL:
+		    gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NORMAL);
+		    break;
+		}
+		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
+		if(item->func_cb != NULL)
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "toggled",
+			GTK_SIGNAL_FUNC(ToolbarClickedCB), item
+		    );
+		if(item->enter_cb != NULL)
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "enter_notify_event",
+			GTK_SIGNAL_FUNC(ToolbarEnterNotifyCB), item
+		    );
+		if(item->leave_cb != NULL)
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "leave_notify_event",
+			GTK_SIGNAL_FUNC(ToolbarLeaveNotifyCB), item
+		    );
+		if(item->tooltip != NULL)
+		    GUISetWidgetTip(w, item->tooltip);
+		SET_BUTTON_LAYOUT(w, display)
+		gtk_widget_show(w);
+		break;
+
+	      case TOOLBAR_ITEM_MENU_BUTTON:
+		item->w = MenuButtonNewV(
+		    item->text,
+		    (guint8 **)item->icon_data,
+		    &menu_rtn
+		);
+		switch(relief)
+		{
+		  case TOOLBAR_RELIEF_NONE:
+		    gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NONE);
+		    break;
+		  case TOOLBAR_RELIEF_HALF:
+		    gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_HALF);
+		    break;
+		  case TOOLBAR_RELIEF_NORMAL:
+		    gtk_button_set_relief(GTK_BUTTON(w), GTK_RELIEF_NORMAL);
+		    break;
+		}
+		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
+		if(item->func_cb != NULL)
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "toggled",
+			GTK_SIGNAL_FUNC(ToolbarClickedCB), item
+		    );
+		if(item->enter_cb != NULL)
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "enter_notify_event",
+			GTK_SIGNAL_FUNC(ToolbarEnterNotifyCB), item
+		    );
+		if(item->leave_cb != NULL)
+		    gtk_signal_connect(
+			GTK_OBJECT(w), "leave_notify_event",
+			GTK_SIGNAL_FUNC(ToolbarLeaveNotifyCB), item
+		    );
+		if(item->tooltip != NULL)
+		    GUISetWidgetTip(w, item->tooltip);
+		SET_BUTTON_LAYOUT(w, display)
+		gtk_widget_show(w);
+		break;
 	    }
 	}
 
@@ -600,28 +544,31 @@ toolbar_struct *ToolBarNew(
  *	Sets the Tool Bar's display.
  */
 void ToolBarSetDisplay(
-	toolbar_struct *tb, toolbar_display display
+	toolbar_struct *tb, const toolbar_display display
 )
 {
-	gint i;
+	GList *glist;
 	GtkWidget *w;
-	toolbar_item_struct *item_ptr;
+	toolbar_item_struct *item;
 
 	if(tb == NULL)
 	    return;
 
-	/* Iterate through all Tool Bar Items */
-	for(i = 0; i < tb->total_items; i++)
+	/* Set the display on each item */
+	for(glist = tb->items_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    item_ptr = tb->item[i];
-	    if(item_ptr == NULL)
+	    item = TOOLBAR_ITEM(glist->data);
+	    if(item == NULL)
 		continue;
 
-	    w = item_ptr->w;
+	    w = item->w;
 	    if(w == NULL)
 		continue;
 
-	    switch(item_ptr->type)
+	    switch(item->type)
 	    {
 	      case TOOLBAR_ITEM_SEPARATOR:
 		break;
@@ -639,9 +586,7 @@ void ToolBarSetDisplay(
 
 #if 0
 	/* Remind tool bar that it needs to resize */
-	w = tb->toplevel;
-	if(w != NULL)
-	    gtk_widget_queue_resize(w);
+	gtk_widget_queue_resize(tb->toplevel);
 #endif
 }
 
@@ -649,28 +594,31 @@ void ToolBarSetDisplay(
  *	Sets the Tool Bar's relief.
  */
 void ToolBarSetRelief(
-	toolbar_struct *tb, toolbar_relief relief
+	toolbar_struct *tb, const toolbar_relief relief
 )
 {
-	gint i;
+	GList *glist;
 	GtkWidget *w;
-	toolbar_item_struct *item_ptr;
+	toolbar_item_struct *item;
 
 	if(tb == NULL)
 	    return;
 
-	/* Iterate through all Tool Bar Items */
-	for(i = 0; i < tb->total_items; i++)
+	/* Set the relief on each item */
+	for(glist = tb->items_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    item_ptr = tb->item[i];
-	    if(item_ptr == NULL)
+	    item = TOOLBAR_ITEM(glist->data);
+	    if(item == NULL)
 		continue;
 
-	    w = item_ptr->w;
+	    w = item->w;
 	    if(w == NULL)
 		continue;
 
-	    switch(item_ptr->type)
+	    switch(item->type)
 	    {
 	      case TOOLBAR_ITEM_SEPARATOR:
 		break;
@@ -730,9 +678,7 @@ void ToolBarSetRelief(
 
 #if 0
 	/* Remind tool bar that it needs to resize */
-	w = tb->toplevel;
-	if(w != NULL)
-	    gtk_widget_queue_resize(w);
+	gtk_widget_queue_resize(tb->toplevel);
 #endif
 }
 
@@ -742,26 +688,31 @@ void ToolBarSetRelief(
  *	text, icon, and tooltip.
  */
 void ToolBarItemUpdateByID(
-	toolbar_struct *tb, gint id,
+	toolbar_struct *tb, const gint id,
 	const gchar *text,
 	guint8 **icon_data,
 	const gchar *tooltip
 )
 {
-	gint i;
+	GList *glist;
 	toolbar_item_struct *item;
 
 	if(tb == NULL)
 	    return;
 
-	/* Iterate through all Tool Bar Items */
-	for(i = 0; i < tb->total_items; i++)
+	/* Update each item in the items list who's ID matches the
+	 * specified ID
+	 */
+	for(glist = tb->items_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    item = tb->item[i];
+	    item = TOOLBAR_ITEM(glist->data);
 	    if(item == NULL)
 		continue;
 
-	    /* Id of current item matches the given id? */
+	    /* This item's ID matches the specified ID? */
 	    if(item->id == id)
 	    {
 		GtkWidget *w = item->w;
@@ -805,7 +756,7 @@ void ToolBarItemUpdateByID(
 		    if(w != NULL)
 			GUIButtonPixmapUpdate(
 			    w, icon_data, text
-			);  
+			);
 		    break;
 		}
 
@@ -822,11 +773,10 @@ void ToolBarItemUpdateByID(
  */
 void ToolBarMap(toolbar_struct *tb)
 {
-	GtkWidget *w = (tb != NULL) ? tb->toplevel : NULL; 
-	if(w == NULL)    
+	if(tb == NULL)    
 	    return;
 
-	gtk_widget_show(w);
+	gtk_widget_show(tb->toplevel);
 }
 
 /*
@@ -834,11 +784,10 @@ void ToolBarMap(toolbar_struct *tb)
  */
 void ToolBarUnmap(toolbar_struct *tb)
 {
-	GtkWidget *w = (tb != NULL) ? tb->toplevel : NULL;
-	if(w == NULL)
+	if(tb == NULL)
 	    return;
 
-	gtk_widget_hide(w);
+	gtk_widget_hide(tb->toplevel);
 }
 
 /*
@@ -849,26 +798,38 @@ void ToolBarDelete(toolbar_struct *tb)
 	if(tb == NULL)
 	    return;
 
-	/* Delete all Tool Bar Items */
-	ToolBarItemListDeleteAll(
-	    &tb->item, &tb->total_items
-	);
+	tb->freeze_count++;
 
-	/* Destroy Tool Bar widgets */
-	GTK_WIDGET_DESTROY(tb->toplevel)
+	if(tb->items_list != NULL)
+	{
+	    g_list_foreach(tb->items_list, (GFunc)ToolBarItemDelete, NULL);
+	    g_list_free(tb->items_list);
+	}
+	gtk_widget_destroy(tb->toplevel);
+
+	tb->freeze_count--;
 
 	g_free(tb);
 }
 
 
 /*
- *	Gets the Tool Bar Item's toplevel GtkWidget specified by id.
+ *	Gets the item's GtkWidget by id.
  */
-GtkWidget *ToolBarItemGetWidgetID(toolbar_struct *tb, gint id)
+GtkWidget *ToolBarItemGetWidgetID(
+	toolbar_struct *tb, const gint id
+)
 {
-	toolbar_item_struct *item_ptr = (tb != NULL) ?
-	    ToolBarItemListMatchByID(tb->item, tb->total_items, id) : NULL;
-	return((item_ptr != NULL) ? item_ptr->w : NULL);
+	toolbar_item_struct *item;
+
+	if(tb == NULL)
+	    return(NULL);
+
+	item = ToolBarItemListMatchByID(tb->items_list, id);
+	if(item == NULL)
+	    return(NULL);
+
+	return(item->w);
 }
 
 
@@ -877,14 +838,15 @@ GtkWidget *ToolBarItemGetWidgetID(toolbar_struct *tb, gint id)
  *	insensitive.
  */
 void ToolBarItemSetSensitiveID(
-	toolbar_struct *tb, gint id, gboolean sensitive
+	toolbar_struct *tb, const gint id,
+	const gboolean sensitive
 )
 {
-	toolbar_item_struct *item_ptr = (tb != NULL) ?
-	    ToolBarItemListMatchByID(tb->item, tb->total_items, id) : NULL;
-	GTK_WIDGET_SET_SENSITIVE(
-	    (item_ptr != NULL) ? item_ptr->w : NULL, sensitive
-	)
+	GtkWidget *w = ToolBarItemGetWidgetID(tb, id);
+	if(w == NULL)
+	    return;
+
+	gtk_widget_set_sensitive(w, sensitive);
 }
 
 
@@ -896,17 +858,24 @@ void ToolBarItemSetSensitiveID(
  *	No signal will be emitted.
  */
 void ToolBarItemSetToggleID(
-	toolbar_struct *tb, gint id, gboolean toggled
+	toolbar_struct *tb, const gint id,
+	const gboolean toggled
 )
 {
-	toolbar_item_struct *item_ptr = (tb != NULL) ? 
-	    ToolBarItemListMatchByID(tb->item, tb->total_items, id) : NULL;
-	if(item_ptr == NULL)
+	toolbar_item_struct *item;
+
+	if(tb == NULL)
 	    return;
 
-	if(item_ptr->type == TOOLBAR_ITEM_TOGGLE_BUTTON)
+	item = ToolBarItemListMatchByID(tb->items_list, id);
+	if(item == NULL)
+	    return;
+
+	if((item->type == TOOLBAR_ITEM_TOGGLE_BUTTON) &&
+	   (item->w != NULL)
+	)
 	{
-	    GtkToggleButton *tb = (GtkToggleButton *)item_ptr->w;
+	    GtkToggleButton *tb = GTK_TOGGLE_BUTTON(item->w);
 	    if(tb != NULL)
 	    {
 		/* Check if toggle button state has changed by comparing
@@ -924,10 +893,9 @@ void ToolBarItemSetToggleID(
 		 */
 		if((gboolean)tb->active != (gboolean)toggled)
 		{
-		    void (*func_cb)(toolbar_item_struct *, gint, gpointer) = item_ptr->func_cb;
-		    item_ptr->func_cb = NULL;
+		    item->freeze_count++;
 		    gtk_toggle_button_set_active(tb, toggled);
-		    item_ptr->func_cb = func_cb;
+		    item->freeze_count--;
 		}
 	    }
 	}
@@ -936,92 +904,116 @@ void ToolBarItemSetToggleID(
 /*
  *	Gets the Tool Bar Item's toggle state.
  */
-gboolean ToolBarItemGetToggleID(toolbar_struct *tb, gint id)
+gboolean ToolBarItemGetToggleID(
+	toolbar_struct *tb, const gint id
+)
 {
-	toolbar_item_struct *item_ptr = (tb != NULL) ? 
-	    ToolBarItemListMatchByID(tb->item, tb->total_items, id) : NULL;
-	if(item_ptr == NULL)
+	toolbar_item_struct *item;
+
+	if(tb == NULL)
 	    return(FALSE);
 
-	if(item_ptr->type == TOOLBAR_ITEM_TOGGLE_BUTTON)
-	    return(GTK_TOGGLE_BUTTON_GET_ACTIVE(item_ptr->w));
-	else
+	item = ToolBarItemListMatchByID(tb->items_list, id);
+	if(item == NULL)
 	    return(FALSE);
+
+	if((item->type != TOOLBAR_ITEM_TOGGLE_BUTTON) ||
+	   (item->w == NULL)
+	)
+	    return(FALSE);
+
+	return(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(item->w)));
 }
 
 /*
  *	Sets the Tool Bar Item's menu.
  */
 void ToolBarItemSetMenuID(
-	toolbar_struct *tb, gint id, GtkWidget *menu   
+	toolbar_struct *tb, const gint id,
+	GtkWidget *menu
 )
 {
-	toolbar_item_struct *item_ptr = (tb != NULL) ?
-	    ToolBarItemListMatchByID(tb->item, tb->total_items, id) : NULL;
-	if(item_ptr == NULL)
+	toolbar_item_struct *item;
+
+	if(tb == NULL)
 	    return;
 
-	if(item_ptr->type == TOOLBAR_ITEM_MENU_BUTTON)
-	    MenuButtonSetMenu(item_ptr->w, GTK_MENU(menu));
+	item = ToolBarItemListMatchByID(tb->items_list, id);
+	if(item == NULL)
+	    return;
+
+	if((item->type != TOOLBAR_ITEM_MENU_BUTTON) ||
+	   (item->w == NULL)
+	)
+	    return;
+
+	MenuButtonSetMenu(item->w, GTK_MENU(menu));
 }
 
 /*
  *	Gets the Tool Bar Item's menu.
  */
-GtkWidget *ToolBarItemGetMenuID(toolbar_struct *tb, gint id)
+GtkWidget *ToolBarItemGetMenuID(
+	toolbar_struct *tb, const gint id
+)
 {
-	toolbar_item_struct *item_ptr = (tb != NULL) ?
-	    ToolBarItemListMatchByID(tb->item, tb->total_items, id) : NULL;
-	if(item_ptr == NULL)
+	toolbar_item_struct *item;
+
+	if(tb == NULL)
 	    return(NULL);
 
-	if(item_ptr->type == TOOLBAR_ITEM_MENU_BUTTON)
-	    return(MenuButtonGetMenu(item_ptr->w));
-	else
+	item = ToolBarItemListMatchByID(tb->items_list, id);
+	if(item == NULL)
 	    return(NULL);
+
+	if((item->type != TOOLBAR_ITEM_MENU_BUTTON) ||
+	   (item->w == NULL)
+	)
+	    return(NULL);
+
+	return(MenuButtonGetMenu(item->w));
 }
 
 
 /*
  *	Checks if the Tool Bar Item specified by id is mapped.
  */
-gboolean ToolBarItemIsMappedID(toolbar_struct *tb, gint id)
+gboolean ToolBarItemIsMappedID(
+	toolbar_struct *tb, const gint id
+)
 {
-	toolbar_item_struct *item_ptr = (tb != NULL) ?
-	    ToolBarItemListMatchByID(tb->item, tb->total_items, id) : NULL;
-	GtkWidget *w = (item_ptr != NULL) ? item_ptr->w : NULL;
-	return((w != NULL) ? GTK_WIDGET_MAPPED(w) : FALSE);
+	GtkWidget *w = ToolBarItemGetWidgetID(tb, id);
+	if(w == NULL)
+	    return(FALSE);
+
+	return(GTK_WIDGET_MAPPED(w));
 }
 
 
 /*
  *	Maps the Tool Bar Item specified by id.
  */
-void ToolBarItemMapID(toolbar_struct *tb, gint id)
+void ToolBarItemMapID(
+	toolbar_struct *tb, const gint id
+)
 {
-	GtkWidget *w;
-	toolbar_item_struct *item_ptr = (tb != NULL) ? 
-	    ToolBarItemListMatchByID(tb->item, tb->total_items, id) : NULL;
-	if(item_ptr == NULL)
+	GtkWidget *w = ToolBarItemGetWidgetID(tb, id);
+	if(w == NULL)
 	    return;
 
-	w = item_ptr->w;
-	if(w != NULL)
-	    gtk_widget_show(w);
+	gtk_widget_show(w);
 }
 
 /*
  *	Unmaps the Tool Bar Item specified by id.
  */
-void ToolBarItemUnmapID(toolbar_struct *tb, gint id)
+void ToolBarItemUnmapID(
+	toolbar_struct *tb, const gint id
+)
 {
-	GtkWidget *w;
-	toolbar_item_struct *item_ptr = (tb != NULL) ? 
-	    ToolBarItemListMatchByID(tb->item, tb->total_items, id) : NULL;
-	if(item_ptr == NULL)
+	GtkWidget *w = ToolBarItemGetWidgetID(tb, id);
+	if(w == NULL)
 	    return;
 
-	w = item_ptr->w;
-	if(w != NULL)
-	    gtk_widget_hide(w);
+	gtk_widget_hide(w);
 }
