@@ -12,7 +12,7 @@ CANCEL_BTN="Cancel"
 
 # Run the File Selector
 #
-PATHS_LIST=`./file_selector -t "$TITLE" --ok_btn "$OK_BTN" --cancel_btn "$CANCEL_BTN" --output_delim " " "$@"`
+PATHS_LIST=`./file-selector -t "$TITLE" --ok_btn "$OK_BTN" --cancel_btn "$CANCEL_BTN" --output_delim " " "$@"`
 RESPONSE="$?"
 
 # Print response response
