@@ -75,7 +75,9 @@ int main(int argc, char *argv[])
 	gint total_devices = 0;
 	edv_context_struct *ctx;
 
-#define DO_FREE_LOCALS	{		\
+#define CLEANUP_RETURN(_v_)	{	\
+					\
+ return(_v_);				\
 }
 
 	/* Set up signal callbacks */
@@ -104,17 +106,18 @@ int main(int argc, char *argv[])
 	    )
 	    {
 		g_print("%s", PROG_HELP_MESG);
-		DO_FREE_LOCALS
-		return(0);
+		CLEANUP_RETURN(0);
 	    }
 	    /* Version */
 	    else if(!g_strcasecmp(arg, "--version") ||
 		    !g_strcasecmp(arg, "-version")
 	    )
 	    {
-		g_print("%s %s\n%s", PROG_NAME, PROG_VERSION, PROG_COPYRIGHT);
-		DO_FREE_LOCALS
-		return(0);
+		g_print(
+		    "%s %s\n%s",
+		    PROG_NAME, PROG_VERSION, PROG_COPYRIGHT
+		);
+		CLEANUP_RETURN(0);
 	    }
 	    /* Skip these arguments so that gtk_window_apply_args()
 	     * handles them
@@ -143,8 +146,7 @@ int main(int argc, char *argv[])
 "-%c: Unsupported argument.\n",
 			    c  
 			);
-			DO_FREE_LOCALS
-			return(2);
+			CLEANUP_RETURN(2);
 		    }
 #endif
 		    v++;
@@ -162,8 +164,7 @@ int main(int argc, char *argv[])
 "%s: Unsupported argument.\n",
 		    arg
 		);
-		DO_FREE_LOCALS
-		return(2);
+		CLEANUP_RETURN(2);
 	    }
 	}
 
@@ -174,8 +175,7 @@ int main(int argc, char *argv[])
 	    if(!gtk_init_check(&argc, &argv))
 	    {
 		g_printerr("Unable to initialize GTK.\n");
-		DO_FREE_LOCALS
-		return(1);
+		CLEANUP_RETURN(1);
 	    }
 	    initialized_gtk = TRUE;
 
@@ -184,7 +184,14 @@ int main(int argc, char *argv[])
 	}
 
 	/* Initialize dialogs */
-	ConMsgInit(PROG_NAME, 0, 0, TRUE, TRUE);
+	ConMsgInit(
+	    PROG_NAME,
+	    NULL,
+	    0,
+	    0,
+	    TRUE,			/* Show stdout dialog */
+	    TRUE			/* Show stderr dialog */
+	);
 	CDialogInit();
 	PDialogInit();
 
@@ -337,8 +344,6 @@ program again.",
 	/* Reset the DND Icon */
 	GUIDNDSetDragIcon(NULL, NULL, 0, 0);
 
-	DO_FREE_LOCALS
-
-	return(0);
-#undef DO_FREE_LOCALS
+	CLEANUP_RETURN(0);
+#undef CLEANUP_RETURN
 }
