@@ -113,7 +113,7 @@ GList *ZipToolOPIDListNew(zip_tool_struct *zt)
 	gint (*enter_notify_cb)(GtkWidget *, GdkEventCrossing *, gpointer);
 	gint (*leave_notify_cb)(GtkWidget *, GdkEventCrossing *, gpointer);
 
-#define DO_APPEND(_id_)	{				\
+#define APPEND_OPID(_id_)	{				\
  zip_tool_opid_struct *opid_ptr = ZIP_TOOL_OPID(	\
   g_malloc0(sizeof(zip_tool_opid_struct))		\
  );							\
@@ -138,72 +138,72 @@ GList *ZipToolOPIDListNew(zip_tool_struct *zt)
 	name = "Close";
 	button_name = name;
 	tooltip = "Close this window";
-	DO_APPEND(ZIP_TOOL_OPID_CLOSE)
+	APPEND_OPID(ZIP_TOOL_OPID_CLOSE);
 
 	func_cb = ZipToolExitCB;
 	icon_data = (guint8 **)icon_exit_20x20_xpm;
 	name = "Exit";
 	button_name = name;
 	tooltip = "Close all windows belonging to this application";
-	DO_APPEND(ZIP_TOOL_OPID_EXIT)
+	APPEND_OPID(ZIP_TOOL_OPID_EXIT);
 
 	func_cb = ZipToolMountCB;
 	icon_data = (guint8 **)icon_mount_20x20_xpm;
 	name = "Mount";
 	button_name = name;
 	tooltip = "Mount the device";
-	DO_APPEND(ZIP_TOOL_OPID_MOUNT)
+	APPEND_OPID(ZIP_TOOL_OPID_MOUNT);
 
 	func_cb = ZipToolUnmountCB;
 	icon_data = (guint8 **)icon_unmount_20x20_xpm;
 	name = "Unmount";
 	button_name = name;
 	tooltip = "Unmount the device";
-	DO_APPEND(ZIP_TOOL_OPID_UNMOUNT)
+	APPEND_OPID(ZIP_TOOL_OPID_UNMOUNT);
 
 	func_cb = ZipToolSpinDownCB;
 	icon_data = (guint8 **)icon_power_20x20_xpm;
 	name = "Spin Down";
 	button_name = "SpinDn";
 	tooltip = "Spin down the device";
-	DO_APPEND(ZIP_TOOL_OPID_SPIN_DOWN)
+	APPEND_OPID(ZIP_TOOL_OPID_SPIN_DOWN);
 
 	func_cb = ZipToolEjectCB;
 	icon_data = (guint8 **)icon_eject_20x20_xpm;
 	name = "Eject";
 	button_name = name;
 	tooltip = "Eject the media from the device";
-	DO_APPEND(ZIP_TOOL_OPID_EJECT)
+	APPEND_OPID(ZIP_TOOL_OPID_EJECT);
 
 	func_cb = ZipToolPasswordCB;
 	icon_data = (guint8 **)icon_security_20x20_xpm;
 	name = "Password";
 	button_name = name;
 	tooltip = "Lock/unlock the media";
-	DO_APPEND(ZIP_TOOL_OPID_PASSWORD)
+	APPEND_OPID(ZIP_TOOL_OPID_PASSWORD);
 
 	func_cb = ZipToolBrowseCB;
 	icon_data = (guint8 **)icon_browse_20x20_xpm;
 	name = "Browse";
 	button_name = name;
 	tooltip = "Run the File Browser to browse the media";
-	DO_APPEND(ZIP_TOOL_OPID_BROWSE)
+	APPEND_OPID(ZIP_TOOL_OPID_BROWSE);
 
 	func_cb = ZipToolRefreshCB;
 	icon_data = (guint8 **)icon_reload_20x20_xpm;
 	name = "Refresh";
 	button_name = name;
 	tooltip = "Refresh device information";
-	DO_APPEND(ZIP_TOOL_OPID_REFRESH)
+	APPEND_OPID(ZIP_TOOL_OPID_REFRESH);
 
 	func_cb = ZipToolFSCKCB;
 	icon_data = (guint8 **)icon_fsck_20x20_xpm;
 	name = "File System Check";
 	button_name = "FSCK";
 	tooltip = "Run FSCK to check the media";
-	DO_APPEND(ZIP_TOOL_OPID_FSCK)
+	APPEND_OPID(ZIP_TOOL_OPID_FSCK);
 
-#undef DO_APPEND
+#undef APPEND_OPID
 
 	return(opid);
 }
@@ -247,22 +247,22 @@ void ZipToolSetDevice(zip_tool_struct *zt, edv_device_struct *dev)
 	{
 	    if(dev != NULL)
 	    {
-		gchar *buf;
+		gchar *msg;
 
 		if((dev->name != NULL) && (dev->device_path != NULL))
-		    buf = g_strdup_printf(
+		    msg = g_strdup_printf(
 			"%s: %s (%s)",
 			PROG_NAME, dev->name, dev->device_path
 		    );
 		else
-		    buf = g_strdup_printf(
+		    msg = g_strdup_printf(
 			"%s: %s",
 			PROG_NAME,
 			(dev->name != NULL) ? dev->name :
 			    dev->device_path
 		    );
-		gtk_window_set_title(GTK_WINDOW(w), buf);
-		g_free(buf);
+		gtk_window_set_title(GTK_WINDOW(w), msg);
+		g_free(msg);
 	    }
 	    else
 	    {
@@ -302,33 +302,39 @@ void ZipToolRefreshDevice(
 	/* Destroy existing display widgets */
 	PieChartDelete(zt->capacity_piechart);
 	zt->capacity_piechart = NULL;
-	GTK_WIDGET_DESTROY(zt->display_mount_path_btn)
+	GTK_WIDGET_DESTROY(zt->display_mount_path_btn);
 	zt->display_mount_path_btn = NULL;
- 	GTK_WIDGET_DESTROY(zt->display_mount_btn)
+ 	GTK_WIDGET_DESTROY(zt->display_mount_btn);
 	zt->display_mount_btn = NULL;
-	GTK_WIDGET_DESTROY(zt->display_lock_btn)
+	GTK_WIDGET_DESTROY(zt->display_lock_btn);
 	zt->display_lock_btn = NULL;
-	GTK_WIDGET_DESTROY(zt->display_child)
+	GTK_WIDGET_DESTROY(zt->display_child);
 	zt->display_child = NULL;
 
 
-	/* Begin creating display widgets */
+	/* Begin creating the display widgets */
 
-	/* Get display parent and begin recreating display widgets */
+	/* Get the display parent and begin recreating display widgets */
 	parent = zt->display_parent;
 	if(parent != NULL)
 	{
-	    gint prefix_label_width;
-	    gchar *buf, *buf2;
-	    pie_chart_struct *pc;
+	    struct stat stat_buf;
+	    gint prefix_label_width, stat_status, font_size;
+	    gulong adj_division = 10;
+	    const gchar *font_encoding;
+	    gchar	*msg, *msg2,
+			*font_name_h1_bold,
+			*font_name_h1,
+			*font_name_h2_bold,
+			*font_name_h2;
+	    GdkFont *font;
 	    GdkColor c, color_fg, color_bg;
 	    GdkPixmap *pixmap = NULL;
 	    GdkBitmap *mask = NULL;
 	    GtkAdjustment *adj;
 	    GtkRcStyle *rcstyle;
-	    gulong adj_division = 10;
-	    struct stat stat_buf;
-	    gint stat_status;
+	    GtkStyle *style = gtk_widget_get_style(parent);
+	    pie_chart_struct *pc;
 
 #define SET_FLAT_BUTTON_STYLE(_w_)      {               \
  if((_w_) != NULL) {                                    \
@@ -380,31 +386,64 @@ void ZipToolRefreshDevice(
   GUISetWidgetTip((_w_), opid_ptr->tooltip);            \
 } }
 
-	    /* Get stats of the mount path */
+	    /* Get the base font size */
+	    font = (style != NULL) ? style->font : NULL;
+	    font_size = GDK_FONT_GET_FONT_NAME_SIZE(font);
+	    if(font_size < 3)
+		font_size = 3;
+
+	    /* Format the font names */
+#if defined(PROG_LANGUAGE_POLISH)
+	    font_encoding = "iso8859-2";
+#else
+	    font_encoding = "iso8859-1";
+#endif
+
+	    font_name_h1_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+		font_size + 2,
+		font_encoding
+	    );
+	    font_name_h1 = g_strdup_printf(
+"-adobe-helvetica-medium-r-normal-*-%i-*-*-*-*-*-%s",
+		font_size + 2,
+		font_encoding
+	    );
+	    font_name_h2_bold = g_strdup_printf(
+"-adobe-helvetica-bold-r-normal-*-%i-*-*-*-*-*-%s",
+		font_size,
+		font_encoding
+	    );
+	    font_name_h2 = g_strdup_printf(
+"-adobe-helvetica-medium-r-normal-*-%i-*-*-*-*-*-%s",
+		font_size,
+		font_encoding
+	    );
+
+	    /* Get the mount path's statistics */
 	    stat_status = !STRISEMPTY(dev->mount_path) ?
-		stat(dev->mount_path, &stat_buf) : -1;
+		(gint)stat((const char *)dev->mount_path, &stat_buf) : -1;
 
-
-	    /* Hbox for multiple columns */
+	    /* GtkHBox for multiple columns */
 	    zt->display_child = w = gtk_hbox_new(TRUE, 0);
 	    gtk_container_border_width(GTK_CONTAINER(w), border_major);
 	    gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
 	    gtk_widget_show(w);
 	    parent = w;
 
-	    /* Left side column vbox */
+	    /* Left side column GtkVBox */
 	    w = gtk_vbox_new(FALSE, border_major);
 	    gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
 	    parent2 = w;
 
-	    /* Hbox for device icon and label */
+	    /* GtkHBox the for device icon and label */
 	    w = gtk_hbox_new(FALSE, border_major);
 	    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
 	    parent3 = w;
  
-	    /* Get pixmap and mask to display device icon */
+	    /* Get the icon to display the device */
 	    if(EDV_DEVICE_IS_MOUNTED(dev) &&
 	       (EDV_DEVICE_TOTAL_ICON_STATES > EDV_DEVICE_ICON_STATE_STANDARD)
 	    )
@@ -456,59 +495,57 @@ void ZipToolRefreshDevice(
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		gtk_widget_show(w);
 	    }
-	    /* Vbox for name and location labels */
+	    /* GtkVBox for the name and location labels */
 	    w = gtk_vbox_new(TRUE, 0);
 	    gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
 	    parent4 = w;
-	    /* Device Name Label */
+	    /* Device Name GtkLabel */
 	    rcstyle = gtk_rc_style_new();
-	    rcstyle->font_name = STRDUP( 
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
-	    );
+	    rcstyle->font_name = STRDUP(font_name_h1_bold);
 	    if(!STRISEMPTY(dev->name))
-		buf = STRDUP(dev->name);
+		msg = STRDUP(dev->name);
 	    else
-		buf = STRDUP("Untitled");
-	    w = gtk_label_new(buf);
-	    g_free(buf);
+		msg = STRDUP("Untitled");
+	    w = gtk_label_new(msg);
+	    g_free(msg);
 	    gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	    gtk_widget_modify_style(w, rcstyle);                     
 	    gtk_widget_show(w);
 	    GTK_RC_STYLE_UNREF(rcstyle)
 
-	    /* Device Path Label */
+	    /* Device Path GtkLabel */
 	    if(!STRISEMPTY(dev->device_path))
-		buf = EDVShortenPath(dev->device_path, 35);
+		msg = EDVShortenPath(dev->device_path, 35);
 	    else
-		buf = STRDUP("*path not set*");
-	    w = gtk_label_new(buf);
-	    g_free(buf);
+		msg = STRDUP("*path not set*");
+	    w = gtk_label_new(msg);
+	    g_free(msg);
 	    gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
 
-	    /* Mount Path Button */
+	    /* Mount Path GtkButton */
 	    if(!STRISEMPTY(dev->mount_path))
 	    {
-		/* Hbox */
+		/* GtkHBox */
 		w = gtk_hbox_new(TRUE, 0); 
 		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 		gtk_widget_show(w);
 		parent3 = w;
-		/* Button */
-		buf2 = EDVShortenPath(dev->mount_path, 35);
-		buf = g_strdup_printf(
+		/* GtkButton */
+		msg2 = EDVShortenPath(dev->mount_path, 35);
+		msg = g_strdup_printf(
 "Mount Path: %s",
-		    buf2
+		    msg2
 		);
 		zt->display_mount_path_btn = w = GUIButtonPixmapLabelH(
-		    (guint8 **)icon_browse_20x20_xpm, buf, NULL
+		    (guint8 **)icon_browse_20x20_xpm, msg, NULL
 		);
-		g_free(buf);
-		g_free(buf2);
+		g_free(msg);
+		g_free(msg2);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
-		SET_FLAT_BUTTON_STYLE(w)
-		SET_BUTTON_CB(w, ZIP_TOOL_OPID_BROWSE)
+		SET_FLAT_BUTTON_STYLE(w);
+		SET_BUTTON_CB(w, ZIP_TOOL_OPID_BROWSE);
 		gtk_widget_show(w);
 	    }
 
@@ -529,7 +566,7 @@ void ZipToolRefreshDevice(
 		ss_mb = STRDUP(
 		    EDVSizeStrDelim(dev->blocks_total / 1000)
 		);
-		buf = g_strdup_printf(
+		msg = g_strdup_printf(
 		    "%s: %s kb (%s mb)",
 #ifdef PROG_LANGUAGE_ENGLISH
 "Total Capacity"
@@ -551,7 +588,7 @@ void ZipToolRefreshDevice(
 		ss_mb = STRDUP(
 		    EDVSizeStrDelim(dev->blocks_free / 1000)
 		);
-		buf2 = g_strdup_printf(
+		msg2 = g_strdup_printf(
 		    "%s kb (%s mb)",
 		    ss_kb, ss_mb
 		);
@@ -560,7 +597,7 @@ void ZipToolRefreshDevice(
 
 		zt->capacity_piechart = pc = PieChartNew(
 		    110, 70, adj, &c,
-		    NULL, buf,
+		    NULL, msg,
 #ifdef PROG_LANGUAGE_ENGLISH
 "Free"
 #endif
@@ -570,16 +607,16 @@ void ZipToolRefreshDevice(
 #ifdef PROG_LANGUAGE_FRENCH
 "Libre"
 #endif
-		    ":", buf2
+		    ":", msg2
 		);
 		gtk_object_unref(GTK_OBJECT(adj));
-		g_free(buf);
-		g_free(buf2);
+		g_free(msg);
+		g_free(msg2);
 		w = pc->toplevel;
 		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 		gtk_widget_show(w);
 
-		GDK_COLOR_SET_COEFF(&c, 0.0f, 1.0f, 1.0f)
+		GDK_COLOR_SET_COEFF(&c, 0.0f, 1.0f, 1.0f);
 		adj = (GtkAdjustment *)gtk_adjustment_new(
 		    0.0f, 0.0f,
 		    (gfloat)(dev->blocks_available / adj_division),
@@ -591,7 +628,7 @@ void ZipToolRefreshDevice(
 		ss_mb = STRDUP(
 		    EDVSizeStrDelim(dev->blocks_available / 1000)
 		);
-		buf = g_strdup_printf(
+		msg = g_strdup_printf(
 		    "%s kb (%s mb)",
 		    ss_kb, ss_mb
 		);
@@ -608,12 +645,12 @@ void ZipToolRefreshDevice(
 #ifdef PROG_LANGUAGE_FRENCH
 "Libre & Disponible"
 #endif
-		    ":", buf
+		    ":", msg
 		);
 		gtk_object_unref(GTK_OBJECT(adj));
-		g_free(buf);
+		g_free(msg);
 
-		GDK_COLOR_SET_COEFF(&c, 1.0f, 0.0f, 1.0f)
+		GDK_COLOR_SET_COEFF(&c, 1.0f, 0.0f, 1.0f);
 		adj = (GtkAdjustment *)gtk_adjustment_new(
 		    0.0, 0.0,
 		    (gfloat)(
@@ -632,7 +669,7 @@ void ZipToolRefreshDevice(
 			(dev->blocks_total - dev->blocks_free) / 1000
 		    )
 		);
-		buf = g_strdup_printf(
+		msg = g_strdup_printf(
 		    "%s kb (%s mb)",
 		    ss_kb, ss_mb
 		);
@@ -649,13 +686,13 @@ void ZipToolRefreshDevice(
 #ifdef PROG_LANGUAGE_FRENCH
 "Utilis"
 #endif
-		    ":", buf
+		    ":", msg
 		);
 		gtk_object_unref(GTK_OBJECT(adj));
-		g_free(buf);
+		g_free(msg);
 	    }
 
-	    /* Right side column vbox */
+	    /* Right side column GtkVBox */
 	    w = gtk_vbox_new(FALSE, border_minor);
 	    gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
@@ -680,11 +717,11 @@ void ZipToolRefreshDevice(
 }
 
 	    /* Status Banner */
-	    GDK_COLOR_SET_COEFF(&color_fg, 1.0f, 1.0f, 1.0f)
-	    GDK_COLOR_SET_COEFF(&color_bg, 0.0f, 0.0f, 0.0f) 
+	    GDK_COLOR_SET_COEFF(&color_fg, 1.0f, 1.0f, 1.0f);
+	    GDK_COLOR_SET_COEFF(&color_bg, 0.0f, 0.0f, 0.0f) ;
 	    w = GUIBannerCreate(
 		"Status",
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1",
+		font_name_h1_bold,
 		color_fg, color_bg,
 		GTK_JUSTIFY_CENTER,
 		FALSE
@@ -692,24 +729,24 @@ void ZipToolRefreshDevice(
 	    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
 
-	    /* Hbox for mount or unmount button */
+	    /* GtkHBox for the mount or unmount button */
 	    w = gtk_hbox_new(FALSE, border_minor);
 	    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
 	    parent3 = w;
-	    /* Button */
+	    /* Mount/Unmount GtkButton */
 	    if(EDV_DEVICE_IS_MOUNTED(dev))
 	    {
-		buf = g_strdup_printf(
+		msg = g_strdup_printf(
 		    "Mounted (%s)",
 		    EDV_DEVICE_IS_READ_ONLY(dev) ? "Read Only" : "Read/Write"
 		);
 		zt->display_mount_btn = w = GUIButtonPixmapLabelH(
 		    (guint8 **)icon_mounted_20x20_xpm,
-		    buf,
+		    msg,
 		    NULL
 		);
-		g_free(buf);
+		g_free(msg);
 		gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 		SET_FLAT_BUTTON_STYLE(w)
 		SET_BUTTON_CB(w, ZIP_TOOL_OPID_UNMOUNT)
@@ -728,7 +765,7 @@ void ZipToolRefreshDevice(
 		gtk_widget_show(w);
 	    }
 
-	    /* Hbox for locked/unlocked button */
+	    /* GtkHBox for the locked/unlocked button */
 	    w = gtk_hbox_new(FALSE, border_minor);
 	    gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
@@ -763,7 +800,7 @@ void ZipToolRefreshDevice(
 		GDK_COLOR_SET_COEFF(&color_bg, 0.0f, 0.0f, 0.0f);
 		w = GUIBannerCreate(
 		    "Ownership",
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1",
+		    font_name_h1_bold,
 		    color_fg, color_bg,
 		    GTK_JUSTIFY_CENTER,
 		    FALSE
@@ -771,58 +808,41 @@ void ZipToolRefreshDevice(
 		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
 		gtk_widget_show(w);
 
-		/* Owner Label */
+		/* Owner GtkLabel */
 		if(stat_status)
-		    buf = STRDUP("");
+		    msg = STRDUP("");
 		else
-		    buf = EDVUIDGetNameFromUID(
+		    msg = EDVUIDGetNameFromUID(
 			zt->ctx,
 			(gint)stat_buf.st_uid
 		    );
-		ADD_LABEL("Owner:", buf);
-		g_free(buf);
+		ADD_LABEL("Owner:", msg);
+		g_free(msg);
 
-		/* Group Label */
+		/* Group GtkLabel */
 		if(stat_status)
-		    buf = STRDUP("");
+		    msg = STRDUP("");
 		else
-		    buf = EDVGIDGetNameFromGID(
+		    msg = EDVGIDGetNameFromGID(
 			zt->ctx,
 			(gint)stat_buf.st_gid
 		    );
-		ADD_LABEL("Group:", buf);
-		g_free(buf);
+		ADD_LABEL("Group:", msg);
+		g_free(msg);
 
 		/* Permissions Label */
 		if(stat_status)
 		{
-		    buf = STRDUP("");
+		    msg = STRDUP("");
 		}
 		else
 		{
-		    const mode_t m = stat_buf.st_mode;
-#if defined(S_IRUSR) && defined(S_IWUSR) && defined(S_IXUSR) && defined(S_IRGRP) && defined(S_IWGRP) && defined(S_IXGRP) && defined(S_IROTH) && defined(S_IWOTH) && defined(S_IXOTH) && defined(S_ISUID) && defined(S_ISGID) && defined(S_ISVTX)
-		    buf = g_strdup_printf(
-			"%c%c%c%c%c%c%c%c%c",
-			(m & S_IRUSR) ? 'r' : '-',
-			(m & S_IWUSR) ? 'w' : '-',
-			(m & S_ISUID) ? 'S' :
-			    ((m & S_IXUSR) ? 'x' : '-'),
-			(m & S_IRGRP) ? 'r' : '-',
-			(m & S_IWGRP) ? 'w' : '-',
-			(m & S_ISGID) ? 'S' :
-			    ((m & S_IXGRP) ? 'x' : '-'),
-			(m & S_IROTH) ? 'r' : '-',
-			(m & S_IWOTH) ? 'w' : '-',
-			(m & S_ISVTX) ? 'S' :
-			    ((m & S_IXOTH) ? 'x' : '-')
+		    msg = EDVGetPermissionsString(
+			EDVStatModeToEDVPermissions(stat_buf.st_mode)
 		    );
-#else
-		    buf = STRDUP("");
-#endif
 		}
-		ADD_LABEL("Permissions:", buf)
-		g_free(buf);
+		ADD_LABEL("Permissions:", msg)
+		g_free(msg);
 	    }
 
 	    /* Details widgets (only if mounted) */
@@ -831,11 +851,11 @@ void ZipToolRefreshDevice(
 		prefix_label_width = 90;
 
 		/* Details Banner */
-		GDK_COLOR_SET_COEFF(&color_fg, 1.0f, 1.0f, 1.0f)
-		GDK_COLOR_SET_COEFF(&color_bg, 0.0f, 0.0f, 0.0f)
+		GDK_COLOR_SET_COEFF(&color_fg, 1.0f, 1.0f, 1.0f);
+		GDK_COLOR_SET_COEFF(&color_bg, 0.0f, 0.0f, 0.0f);
 		w = GUIBannerCreate(
 		    "Details",
-"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1",
+		    font_name_h1_bold,
 		    color_fg, color_bg,
 		    GTK_JUSTIFY_CENTER,
 		    FALSE
@@ -845,34 +865,39 @@ void ZipToolRefreshDevice(
 
 		/* Device Label */
 		if(stat_status)
-		    buf = STRDUP("");
+		    msg = STRDUP("");
 		else  
-		    buf = g_strdup_printf(
+		    msg = g_strdup_printf(
 			"%ld",
 			(gulong)stat_buf.st_dev
 		    );
-		ADD_LABEL("Device:", buf)
-		g_free(buf);
+		ADD_LABEL("Device:", msg)
+		g_free(msg);
 
-		/* Filesystem Label */
-		buf = STRDUP(
+		/* Filesystem GtkLabel */
+		msg = STRDUP(
 		    EDVDeviceGetFSNameFromType(dev->fs_type)
 		);
-		ADD_LABEL("Filesystem:", buf)   
-		g_free(buf);
+		ADD_LABEL("Filesystem:", msg)   
+		g_free(msg);
 
-		/* IO Block Size Label */
+		/* IO Block Size GtkLabel */
 		if(stat_status)
-		    buf = STRDUP("");
+		    msg = STRDUP("");
 		else
-		    buf = g_strdup_printf(
-			"%ld bytes",
-			stat_buf.st_blksize
+		    msg = g_strdup_printf(
+			"%ld %s",
+			(gulong)stat_buf.st_blksize,
+			(stat_buf.st_blksize == 1l) ? "byte" : "bytes"
 		    );
-		ADD_LABEL("IO Block Size:", buf)
-		g_free(buf);      
+		ADD_LABEL("IO Block Size:", msg)
+		g_free(msg);      
 	    }
 
+	    g_free(font_name_h1_bold);
+	    g_free(font_name_h1);
+	    g_free(font_name_h2_bold);
+	    g_free(font_name_h2);
 
 #undef SET_BUTTON_CB
 #undef SET_FLAT_BUTTON_STYLE
@@ -929,8 +954,8 @@ zip_tool_struct *ZipToolNew(edv_context_struct *ctx)
 	{
 	    gdk_window_set_decorations(
 		window,
-                GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
-                GDK_DECOR_MINIMIZE
+		GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
+		GDK_DECOR_MINIMIZE
 	    );
 	    gdk_window_set_functions(
 		window,
@@ -959,7 +984,7 @@ zip_tool_struct *ZipToolNew(edv_context_struct *ctx)
 
 	/* Create the Tool Bar Items list */
 	tb_items_list = NULL;
-#define DO_APPEND_BUTTON(_id_)	{			\
+#define APPEND_BUTTON(_id_)	{			\
  zip_tool_opid_struct *opid = ZipToolOPIDListFind(	\
   zt->opid, (_id_)					\
  );							\
@@ -975,7 +1000,7 @@ zip_tool_struct *ZipToolNew(edv_context_struct *ctx)
   );							\
   tb_items_list = g_list_append(tb_items_list, tb_item);\
 } }
-#define DO_APPEND_SEPARATOR	{			\
+#define APPEND_SEPARATOR	{			\
  tb_item = ToolBarItemNew(				\
   TOOLBAR_ITEM_SEPARATOR,				\
   NULL,							\
@@ -986,21 +1011,21 @@ zip_tool_struct *ZipToolNew(edv_context_struct *ctx)
  );							\
  tb_items_list = g_list_append(tb_items_list, tb_item);	\
 }
-	DO_APPEND_BUTTON(ZIP_TOOL_OPID_MOUNT);
-	DO_APPEND_BUTTON(ZIP_TOOL_OPID_UNMOUNT);
-	DO_APPEND_SEPARATOR
-	DO_APPEND_BUTTON(ZIP_TOOL_OPID_SPIN_DOWN);
-	DO_APPEND_BUTTON(ZIP_TOOL_OPID_EJECT);
-	DO_APPEND_BUTTON(ZIP_TOOL_OPID_PASSWORD);
-	DO_APPEND_SEPARATOR
-	DO_APPEND_BUTTON(ZIP_TOOL_OPID_FSCK);
-	DO_APPEND_SEPARATOR
-	DO_APPEND_BUTTON(ZIP_TOOL_OPID_REFRESH);
-	DO_APPEND_SEPARATOR
-	DO_APPEND_BUTTON(ZIP_TOOL_OPID_CLOSE);
+	APPEND_BUTTON(ZIP_TOOL_OPID_MOUNT);
+	APPEND_BUTTON(ZIP_TOOL_OPID_UNMOUNT);
+	APPEND_SEPARATOR
+	APPEND_BUTTON(ZIP_TOOL_OPID_SPIN_DOWN);
+	APPEND_BUTTON(ZIP_TOOL_OPID_EJECT);
+	APPEND_BUTTON(ZIP_TOOL_OPID_PASSWORD);
+	APPEND_SEPARATOR
+	APPEND_BUTTON(ZIP_TOOL_OPID_FSCK);
+	APPEND_SEPARATOR
+	APPEND_BUTTON(ZIP_TOOL_OPID_REFRESH);
+	APPEND_SEPARATOR
+	APPEND_BUTTON(ZIP_TOOL_OPID_CLOSE);
 
-#undef DO_APPEND_BUTTON
-#undef DO_APPEND_SEPARATOR
+#undef APPEND_BUTTON
+#undef APPEND_SEPARATOR
 
 	/* Create the Tool Bar */
 	zt->tool_bar_handle = w = gtk_handle_box_new();
