@@ -11,7 +11,7 @@
 #include "../cdialog.h"
 #include "../pdialog.h"
 
-#include "../edvtypes.h"
+#include "../edv_types.h"
 #include "../lib/endeavour2.h"
 
 #include "ziptoolio.h"
